/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(ob){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function mb(nb){var r=nb.a;var s=r.buffer;r.grow=kb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=nb.abort;var M=NaN;var N=Infinity;var O=nb.b;var P=nb.c;var Q=nb.d;var R=nb.e;var S=nb.f;var T=nb.g;var U=nb.h;var V=nb.i;var W=nb.j;var X=nb.k;var Y=nb.l;var Z=nb.m;var _=nb.n;var $=nb.o;var aa=nb.p;var ba=nb.q;var ca=nb.r;var da=nb.s;var ea=nb.t;var fa=nb.u;var ga=nb.v;var ha=nb.w;var ia=nb.x;var ja=nb.y;var ka=nb.z;var la=nb.A;var ma=nb.B;var na=nb.C;var oa=nb.D;var pa=nb.E;var qa=nb.F;var ra=nb.G;var sa=nb.H;var ta=nb.I;var ua=nb.J;var va=nb.K;var wa=nb.L;var xa=nb.M;var ya=nb.N;var za=nb.O;var Aa=nb.P;var Ba=nb.Q;var Ca=nb.R;var Da=nb.S;var Ea=nb.T;var Fa=nb.U;var Ga=nb.V;var Ha=nb.W;var Ia=nb.X;var Ja=nb.Y;var Ka=nb.Z;var La=nb._;var Ma=nb.$;var Na=nb.aa;var Oa=nb.ba;var Pa=nb.ca;var Qa=nb.da;var Ra=nb.ea;var Sa=nb.fa;var Ta=nb.ga;var Ua=nb.ha;var Va=nb.ia;var Wa=nb.ja;var Xa=nb.ka;var Ya=nb.la;var Za=nb.ma;var _a=nb.na;var $a=nb.oa;var ab=5708336;var bb=0;var cb=0;var db=0;
// EMSCRIPTEN_START_FUNCS
function Sr(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,V=0,W=C(0),X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=C(0),Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=C(0),Xa=0;$=ab-48|0;ab=$;fa=$+40|0;v[fa>>2]=49728;v[fa>>2]=49628;d=jI($+32|0);f=jI($+24|0);k=v[d+4>>2];v[$+16>>2]=v[d>>2];v[$+20>>2]=k;d=v[f+4>>2];v[$+8>>2]=v[f>>2];v[$+12>>2]=d;ha=b;pa=c;b=0;T=ab-112|0;ab=T;e=a;qa=e+24604|0;a=qa;a:{if(!v[a+16>>2]){break a}c=v[a+20>>2];if(c>>>0>4|!(1<<c&22)){break a}a=v[a+28>>2];if(a>>>0>4){break a}b=23>>>a&1}if(!b){c=T+96|0;rL(c,9104,12976,220,45);a=ab+-64|0;ab=a;v[a+56>>2]=0;d=us(a+56|0);b=Mb(a+24|0,17697);v[22452]=0;U(5,a+8|0,1,17360);f=v[22452];v[22452]=0;b:{c:{d:{e:{if((f|0)!=1){v[22452]=0;U(2,a+40|0,b|0,a+8|0);f=v[22452];v[22452]=0;if((f|0)==1){break e}v[22452]=0;ga(819,d|0,c|0,1,13578,a+40|0);c=v[22452];v[22452]=0;if((c|0)!=1){break b}c=P()|0;O()|0;pb(a+40|0);break d}c=P()|0;O()|0;break c}c=P()|0;O()|0}pb(a+8|0)}pb(b);S(c|0);L()}pb(a+40|0);pb(a+8|0);pb(b);ab=a- -64|0}ra=$+16|0;sa=$+8|0;ta=e+8204|0;ua=e+397452|0;va=e+397448|0;ca=e+393352|0;J=e+397456|0;aa=e+12|0;wa=e+1298300|0;Ga=e+1074376|0;Ha=e+1298420|0;Ia=e+1074365|0;while(1){f:{g:{b=v[e+480208>>2];if(!(!ha|b&512)){h:{if(v[e+1074380>>2]){break h}a=b|512;i:{if(b&256){break i}k=0;n=ab-48|0;ab=n;H=ab-32|0;ab=H;j=e+1074312|0;c=e+1074992|0;l=e+1298264|0;m=e+1074424|0;g=e+484344|0;f=e+484360|0;h=e+1074448|0;q=e+1074376|0;a=v[e+1074392>>2];p=e+480210|0;s=e+484376|0;j:{k:{l:while(1){m:{a=a+1|0;v[e+1074392>>2]=a;if(Nk(q)>>>0>a>>>0){break m}HM(H+24|0,e,q,(v[e+480208>>2]&524288)>>>19|0);n:{o:{p:{q:{r:{if(w[e+480208|0]&32){a=x[e+1074446>>1];break r}a=65535;b=Kb(f);b=wc(v[b>>2],v[b+4>>2]);d=x[h>>1];if(b>>>0>d>>>0){a=x[Yb(v[Kb(f)>>2],d)>>1]}u[e+1074446>>1]=a;s:{t:{b=a&65535;if(lf(g)>>>0<=b>>>0){break t}if(Gh(Rb(g,b))){break t}b=0;break s}b=1}while(1){u:{v:{if(!b){a=65534;u[e+1074446>>1]=65534;break v}w:{x:{y:{b=a&65535;if(lf(g)>>>0<=b>>>0){z:{if((b|0)!=65535){a=Kb(f);if(wc(v[a>>2],v[a+4>>2])>>>0>(d&65535)>>>0){break z}}a=x[Kb(f)+28>>1];if(a){break x}b=d&65535;a=Kb(f);if(!b|wc(v[a>>2],v[a+4>>2])>>>0<b>>>0){break y}while(1){a=b;b=a-1|0;if(!b){break y}if(x[Yb(v[Kb(f)>>2],b)>>1]!=65535){continue}break}break x}d=d+1|0;u[h>>1]=d;break w}u[e+1074450>>1]=d;break r}a=0}u[e+1074448>>1]=a;v[e+480208>>2]=v[e+480208>>2]&-524289;while(1){A:{b=Kb(f);d=wc(v[b>>2],v[b+4>>2]);b=a&65535;if(d>>>0<=b>>>0){break A}if(x[Yb(v[Kb(f)>>2],b)>>1]!=65534){break A}a=a+1|0;u[h>>1]=a;continue}break}a=Kb(f);if(wc(v[a>>2],v[a+4>>2])>>>0<=b>>>0){break q}if(!aq(Kb(f),b)){break q}d=x[h>>1]}a=65535;b=Kb(f);E=wc(v[b>>2],v[b+4>>2]);b=d&65535;if(E>>>0>b>>>0){a=x[Yb(v[Kb(f)>>2],b)>>1]}u[e+1074446>>1]=a;b=a&65535;if(lf(g)>>>0<=b>>>0){break v}if(!Gh(Rb(g,b))){break u}}b=1;continue}b=0;continue}}b=a&65535;if(!he(g,b)){break k}a=v[m>>2];if(a>>>0>=y[Rb(g,b)+12>>2]){v[m>>2]=0;a=0}if(v[e+480208>>2]&32?v[e+480272>>2]!=-1:0){break n}if(!Ms(l,x[h>>1],a,lp(H+16|0,c),w[H+24|0])){break n}a=v[e+480272>>2];if(a){if((a|0)>0){v[e+480272>>2]=a-1}An(l,1);Ms(l,x[h>>1],v[m>>2],lp(H+16|0,c),w[H+24|0]);break n}if(!(w[p|0]&64)){break q}a=0;if(aN(l,h,m,1)){break o}v[e+1074448>>2]=0;v[e+1074424>>2]=0;v[e+1074428>>2]=0;d=dj(f)-1|0;b=w[s|0];if((d|0)>(b|0)){break p}si(f,0)}An(l,1);break k}si(f,b+1&255);An(l,1)}while(1){if((a|0)==256){fL(e);v[e+1074416>>2]=v[e+480196>>2];v[e+1074420>>2]=v[e+480204>>2];v[e+1074456>>2]=v[e+480200>>2];a=x[e+1074448>>1];u[e+1074450>>1]=a;b=v[e+1074424>>2];v[e+1074428>>2]=b;d=Kb(f);if(wc(v[d>>2],v[d+4>>2])>>>0>a>>>0){Ua=e,Va=x[Yb(v[Kb(f)>>2],a)>>1],u[Ua+1074446>>1]=Va}Ms(l,a,b,lp(H+16|0,c),w[H+24|0]);if(!he(g,x[e+1074446>>1])){break k}}else{Dn((B(a,872)+e|0)+1074992|0,e,a&65535,134217728);a=a+1|0;continue}break}}GM(e,q,(v[e+480208>>2]&32)>>>5|0);b=Qc(Rb(g,x[e+1074446>>1]),v[e+1074424>>2],0);i=(B(x[e+480188>>1],872)+e|0)+1074992|0;a=c;while(1){if((a|0)==(i|0)){d=e+1074412|0;B:{C:{a=e+484344|0;b=x[e+1074446>>1];if(lm(a,b)){i=Rb(a,b);if(DM(v[i+16>>2],v[i+20>>2])){break C}}v[e+1074408>>2]=v[e+480216>>2];a=e+480220|0;break B}Ua=e+1074408|0,Va=v[Rb(a,b)+16>>2],v[Ua>>2]=Va;a=Rb(a,b)+20|0}v[d>>2]=v[a>>2];if(!w[H+24|0]){break m}a=v[e+1074416>>2];v[e+1074392>>2]=a;continue l}rb(H+16|0,j,82);D:{if(!sb(v[v[H+16>>2]>>2],v[H+20>>2])|w[a+805|0]!=1){break D}d=w[b+3|0];if((d|0)!=2&(d|0)!=3){break D}Ua=a,Va=Kg(e,w[a+800|0],u[a+772>>1],v[a+704>>2]),v[Ua+700>>2]=Va}rb(H+16|0,j,91);E:{if(!sb(v[v[H+16>>2]>>2],v[H+20>>2])){break E}if(Kc(w[b|0])){break E}d=w[a+788|0];if(!Kc(d)|w[a+791|0]!=19){break E}o=w[a+793|0];if((o&240)!=208|y[e+1074416>>2]>(o&15)>>>0){break E}Ua=a,Va=Kg(e,d,u[a+772>>1],0),v[Ua+700>>2]=Va}rb(H+16|0,j,92);F:{if(!sb(v[v[H+16>>2]>>2],v[H+20>>2])){break F}rb(H+8|0,j,5);if(sb(v[v[H+8>>2]>>2],v[H+12>>2])|v[e+1074416>>2]!=1|w[a+791|0]!=17){break F}v[e+1074420>>2]=B(w[a+793|0],1e4)}d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+788|0]=d;t[a+789|0]=d>>>8;t[a+790|0]=d>>>16;t[a+791|0]=d>>>24;d=w[b+4|0]|w[b+5|0]<<8;t[a+792|0]=d;t[a+793|0]=d>>>8;d=v[a+676>>2];v[a+20>>2]=v[a+672>>2];v[a+24>>2]=d;v[a+88>>2]=v[a+88>>2]&-393217;rb(H+16|0,j,21);if(!sb(v[v[H+16>>2]>>2],v[H+20>>2])){t[a+831|0]=0}v[a+860>>2]=0;t[a+805|0]=0;b=b+6|0;a=a+872|0;continue}}break}d=v[e+1074416>>2];if(!d){v[e+1074416>>2]=1;d=1}a=v[e+480208>>2];c=v[e+1074392>>2];G:{H:{if(c){b=a&-4097;v[e+480208>>2]=b;f=v[e+480180>>2];if(f&1048580|(a&2097152?0:(f|0)==1)){break G}if(Nk(q)>>>0<=c>>>0){break G}if(!((c>>>0)%(v[e+1074400>>2]+d>>>0)|0)){break H}break G}b=a&-528385}v[e+480208>>2]=b|4096}h=0;i=ab-16|0;ab=i;u[e+1074444>>1]=65535;a=e+1074436|0;v[a>>2]=-1;v[a+4>>2]=-1;K=e+480180|0;ba=e+1075809|0;F=e+1298300|0;r=e+1074312|0;G=e+480208|0;I=e+1074376|0;Z=e+480188|0;_=e+480190|0;M=e+480192|0;while(1){I:{if(x[Z>>1]<=h>>>0){J:{if(!(w[G+1|0]&16)){break J}if(!vM(e,I,Kb(e+484360|0),1)){break J}v[G>>2]=v[G>>2]|524288}ab=i+16|0;break I}o=B(h,872)+e|0;j=o+1075785|0;d=w[j|0];m=o+1075783|0;N=w[m|0];p=o+1075784|0;A=w[p|0];V=o+1075782|0;l=w[V|0];X=o+1075781|0;b=w[X|0];a=v[e+1074392>>2];c=v[e+1074400>>2];f=v[e+1074416>>2];R=o+1075780|0;g=Js(R);q=o+1075843|0;t[q|0]=v[e+480208>>2]>>>12&1|w[q|0]&254;f=(a>>>0)%(c+f>>>0)|0;a=w[R|0];K:{L:{M:{if((a|0)==252){s=Lj(l,A);E=Lj(N,d);a=252;if((b-1&255)>>>0>249){break M}c=v[(B(b,160)+e|0)+906140>>2];if(!c){break M}eb[v[v[c>>2]+44>>2]](c,s,C(C(E>>>0)/C(999)));a=w[R|0]}if((a&255)==251){break L}}if(z[o+1075852>>2]==C(0)|N){break K}}s=v[G>>2]&4096;N:{if(!s){c=w[o+1075862|0];break N}c=w[X|0];t[o+1075862|0]=c}if((c-1&255)>>>0>249){break K}E=(B(c&255,160)+e|0)+906140|0;c=v[E>>2];if(!c){break K}O:{if(!s){a=x[o+1075860>>1];break O}a=ry(w[V|0],w[p|0]);u[o+1075860>>1]=a;W=C(C(ry(w[m|0],w[j|0])>>>0)/C(999));z[o+1075856>>2]=W;Ua=o+1075852|0,Wa=C(C(W-C(eb[v[v[c>>2]+48>>2]](c,a)))/C(Nk(I)>>>0)),z[Ua>>2]=Wa;c=v[E>>2]}j=a;a=(v[e+1074392>>2]+1|0)==(Nk(I)|0);eb[v[v[c>>2]+(a?44:104)>>2]](c,j,z[(a?o+1075856|0:o+1075852|0)>>2]);a=w[R|0]}j=o+1074992|0;if(mM(a&255)){a=ab-16|0;ab=a;u[a+12>>1]=0;v[a+8>>2]=0;Fh(a+8|0);b=x[a+12>>1];t[j+792|0]=b;t[j+793|0]=b>>>8;b=v[a+8>>2];t[j+788|0]=b;t[j+789|0]=b>>>8;t[j+790|0]=b>>>16;t[j+791|0]=b>>>24;ab=a+16|0;g=0;N=0;A=0;l=0;d=0;b=0}P:{if(!(w[G+1|0]&16)){PL(e,j);break P}if(!b){break P}v[o+1075752>>2]=0}Q:{R:{if((N|0)==33){rb(i+8|0,r,30);a=d>>>4|0;gy(e,h&65535,a+(d&15)|0,sb(v[v[i+8>>2]>>2],v[i+12>>2]));break R}a=0;if((N-19&255)>>>0>1){break R}S:{if(!(!(v[K>>2]&16777250)|d)){d=w[o+1075825|0];break S}t[o+1075825|0]=d}c=d&240;if((c|0)==208){c=d&15;if(!c){c=v[K>>2];if(c&16777248){a=1;break R}if((c|0)!=2){break R}break Q}if(c>>>0>=v[e+1074400>>2]+v[e+1074416>>2]>>>0){rb(i+8|0,r,14);a=c;if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])){break R}if(!b){break Q}t[o+1075795|0]=b;break Q}a=c;break R}if(!(w[G+1|0]&16)|(c|0)!=224){break R}c=v[K>>2];if(v[e+1074396>>2]?c&16777250:0){break R}p=c&2;c=d&15;if(c?0:p){break R}v[e+1074396>>2]=c+1}c=v[K>>2]==16&(N|0)==19&(d&240)==208;E=c?0:a;T:{if(!E|w[R|0]!=255|w[V|0]!=2){break T}rb(i+8|0,r,74);if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])){break T}t[V|0]=0}Y=d&15;a=v[e+1074392>>2];rb(i+8|0,r,72);U:{if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){p=0;if(E>>>0>=y[e+1074416>>2]){break U}}rb(i+8|0,r,88);p=(f|0)==(E|0)|(a|0)==(E|0);if(!(!sb(v[v[i+8>>2]>>2],v[i+12>>2])|!E)){break U}p=(a|0)==(E|0)}rb(i+8|0,r,44);c=c?Y|144:d;V:{if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])){a=w[q|0];break V}a=w[q|0]&-2|(f|0)==(E|0)}t[q|0]=a&253|(p?2:0);rb(i+8|0,r,66);g=(!E|sb(v[v[i+8>>2]>>2],v[i+12>>2])^1)&g;W:{X:{if(!(v[e+1074392>>2]|(!(w[G+2|0]&32)|!b))){v[o+1075652>>2]=0;if(p){break X}a=o+1075e3|0;if(!gi(v[a>>2],v[a+4>>2])){break W}t[o+1075795|0]=b;if(x[_>>1]<b>>>0){break W}a=B(b,104)+e|0;v[o+1075680>>2]=x[a+484410>>1];u[o+1075764>>1]=t[a+484417|0];break W}if(!p){break W}}d=w[R|0];if(b){t[o+1075795|0]=b}Y:{Z:{if(!Kc(d)){break Z}rb(i+8|0,r,67);if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])){break Z}a=u[o+1075762>>1];_:{if(!b|g){break _}f=wy(e,d,b);if(!f){break _}a=t[Tj(e,f)+36|0]}d=(a+d|0)-132>>>0<4294967176?0:d;break Y}if(!(v[K>>2]&25165856)){break Y}m=x[M>>1];if(!m){break Y}if(d){a=Kc(d)}else{a=1}if(!a){break Y}f=b;$:{if(!b){f=w[o+1075796|0];if(!f){break $}}if(v[((f<<2)+e|0)+900380>>2]?f>>>0<=m>>>0:0){break Y}d=0}b=0}if(!((N|0)!=25|c)){rb(i+8|0,r,55);a=sb(v[v[i+8>>2]>>2],v[i+12>>2]);b=a?0:b;d=a?0:d}rb(i+8|0,r,65);a=(b|0)!=0;f=sb(v[v[i+8>>2]>>2],v[i+12>>2]);m=!d;Q=1;aa:{if(v[K>>2]&16777248){break aa}rb(i+8|0,r,107);if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){break aa}rb(i,r,85);Q=0;if(!sb(v[v[i>>2]>>2],v[i+4>>2])){break aa}s=o+1075e3|0;if(gi(v[s>>2],v[s+4>>2])){break aa}Q=1;s=v[o+1075096>>2];if(!s){break aa}Q=Fd(s)^1}s=a&f;a=a&m;ba:{ca:{da:{ea:{fa:{ga:{ha:{if(!(v[K>>2]&1048580)){break ha}ia:{if((d|0)!=255){break ia}if(!(!((l|0)==1|b)&(N|0)!=13)){rb(i+8|0,r,55);if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){break ia}}f=v[o+1075648>>2];if(t[f+60|0]&1?f:0){break ia}v[o+1075680>>2]=0;a=o+1075080|0;v[a>>2]=v[a>>2]|2097152;ja:{if(!(v[e+480208>>2]&4096)){break ja}rb(i+8|0,r,86);if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])){break ja}v[a>>2]=v[a>>2]|4096}b=0;d=0;a=0;f=0;m=1;if(s){break ca}break ba}rb(i+8|0,r,59);if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])|v[G>>2]&4096){break ha}if(!d){d=w[o+1075789|0]-w[o+1075762|0]|0;break ga}if(d>>>0>250){Q=0;s=1;d=0;break ga}if(!b){rb(i+8|0,r,98);if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){break ga}}Q=1;s=1;break ga}f=0;if(!a){break ea}break fa}f=d;g=0}rb(i+8|0,r,65);if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])){break da}d=f;f=1}a=d;m=1;if(s){break ca}break ba}d=f;f=1;m=s}ka:{la:{if(!x[M>>1]){if(x[_>>1]<b>>>0){break ka}a=(B(b,104)+e|0)+484380|0;break la}a=v[o+1075096>>2];if(!a){break ka}}ma:{if(u[a+34>>1]<0){break ma}if(v[K>>2]==2){if(!Fd(a)){break ma}}v[o+1075680>>2]=x[a+30>>1]}if(!m){break ka}xp(j,x[a+28>>1],e)}a=d}rb(i+8|0,r,71);if(!(!sb(v[v[i+8>>2]>>2],v[i+12>>2])|!b)){t[o+1075831|0]=32}na:{if(!x[M>>1]){break na}rb(i+8|0,r,100);if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])|!b){break na}if(Kc(a&255)){break na}d=v[G>>2];oa:{if(g){if(d&8){break oa}break na}if(!(d&4)){break na}}Ml(j);v[o+1075688>>2]=65536;d=o+1075080|0;v[d>>2]=v[d>>2]|2097152}if(f){rb(i+8|0,r,11);pa:{qa:{ra:{if(!(sb(v[v[i+8>>2]>>2],v[i+12>>2])|v[K>>2]==268435456)){d=x[M>>1];break ra}rb(i+8|0,r,87);f=0;if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){d=o+1075e3|0;f=gi(v[d>>2],v[d+4>>2])^1}d=x[M>>1];sa:{if(d){if(b>>>0>d>>>0){break qa}if(v[o+1075648>>2]!=v[((b<<2)+e|0)+900380>>2]|f){break sa}break qa}if((f^-1)&v[o+1075096>>2]==((B(b,104)+e|0)+484380|0)){break pa}}a=w[o+1075789|0]}if(!(d&65535)){break pa}}if(!(v[K>>2]&1048588)){break pa}Ml(j);t[o+1075810|0]=0;v[o+1075748>>2]=0;v[o+1075688>>2]=65536;d=o+1075080|0;v[d>>2]=v[d>>2]&-2101249|2097152;rb(i+8|0,r,86);if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])){break pa}v[d>>2]=v[d>>2]&-2049}b=Q?b:0}m=a&255;ta:{if(m>>>0<251){break ta}rb(i+8|0,r,50);ua:{if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])|!b){break ua}d=wy(e,w[o+1075791|0],b);if(!d){break ua}d=B(d,104)+e|0;if(u[d+484414>>1]<0){break ua}v[o+1075680>>2]=x[d+484410>>1]}rb(i+8|0,r,100);if(Ua=sb(v[v[i+8>>2]>>2],v[i+12>>2]),Va=0,Xa=v[G>>2]&4,Xa?Ua:Va){break ta}b=0}d=Kc(m);va:{if(!d){break va}t[o+1075794|0]=a;t[o+1075791|0]=a;if(!g){QL(e,h&65535,b,m,0)}f=o+1075776|0;a=u[f>>1];if(a){v[o+1075684>>2]=(a&32767)-1;if((a|0)<0){a=o+1075080|0;v[a>>2]=v[a>>2]|256}u[f>>1]=0}a=o+1075787|0;f=w[a|0];if(f){t[o+1075830|0]=f-1;t[a|0]=0}a=o+1075788|0;f=w[a|0];if(!f){break va}t[o+1075829|0]=f-1;t[a|0]=0}wa:{xa:{ya:{za:{Aa:{if(b){f=o+1075096|0;s=v[f>>2];kp(e,j,b,g,1,1);a=v[f>>2];Ba:{if(!a|!(w[a+35|0]&2)){break Ba}if(!td(F)){break Ba}Ry(v[F>>2],h&65535,a+68|0)}Ca:{Da:{if(v[K>>2]==1){if(!g){break Da}rb(i+8|0,r,85);if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])){break Da}break Ca}rb(i+8|0,r,50);if((d|sb(v[v[i+8>>2]>>2],v[i+12>>2])^1)!=1){break Ca}}t[o+1075795|0]=0}rb(i+8|0,r,42);if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!d|(s|0)==v[f>>2]){break za}break Aa}if(v[K>>2]&16777248){a=0;if(d&(s|0)!=v[f>>2]){break ya}}rb(i+8|0,r,107);Ea:{if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])|(s|0)==v[f>>2]){break Ea}if((d^1|g)==1){a=o+1075068|0;if(y[a>>2]>=y[j+4>>2]){break Ea}v[a>>2]=0;break za}g=0}rb(i+8|0,r,85);if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])){break za}a=o+1075e3|0;if(!gi(v[a>>2],v[a+4>>2])){break Aa}break za}if(!m){a=g;break wa}f=0;s=o+1075795|0;a=w[s|0];if(!(!a|d^1)){kp(e,j,a,g,!(v[o+1075096>>2]?1:v[o+1075648>>2]),!(v[K>>2]&1048580));t[s|0]=0;f=1}a=g;break xa}v[j>>2]=0;v[j+4>>2]=0}a=g}f=0;if(!m){break wa}}d=v[o+1075096>>2];Fa:{if(!d|!(w[d+35|0]&2)){break Fa}if(!td(F)){break Fa}if(!f){if(RL(v[F>>2],h&65535)){break Fa}}Ry(v[F>>2],h&65535,d+68|0)}d=h&65535;Is(e,j,m,a,!(v[K>>2]&1048580),0,d);AM(e,I,d);if(!(!a|(!(v[K>>2]&1048580)|!b))){b=o+1075080|0;v[b>>2]=v[b>>2]|2097152;Ml(j);t[o+1075810|0]=0;v[o+1075748>>2]=0}if(!(v[o+1075080>>2]&512)){break wa}if(!td(F)){break wa}if(m>>>0<=253){if((m|0)!=253){break wa}rb(i+8|0,r,99);if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){break wa}}rb(i+8|0,r,110);if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){Sy(v[F>>2],d,0,1,0)}Nj(v[F>>2],d)}Ga:{Ha:{switch(l-1|0){case 0:A=A>>>0<64?A:64;v[o+1075680>>2]=A<<2;b=o+1075080|0;v[b>>2]=v[b>>2]|2097152;break Ga;case 1:break Ha;default:break Ga}}Nl(e,j,A,6)}if(x[M>>1]){OL(e,h&65535)}g=a}rb(i+8|0,r,77);if(Ua=sb(v[v[i+8>>2]>>2],v[i+12>>2]),Va=0,Xa=v[((h<<5)+e|0)+480280>>2]&1024,Xa?Ua:Va){break Q}a=v[e+1074392>>2];rb(i+8|0,r,75);d=a>>>0>=E>>>0;Ia:{Ja:{Ka:{La:{if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])|!E){break La}b=v[e+1074392>>2];if(!b){break Ka}d=1;if((b|0)!=(E|0)){break La}d=!w[X|0]&(l|0)!=11}a=l;if(!d|a>>>0<3){break Ka}if((a|0)==11){a=i+8|0;vy(a,e,R,E);b=w[Me(a)|0];rn(e,j,x[a>>1]);if(b){break Ja}l=11;break Ka}rb(i+8|0,r,62);Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{if(!(!sb(v[v[i+8>>2]>>2],v[i+12>>2])|A)){A=0;l=0;Ta:{switch(a-8|0){case 0:break Sa;case 1:break Ta;default:break Ka}}if(w[G+1|0]&16){break Ka}v[o+1075684>>2]=0;break Ka}rb(i+8|0,r,41);Ua:{if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ua}if(A){t[o+1075826|0]=A;break Ua}A=w[o+1075826|0]}Va:{switch(a-3|0){case 0:case 1:Wa:{Xa:{if(A){break Xa}rb(i+8|0,r,41);if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])){break Xa}A=w[o+1075826|0];if(A){break Wa}A=0;break Ka}t[o+1075826|0]=A}xn(e,j,((a|0)==3?A<<4:A)&255);break Ka;case 2:if((E|0)!=v[e+1074392>>2]){rb(i+8|0,r,41);l=5;if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ka}}rb(i+8|0,r,41);wn(e,j,A,sb(v[v[i+8>>2]>>2],v[i+12>>2]));l=5;break Ka;case 3:if((E|0)!=v[e+1074392>>2]){rb(i+8|0,r,41);l=6;if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ka}}rb(i+8|0,r,41);vn(e,j,A,sb(v[v[i+8>>2]>>2],v[i+12>>2]));l=6;break Ka;case 11:break Ma;case 12:break Na;case 10:break Oa;case 9:break Pa;case 7:break Qa;case 6:break Ra;case 5:break Sa;case 4:break Va;default:break Ka}}rb(i+8|0,r,53);if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){t[o+1075815|0]=A&15;l=7;break Ka}Mk(j,A<<4);l=7;break Ka}Mk(j,A);l=8;break Ka}rb(i+8|0,r,62);fy(e,j,A,sb(v[v[i+8>>2]>>2],v[i+12>>2])^1);l=9;break Ka}rb(i+8|0,r,62);fy(e,j,A<<4&240,sb(v[v[i+8>>2]>>2],v[i+12>>2])^1);l=10;break Ka}l=12;rb(i+8|0,r,12);NL(e,h&65535,A<<2&252,sb(v[v[i+8>>2]>>2],v[i+12>>2]));break Ka}rb(i+8|0,r,12);ML(e,h&65535,A<<2&252,sb(v[v[i+8>>2]>>2],v[i+12>>2]));l=13;break Ka}l=15;if(!p){break Ka}a=v[o+1075096>>2];if(!a|A>>>0>9){break Ka}Ya:{if(!A){b=v[o+1075656>>2];break Ya}b=v[Fb(a+68|0,A-1|0)>>2];v[o+1075656>>2]=b}yn(e,j,b);break Ka}l=14;if(A>>>0>1){break Ka}t[q|0]=w[q|0]&247|!A<<3}b=c;Za:{_a:{$a:{ab:{switch(N-1|0){case 12:if(!(w[G+1|0]&16)){break Ja}a=B(h,872)+e|0;v[a+1075680>>2]=c>>>0<64?c<<2:256;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Ja;case 1:if(!c){b=0;if(t[K|0]&1){break Ia}}NL(e,h&65535,c,0);break Ja;case 2:if(!c){b=0;if(t[K|0]&1){break Ia}}ML(e,h&65535,c,0);break Ja;case 10:if(!c){b=0;if(v[K>>2]==1){break Ia}}xn(e,j,c);break Ja;case 3:rn(e,j,c);break Ja;case 5:if(!(!c&v[K>>2]==1)){xn(e,j,c)}rn(e,j,0);break Ja;case 4:Mk(j,c);break Ja;case 6:if(!(!c&v[K>>2]==1)){xn(e,j,c)}Mk(j,0);break Ja;case 15:if(!(w[G+1|0]&16)){break Ja}break Za;case 16:rb(i+8|0,r,5);if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!(w[G+1|0]&16)){break Ja}if(c){break Za}break Ja}b=un(e,x[e+1074446>>1],v[e+1074424>>2],h&65535,0);bb:{if(!(v[e+480180>>2]&16777250)){break bb}if(b){t[(B(h,872)+e|0)+1075827|0]=b;break bb}b=w[(B(h,872)+e|0)+1075827|0]}v[i+8>>2]=B(b,1e4);mc(i+8|0,B(v[v[e+8>>2]+24>>2],1e4));a=ab-16|0;ab=a;d=v[i+8>>2];v[a+8>>2]=d;c=v[e+8>>2];cb:{if(d>>>0>=(v[e+480180>>2]&16393?1e4:32e4)>>>0){d=v[e+480208>>2];rb(a,e+1074312|0,92);if((sb(v[v[a>>2]>>2],v[a+4>>2])|0)==((d&4096)>>>12|0)){break cb}v[a>>2]=B(v[c+24>>2],1e4);Ua=e+1074420|0,Va=v[zb(a+8|0,a)>>2],v[Ua>>2]=Va;break cb}if(w[e+480209|0]&16){break cb}f=e+1074420|0;d=(d>>>0)/1e4|0;g=B(d&15,1e4);v[f>>2]=v[f>>2]+((d&240)==16?g:0-g|0);d=v[c+20>>2];c=v[c+24>>2];rb(a,e+1074312|0,8);jo(f,B(d,1e4),sb(v[v[a>>2]>>2],v[a+4>>2])?255e4:B(c,1e4))}ab=a+16|0;break Ia;case 9:if(!p|(v[K>>2]==4?g:0)){break Ja}zM(e,j,h&65535,v[e+1074424>>2],x[e+1074446>>1]);break Ja;case 43:if(!p){break Ja}b=oia(v[(B(h,872)+e|0)+1075068>>2],0,c,0);a=db;g=a>>>8|0;yn(e,j,Fc((a&255)<<24|b>>>8,g));break Ja;case 0:if(v[e+1074392>>2]){break Ja}a=B(h,872)+e|0;db:{if(w[a+1075789|0]?v[a+1075692>>2]:0){break db}a=v[a+1075648>>2];if(a){if(fj(w[a+31|0])){break db}}rb(i+8|0,r,13);if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){break db}if(v[K>>2]&16777248){break Ja}}if(!c){b=0;if(w[K|0]&5){break Ia}t[(B(h,872)+e|0)+1075797|0]=1;break Ia}a=B(h,872)+e|0;t[a+1075798|0]=c;t[a+1075797|0]=1;break Ja;case 14:if(v[K>>2]&1048580){c=c&240?c:w[(B(h,872)+e|0)+1075799|0]&240|c;if(!(c&15)){c=w[(B(h,872)+e|0)+1075799|0]&15|c}b=c|256}else{b=c}rb(i+8|0,r,23);if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){c=e;d=h&65535;if(b){t[(B(h,872)+e|0)+1075799|0]=b;a=b}else{a=w[(B(h,872)+e|0)+1075799|0]}ey(c,d,a&255,(l|0)==15?A+1|0:0);break Ia}eb:{if(b){t[(B(h,872)+e|0)+1075799|0]=b;break eb}b=w[(B(h,872)+e|0)+1075799|0]}ey(e,h&65535,b,(l|0)==15?A+1|0:0);break Ia;case 17:if(!(w[G+1|0]&16)){break Ja}rb(i+8|0,r,22);fb:{gb:{if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!c){c=0;break gb}if(w[G|0]&4){break gb}a=c&240?c-16|0:c;c=a-((a&15)!=0)|0;t[(B(h,872)+e|0)+1075832|0]=c;break gb}rb(i+8|0,r,71);if(!sb(v[v[i+8>>2]>>2],v[i+12>>2])){break fb}}a=(B(h,872)+e|0)+1075831|0;t[a|0]=w[a|0]|128}a=B(h,872)+e|0;t[a+1075797|0]=18;if(!c){b=0;break Ia}t[a+1075832|0]=c;break Ja;case 22:if(!(w[G+1|0]&16)){break Ja}a=v[K>>2];b=c<<!(a&59593760);if(b>>>0<=128){v[e+1074456>>2]=b<<1;break Ia}if(a&16777250){break Ia}v[e+1074456>>2]=256;break Ia;case 23:rb(i+8|0,r,9);if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){LL(e,c,(B(h,872)+e|0)+1075809|0);break Ja}LL(e,c,ba);break Ja;case 8:if(!(w[G+1|0]&16)){break Ja}Nl(e,j,c,8);break Ja;case 28:fy(e,j,c,1);break Ja;case 7:rM(j,c);break Ja;case 25:sM(e,j,c);break Ja;case 18:g=e+1074376|0;d=h&65535;f=B(d,872);b=(g+f|0)+616|0;a=c&15;hb:{ib:{switch(c>>>4|0){case 0:a=(c&1)<<14;b=x[e+480188>>1];g=0;while(1){if((b|0)==(g|0)){break hb}d=(B(g,872)+e|0)+1075080|0;v[d>>2]=(a|v[d>>2]&-16385)^16384;g=g+1|0;continue};case 1:if(a){dy(e,b,a);break hb}if(!(v[e+480180>>2]&1048580)){break hb}dy(e,b,0);break hb;case 2:if(a){cy(e,b,a);break hb}if(!(v[e+480180>>2]&1048580)){break hb}cy(e,b,0);break hb;case 3:b=(e+f|0)+1075080|0;v[b>>2]=v[b>>2]&-1048577|((a|0)!=0)<<20;break hb;case 4:t[(e+f|0)+1075814|0]=c&7;break hb;case 5:if(!(w[e+480209|0]&16)){break hb}f=v[e+480180>>2];if(f&69206025){b=B(d,872)+e|0;u[b+1075764>>1]=a<<28>>24;f=b+1075692|0;if(!v[f>>2]){break hb}if(!Kc(w[b+1075780|0])){break hb}b=B(d,872)+e|0;Ua=f,Va=Kg(e,w[b+1075789|0],a<<28>>24,v[b+1075696>>2]),v[Ua>>2]=Va;break hb}b=Kc(w[(B(d,872)+e|0)+1075780|0]);if((f|0)==16){if(!b){break hb}b=B(d,872)+e|0;f=v[b+1075096>>2];if(!f){break hb}t[f+37|0]=a;u[b+1075764>>1]=a;b=b+1075692|0;if(!v[b>>2]){break hb}f=b;b=B(d,872)+e|0;Ua=f,Va=Kg(e,w[b+1075789|0],a,v[b+1075696>>2]),v[Ua>>2]=Va;break hb}if(!b){break hb}a=B(d,872)+e|0;b=(c<<4^-128)<<24>>24;u[a+1075764>>1]=b;d=a+1075692|0;if(!v[d>>2]){break hb}Ua=d,Va=Kg(e,w[a+1075789|0],b,v[a+1075696>>2]),v[Ua>>2]=Va;break hb;case 6:if(!(w[e+480209|0]&16)){break hb}Hs(e,g,b,a);break hb;case 7:t[(e+f|0)+1075817|0]=c&7;break hb;case 8:if(!(w[e+480209|0]&16)){break hb}Nl(e,b,a,4);break hb;case 9:ey(e,d,a,0);break hb;case 10:if(a){wn(e,b,a,0);break hb}if(!(v[e+480180>>2]&1048580)){break hb}wn(e,b,0,0);break hb;case 11:if(a){vn(e,b,a,0);break hb}if(!(v[e+480180>>2]&1048580)){break hb}vn(e,b,0,0);break hb;case 12:gy(e,d,a,0);break hb;case 15:break ib;default:break hb}}if(v[e+480180>>2]==1){t[(B(d,872)+e|0)+1075838|0]=a;if(!(w[e+480209|0]&16)){break hb}PL(e,b);break hb}t[(B(d,872)+e|0)+1075836|0]=a}break Ja;case 19:rb(i+8|0,r,78);if(!(!sb(v[v[i+8>>2]>>2],v[i+12>>2])|c)){b=w[(B(h,872)+e|0)+1075798|0]}KL(e,h&65535,b);break Ia;case 24:rb(i+8|0,r,55);if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){if(v[e+1074392>>2]!=(c|0)){break Ja}a=v[(B(h,872)+e|0)+1075648>>2];if(t[a+60|0]&1?a:0){break _a}if(!(!(w[V|0]?1:w[X|0])|c)){a=(B(h,872)+e|0)+1075080|0;v[a>>2]=v[a>>2]|4096;break _a}a=B(h,872)+e|0;v[a+1075680>>2]=0;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break _a}if(w[G+1|0]&16){break _a}break Ja;case 27:a=(c&240)-16>>>4|0;if(a>>>0>9){break Ja}if(!(1<<a&880)){if(!a){break $a}if((a|0)!=1){break Ja}JL(e,j,c&15);break Ja}rb(i+8|0,r,58);if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ja}KL(e,h&65535,c);break Ja;case 34:case 35:if(!(w[G+1|0]&16)&(N|0)!=36){break Ja}b=h&65535;wM(e,b,I,(N|0)==36);a=Bs(e,j);if(!a){break Ja}eb[v[v[a>>2]+80>>2]](a,(x[(B(h,872)+e|0)+1075766>>1]&65532)>>>2^8192,b);break Ja;case 20:if(!(w[G+1|0]&16)|c>>>0>64){break Ja}a=B(h,872)+e|0;v[a+1075740>>2]=c;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Ja;case 21:a=c;jb:{if(a){t[j+816|0]=a;break jb}a=w[j+816|0]}d=a&255;f=a&240;b=a&15;kb:{lb:{if(!(!f|(b|0)!=15)){if(!(w[e+480209|0]&16)){break kb}a=d>>>4|0;break lb}g=v[e+480208>>2]&4096;if(!(!b|(f|0)!=240)){if(!g){break kb}a=0-b|0;break lb}if(g){break kb}if(b){a=0-b|0;if(!(v[e+480180>>2]&25690144)|!f){break lb}break kb}if((a&255)>>>0<16){break kb}a=d>>>4|0}Ua=j,Va=Sb(a+v[j+748>>2]|0,0,64),v[Ua+748>>2]=Va}break Ja;case 26:qM(j,c);break Ja;case 29:if(!(w[G+1|0]&16)){break Ja}a=B(h,872)+e|0;v[a+1075716>>2]=c;rb(i+8|0,r,60);if(Ua=0,Va=sb(v[v[i+8>>2]>>2],v[i+12>>2]),Xa=w[a+1075722|0]&4,Xa?Ua:Va){break Ja}a=B(h,872)+e|0;v[a+1075732>>2]=c;v[a+1075724>>2]=c;break Ja;case 11:uM(e,I,h&65535);break Ja;case 13:a=tM(e,I,h&65535,c);if((a|0)==-1){break Ja}v[e+1074436>>2]=a;if(!(w[e+480208|0]&32)){break Ja}u[e+1074444>>1]=x[e+1074448>>1];break Ja;case 37:case 38:case 39:case 40:a=(N|0)==38|(N|0)==40;b=(N&254)==40;mb:{nb:{ob:{if(w[e+480209|0]&16){g=w[j+848|0];d=c&240;if(d){g=d|g&15;t[j+848|0]=g}d=c&15;if(d){g=d|g&-16;t[j+848|0]=g}t[j+849|0]=(g&240)>>>4;if(v[e+480180>>2]!=32768){break mb}break ob}if(v[e+480180>>2]==32768){break ob}d=w[j+849|0]-1|0;t[j+849|0]=d;if(d&255){break mb}g=w[j+848|0];break nb}g=w[j+848|0];if((g&240)==16){break nb}if(!(w[e+480209|0]&16)){break mb}}t[j+849|0]=(g&240)>>>4;d=g&15;a=a?d:0-d|0;d=v[j+656>>2];pb:{if(hj(d)){v[j+852>>2]=v[j+852>>2]+B(a,v[v[d+44>>2]+36>>2]);break pb}Ua=j,Va=Kg(e,As(e,v[j+700>>2],u[j+772>>1],v[j+704>>2])+a|0,u[j+772>>1],v[j+704>>2]),v[Ua+700>>2]=Va}if(!b){break mb}v[j>>2]=0;v[j+4>>2]=0}break Ja;case 41:yM(j,c);break Ja;case 42:if(v[e+1074392>>2]|Y>>>0>1|c>>>0>47){break Ja}b=h;f=b;if((c&240)==16){f=x[e+480188>>1]-1|0;b=0}a=((Y|0)==1)<<26;while(1){d=b&65535;if(d>>>0>(f&65535)>>>0){break Ja}g=((d<<5)+e|0)+480280|0;v[g>>2]=a|v[g>>2]&-67108865;d=(B(d,872)+e|0)+1075080|0;v[d>>2]=a|v[d>>2]&-67108865;b=b+1|0;continue};case 44:break ab;default:break Ia}}xM(j,c);break Ja}IL(e,j,c&15);break Ja}tn(e,j);break Ja}yy(e,I,c)}b=c}rb(i+8|0,r,78);if(!(!sb(v[v[i+8>>2]>>2],v[i+12>>2])|!b)){a=b&255;t[j+840|0]=a;t[j+812|0]=a;t[j+811|0]=a;t[j+809|0]=a;t[j+807|0]=a;t[j+806|0]=a;t[j+826|0]=a>>>4;t[j+827|0]=a<<2&60}a=w[X|0];if(!a){break Q}t[o+1075796|0]=a}h=h+1|0;continue}break}a=1;break j}a=0}ab=H+32|0;qb:{if(!a|!v[e+1074420>>2]){break qb}a=CM(e,e+1074376|0);v[e+1074380>>2]=a;v[e+1074404>>2]=a;b=Ld(x[e+480188>>1],1,31);rb:{if(zd(w[e+1074366|0])){a=v[e+24628>>2];if((a|0)>=129){a=((B(a-128|0,b+4|0)|0)/16|0)+128|0}l=((B(v[e+480228>>2],a)<<1&-128)>>>0)/w[(b>>>1|0)+32144|0]|0;break rb}l=v[e+480228>>2]}u[e+480212>>1]=0;i=e+1298300|0;q=e+1074312|0;R=e+1074365|0;r=e+480180|0;E=e+480210|0;F=e+480209|0;Q=e+1074366|0;V=e+1074364|0;X=e+1074360|0;N=0;while(1){if((N|0)==256){k=1;a=v[e+24608>>2];f=x[e+480212>>1];if(a>>>0>f>>>0){break qb}d=ab-16|0;ab=d;v[d+8>>2]=e;b=e+1074478|0;c=b;f=b+(f<<1)|0;sb:{a=b+(a<<1)|0;b=a-b|0;if((b|0)<3){break sb}k=b>>1;b=(k-2|0)/2|0;while(1){if((b|0)<0){break sb}Nx(c,v[d+8>>2],k,c+(b<<1)|0);b=b-1|0;continue}}k=a-c>>1;b=a;while(1){if((b|0)!=(f|0)){if(_o(v[d+8>>2],x[b>>1],x[c>>1])){Ox(b,c);Nx(c,v[d+8>>2],k,c)}b=b+2|0;continue}break}b=a-c>>1;while(1){if((b|0)>1){a=a-2|0;Ox(c,a);b=b-1|0;Nx(c,v[d+8>>2],b,c);continue}break}ab=d+16|0}else{j=B(N,872)+e|0;m=j+1075080|0;tb:{if(!(v[m>>2]&4096)|(v[j+1075016>>2]|(v[j+1075012>>2]|v[j+1075688>>2]))){break tb}rb(n+16|0,q,64);if(sb(v[v[n+16>>2]>>2],v[n+20>>2])){break tb}v[j+1075068>>2]=0;a=j+1075084|0;v[a>>2]=0;v[a+4>>2]=0}c=x[e+480188>>1];b=v[m>>2];ub:{if(v[j+1075068>>2]|c>>>0>N>>>0?b&1024:1){if(c>>>0>N>>>0){XK(e,N&65535)}u[j+1075834>>1]=0;break ub}d=0;I=j+1075712|0;v[I>>2]=0;H=j+1075672|0;v[H>>2]=0;o=j+1075e3|0;a=o;v[a>>2]=0;v[a+4>>2]=0;v[j+1075092>>2]=0;v[n+44>>2]=1065353216;u[n+42>>1]=0;K=j+1075648|0;G=v[K>>2];v[n+36>>2]=0;k=0;s=j+1075692|0;k=v[s>>2]?v[j+1075068>>2]!=0:k;a=j+1074992|0;vb:{wb:{xb:{if(c>>>0<=N>>>0){break xb}if(w[((N<<5)+e|0)+480288|0]){break wb}if(!G){break xb}d=w[G+34|0]!=0}if((d|k)!=1){break vb}}v[n+8>>2]=v[j+1075680>>2];v[n+32>>2]=v[j+1075744>>2];rb(n+16|0,q,28);g=n+8|0;b=sb(v[v[n+16>>2]>>2],v[n+20>>2])?n+32|0:g;c=ab-16|0;ab=c;d=e+1074312|0;rb(c+8|0,d,28);yb:{if(sb(v[v[c+8>>2]>>2],v[c+12>>2])){v[b>>2]=v[b>>2]+u[a+776>>1];ce(b,0,64);break yb}rb(c+8|0,d,1);d=u[a+776>>1];if(sb(v[v[c+8>>2]>>2],v[c+12>>2])){v[b>>2]=d+v[b>>2];ce(b,0,256);break yb}v[a+688>>2]=d+v[a+688>>2];ce(a+688|0,0,256);v[b>>2]=v[a+688>>2];u[a+776>>1]=0}ab=c+16|0;b=ab-16|0;ab=b;c=e+1074312|0;rb(b+8|0,c,28);zb:{Ab:{if(!sb(v[v[b+8>>2]>>2],v[b+12>>2])){rb(b,c,1);if(!sb(v[v[b>>2]>>2],v[b+4>>2])){break Ab}}v[a+684>>2]=v[a+692>>2]+u[a+778>>1];ce(a+684|0,0,256);break zb}v[a+692>>2]=v[a+692>>2]+u[a+778>>1];ce(a+692|0,0,256);u[a+778>>1]=0;v[a+684>>2]=v[a+692>>2]}ab=b+16|0;c=ab-16|0;ab=c;Bb:{if(!(w[a+90|0]&4)|(v[e+480208>>2]&2101248)==2101248){break Bb}Cb:{if(v[g>>2]<=0){rb(c+8|0,e+1074312|0,21);if(!sb(v[v[c+8>>2]>>2],v[c+12>>2])){break Cb}}d=5;if(!(v[e+480180>>2]&5)){rb(c+8|0,e+1074312|0,21);d=sb(v[v[c+8>>2]>>2],v[c+12>>2])?5:6}b=Rx(e,w[a+825|0],w[a+820|0]);Db:{if((w[a+825|0]&3)!=1){break Db}rb(c+8|0,e+1074312|0,89);if(!sb(v[v[c+8>>2]>>2],v[c+12>>2])){break Db}b=w[a+819|0];h=w[a+820|0];f=h<<2&124;b=(!(w[a+90|0]&2)|w[e+480209|0]&16?b:w[a+823|0]+b|0)&32?f^127:f;b=h&32?0-b|0:b}if(v[e+480180>>2]!=131072){b=v[g>>2]+((B(w[a+827|0],b)|0)/(1<<d)|0)|0}else{d=64-b|0;b=v[g>>2];b=((B(w[a+827|0],B(d,b))|0)/-8192|0)+b|0}v[g>>2]=b}b=v[e+480208>>2];if(!(v[e+480180>>2]&16777248)|b&4?b&4096:0){break Bb}rb(c+8|0,e+1074312|0,21);b=w[a+826|0];d=w[a+820|0];f=sb(v[v[c+8>>2]>>2],v[c+12>>2]);t[a+820|0]=(f?b<<2:d)+(f?d:b)}ab=c+16|0;h=N&65535;d=ab-16|0;ab=d;b=e+1074312|0;rb(d+8|0,b,71);Eb:{if(sb(v[v[d+8>>2]>>2],v[d+12>>2])){b=(B(h,872)+e|0)+1075831|0;c=t[b|0];if((c|0)>=0){break Eb}if(!(w[e+480209|0]&16|w[(B(h,872)+e|0)+1075797|0]!=18)){f=c&-33;t[b|0]=f;Fb:{Gb:{if((f|0)!=-64){c=c&223;if((c|0)!=128){break Gb}c=w[(B(h,872)+e|0)+1075832|0]>>>4|-64;break Fb}c=w[(B(h,872)+e|0)+1075832|0]&15|-128;break Fb}c=c-1|0}t[b|0]=c;b=(B(h,872)+e|0)+1075080|0;v[b>>2]=v[b>>2]|2097152}if((c&224)!=128){break Eb}v[g>>2]=0;break Eb}if(w[(B(h,872)+e|0)+1075797|0]!=18){break Eb}rb(d+8|0,b,22);Hb:{if(sb(v[v[d+8>>2]>>2],v[d+12>>2])){p=B(h,872)+e|0;b=p+1075831|0;f=w[b|0];c=f<<24>>24;if(!((c|0)>=0|!v[p+1075068>>2])){Ib:{Jb:{if((f|0)!=192){if((f|0)!=128){break Jb}c=w[(B(h,872)+e|0)+1075832|0]>>>4|-64;break Ib}c=w[(B(h,872)+e|0)+1075832|0]&15|-128;break Ib}c=c-1|0}t[b|0]=c}if((c&192)!=128){break Hb}v[g>>2]=0;break Hb}b=w[(B(h,872)+e|0)+1075832|0];f=b>>>4|0;A=f+(b&15)|0;p=v[e+480180>>2];if(!(w[e+480208|0]&4?0:p&16777248)){A=A+2|0;f=f+1|0}b=(B(h,872)+e|0)+1075831|0;c=w[b|0];if(!(p&4)){c=(c&255)>>>0<A>>>0?c:0;if((c&255)>>>0>=f>>>0){v[g>>2]=0}t[b|0]=c+1;break Hb}Kb:{if(w[e+480209|0]&16){c=c&255?c-1|0:0;break Kb}t[b|0]=c+1}if(((c&255)>>>0)%(A>>>0)>>>0<f>>>0){break Hb}v[g>>2]=0}b=(B(h,872)+e|0)+1075080|0;v[b>>2]=v[b>>2]|2097152}b=B(h,872)+e|0;Lb:{if(w[b+1075797|0]!=18){break Lb}c=v[b+1075648>>2];if(!c){break Lb}b=w[c+34|0];if(!b|w[c+15|0]&2){break Lb}f=B(h,872)+e|0;if(v[f+1075080>>2]&134218752){break Lb}f=f+1075791|0;p=w[f|0];if(!Kc(p)){break Lb}b=v[(B(b,160)+e|0)+906140>>2];if(!b){break Lb}p=eb[v[v[b>>2]+100>>2]](b,p,h)|0;A=v[g>>2];if(!(!p|A)){eb[v[v[b>>2]+92>>2]](b,c,w[f|0]+255|0,0,h);break Lb}if(p|!A){break Lb}eb[v[v[b>>2]+92>>2]](b,c,w[f|0],x[(B(h,872)+e|0)+1075680>>1],h)}ab=d+16|0;ce(g,0,256);v[n+8>>2]=v[n+8>>2]<<6;Mb:{if(G){rb(n+16|0,q,31);if(sb(v[v[n+16>>2]>>2],v[n+20>>2])){Fs(e,a)}d=n+8|0;b=ab-16|0;ab=b;Nb:{if(!Px(e,a,0)){break Nb}f=v[a+656>>2];g=e+1074312|0;rb(b+8|0,g,31);Ob:{if(sb(v[v[b+8>>2]>>2],v[b+12>>2])){c=v[a+724>>2];if(c){break Ob}break Nb}c=v[a+724>>2]}rb(b+8|0,g,31);A=c-sb(v[v[b+8>>2]>>2],v[b+12>>2])|0;c=wp(f+48|0,A,256,64);M=w[f+65|0];Pb:{if((M|0)==255){break Pb}p=u[a+728>>1];if((p|0)==-1){break Pb}M=Fb(v[f+48>>2],M);f=w[M+2|0];M=x[M>>1];rb(b+8|0,g,94);g=f<<2;c=(A|0)==(M|0)?g:c;if(sb(v[v[b+8>>2]>>2],v[b+12>>2])){c=p+(c-g<<1)|0;break Pb}if(!f){c=0;break Pb}c=(B(c,p)|0)/(g|0)|0}Ua=d,Va=(B(Sb(c,0,512),v[d>>2])|0)/256|0,v[Ua>>2]=Va}ab=b+16|0;hM(a,d);b=ab-16|0;ab=b;Qb:{if(!Px(e,a,1)){break Qb}d=v[a+656>>2];f=e+1074312|0;rb(b+8|0,f,31);Rb:{if(sb(v[v[b+8>>2]>>2],v[b+12>>2])){c=v[a+732>>2];if(c){break Rb}break Qb}c=v[a+732>>2]}rb(b+8|0,f,31);d=wp(d+68|0,c-sb(v[v[b+8>>2]>>2],v[b+12>>2])|0,64,64)-32|0;c=v[a+684>>2];Ua=a,Va=Sb(((B(d,(c|0)>127?256-c|0:c)|0)/32|0)+c|0,0,256),v[Ua+684>>2]=Va}ab=b+16|0;rb(n+16|0,q,115);if(sb(v[v[n+16>>2]>>2],v[n+20>>2])){break Mb}c=w[j+1075789|0];if(!c){break Mb}b=v[K>>2];if(!b|!w[b+26|0]){break Mb}jM(j+1075676|0,c,b);break Mb}if(!(w[m+1|0]&16)){break Mb}v[j+1075688>>2]=0;v[n+8>>2]=0}Sb:{if(w[j+1075843|0]&8){c=0;v[n+8>>2]=0;break Sb}c=v[n+8>>2];if(!c){c=0;break Sb}if(w[m+3|0]&8){v[H>>2]=0;break Sb}if(zd(w[R|0])){b=B(v[n+32>>2],v[j+1075740>>2]);d=b;f=b>>31;b=c<<8;Ua=H,Va=vc(pia(oia(d,f,b,b>>31),db,1048576,0),db),v[Ua>>2]=Va;break Sb}b=B(v[n+32>>2],v[j+1075740>>2]);d=b;f=b>>31;b=B(v[e+1074456>>2],c);Ua=H,Va=vc(pia(oia(d,f,b,b>>31),db,1048576,0),db),v[Ua>>2]=Va}v[I>>2]=c;Tb:{Ub:{c=v[s>>2];if(!(v[r>>2]==2|(c|0)>=v[e+480260>>2])){if(!_i(e)){break Ub}c=v[s>>2]}if((c|0)<v[e+480264>>2]){break Tb}rb(n+16|0,q,113);if(!sb(v[v[n+16>>2]>>2],v[n+20>>2])){break Tb}if(_i(e)){break Tb}v[s>>2]=v[e+480264>>2];break Tb}v[s>>2]=v[e+480260>>2]}rb(n+16|0,q,73);b=v[s>>2];v[n+36>>2]=b;Vb:{if((v[m>>2]&1572864)!=1572864){break Vb}c=v[e+480208>>2];if(c&2097152){if(!Js(j+1075780|0)|c&4096){break Vb}}c=j+1075704|0;Wb:{if((b|0)==v[c>>2]){c=v[j+1075708>>2];break Wb}v[c>>2]=b;d=b;b=j+1075764|0;c=j+1075696|0;c=Kg(e,As(e,d,u[b>>1],v[c>>2]),u[b>>1],v[c>>2]);v[j+1075708>>2]=c}v[n+36>>2]=c}g=ab-16|0;ab=g;M=B(h,872)+e|0;Y=M+1075648|0;b=v[Y>>2];Xb:{if(!b){break Xb}c=w[b+34|0];if(!c|w[b+15|0]&2|(!v[(B(c,160)+e|0)+906140>>2]|v[(B(h,872)+e|0)+1075080>>2]&134218752)){break Xb}c=B(h,872)+e|0;_=c+1075783|0;A=w[_|0];d=0;f=w[c+1075791|0];if(Kc(f)){d=w[Cb(b+108|0,f-1|0)|0]}p=c+1075780|0;Yb:{Zb:{if((A|0)==1){f=0;_b:{$b:{switch((y[e+1074392>>2]%3|0)-1|0){case 0:f=w[(B(h,872)+e|0)+1075798|0]>>>4|0;break _b;case 1:break $b;default:break _b}}f=w[(B(h,872)+e|0)+1075798|0]&15}b=B(h,872)+e|0;t[b+1075793|0]=d;if(w[b+1075792|0]==(d+f|0)){break Yb}b=d;if(!(w[e+480209|0]&16)){break Zb}b=d;if(!Kc(w[p|0])){break Zb}break Yb}f=0;if(w[p|0]){break Yb}b=B(h,872)+e|0;if(!w[b+1075792|0]){break Yb}b=w[b+1075793|0]}Ll(e,h,(b&255)+f|0,x[(B(h,872)+e|0)+1075680>>1])}b=(B(h,872)+e|0)+1075792|0;c=w[b|0];ac:{if(!c){if(!(w[e+480209|0]&16)|(A|0)!=1){break ac}if(Kc(w[p|0])){break ac}c=d;if(!Kc(c)){break ac}}Ll(e,h,(c&255)+255|0,0)}t[b|0]=w[_|0]==1?w[(B(h,872)+e|0)+1075793|0]+f|0:0}bc:{if(w[M+1075797|0]!=1){break bc}if(hj(v[Y>>2])){f=0;cc:{dc:{ec:{switch(y[e+1074392>>2]%3|0){case 1:f=w[(B(h,872)+e|0)+1075798|0]>>>4|0;break dc;case 0:break dc;case 2:break ec;default:break cc}}f=w[(B(h,872)+e|0)+1075798|0]&15}u[n+42>>1]=f}b=(B(h,872)+e|0)+1075843|0;t[b|0]=w[b|0]|96;break bc}if(!(!(w[e+480209|0]&16)|v[e+480180>>2]!=1048576)){b=B(h,872)+e|0;c=Kg(e,w[b+1075789|0],u[b+1075764>>1],v[b+1075696>>2]);v[n+36>>2]=c;v[b+1075692>>2]=c}b=e+1074312|0;rb(g+8|0,b,13);if(sb(v[v[g+8>>2]>>2],v[g+12>>2])){f=w[(B(h,872)+e|0)+1075798|0];if(!f){break bc}b=65536;fc:{switch(((y[e+1074392>>2]%(v[e+1074400>>2]+v[e+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:f=f<<4;case 0:b=v[((f&240)<<2)+37296>>2];break;default:break fc}}f=_i(e);c=v[n+36>>2];d=c;c=c>>31;if(f){b=oia(d,c,b,b>>31)+32768|0;c=db;b=pia(b,b>>>0<32768?c+1|0:c,65536,0)}else{f=(b|0)/2|0;h=f>>31;p=c<<16|d>>>16;c=f;f=d<<16;d=c+f|0;c=h+p|0;b=pia(d,d>>>0<f>>>0?c+1|0:c,b,b>>31)}c=db;Ua=n,Va=vc(b,c),v[Ua+36>>2]=Va;break bc}rb(g+8|0,b,51);if(sb(v[v[g+8>>2]>>2],v[g+12>>2])){if(w[e+480209|0]&16){break bc}gc:{hc:{b=v[e+1074416>>2];b=b-(y[e+1074392>>2]%(b>>>0)|0)|0;if((b|0)>16){break hc}if((b|0)==16){break bc}d=0;ic:{switch((b|0)%3|0){case 0:break bc;case 2:break hc;case 1:break ic;default:break gc}}d=w[(B(h,872)+e|0)+1075798|0]>>>4|0;break gc}d=w[(B(h,872)+e|0)+1075798|0]&15}b=B(h,872)+e|0;c=b+1075764|0;b=b+1075696|0;d=As(e,v[n+36>>2],u[c>>1],v[b>>2])+d|0;c=Kg(e,d,u[c>>1],v[b>>2]);v[n+36>>2]=c;if(d>>>0<109){break bc}v[g+8>>2]=c;Ua=g,Va=Kg(e,109,0,v[b>>2]),v[Ua+4>>2]=Va;Ua=n,Va=v[Pc(g+8|0,g+4|0)>>2],v[Ua+36>>2]=Va;break bc}c=v[e+1074392>>2];p=e+480180|0;f=v[p>>2];jc:{if((f|0)!=1){d=w[(B(h,872)+e|0)+1075789|0];break jc}d=B(h,872)+e|0;d=As(e,v[n+36>>2],u[d+1075764>>1],v[d+1075696>>2]);f=v[p>>2]}kc:{lc:{switch((((f&67633152?c+2|0:c)>>>0)%3|0)-1|0){case 0:d=(w[(B(h,872)+e|0)+1075798|0]>>>4|0)+d|0;break kc;case 1:break lc;default:break kc}}d=(w[(B(h,872)+e|0)+1075798|0]&15)+d|0}if(!(f&67633408|w[(B(h,872)+e|0)+1075789|0]!=(d&255))){rb(g+8|0,b,82);if(!sb(v[v[g+8>>2]>>2],v[g+12>>2])){break bc}}if(w[e+480210|0]&32){c=d&255;if((c|0)==85){v[n+36>>2]=2147483647;break bc}d=c>>>0>85?d-37|0:d}c=B(h,872)+e|0;f=Kg(e,d&255,u[c+1075764>>1],v[c+1075696>>2]);v[n+36>>2]=f;if(v[e+480180>>2]&71860480){v[c+1075692>>2]=f;break bc}rb(g+8|0,b,82);if(!sb(v[v[g+8>>2]>>2],v[g+12>>2])){break bc}t[(B(h,872)+e|0)+1075792|0]=d}ab=g+16|0;if(!(!(w[E|0]&33)|v[n+36>>2]==2147483647)){mc:{if(v[r>>2]==2){c=452;b=3424;break mc}b=B(x[j+1075764>>1]>>>4&15,24);c=x[b+33030>>1]>>>1|0;c=c>>>0>452?c:452;b=x[b+33008>>1]<<1}ce(n+36|0,c,b);ce(s,c,b)}oM(e,a);b=v[m>>2]}nc:{if(!(b&256)|w[F|0]&64){break nc}rb(n+16|0,q,37);if(!sb(v[v[n+16>>2]>>2],v[n+20>>2])){break nc}v[j+1075676>>2]=128}s=N&65535;XK(e,s);oc:{if(!k){break oc}b=iM(e,a,n+36|0);if((b|0)<0|!(w[m+1|0]&2)){break oc}if(!td(i)){break oc}vp(v[i>>2],s,b>>>2&255,1)}pc:{if(w[j+1075782|0]!=8){break pc}qc:{rc:{b=w[j+1075783|0];switch(b-5|0){case 1:break pc;case 0:case 2:break qc;default:break rc}}if((b|0)!=26){break pc}}b=v[r>>2];if((b|0)==4){if(w[F|0]&16){break pc}b=j+1075811|0;t[b|0]=w[b|0]+w[j+1075815|0];break pc}if(!(b&16777248)){break pc}Mk(a,w[j+1075784|0]);WK(e,s,n+36|0,n+44|0)}WK(e,s,n+36|0,n+44|0);sc:{if(!k){break sc}v[n+32>>2]=0;c=n+36|0;p=ab-16|0;ab=p;f=v[a+104>>2];tc:{if(!f|!w[f+40|0]){break tc}M=hj(v[a+656>>2]);k=_i(e);rb(p+8|0,e+1074312|0,21);b=k?38320:37296;g=k?37296:38320;if(!(M|!sb(v[v[p+8>>2]>>2],v[p+12>>2])|v[e+480180>>2]==1048576)){if(!w[f+41|0]){break tc}d=w[a+818|0];v[p+4>>2]=v[a+756>>2]+w[f+39|0];Jh(p+4|0,w[f+40|0]<<8);h=v[p+4>>2];v[a+756>>2]=h;t[a+818|0]=w[a+818|0]+w[f+41|0];h=(h|0)/256|0;uc:{vc:{switch(w[f+38|0]-1|0){case 3:d=UK(sn(e))+-64|0;break uc;case 2:d=64-(d+1>>>1|0)|0;break uc;case 1:d=(d+1>>>1|0)+-64|0;break uc;case 0:d=(d>>>1^-1)&64;break uc;default:break vc}}d=t[d+33600|0]}Jh(c,8388607);f=v[c>>2]<<8;v[c>>2]=f;h=B(d,h);A=(h|0)/64|0;d=A>>31;A=d^d+A;M=A>>>2|0;d=f;wc:{xc:{if((h|0)<=-64){h=f>>31;b=v[(M<<2)+b>>2];b=vc(pia(oia(f,h,b,b>>31),db,65536,0),db)-f|0;g=A&3;if(!g){break wc}k=(g<<2)+(k?37232:37168)|0;break xc}h=f>>31;b=v[g+(M<<2)>>2];b=vc(pia(oia(f,h,b,b>>31),db,65536,0),db)-f|0;g=A&3;if(!g){break wc}k=(g<<2)+(k?37168:37232)|0}g=b;b=v[k>>2];b=(g+vc(pia(oia(b,b>>31,f,h),db,65536,0),db)|0)-f|0}v[c>>2]=(b+d|0)/256;v[n+32>>2]=b&255;break tc}k=v[e+480180>>2]&16777248;d=w[f+39|0];yc:{if(!(k|d)){v[a+756>>2]=w[f+40|0]<<8;break yc}zc:{Ac:{if(k){A=d<<1;h=v[a+756>>2];d=a+756|0;break Ac}if(w[a+89|0]&8){break zc}h=((w[f+40|0]<<8&65280)>>>0)/(d>>>0)|0;A=v[a+756>>2];d=a+756|0}v[d>>2]=h+A}Jh(a+756|0,w[f+40|0]<<8)}d=w[a+818|0]+w[f+41|0]|0;t[a+818|0]=d;d=d<<24>>24;Bc:{Cc:{switch(w[f+38|0]-1|0){case 3:t[a+818|0]=d+1;k=t[(d&63)+33536|0];break Bc;case 2:k=(64-(d>>>1|0)&127)+-64|0;break Bc;case 1:k=((d>>>1|0)- -64&127)+-64|0;break Bc;case 0:k=(d|0)>=0?-64:64;break Bc;default:break Cc}}k=0-t[(d&255)+33600|0]|0;if(v[e+480180>>2]!=1048576){break Bc}k=(64-t[(d+-64&255)+33600|0]|0)/2<<16>>16}d=k;k=B(d,v[a+756>>2]);h=(k|0)/256|0;if(M){z[n+44>>2]=z[n+44>>2]+C(C(C(C(w[f+40|0])*C(.05000000074505806))*C(d|0))*C(.000244140625));t[a+851|0]=w[a+851|0]|64;break tc}if(v[e+480180>>2]!=4){Dc:{if((k|0)<=-256){h=0-h|0;k=0-k>>>16|0;d=(k<<2)+b|0;break Dc}b=g;k=(k|0)/65536|0;d=b+(k<<2)|0}f=v[c>>2];g=v[((k<<2)+b|0)+4>>2];b=v[d>>2];b=((B(g-b|0,(h|0)/4&63)|0)/64|0)+b|0;b=vc(pia(oia(f,f>>31,b,b>>31),db,256,0),db);v[c>>2]=b;v[n+32>>2]=b&255;v[c>>2]=v[c>>2]/256;break tc}v[c>>2]=v[c>>2]+((k|0)/16384|0)}ab=p+16|0;k=v[n+36>>2];if((k|0)<=v[e+480260>>2]){rb(n+16|0,q,81);if(sb(v[v[n+16>>2]>>2],v[n+20>>2])){v[j+1075068>>2]=0}k=v[e+480260>>2];v[n+36>>2]=k}Ec:{if(!hj(v[K>>2])){break Ec}b=j+1075843|0;c=w[b|0];if(!(v[e+1074392>>2]|!(c&32)?c&64:1)){break Ec}oO(a,z[n+44>>2],u[n+42>>1],e);c=b;b=w[b|0];t[c|0]=(b&64?-65:-33)&b}b=n+16|0;xy(b,e,a,k,v[n+32>>2]);c=vb(b);d=oia(v[b>>2],v[b+4>>2],v[e+480240>>2],0);g=db;f=pia(d,g,65536,0);k=db;d=d+65535|0;g=d>>>0<65535?g+1|0:g;d=!g&d>>>0<131071;f=d?1:f;v[b>>2]=f;g=b;b=d?0:k;v[g+4>>2]=b;v[o>>2]=f;v[o+4>>2]=b;if((v[m>>2]&134219264)!=512){break sc}if(!td(i)){break sc}rb(n+8|0,q,99);Fc:{Gc:{if(Ua=sb(v[v[n+8>>2]>>2],v[n+12>>2]),Va=1,Xa=w[m+1|0]&16,Xa?Ua:Va){b=v[r>>2];break Gc}b=v[r>>2];if((b|0)!=2){break Fc}}d=v[m>>2];f=d&2048;Hc:{if(f?(b|0)==2:0){break Hc}b=oia(v[c>>2],0,261625,0)+66904|0;c=db;c=Fc(ria(b,b>>>0<66904?c+1|0:c,133808,0),db);b=1;Ic:{if(f){break Ic}b=0;if(!(d&4096)){break Ic}b=!v[j+1075688>>2]}rb(n+8|0,q,110);if(Ua=sb(v[v[n+8>>2]>>2],v[n+12>>2]),Va=0,Xa=b,Xa?Ua:Va){break Hc}d=v[i>>2];rb(n+8|0,q,95);Sy(d,s,c,b,sb(v[v[n+8>>2]>>2],v[n+12>>2]))}c=v[i>>2];b=oia(B(v[j+1075744>>2],B(v[j+1075740>>2],v[I>>2])),0,63,0)+33554432|0;g=db;g=b>>>0<33554432?g+1|0:g;vp(c,s,Fc((g&67108863)<<6|b>>>26,g>>>26|0)&255,0);b=j+1075676|0;k=b;d=v[b>>2];c=0;b=v[i>>2];f=Rk(b,s);Jc:{if((f|0)==255){break Jc}if(Oj(b)){break Jc}c=Cb(ld(b+318|0,f),10);g=b;f=Ts(f)|192;b=w[c|0]&-49;b=(d|0)<171?b|16:b;b=((d|0)>84?b|32:b)&255;Mg(g,s,f,b);c=(b>>>5&1)+(b<<27>>31)|0}v[k>>2]=(c<<7)+128}Kc:{b=v[K>>2];if(!b|(w[b+60|0]&7)!=1){break Kc}c=v[b+48>>2];b=v[b+52>>2];if(jc(c,b)){break Kc}c=v[VK(a,0)>>2];b=on(b);if(c>>>0<x[b>>1]|w[b+2|0]){break Kc}cj(v[i>>2],s,1);rb(n+8|0,q,109);b=v[m>>2];Ua=m,Va=(sb(v[v[n+8>>2]>>2],v[n+12>>2])?b:b&-4609)|4096,v[Ua>>2]=Va;v[j+1075688>>2]=0;break sc}rb(n+8|0,q,99);if(!sb(v[v[n+8>>2]>>2],v[n+12>>2])|!(w[m+1|0]&16)|v[j+1075688>>2]){break sc}cj(v[i>>2],s,1);v[m>>2]=v[m>>2]&-513}Lc:{if(!G){break Lc}rb(n+16|0,q,31);if(sb(v[v[n+16>>2]>>2],v[n+20>>2])){break Lc}Fs(e,a)}c=v[m>>2];b=c&-65537;s=j+1075012|0;h=v[H>>2];A=j+1075016|0;c=v[s>>2]|(h|v[A>>2])?(b|c<<7&65536)^65536:b;v[m>>2]=c;H=j+1075664|0;b=H;v[b>>2]=0;v[b+4>>2]=0;g=j+1075834|0;b=w[g|0];d=b-4|0;k=b>>>0<d>>>0?0:d;t[g|0]=k;p=j+1075835|0;b=w[p|0];d=b-4|0;b=b>>>0<d>>>0?0:d;t[p|0]=b;Mc:{Nc:{Oc:{Pc:{Qc:{Rc:{Sc:{Tc:{Uc:{d=v[j+1075096>>2];Vc:{if(!d){break Vc}if(!Fd(d)|!v[j+1075068>>2]){break Vc}if(gi(v[o>>2],v[o+4>>2])){break Uc}}v[j+1075008>>2]=0;break Tc}d=v[d+20>>2];v[j+1075008>>2]=d;if(d){break Sc}}if(!Kj(v[K>>2])){break Rc}d=0;if(c&6144){break Rc}}G=v[j+1075676>>2];f=(B(h,256-G|0)|0)/16384|0;f=f>>>0<127?f:127;if(k<<24>>24<0){t[g|0]=f;k=f}f=f>>>1|0;if((k&255)>>>0<f>>>0){t[g|0]=f}f=(B(h,G)|0)/16384|0;f=f>>>0<127?f:127;k=f>>>1|0;if(b<<24>>24<0){t[p|0]=f;b=f}if((b&255)>>>0<k>>>0){break Qc}break Pc}if((k&255)>>>0>=129){t[g|0]=0}d=0;k=0;if((b&255)>>>0<129){break Oc}}t[p|0]=k}if(!d){break Oc}c=128;if(y[e+24624>>2]>=2){c=Sb(v[j+1075676>>2],0,256)}v[n+16>>2]=c;b=B(h,l)>>>(zd(w[Q|0])?7:8)|0;Wc:{Xc:{Yc:{switch(w[V|0]){case 0:if(!(w[e+24616|0]&16)){break Xc}case 1:if((c|0)<=127){d=b>>>1|0;b=(B(b,c)|0)/256|0;break Wc}d=(B(b,256-c|0)|0)/256|0;b=b>>>1|0;break Wc;case 3:break Yc;default:break Xc}}Jh(n+16|0,255);c=v[n+16>>2];if((c|0)<=0){d=65536}else{d=x[(0-c<<1)+39856>>1]}d=B(d,b)>>>16|0;b=B(b,x[(c<<1)+39344>>1])>>>16|0;break Wc}d=(B(b,256-c|0)|0)/256|0;b=(B(b,c)|0)/256|0}c=v[K>>2];Zc:{if(c){k=w[c+14|0];if(bo(k)){break Zc}}k=w[e+480268|0];if(bo(k)){break Zc}if(w[E|0]&128){k=255;if(v[e+24668>>2]){break Zc}}k=w[e+24648|0]}f=j+1075668|0;h=j+1075786|0;t[h|0]=k;g=v[m>>2];c=v[o>>2];p=v[o+4>>2];if(!(g&131072|((c|0)!=0|(p|0)!=1)|(v[j+1075748>>2]|(k&255)==255))){t[h|0]=0}k=d;d=1<<v[X>>2];v[H>>2]=(k|0)/(d|0);b=(b|0)/(d|0)|0;v[f>>2]=b;if(!(!(g&256)|v[e+24624>>2]!=2)){v[f>>2]=0-b}if(g&128){v[o>>2]=0-c;v[o+4>>2]=0-(((c|0)!=0)+p|0)}h=0;g=ab-16|0;ab=g;v[a+28>>2]=0;v[a+32>>2]=0;Jh(a+672|0,524287);Jh(a+676|0,524287);d=a;d=a;_c:{$c:{c=v[a+88>>2];if(!(c&65536)){a=v[d+676>>2];b=v[d+672>>2];break $c}b=v[d+20>>2];f=v[d+672>>2];ad:{if((b|0)!=(f|0)){a=v[d+24>>2];k=v[d+676>>2];break ad}a=v[d+24>>2];k=v[d+676>>2];if((a|0)==(k|0)){break $c}}c=v[e+24620>>2];f=(b|0)<(f|0)|(a|0)<(k|0);bd:{if(f){b=Ys(c,v[e+24636>>2]);break bd}b=Ys(c,v[e+24640>>2])}rb(g,e+1074312|0,4);if(!(!sb(v[v[g>>2]>>2],v[g+4>>2])|!(v[e+480180>>2]&4))){a=v[e+24620>>2];a=oia(a,a>>31,5,0)+500|0;c=db;b=vc(pia(a,a>>>0<500?c+1|0:c,1e3,0),db)}c=v[d+656>>2];cd:{if(!c){a=b;break cd}a=b;if(!f){break cd}c=x[c+12>>1];if(c){a=(B(c,v[e+24620>>2])>>>0)/1e5|0}h=(c|0)!=0}f=a?a:1;c=v[d+676>>2];a=v[d+24>>2];p=c-a<<12;k=v[d+672>>2];s=v[d+20>>2];o=k-s<<12;if(!(w[d+90|0]&32|(!(c|k)|(!(a|s)|h)))){v[g+12>>2]=v[e+1074380>>2];ce(g+12|0,b,2048);k=v[d+672>>2];f=v[g+12>>2];c=v[d+676>>2]}h=(p|0)/(f|0)|0;v[d+32>>2]=h;p=(o|0)/(f|0)|0;v[d+28>>2]=p;a=((B(f,h)|0)/-4096|0)+c|0;v[d+24>>2]=a;b=((B(f,p)|0)/-4096|0)+k|0;v[d+20>>2]=b;if(h|p){v[d+100>>2]=f;c=v[d+88>>2];break _c}v[d+24>>2]=c;v[d+20>>2]=k;a=c;b=k;c=v[d+88>>2]&-65537;break _c}v[d+24>>2]=a;v[d+20>>2]=b;c=c&-65537}v[d+88>>2]=c&-2097153;v[d+40>>2]=a<<12;v[d+36>>2]=b<<12;ab=g+16|0;c=v[m>>2];if(!(c&512)){break Nc}break Mc}v[s>>2]=0;v[A>>2]=0;v[j+1075068>>2]=0;if(v[j+1075088>>2]){break Nc}if(!v[j+1075084>>2]){break Mc}}a=x[e+480212>>1];u[e+480212>>1]=a+1;u[((a<<1)+e|0)+1074478>>1]=N}v[j+1075660>>2]=c}N=N+1|0;continue}break}k=1}ab=n+48|0;if(k){b=v[e+480208>>2];break h}if(zd(w[Ha|0])){a=v[e+480208>>2]|512;break i}l=0;dd:{a=v[e+24620>>2]/10|0;b=vc(a,a>>31);if(!b){break dd}c=b>>>0<1048576?b:1048576;v[e+1074380>>2]=c;f=x[e+480212>>1];d=e+1074376|0;while(1){if((f|0)==(l|0)){break dd}a=d+B(x[(d+(l<<1)|0)+102>>1],872)|0;k=a+1288|0;v[k>>2]=0;v[k+4>>2]=0;v[a+716>>2]=c;k=v[a+640>>2]<<12;v[a+656>>2]=k;g=v[a+636>>2]<<12;v[a+652>>2]=g;v[a+704>>2]=v[a+704>>2]|65536;v[a+644>>2]=(0-g|0)/(c|0);v[a+648>>2]=(0-k|0)/(c|0);l=l+1|0;continue}}c=v[e+480208>>2];a=c|256;if(b){break i}a=c|512}b=a;v[e+480208>>2]=b}if(!(b&512)){break g}Ua=e+1074392|0,Va=Nk(Ga),v[Ua>>2]=Va}ab=T+112|0;break f}v[T+96>>2]=512;a=v[e+1074380>>2];v[T+104>>2]=ha;v[T+100>>2]=a;j=au(T+96|0);if(v[e+24632>>2]){b=0;a=ab-48|0;ab=a;c=j<<2;while(1){if((b|0)==4){ed:{b=0;while(1){if((b|0)==4){break ed}v[(a+32|0)+(b<<2)>>2]=((b<<11)+e|0)+16396;b=b+1|0;continue}}}else{v[a+32>>2]=0;d=((b<<11)+e|0)+16396|0;Bz(d,c+d|0,a+32|0);b=b+1|0;continue}break}b=ag(a+16|0,a+32|0,v[e+24632>>2],j);c=v[v[fa>>2]+8>>2];v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;eb[c|0](fa,a);ab=a+48|0}if(RK(sa)){b=0;while(1){if((b|0)==4){b=v[sa>>2];a=ag(T+80|0,T+96|0,v[e+24632>>2],j);c=v[v[b>>2]+8>>2];v[T+40>>2]=v[a+8>>2];d=v[a+4>>2];v[T+32>>2]=v[a>>2];v[T+36>>2]=d;eb[c|0](b,T+32|0)}else{v[(T+96|0)+(b<<2)>>2]=((b<<11)+e|0)+16396;b=b+1|0;continue}break}}ia=0;F=ab-48|0;ab=F;if(j){i=e+12|0;o=e+24592|0;r=e+24588|0;ym(i,j,o,r);if(y[e+24624>>2]>=3){ym(e+8204|0,j,e+24600|0,e+24596|0)}u[F+42>>1]=0;xa=e+1074312|0;Ja=e+24648|0;A=e+24596|0;N=e+24600|0;K=e+8204|0;H=e+397452|0;G=e+397448|0;s=e+393352|0;ya=e+397456|0;na=e+1074376|0;Ka=e+480190|0;while(1){if(x[e+480212>>1]<=ia>>>0){Ua=e,Va=x[Ne(e+480214|0,F+42|0)>>1],u[Ua+480214>>1]=Va}else{l=(ia<<1)+na|0;a=B(x[l+102>>1],872);h=a+na|0;Q=h;fd:{gd:{if(v[h+632>>2]){break gd}b=a+e|0;if(v[b+1075088>>2]){break gd}if(!v[b+1075084>>2]){break fd}}g=a+e|0;a=w[g+1075786|0]+1|0;if((a&255)>>>0<=5){k=v[(a<<24>>24<<2)+27776>>2]}else{k=0}I=g+1075080|0;f=v[I>>2];hd:{if(!(!(f&16777216)&w[e+24612|0]>>>5)){b=o;a=r;c=f;d=i;if(!(c&8388608)){break hd}}b=G;a=H;if(!w[ya+12|0]){ym(s,j,b,a)}t[ya+12|0]=1;c=v[I>>2];d=s}if(!(!(c&256)|y[e+24624>>2]<3)){d=K;b=N;a=A}oa=ml(e,na,x[l+102>>1],2,1);za=(oa-1&255)>>>0>249;id:{if(za){break id}l=v[(B(oa,160)+e|0)+906140>>2];if(!l){break id}c=v[l+24>>2];if(!c){break id}a=l+36|0;b=l+40|0;if(!(t[l+28|0]&1)){ym(c,j,b,a);v[l+28>>2]=v[l+28>>2]|1}d=c}m=h+616|0;if(w[g+1075843|0]&8){TC(m,d,j);c=b;d=v[b>>2];b=g+1075084|0;v[c>>2]=d+v[b>>2];v[a>>2]=v[a>>2]+v[g+1075088>>2];v[b>>2]=0;v[b+4>>2]=0;break fd}V=0;l=ab-16|0;ab=l;ja=F+16|0;c=ja;v[c>>2]=0;v[c+4>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;h=l+8|0;n=e+1074312|0;rb(h,n,33);Ua=c,Va=sb(v[v[l+8>>2]>>2],v[l+12>>2]),t[Ua+16|0]=Va;rb(h,n,116);Ua=c,Va=sb(v[v[l+8>>2]>>2],v[l+12>>2])^1,t[Ua+17|0]=Va;if(v[m+16>>2]){SC(ja,m);h=v[m+12>>2];n=h;c=h>>31;h=c+v[m+8>>2]|0;p=c+n|0;p=h>>>0<c>>>0?p+1|0:p;c=c^p;v[ja+12>>2]=c>>>0>8191?2:16384/(c+1>>>0)|0}La=f>>>12&8|(f>>>5&2|(k|f&1));Ma=g+1075795|0;Na=g+1075778|0;Oa=g+1075688|0;Pa=g+1075024|0;Qa=g+1075020|0;Ra=g+1075668|0;Sa=g+1075664|0;X=g+1075088|0;Y=g+1075084|0;Aa=g+1075016|0;Ba=g+1075012|0;ka=g+1075096|0;_=g+1075076|0;R=g+1075068|0;M=g+1075e3|0;la=g+1075072|0;ba=g+1075092|0;ab=l+16|0;k=j;while(1){jd:{c=v[ba>>2];ma=c?c>>>0<k>>>0?c:k:k;v[F+8>>2]=ma;kd:{ld:{if(!ma){break ld}f=v[M>>2];h=v[M+4>>2];if(!(f|h)){break ld}q=v[R>>2];if(!q){break ld}c=v[F+16>>2];if(!c){break ld}E=v[I>>2];p=v[la>>2];v[Q+632>>2]=c;c=v[m+4>>2];l=c;g=v[m>>2];md:{nd:{n=p&E<<30>>31;if((n|0)>(c|0)){if((h|0)<0){g=yg(0,n<<1,g,l);c=db;l=c;v[m>>2]=g;v[m+4>>2]=c;if(!(c>>>0<n+q>>>1>>>0&(c|0)>=(n|0))){g=0;v[m>>2]=g;l=n;v[m+4>>2]=n}od:{if(E&4){E=E&-129;v[I>>2]=E;h=0-(((f|0)!=0)+h|0)|0;f=0-f|0;v[M>>2]=f;v[M+4>>2]=h;break od}c=q-1|0;l=c;v[m>>2]=g;v[m+4>>2]=c}if(!(E&2)){break ld}if(l>>>0<q>>>0){break md}break ld}if((l|0)>0|(l|0)>=0){break md}l=0;break nd}if(c>>>0<q>>>0){break md}if(!(E&2)){break ld}if(E&4){if(!!f&(h|0)>=0|(h|0)>0){h=0-(((f|0)!=0)+h|0)|0;f=0-f|0;v[M>>2]=f;v[M+4>>2]=h}v[I>>2]=E|128;if(w[F+33|0]){E=w[F+32|0];Z=v[_>>2]-(E+p|0)|0;g=yg(g,l,0,q);c=db;l=c;if(c>>>0<Z>>>0){g=yg(0,q-E|0,g,l);l=db;break nd}g=0;l=p;break nd}l=c;c=1-((g|0)!=0)|0;g=0-g|0;c=(q<<1)-(l+c|0)|0;E=g;v[m>>2]=g;Z=0;l=Z|c;v[m+4>>2]=l;if(c>>>0<q>>>0&c>>>0>p>>>0){break md}v[F+44>>2]=w[F+32|0]+1;g=E;l=Z|q-v[zb(R,F+44|0)>>2];break nd}if((h|0)<0){h=0-(((f|0)!=0)+h|0)|0;f=0-f|0;v[M>>2]=f;v[M+4>>2]=h}Lb(m,0,n-q|0);v[I>>2]=v[I>>2]|8192;g=v[m>>2];l=v[m+4>>2];break md}v[m>>2]=g;v[m+4>>2]=l}E=l;pd:{if((l|0)<(n|0)){if((l|0)<0){break ld}if((h|0)>0|(h|0)>=0){break pd}break ld}if((l|0)<0){break ld}}if(y[R>>2]<=E>>>0){break ld}v[F+44>>2]=ma;mc(F+8|0,v[F+28>>2]);c=h>>31;da=c;p=c+f|0;q=c;c=c+h|0;c=p>>>0<q>>>0?c+1|0:c;Ta=p;ea=v[la>>2];Ca=ea+16|0;Da=v[F+8>>2];Z=Tu(f,h,Da-1|0)+g|0;p=l+db|0;p=g>>>0>Z>>>0?p+1|0:p;ea=E>>>0<ea>>>0;if(!(!ea&E>>>0<Ca>>>0)){v[I>>2]=v[I>>2]&-8193}Z=da^Ta;da=c^q;q=p;qd:{rd:{p=v[F+20>>2];sd:{if(p){c=v[F+24>>2];if(c>>>0<=E>>>0){td:{if((h|0)<0){f=0;h=c;break td}f=g;h=l;g=0;l=v[_>>2]}Ua=F,Va=ko(yg(yg(g,l,f,h),db,1,0),db,Z,da)+1|0,v[Ua+44>>2]=Va;v[Q+632>>2]=p;break qd}if(!(ea|!(w[I+1|0]&32)|E>>>0>=Ca>>>0)){Ua=F,Va=ko(yg(yg(0,n+16|0,g,l),db,1,0),db,Z,da)+1|0,v[Ua+44>>2]=Va;Ua=Q,Va=p+B(v[_>>2]-n|0,hk(x[v[ka>>2]+34>>1]))|0,v[Ua+632>>2]=Va;break qd}if(!f&(h|0)<=0|(h|0)<0){break sd}if(ma>>>0<2|c>>>0>q>>>0){break rd}Ua=F,Va=ko(yg(yg(0,c,g,l),db,1,0),db,Z,da)+1|0,v[Ua+44>>2]=Va;break qd}if((h|0)>0|(h|0)>=0){break rd}}if((n|0)<=(q|0)){break qd}Ua=F,Va=ko(yg(yg(g,l,0,n),db,1,0),db,Z,da)+1|0,v[Ua+44>>2]=Va;break qd}c=v[R>>2];if((c|0)>(q|0)){break qd}Ua=F,Va=ko(yg(yg(0,c,g,l),db,1,0),db,Z,da)+1|0,v[Ua+44>>2]=Va}jo(F+44|0,1,Da);f=v[F+44>>2];if((f|0)>0){break kd}}v[Q+632>>2]=0;v[R>>2]=0;v[m>>2]=0;v[m+4>>2]=0;v[ba>>2]=0;TC(m,d,k);v[b>>2]=v[b>>2]+v[Y>>2];v[a>>2]=v[a>>2]+v[X>>2];v[X>>2]=0;v[Y>>2]=0;v[I>>2]=v[I>>2]&-129;E=x[F+42>>1];break jd}ud:{vd:{E=x[F+42>>1];if(E>>>0<y[e+24608>>2]){V=4;if(v[ba>>2]){break vd}V=0;if(v[Aa>>2]|v[Ba>>2]){break vd}}Lb(m,oia(v[M>>2],v[M+4>>2],f,f>>31),db);V=0;v[X>>2]=0;v[Y>>2]=0;c=(f<<3)+d|0;break ud}c=(f<<3)+d|0;g=c-8|0;v[Y>>2]=0-v[g>>2];l=c-4|0;v[X>>2]=0-v[l>>2];eb[v[((V|La)<<2)+27392>>2]](m,Ja,d,f);v[Y>>2]=v[Y>>2]+v[g>>2];v[X>>2]=v[X>>2]+v[l>>2];V=1}d=c;c=v[ba>>2];wd:{if(!c){break wd}if(c>>>0<=f>>>0){v[ba>>2]=0;v[Ba>>2]=v[Sa>>2];v[Aa>>2]=v[Ra>>2];v[Qa>>2]=0;v[Pa>>2]=0;if(v[Oa>>2]|!(w[I+1|0]&16)){break wd}v[R>>2]=0;v[Q+632>>2]=0;break wd}v[ba>>2]=c-f}g=0;c=0;l=v[m+4>>2];c=l>>>0>=y[_>>2]?(w[I|0]&2)>>>1|0:c;h=l;l=v[R>>2];g=h>>>0<l>>>0|(!l|w[I|0]&2)?g:!x[Na>>1];k=k-f|0;rb(F+8|0,xa,85);xd:{yd:{zd:{Ad:{if(!sb(v[v[F+8>>2]>>2],v[F+12>>2])){break Ad}f=w[Ma|0];if(!f|f>>>0>x[Ka>>1]){break Ad}h=!(c|g);f=B(f,104)+e|0;g=f+484380|0;l=v[ka>>2];if(h|(g|0)==(l|0)){break zd}v[ka>>2]=g;v[Q+632>>2]=v[f+484400>>2];c=x[f+484414>>1];v[I>>2]=c|v[I>>2]&-768;l=c<<30>>31;c=v[f+484388>>2];v[R>>2]=l&c;f=v[f+484384>>2];v[la>>2]=f;v[_>>2]=c;v[m+4>>2]=f;SC(ja,m);if(!v[Q+632>>2]){break jd}if((k|0)>0){continue}break jd}if(c){break yd}break xd}if(!c|(g|0)!=(l|0)){break xd}}rb(F+8|0,xa,83);if(!sb(v[v[F+8>>2]>>2],v[F+12>>2])|v[la>>2]){break xd}v[m>>2]=v[m>>2];v[m+4>>2]=0;c=v[v[ka>>2]+8>>2];v[R>>2]=c;v[_>>2]=c}if((k|0)>0){continue}}break}v[Q+632>>2]=v[F+16>>2];u[F+42>>1]=E+V;if(za|!V){break fd}a=v[(B(oa,160)+e|0)+906140>>2];if(!a){break fd}eb[v[v[a>>2]+148>>2]](a)}ia=ia+1|0;continue}break}}ab=F+48|0;if(td(wa)){a=aa;b=j;c=(B(v[e+480232>>2],v[e+480236>>2])>>>0)/48|0;h=ab-16|0;ab=h;Bd:{o=v[wa>>2];if(!w[o+534|0]){break Bd}f=oia(c,0,6169,0);d=db;c=d>>>16|0;s=Fc((d&65535)<<16|f>>>16,c);while(1){if(!b){break Bd}g=v[o>>2];n=v[g>>2];d=v[g+4>>2];while(1){if((d|0)>=(n|0)){v[g+8>>2]=v[g+12>>2];n=0;f=0;l=0;c=ab-16|0;ab=c;while(1){if((l|0)==18){d=(n|0)<32767?n:32767;u[g+12>>1]=(d|0)>-32768?d:-32768;d=(f|0)<32767?f:32767;u[g+14>>1]=(d|0)>-32768?d:-32768;u[g+3832>>1]=x[g+3832>>1]+1;d=(x[g+3834>>1]+1>>>0)%13440|0;u[g+3834>>1]=d;d=d>>>0<6720?d:13440-d|0;u[g+3836>>1]=(d&65280)>>>8;if(!w[g+3843|0]){u[g+3836>>1]=(d&64512)>>>10}d=x[g+3838>>1]+1|0;u[g+3838>>1]=d;if((d&65535)>>>0>=1024){u[g+3838>>1]=0;u[g+3840>>1]=x[g+3840>>1]+1&7}ab=c+16|0}else{k=g+B(l,44)|0;Cd:{if(!w[k+56|0]){u[c+12>>1]=0;u[c+14>>1]=0;break Cd}m=v[k+32>>2];d=x[m+3840>>1];if(d&3){m=(x[k+36>>1]>>>7&7)>>>(w[m+3844|0]^1)>>>(d&1)<<x[k+38>>1];d=d&4?0-m|0:m}else{d=0}m=v[k+52>>2];Dd:{if(m){r=x[m+32>>1];i=x[k+48>>1];m=Tf(v[k+16>>2],v[k+40>>2],d<<16>>16,0,u[k+46>>1]);q=v[k+40>>2];p=v[k+20>>2];if(!r){if(!i){d=d<<16>>16;m=Tf(p,q,d,m,0);m=Tf(v[k+24>>2],v[k+40>>2],d,m,0);d=Tf(v[k+28>>2],v[k+40>>2],d,m,0);break Dd}d=d<<16>>16;q=Tf(p,q,d,0,0);q=Tf(v[k+24>>2],v[k+40>>2],d,q,0);d=Tf(v[k+28>>2],v[k+40>>2],d,q,0)+m|0;break Dd}if(!i){d=d<<16>>16;m=Tf(p,q,d,m,0);q=Tf(v[k+24>>2],v[k+40>>2],d,0,0);d=Tf(v[k+28>>2],v[k+40>>2],d,q,0)+m|0;break Dd}d=d<<16>>16;q=Tf(p,q,d,0,0);d=(Tf(v[k+24>>2],v[k+40>>2],d,q,0)+m|0)+Tf(v[k+28>>2],v[k+40>>2],d,0,0)|0;break Dd}i=x[k+48>>1];d=d<<16>>16;m=Tf(v[k+16>>2],v[k+40>>2],d,0,u[k+46>>1]);q=v[k+40>>2];p=v[k+20>>2];if(!i){d=Tf(p,q,d,m,0);break Dd}d=Tf(p,q,d,0,0)+m|0}u[c+14>>1]=w[k+57|0]?d:0;u[c+12>>1]=w[k+58|0]?d:0}l=l+1|0;f=u[c+12>>1]+f|0;n=u[c+14>>1]+n|0;continue}break}n=v[g>>2];d=v[g+4>>2]-n|0;v[g+4>>2]=d;continue}break}c=n-d|0;u[h+14>>1]=(B(u[g+12>>1],d)+B(c,u[g+8>>1])|0)/(n|0);u[h+12>>1]=(B(u[g+14>>1],d)+B(c,u[g+10>>1])|0)/(n|0);v[g+4>>2]=d+49716;v[a>>2]=v[a>>2]+B(s,u[h+14>>1]);v[a+4>>2]=v[a+4>>2]+B(s,u[h+12>>1]);a=a+8|0;b=b-1|0;continue}}ab=h+16|0}Ed:{if(!w[J+12|0]){if(!v[J+16>>2]){break Ed}ym(ca,j,va,ua)}a=v[J>>2];b=v[J+80>>2];c=B(a,b)>>>4|0;c=c>>>0<32767?c:32767;u[J+98>>1]=c;u[J+96>>1]=c;c=v[J+49948>>2];d=B(c,a)>>>4|0;d=d>>>0<65536?d:65536;f=d+127>>>3|0;u[J+49946>>1]=f;d=d+255>>>4|0;u[J+49944>>1]=d;u[J+49942>>1]=d;u[J+49940>>1]=f;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0>8?a:8)|0;a=16-(B((b|0)<32768?b:32768,a>>>0>16?0:a)>>15)|0;b=0;while(1){if((b|0)!=(j|0)){c=b<<3;d=c+aa|0;v[d>>2]=v[d>>2]+B(a,v[c+ca>>2]>>4);c=c|4;d=c+aa|0;v[d>>2]=v[d>>2]+B(a,v[c+ca>>2]>>4);b=b+1|0;continue}break}q=J+68|0;b=0;f=u[J+84>>1];a=v[J+40>>2];d=v[J+36>>2];while(1){if((b|0)==(j|0)){v[J+40>>2]=a;v[J+36>>2]=d;d=j}else{c=ca+(b<<3)|0;k=v[c>>2]>>12;d=(B(f,k-d|0)>>15)+k|0;v[c>>2]=d;l=c;c=v[c+4>>2]>>12;a=(B(f,c-a|0)>>15)+c|0;v[l+4>>2]=a;b=b+1|0;continue}break}if(d){b=ca;a=d;n=v[q>>2]-1|0;c=x[q+22>>1];k=u[q+26>>1];s=u[q+18>>1];h=x[q+20>>1];g=u[q+24>>1];i=u[q+16>>1];f=v[q+4>>2];l=q+32928|0;while(1){if(a){m=Sc(v[b>>2]);p=Sc(v[b+4>>2]);h=Sc((h<<16>>16)-m|0);c=Sc((c<<16>>16)-p|0);h=Jc(Sc((B(h,i)|0)/65536<<1)+m|0);c=Jc(Sc((B(c,s)|0)/65536<<1)+p|0);p=l+(f<<2)|0;o=u[p>>1];m=Jc(((B(o,g)|0)/-65536|0)+h|0);f=f+1&127;r=l+(f<<2)|0;p=u[p+2>>1];A=Jc(((B(p,k)|0)/-65536|0)+c|0);u[r+2>>1]=A;u[r>>1]=m;n=n+1&8191;r=q+(n<<2)|0;Ua=r,Va=Jc(o+((B(g,m)|0)/65536|0)|0),u[Ua+160>>1]=Va;Ua=r,Va=Jc(p+((B(k,A)|0)/65536|0)|0),u[Ua+162>>1]=Va;b=b+8|0;a=a-1|0;continue}break}u[q+22>>1]=c;u[q+20>>1]=h;v[q+4>>2]=f}g=J+49892|0;A=J+33508|0;a=d;b=ca;while(1){if(a){f=v[J+76>>2];k=f&4095;h=A+(k<<2)|0;c=b;k=4096-k|0;r=f-v[J+49892>>2]&4095;f=4096-r|0;f=f>>>0>k>>>0?k:f;f=a>>>0>f>>>0?f:a;k=f>>>0<64?f:64;n=k;f=0;p=ab-32|0;ab=p;l=v[q>>2];while(1){if((f|0)==7){Fd:{i=u[q+28>>1]/8<<16>>16;Gd:while(1){if(!n){break Fd}n=n-1|0;f=0;m=0;l=0;while(1)if((f|0)==4){f=4;E=0;o=Jc((l|0)/32768|0);N=Jc((m|0)/32768|0);m=0;while(1)if((f|0)==7){f=Jc(o+((m|0)/32768|0)|0);u[h>>1]=f;v[c>>2]=B(f,i);f=Jc(N+((E|0)/32768|0)|0);u[h+2>>1]=f;v[c+4>>2]=B(f,i);c=c+8|0;h=h+4|0;continue Gd}else{l=p+(f<<2)|0;s=v[l>>2]+1&8191;v[l>>2]=s;s=q+(s<<2)|0;K=u[s+160>>1];l=q+(f<<4)|0;s=u[s+162>>1];E=(B(K,u[l+44>>1])+E|0)+B(s,u[l+46>>1])|0;m=(B(K,u[l+40>>1])+m|0)+B(s,u[l+42>>1])|0;f=f+1|0;continue}}else{s=p+(f<<2)|0;o=v[s>>2]+1&8191;v[s>>2]=o;E=m;m=q+(o<<2)|0;o=u[m+160>>1];s=q+(f<<4)|0;N=u[m+162>>1];m=(E+B(o,u[s+44>>1])|0)+B(N,u[s+46>>1])|0;l=(B(o,u[s+40>>1])+l|0)+B(N,u[s+42>>1])|0;f=f+1|0;continue}}}}else{v[p+(f<<2)>>2]=l+(v[(q+(f<<4)|0)+32>>2]^-1);f=f+1|0;continue}break}ab=p+32|0;h=A+(r<<2)|0;c=b;f=k;m=v[g+4>>2];l=g+8256|0;n=g- -64|0;p=g+24640|0;s=g+16448|0;while(1){i=m&2047;if(f){N=u[l+((m+1206&2047)<<2)>>1];K=u[(l+((m+754&2047)<<2)|0)+2>>1];r=u[(n+((m+1602&2047)<<2)|0)+2>>1];H=u[n+((m+1750&2047)<<2)>>1];o=u[h>>1];E=u[h+2>>1];G=p+((m+502&2047)<<2)|0;F=u[G>>1];I=Sc(u[g+32>>1]-F|0);G=u[G+2>>1];M=Sc(u[g+34>>1]-G|0);R=u[g+26>>1];Q=p+((m+22&2047)<<2)|0;V=u[Q>>1];X=Sc(u[g+36>>1]-V|0);Y=u[g+28>>1];Q=u[Q+2>>1];_=Sc(u[g+38>>1]-Q|0);ba=u[g+30>>1];F=Jc(Sc((B(I,u[g+24>>1])|0)/65536<<1)+F|0);u[g+32>>1]=F;Ua=g,Va=Jc(Sc((B(M,R)|0)/65536<<1)+G|0),u[Ua+34>>1]=Va;Ua=g,Va=Jc(Sc((B(X,Y)|0)/65536<<1)+V|0),u[Ua+36>>1]=Va;G=Jc(Sc((B(_,ba)|0)/65536<<1)+Q|0);u[g+38>>1]=G;F=Sc((B(F,u[g+16>>1])|0)/32768|0);I=Sc((B(G,u[g+22>>1])|0)/32768|0);G=Sc(F+((o|0)/4<<16>>16)|0);E=Sc(I+((E|0)/4<<16>>16)|0);F=u[g+8>>1];I=Sc(G+((B(F,H)|0)/-65536|0)|0);o=i<<2;R=o+n|0;M=u[g+10>>1];Q=Sc(E+((B(M,r)|0)/-65536|0)|0);u[R+2>>1]=Q;u[R>>1]=I;H=Sc(H+((B(F,I)|0)/65536|0)|0);I=o+s|0;r=Sc(r+((B(M,Q)|0)/65536|0)|0);u[I+2>>1]=r;u[I>>1]=H;H=Sc(G+H|0);G=Sc(r+E|0);r=s+((m+682&2047)<<2)|0;E=u[r+2>>1];I=u[r>>1];r=Sc((B(E,u[g+42>>1])+B(I,u[g+40>>1])|0)/32768|0);m=s+((m+426&2047)<<2)|0;R=u[m+2>>1];Q=u[m>>1];m=Sc((B(R,u[g+46>>1])+B(Q,u[g+44>>1])|0)/32768|0);I=Sc(Sc(H+I|0)-r|0);E=Sc(Sc(E+G|0)-m|0);H=Sc(Sc(H+Q|0)-r|0);G=Sc(Sc(G+R|0)-m|0);r=Sc(r+((B(F,N)|0)/-65536|0)|0);F=u[g+8>>1];R=u[g+10>>1];Q=l+o|0;M=Sc(m+((B(K,M)|0)/-65536|0)|0);u[Q+2>>1]=M;u[Q>>1]=r;r=(B(r,F)|0)/65536|0;m=Sc(r+N|0);o=o+p|0;N=(B(M,R)|0)/65536|0;K=Sc(N+K|0);u[o+2>>1]=K;u[o>>1]=m;Ua=c,Va=(v[c>>2]+B(Sc(m+I|0),u[g+48>>1])|0)+B(Sc(E+K|0),u[g+50>>1])|0,v[Ua>>2]=Va;Ua=c,Va=(v[c+4>>2]+B(Sc(Sc(r)+H|0),u[g+52>>1])|0)+B(Sc(Sc(N)+G|0),u[g+54>>1])|0,v[Ua+4>>2]=Va;c=c+8|0;m=i+1|0;h=h+4|0;f=f-1|0;continue}break}v[g+4>>2]=i;v[J+76>>2]=k+v[J+76>>2]&4095;v[J+68>>2]=k+v[J+68>>2]&8191;a=a-k|0;b=(k<<3)+b|0;continue}break}v[J+68>>2]=v[J+68>>2]&8191;h=ca;c=aa;f=d;b=0;a=0;n=v[J+56>>2];l=v[J- -64>>2];m=v[J+52>>2];k=v[J+60>>2];while(1){if(f){b=v[h>>2];a=v[h+4>>2];g=l-a|0;g=(((g|0)/1024|0)-g|0)+n|0;v[c+4>>2]=g+v[c+4>>2];k=k-b|0;k=(((k|0)/1024|0)-k|0)+m|0;v[c>>2]=k+v[c>>2];n=g+((g|0)/-512|0)|0;m=k+((k|0)/-512|0)|0;c=c+8|0;h=h+8|0;f=f-1|0;k=b;l=a;continue}break}v[J+64>>2]=a;v[J+60>>2]=b;v[J+56>>2]=n;v[J+52>>2]=m;Hd:{if(w[J+12|0]){v[J+16>>2]=v[J+20>>2];break Hd}a=v[J+16>>2];if(a>>>0>d>>>0){v[J+16>>2]=a-d;break Hd}hJ(J,va,ua);v[J+16>>2]=0}t[J+12|0]=0}if(v[e+946300>>2]){Id:{f=0;h=0;d=j<<2;p=x[e+480214>>1]!=0;Ea=z[e+1074336>>2];W=z[e+1074332>>2];while(1)if((f|0)==250){k=e+12|0;m=e+12300|0;n=e+14348|0;Ru(k,m,n,j,W);a=e+1074476|0;r=w[a|0];t[a|0]=0;b=n;a=m;while(1){Jd:{Kd:{Ld:{if((h|0)!=250){q=(B(h,160)+e|0)+906300|0;g=v[q>>2];if(!g|!v[g+24>>2]){break Jd}c=g+44|0;if(!Ih(c)){break Jd}l=g;Md:{if(Qu(q)){break Md}d=eb[v[v[g>>2]+144>>2]](g)|0;l=v[q>>2];if(d){break Md}f=0;if(w[l+28|0]&2){break Md}while(1){if((f|0)==(h|0)){break Jd}d=B(f,160);f=f+1|0;if((vm((e+d|0)+906300|0)|0)!=(h|0)){continue}break}}s=Gd(c,0);o=Gd(c,1);i=(a|0)==(s|0);a=i?m:a;c=a;b=i?n:b;d=b;Nd:{if(!(w[q+28|0]|w[q+29|0]<<8|(w[q+30|0]<<16|w[q+31|0]<<24))){break Nd}c=a;f=vm(q);d=b;if(f>>>0<=h>>>0){break Nd}d=b;if(f>>>0>249){break Nd}f=v[(B(f,160)+e|0)+906300>>2];d=b;if(!f){break Nd}if(!(w[l+28|0]&4)){eb[v[v[f>>2]+148>>2]](f)}f=f+44|0;d=b;if(!Ih(f)){break Nd}c=Gd(f,0);d=Gd(f,1)}if(!Qu(q)){break Kd}f=0;Od:{if(i){break Od}while(1){if((f|0)==(j|0)){break Od}i=f<<2;A=i+s|0;N=a+i|0;z[A>>2]=z[N>>2]+z[A>>2];A=i+o|0;i=b+i|0;z[A>>2]=z[i>>2]+z[A>>2];v[N>>2]=0;v[i>>2]=0;f=f+1|0;continue}}b=d;a=c;if(!(p&1)){break Kd}a=v[q>>2];if(a){eb[v[v[a>>2]+148>>2]](a)}f=vm(q);b=h;while(1){a=f;f=a&255;if(f>>>0>249|f>>>0<=(b&255)>>>0){break Ld}i=(B(f,160)+e|0)+906300|0;f=vm(i);b=a;a=v[i>>2];if(!a){continue}eb[v[v[a>>2]+148>>2]](a);continue}}c=0;while(1){if((c|0)!=(j|0)){W=C(z[a>>2]*Ea);Pd:{if(C(D(W))<C(2147483648)){d=~~W;break Pd}d=-2147483648}v[k>>2]=d;W=C(z[b>>2]*Ea);Qd:{if(C(D(W))<C(2147483648)){d=~~W;break Qd}d=-2147483648}v[k+4>>2]=d;c=c+1|0;k=k+8|0;b=b+4|0;a=a+4|0;continue}break}break Id}b=d;a=c}f=0;Rd:{Sd:{if(!((w[q+24|0]&2)>>>1|0)){if(!PC(q)|!(w[l+28|0]&4)){break Sd}}while(1){if((f|0)==(j|0)){break Rd}g=f<<2;q=g+c|0;z[q>>2]=z[g+s>>2]+z[q>>2];q=d+g|0;z[q>>2]=z[g+o>>2]+z[q>>2];f=f+1|0;continue}}if(r){eb[v[v[g>>2]+128>>2]](g)}eb[v[v[g>>2]+60>>2]](g,c,d,j);v[l+32>>2]=j+v[l+32>>2];if(!PC(q)){break Rd}if((eb[v[v[g>>2]+156>>2]](g)|0)<=0|y[l+32>>2]<v[e+24620>>2]<<2>>>0){break Rd}Td:{while(1){if((f|0)==(j|0)){break Td}g=f<<2;W=z[g+c>>2];Ud:{if(W>=C(1.1920928955078125e-7)|W<=C(-1.1920928955078125e-7)){break Ud}W=z[d+g>>2];if(W>=C(1.1920928955078125e-7)){break Ud}f=f+1|0;if(!(W<=C(-1.1920928955078125e-7))){continue}}break}v[l+32>>2]=0;break Rd}v[l+28>>2]=v[l+28>>2]|4}v[l+28>>2]=v[l+28>>2]&-3}h=h+1|0;continue}}else{k=(B(f,160)+e|0)+906300|0;a=v[k>>2];Vd:{if(!a|!v[a+24>>2]){break Vd}c=a+44|0;if(!Ih(c)){break Vd}if(!(eb[v[v[a>>2]+112>>2]](a)|0)){eb[v[v[a>>2]+108>>2]](a,1);eb[v[v[a>>2]+120>>2]](a)}b=Gd(c,0);c=Gd(c,1);Wd:{if(t[a+28|0]&1){Ru(v[a+24>>2],b,c,j,W);break Wd}g=a+40|0;if(v[a+36>>2]?1:v[g>>2]){ym(v[a+24>>2],j,g,a+36|0);Ru(v[a+24>>2],b,c,j,W);break Wd}Jb(b,0,d);Jb(c,0,d)}b=a;a=v[a+28>>2];v[b+28>>2]=a&-2;if(Qu(k)){break Vd}p=!(a&4)|p}f=f+1|0;continue}}}if(v[e+24624>>2]==1){a=0;while(1){if((a|0)!=(j|0)){b=(a<<3)+aa|0;v[(a<<2)+aa>>2]=(v[b+4>>2]+v[b>>2]|0)/2;a=a+1|0;continue}break}}if(zd(w[Ia|0])){k=0;c=ab-16|0;ab=c;Xd:{if(!v[e+1074376>>2]){l=e+1074460|0;a=l;v[a>>2]=0;v[a+4>>2]=0;b=v[e+1074456>>2];v[e+1074468>>2]=b;break Xd}a=v[e+1074468>>2];b=v[e+1074456>>2];Yd:{if((a|0)==(b|0)){d=v[e+1074460>>2];break Yd}v[e+1074468>>2]=b;d=v[e+24620>>2];f=e+1074460|0;Zd:{if((a|0)<(b|0)){d=Ys(d,v[e+24636>>2]);break Zd}d=Ys(d,v[e+24640>>2])}v[f>>2]=d;v[e+1074464>>2]=d;a=b}l=e+1074460|0;if((d|0)<=0){break Xd}a=(a<<12)-v[e+1074472>>2]|0;k=(a|0)/(d|0)|0;if(w[e+1074368|0]!=2){break Xd}v[c+12>>2]=50;f=v[e+1074464>>2];v[c+8>>2]=1e4/(f+1|0);g=v[Ee(c+12|0,c+8|0)>>2];while(1){h=k>>31;if((g|0)>=(h+k^h)){break Xd}d=d+f|0;v[l>>2]=d;k=(a|0)/(d|0)|0;continue}}_d:{$d:{switch(v[e+24624>>2]-1|0){case 0:a=0;g=(j|0)>0?j:0;h=b<<12;d=e+12|0;m=b>>31;while(1){if((a|0)==(g|0)){break _d}ae:{if(v[l>>2]>0){f=v[e+1074472>>2]+k|0;v[e+1074472>>2]=f;n=v[d>>2];Ua=d,Va=vc(pia(oia(n,n>>31,f,f>>31),db,1048576,0),db),v[Ua>>2]=Va;v[e+1074460>>2]=v[e+1074460>>2]-1;break ae}f=v[d>>2];Ua=d,Va=vc(pia(oia(f,f>>31,b,m),db,256,0),db),v[Ua>>2]=Va;v[e+1074472>>2]=h}a=a+1|0;d=d+4|0;continue};case 1:a=0;h=(j|0)>0?j:0;m=b<<12;d=e+12|0;f=b>>31;while(1){if((a|0)==(h|0)){break _d}be:{if(v[l>>2]>0){g=v[e+1074472>>2]+k|0;v[e+1074472>>2]=g;n=v[d>>2];Ua=d,Va=vc(pia(oia(n,n>>31,g,g>>31),db,1048576,0),db),v[Ua>>2]=Va;g=v[e+1074472>>2];n=g;p=g>>31;g=v[d+4>>2];Ua=d,Va=vc(pia(oia(n,p,g,g>>31),db,1048576,0),db),v[Ua+4>>2]=Va;v[e+1074460>>2]=v[e+1074460>>2]-1;break be}g=v[d>>2];Ua=d,Va=vc(pia(oia(g,g>>31,b,f),db,256,0),db),v[Ua>>2]=Va;g=v[d+4>>2];Ua=d,Va=vc(pia(oia(g,g>>31,b,f),db,256,0),db),v[Ua+4>>2]=Va;v[e+1074472>>2]=m}a=a+1|0;d=d+8|0;continue};case 3:break $d;default:break _d}}h=0;m=(j|0)>0?j:0;n=b<<12;d=e+8204|0;a=e+12|0;f=b>>31;while(1){if((h|0)==(m|0)){break _d}ce:{if(v[l>>2]>0){g=v[e+1074472>>2]+k|0;v[e+1074472>>2]=g;q=v[a>>2];Ua=a,Va=vc(pia(oia(q,q>>31,g,g>>31),db,1048576,0),db),v[Ua>>2]=Va;g=v[e+1074472>>2];p=g;q=g>>31;g=v[a+4>>2];Ua=a,Va=vc(pia(oia(p,q,g,g>>31),db,1048576,0),db),v[Ua+4>>2]=Va;g=v[e+1074472>>2];p=g;q=g>>31;g=v[d>>2];Ua=d,Va=vc(pia(oia(p,q,g,g>>31),db,1048576,0),db),v[Ua>>2]=Va;g=v[e+1074472>>2];p=g;q=g>>31;g=v[d+4>>2];Ua=d,Va=vc(pia(oia(p,q,g,g>>31),db,1048576,0),db),v[Ua+4>>2]=Va;v[e+1074460>>2]=v[e+1074460>>2]-1;break ce}g=v[a>>2];Ua=a,Va=vc(pia(oia(g,g>>31,b,f),db,256,0),db),v[Ua>>2]=Va;g=v[a+4>>2];Ua=a,Va=vc(pia(oia(g,g>>31,b,f),db,256,0),db),v[Ua+4>>2]=Va;g=v[d>>2];Ua=d,Va=vc(pia(oia(g,g>>31,b,f),db,256,0),db),v[Ua>>2]=Va;g=v[d+4>>2];Ua=d,Va=vc(pia(oia(g,g>>31,b,f),db,256,0),db),v[Ua+4>>2]=Va;v[e+1074472>>2]=n}h=h+1|0;d=d+8|0;a=a+8|0;continue}}ab=c+16|0}if(v[qa>>2]!=128){b=e+12|0;c=e+8204|0;a=v[e+24604>>2];d=v[e+24624>>2];de:{if((a|0)==128|d>>>0<2){break de}QK(b,j,a);if(d>>>0<4){break de}QK(c,j,a)}}if(v[e+24624>>2]==4){b=j;while(1){b=b-1|0;if((b|0)>=0){a=(b<<4)+aa|0;c=b<<3;d=c|4;v[a+12>>2]=v[d+ta>>2];v[a+8>>2]=v[c+ta>>2];v[a+4>>2]=v[d+aa>>2];v[a>>2]=v[c+aa>>2];continue}break}}if(RK(ra)){b=v[ra>>2];a=ag(T- -64|0,aa,v[e+24624>>2],j);c=v[v[b>>2]+8>>2];v[T+24>>2]=v[a+8>>2];d=v[a+4>>2];v[T+16>>2]=v[a>>2];v[T+20>>2]=d;eb[c|0](b,T+16|0)}a=ag(T+48|0,aa,v[e+24624>>2],j);b=v[v[pa>>2]+8>>2];v[T+8>>2]=v[a+8>>2];c=v[a+4>>2];v[T>>2]=v[a>>2];v[T+4>>2]=c;eb[b|0](pa,T);v[e+1074380>>2]=v[e+1074380>>2]-j;v[e+1074376>>2]=j+v[e+1074376>>2];ha=ha-j|0;Fa=j+Fa|0;continue}break}ab=$+48|0;return Fa}function eg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),m=0,o=0,p=0,r=0,s=0,E=0,F=C(0),G=0,H=0,I=C(0),J=0,K=0,M=0,N=0,R=0;i=ab-2608|0;ab=i;a:{b:{c:{d:{e:{f:{if(Eq(c)){mc(b,268435456);K=v[c+8>>2];H=i+2584|0;e=H;v[e>>2]=0;v[e+4>>2]=0;Pb(e+8|0);v[i+2580>>2]=0;g:{h:{i:{j:{k:{l:{e=w[a+3|0];m:{n:{if(e-4>>>0<=4){v[22452]=0;d=T(193,c|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break l}v[i+2580>>2]=d;break n}if(e>>>0>17){break m}o:{f=1<<e;if(!(f&63503)){if(!(f&198144)){break m}break o}if(w[a|0]){break o}break n}e=0;g=BA(a,v[b>>2]);v[22452]=0;U(194,i+416|0,c|0,g|0);g=v[22452];v[22452]=0;if((g|0)==1){break k}d=i+416|0;g=v[d+4>>2];v[H>>2]=v[d>>2];v[H+4>>2]=g;bm(H+8|0,d+8|0);rc(d);g=Sd(H);d=v[H>>2];v[i+2580>>2]=d;if(!g){break g}}e=w[a+3|0]}o=1;p:{q:{switch(e&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:o=!w[a|0];break p;case 9:case 10:case 16:case 17:break q;default:break p}}o=0}h=v[b>>2];if(!(h>>>0<262145|o)){e=e&255;v[i+416>>2]=((e|0)==10)<<4;f=d-v[zb(i+416|0,i+2580|0)>>2]|0;if(e>>>0>15){break j}r:{if(!(1<<e&63503)){if((e|0)==10){break r}break j}if(!(w[a|0]&7)){break j}}e=(f|0)>=0?f<<1:-1;break i}e=e&255;if(e>>>0>8){break h}if(!(1<<e&432)){if((e|0)!=6){break h}e=0;if(d>>>0<10){break g}v[22452]=0;Q(179,c|0,4)|0;d=v[22452];v[22452]=0;if((d|0)==1){break l}v[22452]=0;e=T(148,c|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){v[i+416>>2]=e;v[i+392>>2]=v[i+2580>>2];d=v[zb(i+416|0,i+392|0)>>2];gg(c,8);e=((d>>>0>50529027?-1:B(d,85))>>>0)/(w[a|0]>>>3>>>0)|0;break i}a=P()|0;O()|0;break a}e=8/(Np(w[a+1|0])>>>0)|0;oia(e,0,d,0);e=db?-1:B(e,d);break i}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}h=0;d=Np(w[a+1|0]);s:{t:{switch(e|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=w[a|0];break s;case 9:h=16;break s;case 10:h=4;break s;case 16:case 17:break t;default:break s}}h=8}e=B(d,h&255)>>>3|0;d=(e+f|0)-1|0;e=((d>>>0<f>>>0?-1:d)>>>0)/(e>>>0)|0}mc(b,e);h=v[b>>2]}if(!h){e=0;break g}u[b+34>>1]=x[b+34>>1]&65470|w[a|0]>15|(w[a+1|0]!=1)<<6;if(!sg(b)){e=0;v[b>>2]=0;break g}u:{if(ae(a,Gc(i+416|0,8,1,0,10))){v[22452]=0;d=Q(195,c|0,i+416|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){e=0;if(!d){break u}a=v[b>>2];d=0;v[22452]=0;v[i+392>>2]=a+1>>>1;e=T(193,c|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break b}mc(i+392|0,e);a=g+16|0;b=v[b+20>>2];h=v[i+392>>2];e=h;while(1)if(e){f=i+416|0;g=d+w[f|w[a|0]&15]|0;t[b|0]=g;d=w[f|w[a|0]>>>4]+(g&255)|0;t[b+1|0]=d;e=e-1|0;a=a+1|0;b=b+2|0;continue}else{e=h+16|0;break u}}a=P()|0;O()|0;break a}v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{f=w[a+3|0];switch(f-4|0){case 3:break D;case 12:case 13:break E;case 4:break F;case 5:break G;case 2:break H;case 0:case 1:break I;default:break C}}v[22452]=0;b=da(196,i+1488|0,c|0,b|0,(f|0)==5|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break f}qb(b);e=v[c+8>>2]-K|0;break u}if(w[a+1|0]!=1){break C}v[22452]=0;Q(179,c|0,4)|0;a=v[22452];v[22452]=0;if((a|0)==1){break f}v[22452]=0;g=T(148,c|0)|0;a=v[22452];v[22452]=0;J:{K:{L:{if((a|0)!=1){v[22452]=0;v[i+392>>2]=g;h=T(197,c|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break L}v[22452]=0;U(198,i+416|0,c|0,g|0);a=v[22452];v[22452]=0;if((a|0)==1){break J}mc(i+392|0,v[i+416>>2]);f=v[i+392>>2];e=Sd(i+416|0);d=x[b+34>>1];g=v[b+20>>2];b=v[b>>2];a=v[i+416>>2];v[22452]=0;ga(199,e|0,a|0,g|0,mj(b,d)|0,h<<24>>24);a=v[22452];v[22452]=0;if((a|0)!=1){break K}a=P()|0;O()|0;rc(i+416|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}e=f+9|0;rc(i+416|0);break u}a=P()|0;O()|0;break a}if(w[a+1|0]!=1|w[a|0]!=16){break C}a=v[i+2580>>2];h=x[Ol(i+1480|0)>>1];f=ab-16|0;ab=f;v[f+12>>2]=a>>>1;v[f+8>>2]=v[b>>2];b=v[b+20>>2];d=v[zb(f+12|0,f+8|0)>>2];e=d;while(1){if(e){a=w[g|0]+h|0;h=a+w[g+1|0]|0;u[b>>1]=h<<8|a&255;b=b+2|0;g=g+2|0;e=e-1|0;continue}break}ab=f+16|0;e=d<<1;break u}if(w[a+1|0]!=1|w[a|0]>16){break C}e=0;v[22452]=0;d=Q(147,c|0,8)|0;g=v[22452];v[22452]=0;if((g|0)==1){break f}if(!d){break u}v[22452]=0;d=T(148,c|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break f}v[i+2580>>2]=d;if(d>>>0<4){break u}v[22452]=0;U(181,i+392|0,c|0,d|0);g=v[22452];v[22452]=0;if((g|0)==1){break c}g=i+392|0;s=Oq(i+416|0,g);qb(g);v[22452]=0;d=T(200,s|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break e}e=d+4|0;p=w[a|0];r=(p|0)!=16;d=0;g=0;while(1){if(y[b>>2]<=g>>>0){break w}M:{if(r){break M}v[22452]=0;E=Q(155,s|0,8)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break M}a=V(30480)|0;break x}v[22452]=0;j=Q(155,s|0,1)|0;a=v[22452];v[22452]=0;if((a|0)==1){break y}v[22452]=0;f=Q(155,s|0,1)|0;a=v[22452];v[22452]=0;if((a|0)==1){break y}N:{O:{P:{if(!f){h=8;while(1){v[22452]=0;f=Q(155,s|0,1)|0;a=v[22452];v[22452]=0;if((a|0)==1){break N}if(f){break P}h=h+16|0;continue}}v[22452]=0;a=Q(155,s|0,3)|0;f=v[22452];v[22452]=0;if((f|0)!=1){break O}break y}v[22452]=0;f=Q(155,s|0,4)|0;a=v[22452];v[22452]=0;if((a|0)==1){break y}a=f+h|0}d=(d&255)+(((j?-1:0)^a)&255)|0;Q:{if((p|0)!=16){t[v[b+20>>2]+g|0]=d;break Q}u[v[b+20>>2]+(g<<1)>>1]=E&255|d<<8}g=g+1|0;continue}break}a=V(30480)|0;break x}o=w[a|0];if((o|0)!=16){break B}e=w[a+1|0];if((e-1&255)>>>0>1){break A}M=i,N=B(v[b>>2],Np(e)),v[M+416>>2]=N;mc(i+416|0,v[i+2580>>2]);b=v[b+20>>2];e=v[i+416>>2];if(w[a+3|0]==16){a=e;while(1){if(!a){break u}M=b,N=x[Yb(30512,w[g|0])>>1],u[M>>1]=N;b=b+2|0;g=g+1|0;a=a-1|0;continue}}a=e;while(1){if(!a){break u}M=b,N=x[Yb(31024,w[g|0])>>1],u[M>>1]=N;b=b+2|0;g=g+1|0;a=a-1|0;continue}}if(w[a+1|0]!=1|w[a|0]>16){break C}e=0;if(y[i+2580>>2]<5){break u}d=x[b+34>>1];g=v[b+20>>2];a=v[b>>2];v[22452]=0;e=Y(201,c|0,g|0,mj(a,d)|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break u}break f}o=w[a|0]}if((o|0)==8){if(w[a+1|0]==1){R:{switch(f|0){case 0:a=v[b>>2];b=v[b+20>>2];d=ab-16|0;ab=d;v[d+12>>2]=v[i+2580>>2];v[d+8>>2]=a;a=v[zb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[g|0];b=b+1|0;g=g+1|0;e=e-1|0;continue}break};ab=d+16|0;e=a;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=ab-16|0;ab=d;v[d+12>>2]=v[i+2580>>2];v[d+8>>2]=a;a=v[zb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[g|0]^128;b=b+1|0;g=g+1|0;e=e-1|0;continue}break};ab=d+16|0;e=a;break u;default:e=0;if((f|0)!=11){break u}break;case 2:break R}}e=v[i+2580>>2];d=Cy(i+384|0);a=v[b>>2];b=v[b+20>>2];h=w[d|0];d=ab-16|0;ab=d;v[d+12>>2]=e;v[d+8>>2]=a;a=v[zb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){h=w[g|0]+h|0;t[b|0]=h;b=b+1|0;g=g+1|0;e=e-1|0;continue}break}ab=d+16|0;e=a;break u}if(w[a+1|0]==3){S:{switch(f|0){case 0:h=ab-16|0;ab=h;f=v[i+2580>>2];v[h+12>>2]=f;d=v[b>>2];v[h+8>>2]=d;a=h+8|0;e=v[zb(a,h+12|0)>>2];v[h+8>>2]=d;v[h+4>>2]=f-e;d=v[zb(a,h+4|0)>>2];o=v[b+20>>2];a=e;f=g;while(1){if(a){t[o|0]=w[f|0];o=o+2|0;f=f+1|0;a=a-1|0;continue}break};o=v[b+20>>2]+1|0;f=v[b>>2]+g|0;a=d;while(1){if(a){t[o|0]=w[f|0];o=o+2|0;f=f+1|0;a=a-1|0;continue}break};ab=h+16|0;e=e+d|0;break u;case 1:h=ab-16|0;ab=h;f=v[i+2580>>2];v[h+12>>2]=f;d=v[b>>2];v[h+8>>2]=d;a=h+8|0;e=v[zb(a,h+12|0)>>2];v[h+8>>2]=d;v[h+4>>2]=f-e;d=v[zb(a,h+4|0)>>2];o=v[b+20>>2];a=e;f=g;while(1){if(a){t[o|0]=w[f|0]^128;o=o+2|0;f=f+1|0;a=a-1|0;continue}break};o=v[b+20>>2]+1|0;f=v[b>>2]+g|0;a=d;while(1){if(a){t[o|0]=w[f|0]^128;o=o+2|0;f=f+1|0;a=a-1|0;continue}break};ab=h+16|0;e=e+d|0;break u;default:e=0;if((f|0)!=11){break u}break;case 2:break S}}h=v[i+2580>>2];e=w[Cy(i+376|0)|0];p=ab-16|0;ab=p;v[p+12>>2]=h;f=v[b>>2];v[p+8>>2]=f;d=p+8|0;j=v[zb(d,p+12|0)>>2];v[p+8>>2]=f;v[p+4>>2]=h-j;h=v[zb(d,p+4|0)>>2];r=b;E=v[b+20>>2];f=e;b=j;d=g;while(1){if(b){f=w[d|0]+f|0;t[E|0]=f;E=E+2|0;d=d+1|0;b=b-1|0;continue}break}E=v[r+20>>2]+1|0;d=v[r>>2]+g|0;b=h;while(1){if(b){e=w[d|0]+e|0;t[E|0]=e;E=E+2|0;d=d+1|0;b=b-1|0;continue}break}ab=p+16|0;e=h+j|0;if(w[a+3|0]!=11){break u}a=v[r+20>>2];b=a+(v[r>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break u}t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;continue}}e=0;if(w[a+1|0]!=2){break u}T:{switch(f|0){case 0:a=v[b>>2];b=v[b+20>>2];d=ab-16|0;ab=d;v[d+12>>2]=v[i+2580>>2]>>>1;v[d+8>>2]=a;a=v[zb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[g|0];t[b+1|0]=w[g+1|0];b=b+2|0;g=g+2|0;e=e-1|0;continue}break};ab=d+16|0;e=a<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=ab-16|0;ab=d;v[d+12>>2]=v[i+2580>>2]>>>1;v[d+8>>2]=a;a=v[zb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[g|0]^128;t[b+1|0]=w[g+1|0]^128;b=b+2|0;g=g+2|0;e=e-1|0;continue}break};ab=d+16|0;e=a<<1;break u;case 2:break T;default:break u}}e=v[i+2580>>2];a=Cy(i+368|0);d=v[b>>2];h=v[b+20>>2];a=w[a|0];f=ab-16|0;ab=f;v[f+12>>2]=e>>>1;v[f+8>>2]=d;b=a;e=v[zb(f+12|0,f+8|0)>>2];d=e;while(1){if(d){a=w[g|0]+a|0;t[h|0]=a;b=w[g+1|0]+b|0;t[h+1|0]=b;h=h+2|0;g=g+2|0;d=d-1|0;continue}break}ab=f+16|0;e=e<<1;break u}if((o|0)!=16){break z}e=w[a+1|0];if((e|0)!=1){break A}if(!w[a+2|0]){U:{switch(f|0){case 0:d=ab-16|0;ab=d;v[d+12>>2]=v[i+2580>>2]>>>1;v[d+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=w[g|0]|w[g+1|0]<<8;b=b+2|0;g=g+2|0;e=e-1|0;continue}break};ab=d+16|0;e=a<<1;break u;case 1:d=ab-16|0;ab=d;v[d+12>>2]=v[i+2580>>2]>>>1;v[d+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=(w[g|0]|w[g+1|0]<<8)^32768;b=b+2|0;g=g+2|0;e=e-1|0;continue}break};ab=d+16|0;e=a<<1;break u;default:e=0;if((f|0)!=11){break u}break;case 2:break U}}a=v[i+2580>>2];h=x[Ol(i+360|0)>>1];d=ab-16|0;ab=d;v[d+12>>2]=a>>>1;v[d+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){h=(w[g|0]+h|0)+(w[g+1|0]<<8)|0;u[b>>1]=h;b=b+2|0;g=g+2|0;e=e-1|0;continue}break}ab=d+16|0;e=a<<1;break u}e=w[a+1|0];if((e|0)!=1){break A}if(w[a+2|0]==1){e=0;V:{switch(f|0){case 0:f=ab-16|0;ab=f;v[f+12>>2]=v[i+2580>>2]>>>1;v[f+8>>2]=v[b>>2];b=v[b+20>>2];d=v[zb(f+12|0,f+8|0)>>2];e=d;while(1){if(e){a=w[g|0]|w[g+1|0]<<8;u[b>>1]=a<<8|a>>>8;b=b+2|0;g=g+2|0;e=e-1|0;continue}break};ab=f+16|0;e=d<<1;break u;case 1:f=ab-16|0;ab=f;v[f+12>>2]=v[i+2580>>2]>>>1;v[f+8>>2]=v[b>>2];b=v[b+20>>2];d=v[zb(f+12|0,f+8|0)>>2];e=d;while(1){if(e){a=w[g|0]|w[g+1|0]<<8;u[b>>1]=(a<<8|a>>>8)^32768;b=b+2|0;g=g+2|0;e=e-1|0;continue}break};ab=f+16|0;e=d<<1;break u;case 2:break V;default:break u}}a=v[i+2580>>2];h=x[Ol(i+352|0)>>1];d=ab-16|0;ab=d;v[d+12>>2]=a>>>1;v[d+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){h=(w[g+1|0]+h|0)+(w[g|0]<<8)|0;u[b>>1]=h;b=b+2|0;g=g+2|0;e=e-1|0;continue}break}ab=d+16|0;e=a<<1;break u}e=w[a+1|0]}if(!(w[a+2|0]|(e&255)!=3)){W:{switch(f|0){case 0:r=ab-16|0;ab=r;d=v[i+2580>>2];v[r+12>>2]=d;j=v[b>>2]<<1;v[r+8>>2]=j;a=r+8|0;f=v[zb(a,r+12|0)>>2];v[r+8>>2]=j;v[r+4>>2]=d-f;a=v[zb(a,r+4|0)>>2];e=v[b+20>>2];f=f>>>1|0;h=f;d=g;while(1){if(h){u[e>>1]=w[d|0]|w[d+1|0]<<8;e=e+4|0;d=d+2|0;h=h-1|0;continue}break};e=g+j|0;d=v[b+20>>2]+2|0;a=a>>>1|0;h=a;while(1){if(h){u[d>>1]=w[e|0]|w[e+1|0]<<8;d=d+4|0;e=e+2|0;h=h-1|0;continue}break};ab=r+16|0;e=a+f<<1;break u;case 1:r=ab-16|0;ab=r;d=v[i+2580>>2];v[r+12>>2]=d;j=v[b>>2]<<1;v[r+8>>2]=j;a=r+8|0;f=v[zb(a,r+12|0)>>2];v[r+8>>2]=j;v[r+4>>2]=d-f;a=v[zb(a,r+4|0)>>2];e=v[b+20>>2];f=f>>>1|0;h=f;d=g;while(1){if(h){u[e>>1]=(w[d|0]|w[d+1|0]<<8)^32768;e=e+4|0;d=d+2|0;h=h-1|0;continue}break};e=g+j|0;d=v[b+20>>2]+2|0;a=a>>>1|0;h=a;while(1){if(h){u[d>>1]=(w[e|0]|w[e+1|0]<<8)^32768;d=d+4|0;e=e+2|0;h=h-1|0;continue}break};ab=r+16|0;e=a+f<<1;break u;default:e=0;if((f|0)!=11){break u}break;case 2:break W}}f=v[i+2580>>2];e=x[Ol(i+344|0)>>1];s=ab-16|0;ab=s;v[s+12>>2]=f;p=v[b>>2]<<1;v[s+8>>2]=p;d=s+8|0;j=v[zb(d,s+12|0)>>2];v[s+8>>2]=p;v[s+4>>2]=f-j;r=v[zb(d,s+4|0)>>2];h=b;f=v[b+20>>2];b=e;j=j>>>1|0;E=j;d=g;while(1){if(E){b=(w[d|0]+b|0)+(w[d+1|0]<<8)|0;u[f>>1]=b;f=f+4|0;d=d+2|0;E=E-1|0;continue}break}d=g+p|0;f=v[h+20>>2]+2|0;b=r>>>1|0;E=b;while(1){if(E){e=(w[d|0]+e|0)+(w[d+1|0]<<8)|0;u[f>>1]=e;f=f+4|0;d=d+2|0;E=E-1|0;continue}break}ab=s+16|0;e=b+j<<1;if(w[a+3|0]!=11){break u}a=v[h+20>>2];b=a+(v[h>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break u}u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;continue}}d=w[a+1|0];if((d|0)==3){if(w[a+2|0]==1){e=0;X:{switch(f|0){case 0:p=ab-16|0;ab=p;d=v[i+2580>>2];v[p+12>>2]=d;r=v[b>>2]<<1;v[p+8>>2]=r;a=p+8|0;f=v[zb(a,p+12|0)>>2];v[p+8>>2]=r;v[p+4>>2]=d-f;j=v[zb(a,p+4|0)>>2];e=v[b+20>>2];f=f>>>1|0;h=f;d=g;while(1){if(h){a=w[d|0]|w[d+1|0]<<8;u[e>>1]=a<<8|a>>>8;e=e+4|0;d=d+2|0;h=h-1|0;continue}break};e=g+r|0;d=v[b+20>>2]+2|0;b=j>>>1|0;h=b;while(1){if(h){a=w[e|0]|w[e+1|0]<<8;u[d>>1]=a<<8|a>>>8;d=d+4|0;e=e+2|0;h=h-1|0;continue}break};ab=p+16|0;e=b+f<<1;break u;case 1:p=ab-16|0;ab=p;d=v[i+2580>>2];v[p+12>>2]=d;r=v[b>>2]<<1;v[p+8>>2]=r;a=p+8|0;f=v[zb(a,p+12|0)>>2];v[p+8>>2]=r;v[p+4>>2]=d-f;j=v[zb(a,p+4|0)>>2];e=v[b+20>>2];f=f>>>1|0;h=f;d=g;while(1){if(h){a=w[d|0]|w[d+1|0]<<8;u[e>>1]=(a<<8|a>>>8)^32768;e=e+4|0;d=d+2|0;h=h-1|0;continue}break};e=g+r|0;d=v[b+20>>2]+2|0;b=j>>>1|0;h=b;while(1){if(h){a=w[e|0]|w[e+1|0]<<8;u[d>>1]=(a<<8|a>>>8)^32768;d=d+4|0;e=e+2|0;h=h-1|0;continue}break};ab=p+16|0;e=b+f<<1;break u;case 2:break X;default:break u}}f=v[i+2580>>2];a=x[Ol(i+336|0)>>1];p=ab-16|0;ab=p;v[p+12>>2]=f;r=v[b>>2]<<1;v[p+8>>2]=r;d=p+8|0;e=v[zb(d,p+12|0)>>2];v[p+8>>2]=r;v[p+4>>2]=f-e;j=v[zb(d,p+4|0)>>2];d=b;o=v[d+20>>2];b=a;e=e>>>1|0;f=e;h=g;while(1){if(f){b=(w[h+1|0]+b|0)+(w[h|0]<<8)|0;u[o>>1]=b;o=o+4|0;h=h+2|0;f=f-1|0;continue}break}h=g+r|0;o=v[d+20>>2]+2|0;b=j>>>1|0;f=b;while(1){if(f){a=(w[h+1|0]+a|0)+(w[h|0]<<8)|0;u[o>>1]=a;o=o+4|0;h=h+2|0;f=f-1|0;continue}break}ab=p+16|0;e=b+e<<1;break u}d=w[a+1|0]}if(!(w[a+2|0]|(d&255)!=2)){e=0;Y:{switch(f|0){case 0:d=ab-16|0;ab=d;v[d+12>>2]=v[i+2580>>2]>>>2;v[d+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=w[g|0]|w[g+1|0]<<8;u[b+2>>1]=w[g+2|0]|w[g+3|0]<<8;b=b+4|0;g=g+4|0;e=e-1|0;continue}break};ab=d+16|0;e=a<<2;break u;case 1:d=ab-16|0;ab=d;v[d+12>>2]=v[i+2580>>2]>>>2;v[d+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=(w[g|0]|w[g+1|0]<<8)^32768;u[b+2>>1]=(w[g+2|0]|w[g+3|0]<<8)^32768;b=b+4|0;g=g+4|0;e=e-1|0;continue}break};ab=d+16|0;e=a<<2;break u;case 2:break Y;default:break u}}d=v[i+2580>>2];a=x[Ol(i+328|0)>>1];f=ab-16|0;ab=f;v[f+12>>2]=d>>>2;v[f+8>>2]=v[b>>2];h=v[b+20>>2];b=a;e=v[zb(f+12|0,f+8|0)>>2];d=e;while(1){if(d){a=(w[g|0]+a|0)+(w[g+1|0]<<8)|0;u[h>>1]=a;b=(w[g+2|0]+b|0)+(w[g+3|0]<<8)|0;u[h+2>>1]=b;h=h+4|0;g=g+4|0;d=d-1|0;continue}break}ab=f+16|0;e=e<<2;break u}e=0;if(w[a+1|0]!=2|w[a+2|0]!=1){break u}Z:{switch(f|0){case 0:f=ab-16|0;ab=f;v[f+12>>2]=v[i+2580>>2]>>>2;v[f+8>>2]=v[b>>2];b=v[b+20>>2];d=v[zb(f+12|0,f+8|0)>>2];e=d;while(1){if(e){a=w[g|0]|w[g+1|0]<<8;u[b>>1]=a<<8|a>>>8;a=w[g+2|0]|w[g+3|0]<<8;u[b+2>>1]=a<<8|a>>>8;b=b+4|0;g=g+4|0;e=e-1|0;continue}break};ab=f+16|0;e=d<<2;break u;case 1:f=ab-16|0;ab=f;v[f+12>>2]=v[i+2580>>2]>>>2;v[f+8>>2]=v[b>>2];b=v[b+20>>2];d=v[zb(f+12|0,f+8|0)>>2];e=d;while(1){if(e){a=w[g|0]|w[g+1|0]<<8;u[b>>1]=(a<<8|a>>>8)^32768;a=w[g+2|0]|w[g+3|0]<<8;u[b+2>>1]=(a<<8|a>>>8)^32768;b=b+4|0;g=g+4|0;e=e-1|0;continue}break};ab=f+16|0;e=d<<2;break u;case 2:break Z;default:break u}}d=v[i+2580>>2];a=x[Ol(i+320|0)>>1];f=ab-16|0;ab=f;v[f+12>>2]=d>>>2;v[f+8>>2]=v[b>>2];h=v[b+20>>2];b=a;e=v[zb(f+12|0,f+8|0)>>2];d=e;while(1){if(d){a=(w[g+1|0]+a|0)+(w[g|0]<<8)|0;u[h>>1]=a;b=(w[g+3|0]+b|0)+(w[g+2|0]<<8)|0;u[h+2>>1]=b;h=h+4|0;g=g+4|0;d=d-1|0;continue}break}ab=f+16|0;e=e<<2;break u}_:{$:{aa:{ba:{if((o|0)==24){if(!(f|w[a+1|0]!=1)){d=v[i+2580>>2];if(!w[a+2|0]){f=ab-16|0;ab=f;v[f+12>>2]=(d>>>0)/3;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=Wc(w[g+1|0]<<16|w[g|0]<<8|w[g+2|0]<<24,16),u[M>>1]=N;b=b+2|0;g=g+3|0;e=e-1|0;continue}break}ab=f+16|0;e=B(a,3);break u}f=ab-16|0;ab=f;v[f+12>>2]=(d>>>0)/3;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=Wc(w[g+1|0]<<16|w[g+2|0]<<8|w[g|0]<<24,16),u[M>>1]=N;b=b+2|0;g=g+3|0;e=e-1|0;continue}break}ab=f+16|0;e=B(a,3);break u}d=0;if(w[a+1|0]!=2){e=0;break ba}e=0;if(f){break ba}d=v[i+2580>>2];if(!w[a+2|0]){f=ab-16|0;ab=f;v[f+12>>2]=(d>>>0)/6;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=Wc(w[g+1|0]<<16|w[g|0]<<8|w[g+2|0]<<24,16),u[M>>1]=N;M=b,N=Wc(w[g+4|0]<<16|w[g+3|0]<<8|w[g+5|0]<<24,16),u[M+2>>1]=N;b=b+4|0;g=g+6|0;e=e-1|0;continue}break}ab=f+16|0;e=B(a,6);break u}f=ab-16|0;ab=f;v[f+12>>2]=(d>>>0)/6;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=Wc(w[g+1|0]<<16|w[g+2|0]<<8|w[g|0]<<24,16),u[M>>1]=N;M=b,N=Wc(w[g+4|0]<<16|w[g+5|0]<<8|w[g+3|0]<<24,16),u[M+2>>1]=N;b=b+4|0;g=g+6|0;e=e-1|0;continue}break}ab=f+16|0;e=B(a,6);break u}ca:{da:{d=(o|0)==32;if(d){if(!(f|w[a+1|0]!=1)){d=v[i+2580>>2];if(!w[a+2|0]){f=ab-16|0;ab=f;v[f+12>>2]=d>>>2;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=Wc(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24),16),u[M>>1]=N;b=b+2|0;g=g+4|0;e=e-1|0;continue}break}ab=f+16|0;e=a<<2;break u}f=ab-16|0;ab=f;v[f+12>>2]=d>>>2;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);M=b,N=Wc(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[M>>1]=N;b=b+2|0;g=g+4|0;e=e-1|0;continue}break}ab=f+16|0;e=a<<2;break u}if(f|w[a+1|0]!=2){break da}d=v[i+2580>>2];if(!w[a+2|0]){f=ab-16|0;ab=f;v[f+12>>2]=d>>>3;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=Wc(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24),16),u[M>>1]=N;M=b,N=Wc(w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24),16),u[M+2>>1]=N;b=b+4|0;g=g+8|0;e=e-1|0;continue}break}ab=f+16|0;e=a<<3;break u}f=ab-16|0;ab=f;v[f+12>>2]=d>>>3;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);M=b,N=Wc(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[M>>1]=N;d=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);M=b,N=Wc(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[M+2>>1]=N;b=b+4|0;g=g+8|0;e=e-1|0;continue}break}ab=f+16|0;e=a<<3;break u}e=0;if((o|0)!=64){break u}if(!(f|w[a+1|0]!=1)){d=v[i+2580>>2];if(!w[a+2|0]){f=ab-16|0;ab=f;v[f+12>>2]=d>>>3;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=Cc(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24),w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24),48),u[M>>1]=N;b=b+2|0;g=g+8|0;e=e-1|0;continue}break}ab=f+16|0;e=a<<3;break u}j=ab-16|0;ab=j;v[j+12>>2]=d>>>3;v[j+8>>2]=v[b>>2];b=v[b+20>>2];d=v[zb(j+12|0,j+8|0)>>2];e=d;while(1){if(e){h=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);a=h<<24|h<<8&16711680;o=h>>>8|0;f=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);h=h>>>24|0;a=a|((o|f<<24)&65280|(h|f<<8)&255);M=b,N=Cc((o|(f&255)<<24)&-16777216|(h|(f&16777215)<<8)&16711680|(f>>>8&65280|f>>>24),a,48),u[M>>1]=N;b=b+2|0;g=g+8|0;e=e-1|0;continue}break}ab=j+16|0;e=d<<3;break u}e=(o|0)==64;if(f|w[a+1|0]!=2){break ca}d=v[i+2580>>2];if(!w[a+2|0]){f=ab-16|0;ab=f;v[f+12>>2]=d>>>4;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=Cc(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24),w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24),48),u[M>>1]=N;M=b,N=Cc(w[g+8|0]|w[g+9|0]<<8|(w[g+10|0]<<16|w[g+11|0]<<24),w[g+12|0]|w[g+13|0]<<8|(w[g+14|0]<<16|w[g+15|0]<<24),48),u[M+2>>1]=N;b=b+4|0;g=g+16|0;e=e-1|0;continue}break}ab=f+16|0;e=a<<4;break u}j=ab-16|0;ab=j;v[j+12>>2]=d>>>4;v[j+8>>2]=v[b>>2];b=v[b+20>>2];d=v[zb(j+12|0,j+8|0)>>2];e=d;while(1){if(e){h=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);a=h<<24|h<<8&16711680;o=h>>>8|0;f=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);h=h>>>24|0;a=a|((o|f<<24)&65280|(h|f<<8)&255);M=b,N=Cc((o|(f&255)<<24)&-16777216|(h|(f&16777215)<<8)&16711680|(f>>>8&65280|f>>>24),a,48),u[M>>1]=N;h=w[g+8|0]|w[g+9|0]<<8|(w[g+10|0]<<16|w[g+11|0]<<24);f=w[g+12|0]|w[g+13|0]<<8|(w[g+14|0]<<16|w[g+15|0]<<24);a=h<<24|h<<8&16711680|((f<<24|h>>>8)&65280|(f<<8|h>>>24)&255);M=b,N=Cc(((f&255)<<24|h>>>8)&-16777216|((f&16777215)<<8|h>>>24)&16711680|(f>>>8&65280|f>>>24),a,48),u[M+2>>1]=N;b=b+4|0;g=g+16|0;e=e-1|0;continue}break}ab=j+16|0;e=d<<4;break u}if(!(w[a+1|0]!=1|(f|0)!=3)){d=v[i+2580>>2];if(!w[a+2|0]){f=ab-16|0;ab=f;v[f+12>>2]=d>>>2;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){k=xf((l(2,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24)),q()));k=kf(C(Ed(Yf(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));ea:{if(C(D(k))<C(2147483648)){d=~~k;break ea}d=-2147483648}M=b,N=Jc(d),u[M>>1]=N;b=b+2|0;g=g+4|0;e=e-1|0;continue}break}ab=f+16|0;e=a<<2;break u}f=ab-16|0;ab=f;v[f+12>>2]=d>>>2;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);k=xf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=kf(C(Ed(Yf(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));fa:{if(C(D(k))<C(2147483648)){d=~~k;break fa}d=-2147483648}M=b,N=Jc(d),u[M>>1]=N;b=b+2|0;g=g+4|0;e=e-1|0;continue}break}ab=f+16|0;e=a<<2;break u}if(!(w[a+1|0]!=2|(f|0)!=3)){d=v[i+2580>>2];if(!w[a+2|0]){f=ab-16|0;ab=f;v[f+12>>2]=d>>>3;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){k=xf((l(2,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24)),q()));k=kf(C(Ed(Yf(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));ga:{if(C(D(k))<C(2147483648)){d=~~k;break ga}d=-2147483648}M=b,N=Jc(d),u[M>>1]=N;k=xf((l(2,w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24)),q()));k=kf(C(Ed(Yf(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));ha:{if(C(D(k))<C(2147483648)){d=~~k;break ha}d=-2147483648}M=b,N=Jc(d),u[M+2>>1]=N;b=b+4|0;g=g+8|0;e=e-1|0;continue}break}ab=f+16|0;e=a<<3;break u}f=ab-16|0;ab=f;v[f+12>>2]=d>>>3;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[zb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);k=xf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=kf(C(Ed(Yf(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));ia:{if(C(D(k))<C(2147483648)){d=~~k;break ia}d=-2147483648}M=b,N=Jc(d),u[M>>1]=N;d=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);k=xf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=kf(C(Ed(Yf(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));ja:{if(C(D(k))<C(2147483648)){d=~~k;break ja}d=-2147483648}M=b,N=Jc(d),u[M+2>>1]=N;b=b+4|0;g=g+8|0;e=e-1|0;continue}break}ab=f+16|0;e=a<<3;break u}e=(o|0)==64;if((o|0)!=64){break $}}if(!(w[a+1|0]!=1|(f|0)!=3)){d=v[i+2580>>2];if(!w[a+2|0]){f=ab-32|0;ab=f;v[f+24>>2]=d>>>3;v[f+16>>2]=v[b>>2];b=v[b+20>>2];d=v[zb(f+24|0,f+16|0)>>2];e=d;while(1){if(e){a=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);l(0,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));l(1,a|0);m=Xf(+n());M=f,R=Ue(m)?m>=0?1:-1:m,A[M+24>>3]=R;v[f+16>>2]=0;v[f+20>>2]=-1074790400;v[f+8>>2]=0;v[f+12>>2]=1072693248;m=be(A[qg(f+24|0,f+16|0,f+8|0)>>3]*32768);ka:{if(D(m)<2147483648){a=~~m;break ka}a=-2147483648}M=b,N=Jc(a),u[M>>1]=N;b=b+2|0;g=g+8|0;e=e-1|0;continue}break}ab=f+32|0;e=d<<3;break u}j=ab-32|0;ab=j;v[j+24>>2]=d>>>3;v[j+16>>2]=v[b>>2];b=v[b+20>>2];f=v[zb(j+24|0,j+16|0)>>2];e=f;while(1){if(e){a=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);d=a<<24;d=d|a<<8&16711680;o=a>>>8|0;h=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);a=a>>>24|0;d=d|((o|h<<24)&65280|(a|h<<8)&255);l(0,(o|(h&255)<<24)&-16777216|(a|(h&16777215)<<8)&16711680|(h>>>8&65280|h>>>24));l(1,d|0);m=Xf(+n());M=j,R=Ue(m)?m>=0?1:-1:m,A[M+24>>3]=R;v[j+16>>2]=0;v[j+20>>2]=-1074790400;v[j+8>>2]=0;v[j+12>>2]=1072693248;m=be(A[qg(j+24|0,j+16|0,j+8|0)>>3]*32768);la:{if(D(m)<2147483648){a=~~m;break la}a=-2147483648}M=b,N=Jc(a),u[M>>1]=N;b=b+2|0;g=g+8|0;e=e-1|0;continue}break}ab=j+32|0;e=f<<3;break u}if(!(w[a+1|0]!=2|(f|0)!=3)){d=v[i+2580>>2];if(!w[a+2|0]){f=ab-32|0;ab=f;v[f+24>>2]=d>>>4;v[f+16>>2]=v[b>>2];b=v[b+20>>2];d=v[zb(f+24|0,f+16|0)>>2];e=d;while(1){if(e){a=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);l(0,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));l(1,a|0);m=Xf(+n());M=f,R=Ue(m)?m>=0?1:-1:m,A[M+24>>3]=R;v[f+16>>2]=0;v[f+20>>2]=-1074790400;v[f+8>>2]=0;v[f+12>>2]=1072693248;m=be(A[qg(f+24|0,f+16|0,f+8|0)>>3]*32768);ma:{if(D(m)<2147483648){a=~~m;break ma}a=-2147483648}M=b,N=Jc(a),u[M>>1]=N;a=w[g+12|0]|w[g+13|0]<<8|(w[g+14|0]<<16|w[g+15|0]<<24);l(0,w[g+8|0]|w[g+9|0]<<8|(w[g+10|0]<<16|w[g+11|0]<<24));l(1,a|0);m=Xf(+n());M=f,R=Ue(m)?m>=0?1:-1:m,A[M+24>>3]=R;v[f+16>>2]=0;v[f+20>>2]=-1074790400;v[f+8>>2]=0;v[f+12>>2]=1072693248;m=be(A[qg(f+24|0,f+16|0,f+8|0)>>3]*32768);na:{if(D(m)<2147483648){a=~~m;break na}a=-2147483648}M=b,N=Jc(a),u[M+2>>1]=N;b=b+4|0;g=g+16|0;e=e-1|0;continue}break}ab=f+32|0;e=d<<4;break u}j=ab-32|0;ab=j;v[j+24>>2]=d>>>4;v[j+16>>2]=v[b>>2];b=v[b+20>>2];f=v[zb(j+24|0,j+16|0)>>2];e=f;while(1){if(e){a=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);d=a<<24;d=d|a<<8&16711680;o=a>>>8|0;h=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);a=a>>>24|0;d=d|((o|h<<24)&65280|(a|h<<8)&255);l(0,(o|(h&255)<<24)&-16777216|(a|(h&16777215)<<8)&16711680|(h>>>8&65280|h>>>24));l(1,d|0);m=Xf(+n());M=j,R=Ue(m)?m>=0?1:-1:m,A[M+24>>3]=R;v[j+16>>2]=0;v[j+20>>2]=-1074790400;v[j+8>>2]=0;v[j+12>>2]=1072693248;m=be(A[qg(j+24|0,j+16|0,j+8|0)>>3]*32768);oa:{if(D(m)<2147483648){a=~~m;break oa}a=-2147483648}M=b,N=Jc(a),u[M>>1]=N;a=w[g+8|0]|w[g+9|0]<<8|(w[g+10|0]<<16|w[g+11|0]<<24);d=a<<24;d=d|a<<8&16711680;o=a>>>8|0;h=w[g+12|0]|w[g+13|0]<<8|(w[g+14|0]<<16|w[g+15|0]<<24);a=a>>>24|0;d=d|((o|h<<24)&65280|(a|h<<8)&255);l(0,(o|(h&255)<<24)&-16777216|(a|(h&16777215)<<8)&16711680|(h>>>8&65280|h>>>24));l(1,d|0);m=Xf(+n());M=j,R=Ue(m)?m>=0?1:-1:m,A[M+24>>3]=R;v[j+16>>2]=0;v[j+20>>2]=-1074790400;v[j+8>>2]=0;v[j+12>>2]=1072693248;m=be(A[qg(j+24|0,j+16|0,j+8|0)>>3]*32768);pa:{if(D(m)<2147483648){a=~~m;break pa}a=-2147483648}M=b,N=Jc(a),u[M+2>>1]=N;b=b+4|0;g=g+16|0;e=e-1|0;continue}break}ab=j+32|0;e=f<<4;break u}if((o|0)!=24){break aa}}if((f|0)!=15|(w[a+1|0]-1&255)>>>0>1){break aa}v[i+416>>2]=-2147483648;d=v[i+2580>>2];qa:{if(!w[a+2|0]){v[i+8>>2]=v[i+312>>2];v[i+308>>2]=0;a=v[i+308>>2];v[i>>2]=v[i+304>>2];v[i+4>>2]=a;E=i+416|0;s=ab-16|0;ab=s;M=s,N=B(v[b>>2],qd(x[b+34>>1])),v[M+12>>2]=N;mc(s+12|0,(d>>>0)/3|0);d=v[i+4>>2];a=g;j=v[s+12>>2];f=j;while(1){if(f){h=w[a+1|0]<<16|w[a|0]<<8|w[a+2|0]<<24;ra:{if((h|0)<0){e=-2147483648;if((h|0)==-2147483648){break ra}h=0-h|0}e=d>>>0<h>>>0?h:d}d=e;f=f-1|0;a=a+3|0;continue}else{sa:{if(!d){break sa}p=d-1|0;r=d>>>1|0;h=v[b+20>>2];a=j;while(1){if(!a){break sa}e=w[g+1|0]<<16|w[g|0]<<8|w[g+2|0]<<24;f=e>>31<<31|e>>>1;e=r|e<<31;ta:{if((f|0)>0|(f|0)>=0){e=ria(e,f,d,0);f=db;break ta}f=ria(p-e|0,0-((e>>>0>p>>>0)+f|0)|0,d,0);e=0-f|0;f=0-(db+((f|0)!=0)|0)|0}M=h,N=Wc(vc(e,f),16),u[M>>1]=N;a=a-1|0;g=g+3|0;h=h+2|0;continue}}}break}if(E){v[E>>2]=d}ab=s+16|0;e=B(j,3);break qa}v[i+24>>2]=v[i+296>>2];v[i+292>>2]=0;a=v[i+292>>2];v[i+16>>2]=v[i+288>>2];v[i+20>>2]=a;E=i+416|0;s=ab-16|0;ab=s;M=s,N=B(v[b>>2],qd(x[b+34>>1])),v[M+12>>2]=N;mc(s+12|0,(d>>>0)/3|0);d=v[i+20>>2];a=g;j=v[s+12>>2];f=j;while(1){if(f){h=w[a+1|0]<<16|w[a+2|0]<<8|w[a|0]<<24;ua:{if((h|0)<0){e=-2147483648;if((h|0)==-2147483648){break ua}h=0-h|0}e=d>>>0<h>>>0?h:d}d=e;f=f-1|0;a=a+3|0;continue}else{va:{if(!d){break va}p=d-1|0;r=d>>>1|0;h=v[b+20>>2];a=j;while(1){if(!a){break va}e=w[g+1|0]<<16|w[g+2|0]<<8|w[g|0]<<24;f=e>>31<<31|e>>>1;e=r|e<<31;wa:{if((f|0)>0|(f|0)>=0){e=ria(e,f,d,0);f=db;break wa}f=ria(p-e|0,0-((e>>>0>p>>>0)+f|0)|0,d,0);e=0-f|0;f=0-(db+((f|0)!=0)|0)|0}M=h,N=Wc(vc(e,f),16),u[M>>1]=N;a=a-1|0;g=g+3|0;h=h+2|0;continue}}}break}if(E){v[E>>2]=d}ab=s+16|0;e=B(j,3)}if(!e){break u}a=v[i+416>>2];if((a|0)==-2147483648){break u}g=oia(x[b+32>>1],0,a,0)+1073741824|0;a=db;a=g>>>0<1073741824?a+1|0:a;M=b,N=Ld(Fc((a&2147483647)<<1|g>>>31,a>>>31|0),1,64),u[M+32>>1]=N;u[b+34>>1]=x[b+34>>1]|8192;break u}if(!d){break _}}if(!((f|0)!=15|(w[a+1|0]-1&255)>>>0>1)){v[i+416>>2]=-2147483648;d=v[i+2580>>2];xa:{if(!w[a+2|0]){v[i+40>>2]=v[i+280>>2];v[i+276>>2]=0;a=v[i+276>>2];v[i+32>>2]=v[i+272>>2];v[i+36>>2]=a;E=i+416|0;s=ab-16|0;ab=s;M=s,N=B(v[b>>2],qd(x[b+34>>1])),v[M+12>>2]=N;mc(s+12|0,d>>>2|0);h=v[i+36>>2];f=g;j=v[s+12>>2];d=j;while(1){if(d){a=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);ya:{if((a|0)<0){e=-2147483648;if((a|0)==-2147483648){break ya}a=0-a|0}e=a>>>0>h>>>0?a:h}h=e;d=d-1|0;f=f+4|0;continue}else{za:{if(!h){break za}p=h-1|0;r=h>>>1|0;d=v[b+20>>2];a=j;while(1){if(!a){break za}e=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);f=e>>31<<31|e>>>1;e=r|e<<31;Aa:{if((f|0)>0|(f|0)>=0){e=ria(e,f,h,0);f=db;break Aa}f=ria(p-e|0,0-((e>>>0>p>>>0)+f|0)|0,h,0);e=0-f|0;f=0-(db+((f|0)!=0)|0)|0}M=d,N=Wc(vc(e,f),16),u[M>>1]=N;a=a-1|0;g=g+4|0;d=d+2|0;continue}}}break}if(E){v[E>>2]=h}ab=s+16|0;e=j<<2;break xa}v[i+56>>2]=v[i+264>>2];v[i+260>>2]=0;a=v[i+260>>2];v[i+48>>2]=v[i+256>>2];v[i+52>>2]=a;E=i+416|0;s=ab-16|0;ab=s;M=s,N=B(v[b>>2],qd(x[b+34>>1])),v[M+12>>2]=N;mc(s+12|0,d>>>2|0);h=v[i+52>>2];d=g;f=v[s+12>>2];a=f;while(1){if(a){e=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);o=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);Ba:{if((o|0)<0){e=-2147483648;if((o|0)==-2147483648){break Ba}o=0-o|0}e=h>>>0<o>>>0?o:h}h=e;a=a-1|0;d=d+4|0;continue}else{Ca:{if(!h){break Ca}p=h-1|0;r=h>>>1|0;d=v[b+20>>2];a=f;while(1){if(!a){break Ca}e=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);j=e>>31<<31|e>>>1;e=r|e<<31;Da:{if((j|0)>0|(j|0)>=0){e=ria(e,j,h,0);j=db;break Da}j=ria(p-e|0,0-((e>>>0>p>>>0)+j|0)|0,h,0);e=0-j|0;j=0-(db+((j|0)!=0)|0)|0}M=d,N=Wc(vc(e,j),16),u[M>>1]=N;a=a-1|0;g=g+4|0;d=d+2|0;continue}}}break}if(E){v[E>>2]=h}ab=s+16|0;e=f<<2}if(!e){break u}a=v[i+416>>2];if((a|0)==-2147483648){break u}g=oia(x[b+32>>1],0,a,0)+1073741824|0;a=db;a=g>>>0<1073741824?a+1|0:a;M=b,N=Ld(Fc((a&2147483647)<<1|g>>>31,a>>>31|0),1,64),u[M+32>>1]=N;u[b+34>>1]=x[b+34>>1]|8192;break u}if((f|0)!=14|(w[a+1|0]-1&255)>>>0>1){break _}v[i+416>>2]=1065353216;d=v[i+2580>>2];Ea:{if(!w[a+2|0]){v[i+244>>2]=0;v[i+248>>2]=1065353216;a=v[i+252>>2];v[i+72>>2]=v[i+248>>2];v[i+76>>2]=a;a=v[i+244>>2];v[i+64>>2]=v[i+240>>2];v[i+68>>2]=a;e=i+416|0;f=ab-16|0;ab=f;M=f,N=B(v[b>>2],qd(x[b+34>>1])),v[M+12>>2]=N;mc(f+12|0,d>>>2|0);F=z[(i- -64|0)+4>>2];h=g;d=v[f+12>>2];a=d;while(1){if(a){k=xf((l(2,w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24)),q()));k=C(D(Yf(k)?k>=C(0)?C(1):C(-1):k));F=k>F?k:F;a=a-1|0;h=h+4|0;continue}else{Fa:{a=F==C(0);if(a){break Fa}I=a?C(1):C(C(1)/F);h=v[b+20>>2];a=d;while(1){if(!a){break Fa}k=xf((l(2,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24)),q()));k=kf(C(Ed(C(I*(Yf(k)?k>=C(0)?C(1):C(-1):k)),C(-1))*C(32768)));Ga:{if(C(D(k))<C(2147483648)){j=~~k;break Ga}j=-2147483648}M=h,N=Jc(j),u[M>>1]=N;a=a-1|0;g=g+4|0;h=h+2|0;continue}}if(e){z[e>>2]=F}ab=f+16|0;e=d<<2}break}break Ea}v[i+228>>2]=0;v[i+232>>2]=1065353216;a=v[i+236>>2];v[i+88>>2]=v[i+232>>2];v[i+92>>2]=a;a=v[i+228>>2];v[i+80>>2]=v[i+224>>2];v[i+84>>2]=a;e=i+416|0;j=ab-16|0;ab=j;M=j,N=B(v[b>>2],qd(x[b+34>>1])),v[M+12>>2]=N;mc(j+12|0,d>>>2|0);F=z[i+84>>2];h=g;d=v[j+12>>2];a=d;while(1){if(a){f=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);k=xf((l(2,f<<24|f<<8&16711680|(f>>>8&65280|f>>>24)),q()));k=C(D(Yf(k)?k>=C(0)?C(1):C(-1):k));F=k>F?k:F;a=a-1|0;h=h+4|0;continue}else{Ha:{a=F==C(0);if(a){break Ha}I=a?C(1):C(C(1)/F);h=v[b+20>>2];a=d;while(1){if(!a){break Ha}f=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);k=xf((l(2,f<<24|f<<8&16711680|(f>>>8&65280|f>>>24)),q()));k=kf(C(Ed(C(I*(Yf(k)?k>=C(0)?C(1):C(-1):k)),C(-1))*C(32768)));Ia:{if(C(D(k))<C(2147483648)){f=~~k;break Ia}f=-2147483648}M=h,N=Jc(f),u[M>>1]=N;a=a-1|0;g=g+4|0;h=h+2|0;continue}}if(e){z[e>>2]=F}ab=j+16|0;e=d<<2}break}}if(!e){break u}k=z[i+416>>2];if(k==C(1)){break u}k=kf(By(C(k*C(x[b+32>>1])),C(1),C(64)));a=65535;Ja:{if(k>=C(65535)){break Ja}a=0;if(k<=C(0)){break Ja}a=~~k>>>0;if(k<C(4294967296)&k>=C(0)){break Ja}a=0}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break u}if(!(!e|((f|0)!=14|(w[a+1|0]-1&255)>>>0>1))){v[i+416>>2]=0;v[i+420>>2]=1072693248;d=v[i+2580>>2];Ka:{if(!w[a+2|0]){v[i+208>>2]=0;v[i+212>>2]=1072693248;v[i+200>>2]=0;v[i+204>>2]=0;v[i+104>>2]=0;v[i+108>>2]=0;v[i+112>>2]=0;v[i+116>>2]=1072693248;a=v[i+220>>2];v[i+120>>2]=v[i+216>>2];v[i+124>>2]=a;a=v[i+196>>2];v[i+96>>2]=v[i+192>>2];v[i+100>>2]=a;h=i+416|0;j=ab-32|0;ab=j;M=j,N=B(v[b>>2],qd(x[b+34>>1])),v[M+4>>2]=N;mc(j+4|0,d>>>3|0);G=A[i+104>>3];d=g;e=v[j+4>>2];a=e;while(1){if(a){f=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);l(0,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));l(1,f|0);m=Xf(+n());m=D(Ue(m)?m>=0?1:-1:m);G=m>G?m:G;a=a-1|0;d=d+8|0;continue}else{La:{a=G==0;if(a){break La}J=a?1:1/G;d=v[b+20>>2];a=e;while(1){if(!a){break La}f=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);l(0,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));l(1,f|0);m=Xf(+n());M=j,R=J*(Ue(m)?m>=0?1:-1:m),A[M+24>>3]=R;v[j+16>>2]=0;v[j+20>>2]=-1074790400;v[j+8>>2]=0;v[j+12>>2]=1072693248;m=be(A[qg(j+24|0,j+16|0,j+8|0)>>3]*32768);Ma:{if(D(m)<2147483648){f=~~m;break Ma}f=-2147483648}M=d,N=Jc(f),u[M>>1]=N;a=a-1|0;g=g+8|0;d=d+2|0;continue}}if(h){A[h>>3]=G}ab=j+32|0;e=e<<3}break}break Ka}v[i+176>>2]=0;v[i+180>>2]=1072693248;v[i+168>>2]=0;v[i+172>>2]=0;v[i+136>>2]=0;v[i+140>>2]=0;v[i+144>>2]=0;v[i+148>>2]=1072693248;a=v[i+188>>2];v[i+152>>2]=v[i+184>>2];v[i+156>>2]=a;a=v[i+164>>2];v[i+128>>2]=v[i+160>>2];v[i+132>>2]=a;j=i+416|0;E=ab-32|0;ab=E;M=E,N=B(v[b>>2],qd(x[b+34>>1])),v[M+4>>2]=N;mc(E+4|0,d>>>3|0);G=A[i+136>>3];d=g;f=v[E+4>>2];a=f;while(1){if(a){e=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);h=e<<24|e<<8&16711680;o=e>>>8|0;r=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);e=e>>>24|0;h=h|((o|r<<24)&65280|(e|r<<8)&255);l(0,(o|(r&255)<<24)&-16777216|(e|(r&16777215)<<8)&16711680|(r>>>8&65280|r>>>24));l(1,h|0);m=Xf(+n());m=D(Ue(m)?m>=0?1:-1:m);G=m>G?m:G;a=a-1|0;d=d+8|0;continue}else{Na:{a=G==0;if(a){break Na}J=a?1:1/G;d=v[b+20>>2];a=f;while(1){if(!a){break Na}p=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);h=p<<24|p<<8&16711680;o=p>>>8|0;r=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);e=o|r<<24;s=(o|(r&255)<<24)&-16777216;o=p>>>24|0;l(0,s|(o|(r&16777215)<<8)&16711680|(r>>>8&65280|r>>>24));l(1,h|(e&65280|(o|r<<8)&255));m=Xf(+n());M=E,R=J*(Ue(m)?m>=0?1:-1:m),A[M+24>>3]=R;v[E+16>>2]=0;v[E+20>>2]=-1074790400;v[E+8>>2]=0;v[E+12>>2]=1072693248;m=be(A[qg(E+24|0,E+16|0,E+8|0)>>3]*32768);Oa:{if(D(m)<2147483648){e=~~m;break Oa}e=-2147483648}M=d,N=Jc(e),u[M>>1]=N;a=a-1|0;g=g+8|0;d=d+2|0;continue}}if(j){A[j>>3]=G}ab=E+32|0;e=f<<3}break}}if(!e){break u}m=A[i+416>>3];if(m==1){break u}m=be(Ay(m*+x[b+32>>1],1,64));a=65535;Pa:{if(m>=65535){break Pa}a=0;if(m<=0){break Pa}a=~~m>>>0;if(m<4294967296&m>=0){break Pa}a=0}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break u}e=0;if(!d){break u}if(!(w[a+1|0]!=1|(f|0)!=12)){d=v[i+2580>>2];if(!w[a+2|0]){e=PM(b,g,d,C(30517578125e-15));break u}e=OM(b,g,d,C(30517578125e-15));break u}if(!(w[a+1|0]!=2|(f|0)!=12)){d=v[i+2580>>2];if(!w[a+2|0]){e=NM(b,g,d,C(30517578125e-15));break u}e=MM(b,g,d,C(30517578125e-15));break u}if(!(w[a+1|0]!=1|(f|0)!=13)){d=v[i+2580>>2];if(!w[a+2|0]){e=PM(b,g,d,C(1.1920928955078125e-7));break u}e=OM(b,g,d,C(1.1920928955078125e-7));break u}if(w[a+1|0]!=2|(f|0)!=13){break u}d=v[i+2580>>2];if(!w[a+2|0]){e=NM(b,g,d,C(1.1920928955078125e-7));break u}e=MM(b,g,d,C(1.1920928955078125e-7));break u}a=V(30480)|0}if((O()|0)!=(fa(30480)|0)){break d}_(a|0)|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)==1){break v}}qb(s);break u}a=P()|0;O()|0;break d}v[22452]=0;Q(146,c|0,e+K|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break f}}rc(H)}ab=i+2608|0;return e|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}qb(s);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}rc(H);S(a|0);L()}function aha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=ab-496|0;ab=d;qc(b);j=ab-16|0;ab=j;i=d+304|0;jq(j+8|0,i);h=b;b=v[j+12>>2];_b(j,h,v[j+8>>2],b);l=v[j+4>>2];if((l|0)==(b|0)){Ob(h,v[j+12>>2])}ab=j+16|0;b=(b|0)==(l|0);if(!b){qS(i)}a:{b:{c:{if(!b){break c}if(!sS(d+304|0)){break c}if(!Hb(h,Fc(rS(d+304|0),db))){break c}if(!c){f=1;break c}vd(a,32);t[d+303|0]=0;j=Bb(d+288|0);d:{e:{f:{g:{h:{i:{j:{if(!Ib(d+304|0,16224,4)){v[22452]=0;R(362,a|0,16777216);b=v[22452];v[22452]=0;if((b|0)==1){break b}v[22452]=0;b=T(151,h|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break b}v[22452]=0;Q(146,h|0,b-4|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break b}v[22452]=0;z=T(148,h|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break j}break b}k:{l:{m:{n:{o:{p:{if(((w[d+344|0]|w[d+345|0]<<8)-2185&65535)>>>0>1910){break p}v[22452]=0;b=T(151,h|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}v[22452]=0;Q(146,h|0,b-4|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break b}v[22452]=0;z=T(148,h|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break b}if(z>>>0<256){break p}v[22452]=0;b=T(151,h|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}if(b>>>0<=z>>>0){break p}v[22452]=0;b=Q(146,h|0,z|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}if(!b){break p}v[22452]=0;b=T(363,h|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}if(!b){break p}v[22452]=0;R(362,a|0,16777216);b=v[22452];v[22452]=0;if((b|0)==1){break b}b=w[d+344|0]|w[d+345|0]<<8;if(b>>>0>=4096){v[22452]=0;c=Q(1,d+104|0,16439)|0;b=v[22452];v[22452]=0;if((b|0)==1){break i}a=v[a+1298464>>2];v[22452]=0;U(364,a|0,1,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(c);break d}b=P()|0;O()|0;pb(c);break a}if(b>>>0<2194){break p}v[22452]=0;f=Q(1,d+104|0,15963)|0;b=v[22452];v[22452]=0;if((b|0)==1){break o}b=v[a+1298464>>2];v[22452]=0;U(364,b|0,4,f|0);b=v[22452];v[22452]=0;if((b|0)==1){break n}pb(f)}if(v[a+480180>>2]!=32){break j}b=w[d+344|0]|w[d+345|0]<<8;if((b&61440)!=20480){break k}b=b&4095;f=b<<16;if(Ib(d+364|0,13593,4)){break m}t[d+303|0]=1;break l}b=P()|0;O()|0;break a}b=P()|0;O()|0;pb(f);break a}if(b>>>0<297){break l}f=w[d+364|0]|w[d+365|0]<<8|f}v[a+1074308>>2]=f;break j}f=w[d+346|0]|w[d+347|0]<<8;if(!((f|0)!=2184&(b|0)!=2184)){t[d+303|0]=1;v[a+1074308>>2]=18284544;break j}if(!((b|0)!=535|(f|0)!=512)){if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)){break j}q:{if(FA(d+368|0,255,64)){v[a+1074308>>2]=18219008;v[22452]=0;b=Q(1,d+104|0,14800)|0;f=v[22452];v[22452]=0;if((f|0)!=1){break q}b=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[22452]=0;b=Q(1,d+104|0,16813)|0;f=v[22452];v[22452]=0;if((f|0)==1){break h}}tb(j,b);pb(b);t[d+303|0]=1;break j}if(!((b|0)!=532|(f|0)!=514)){if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)){break j}v[a+1074308>>2]=17367040;v[22452]=0;b=Q(1,d+104|0,14692)|0;f=v[22452];v[22452]=0;if((f|0)!=1){tb(j,b);pb(b);t[d+303|0]=1;break j}b=P()|0;O()|0;break a}if((b|0)!=768|(f|0)!=768|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24))|((w[d+336|0]|w[d+337|0]<<8)!=256|w[d+356|0]!=128)){break j}if(w[d+357|0]){break j}v[a+1074308>>2]=18285088;t[d+303|0]=1}b=v[a+480208>>2]&-17|(w[d+348|0]|w[d+349|0]<<8)<<1&16;v[a+480208>>2]=b;b=b&-5|(w[d+348|0]|w[d+349|0]<<8)>>>2&4;v[a+480208>>2]=b;b=b&-9|(w[d+348|0]|w[d+349|0]<<8)>>>2&8;v[a+480208>>2]=b;v[a+480208>>2]=b&-32769|(w[d+348|0]|w[d+349|0]<<8)<<3&32768;zq(d+216|0,d+304|4);v[22452]=0;W(213,d+104|0,v[d+216>>2],v[d+220>>2],w[d+224|0]);b=v[22452];v[22452]=0;if((b|0)==1){break g}b=d+104|0;tb(a+1298308|0,b);pb(b);if(!(!(w[d+350|0]&4)|v[a+1074308>>2]-18285314>>>0>4276681982)){v[a+480216>>2]=w[d+334|0];v[a+480220>>2]=w[d+335|0]}b=w[d+352|0];v[a+480200>>2]=b>>>0>128?256:b<<1;b=w[d+354|0];if(b){v[a+480196>>2]=b}t[d+104|0]=31;t[d+216|0]=w[d+355|0];b=d+104|0;f=d+216|0;I=a,J=B(w[$e(b,f)|0],1e4),v[I+480204>>2]=J;t[d+104|0]=w[d+353|0];t[d+216|0]=128;I=a,J=w[Qb(b,f)|0],v[I+480228>>2]=J;f=0;while(1){if((f|0)==64){r:{v[22452]=0;Q(146,h|0,192)|0;b=v[22452];v[22452]=0;if((b|0)==1){break b}if(v[a+480180>>2]==16777216&((w[d+344|0]|w[d+345|0]<<8)-2187&65535)>>>0<=2){break r}b=Kb(a+484360|0);f=w[d+336|0]|w[d+337|0]<<8;v[22452]=0;ea(337,b|0,h|0,f|0,255,254)|0;b=v[22452];v[22452]=0;if((b|0)==1){break b}break e}}else{b=(d+304|0)+f|0;l=b- -64|0;s:{if(w[l|0]==255){break s}m=(f<<5)+a|0;i=m+480280|0;Le(i);I=m+480286|0,J=Ld(w[b+128|0],0,64),u[I>>1]=J;b=t[l|0];if((b|0)<0){v[i>>2]=v[i>>2]|1024;b=w[l|0]}b=b&127;if(b>>>0<=64){u[m+480284>>1]=b<<2;break s}if((b|0)!=100){break s}v[i>>2]=v[i>>2]|256}f=f+1|0;continue}break}f=0;v[22452]=0;b=T(185,h|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break f}if(b){break d}v[22452]=0;b=T(148,h|0)|0;i=v[22452];v[22452]=0;t:{if((i|0)==1){break t}if(b>>>0>4e3){break d}i=Kb(a+484360|0);v[22452]=0;b=Y(365,i|0,h|0,b|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break t}if(!b){break d}break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}s=Pb(d+272|0);m=Pb(d+256|0);l=Pb(d+240|0);b=w[d+338|0]|w[d+339|0]<<8;f=0;v[22452]=0;b=Y(366,h|0,s|0,b|0)|0;i=v[22452];v[22452]=0;u:{v:{w:{if((i|0)==1){break w}if(!b){break u}b=w[d+340|0]|w[d+341|0]<<8;v[22452]=0;b=Y(366,h|0,m|0,b|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break w}if(!b){break u}b=w[d+342|0]|w[d+343|0]<<8;v[22452]=0;b=Y(366,h|0,l|0,b|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break w}if(!b){break u}v[d+236>>2]=-1;I=d,J=wb(v[s>>2]),v[I+104>>2]=J;i=wb(v[s+4>>2]);while(1){b=v[d+104>>2];if(Tb(b,i)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+236>>2])){v[d+236>>2]=b}te(d+104|0);continue}else{I=d,J=wb(v[m>>2]),v[I+104>>2]=J;i=wb(v[m+4>>2]);while(1){b=v[d+104>>2];if(Tb(b,i)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+236>>2])){v[d+236>>2]=b}te(d+104|0);continue}else{I=d,J=wb(v[l>>2]),v[I+104>>2]=J;i=wb(v[l+4>>2]);x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{while(1){b=v[d+104>>2];if(Tb(b,i)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+236>>2])){v[d+236>>2]=b}te(d+104|0);continue}else{if(t[d+350|0]&1){v[d+104>>2]=w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24);I=d,J=v[zb(d+236|0,d+104|0)>>2],v[I+236>>2]=J}if((w[d+346|0]|w[d+347|0]<<8)!=532){break F}b=w[d+344|0]|w[d+345|0]<<8;if(w[d+335|0]|(b?(b|0)!=532:0)|(w[d+334|0]|w[d+357|0])){break F}if(w[d+348|0]&192|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24))){break F}if(w[d+338|0]|w[d+339|0]<<8){break G}b=w[d+340|0]|w[d+341|0]<<8;if(!b){break G}if((v[h+8>>2]+(nc(v[m>>2],v[m+4>>2])<<2)|0)+2>>>0>y[d+236>>2]){break G}}break}while(1){if((f&65535)>>>0<(b&65535)>>>0){v[22452]=0;b=T(148,h|0)|0;e=v[22452];v[22452]=0;H:{if((e|0)!=1){if(!b){break H}gg(h,((f&65535)<<2)+4|0);break G}b=P()|0;O()|0;break v}f=f+1|0;b=w[d+340|0]|w[d+341|0]<<8;continue}break}v[22452]=0;b=Q(1,d+104|0,14950)|0;e=v[22452];v[22452]=0;if((e|0)==1){break E}tb(j,b);pb(b)}e=1;if(w[d+344|0]|w[d+345|0]<<8){break F}v[22452]=0;b=Q(1,d+104|0,15311)|0;f=v[22452];v[22452]=0;if((f|0)==1){break D}tb(j,b);pb(b)}b=w[d+350|0]|w[d+351|0]<<8;I:{if(b&2){v[22452]=0;f=T(185,h|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break y}v[22452]=0;b=f<<3;i=Q(147,h|0,b|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break y}if(!(!i|y[d+236>>2]<b+v[h+8>>2]>>>0)){v[22452]=0;b=a+1298408|0;R(367,b|0,f|0);i=v[22452];v[22452]=0;if((i|0)==1){break y}I=d,J=wb(v[b>>2]),v[I+216>>2]=J;i=wb(v[a+1298412>>2]);J:{K:{while(1){b=v[d+216>>2];if(!Tb(b,i)){if(!(!f&e)){break I}if(!(w[d+350|0]&4)){break J}v[22452]=0;b=Q(1,d+104|0,15405)|0;e=v[22452];v[22452]=0;if((e|0)==1){break K}tb(j,b);pb(b);break I}v[22452]=0;R(368,h|0,d+104|0);k=v[22452];v[22452]=0;if((k|0)!=1){Jb(b,0,44);k=w[d+104|0]|w[d+105|0]<<8;if(w[d+106|0]|w[d+107|0]<<8?1:k){v[b+20>>2]=(k>>>9|0)+80;I=b,J=Sb((w[d+104|0]|w[d+105|0]<<8)>>>5&15,1,12)-1|0,v[I+16>>2]=J;I=b,J=Sb((w[d+104|0]|w[d+105|0]<<8)&31,1,31),v[I+12>>2]=J;I=b,J=Sb((w[d+106|0]|w[d+107|0]<<8)>>>11|0,0,23),v[I+8>>2]=J;I=b,J=Sb((w[d+106|0]|w[d+107|0]<<8)>>>5&63,0,59),v[I+4>>2]=J;I=b,J=Sb((w[d+106|0]|w[d+107|0]<<8)<<1&62,0,59),v[I>>2]=J}v[b+44>>2]=w[d+108|0]|w[d+109|0]<<8|(w[d+110|0]<<16|w[d+111|0]<<24);v[d+216>>2]=v[d+216>>2]+48;continue}break}b=P()|0;O()|0;break v}b=P()|0;O()|0;break v}v[22452]=0;b=Q(1,d+104|0,14977)|0;e=v[22452];v[22452]=0;if((e|0)!=1){tb(j,b);pb(b);break I}b=P()|0;O()|0;break v}gg(h,2);break I}if(!(b>>>0<2&e)){break I}v[22452]=0;b=T(185,h|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break x}if(!b){v[22452]=0;b=Q(1,d+104|0,14950)|0;e=v[22452];v[22452]=0;if((e|0)!=1){tb(j,b);pb(b);break I}b=P()|0;O()|0;break v}gg(h,2)}L:{if(!(w[d+350|0]&8?1:w[d+348|0]&128)){break L}v[22452]=0;b=a+901404|0;e=Q(369,h|0,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break C}if(!e){break L}EA(b)}if((w[d+344|0]|w[d+345|0]<<8)>>>0<=531){Pp(a+901404|0)}v[22452]=0;A=T(165,d+216|0)|0;b=v[22452];v[22452]=0;M:{N:{O:{if((b|0)!=1){v[22452]=0;b=Q(359,h|0,13830)|0;e=v[22452];v[22452]=0;if((e|0)==1){break O}if(b){v[22452]=0;b=T(148,h|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break N}v[22452]=0;U(181,d+192|0,h|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break N}b=d+192|0;e=bc(d+104|0,b);Mc(A,e);qb(e);qb(b)}u[a+480188>>1]=1;v[22452]=0;b=Q(359,h|0,13835)|0;e=v[22452];v[22452]=0;if((e|0)==1){break O}if(!b){break A}v[22452]=0;b=T(148,h|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){v[22452]=0;U(181,d+192|0,h|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break M}}b=P()|0;O()|0;break z}b=P()|0;O()|0;break v}b=P()|0;O()|0;break z}b=P()|0;O()|0;break z}b=d+192|0;e=bc(d+104|0,b);qb(b);v[22452]=0;b=T(151,e|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break B}u[d+192>>1]=(b>>>0)/20;b=x[Lc(26644,d+192|0)>>1];u[a+480188>>1]=b;f=0;while(1){if((b|0)==(f|0)){qb(e);break A}v[22452]=0;U(370,e|0,((f<<5)+a|0)+480289|0,20);i=v[22452];v[22452]=0;if((i|0)!=1){f=f+1|0;continue}break}break B}b=P()|0;O()|0;break v}b=P()|0;O()|0;break v}b=P()|0;O()|0;break v}b=P()|0;O()|0;qb(e);break z}P:{b=v[d+236>>2];e=v[h+8>>2];Q:{if(b>>>0>=e>>>0){f=b-e|0;break Q}v[22452]=0;f=T(193,h|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break P}}v[22452]=0;U(181,d+104|0,h|0,f|0);b=v[22452];v[22452]=0;if((b|0)==1){break P}b=d+104|0;D=bc(d+192|0,b);qb(b);v[22452]=0;E=Q(371,a|0,D|0)|0;b=v[22452];v[22452]=0;R:{S:{T:{if((b|0)==1){break T}if(!(t[d+350|0]&1)|!(w[d+358|0]|w[d+359|0]<<8)){break S}b=w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24);v[22452]=0;b=Q(146,h|0,b|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break T}if(!b){break S}b=w[d+358|0]|w[d+359|0]<<8;v[22452]=0;W(326,a+1298332|0,h|0,b|0,4);b=v[22452];v[22452]=0;if((b|0)!=1){break S}}b=P()|0;O()|0;break R}e=a+480192|0;u[e>>1]=0;if(w[d+348|0]&4){u[d+104>>1]=w[d+338|0]|w[d+339|0]<<8;u[d+32>>1]=255;g=x[Lc(d+104|0,d+32|0)>>1];u[e>>1]=g}f=0;U:{while(1){if((g&65535)>>>0<=f>>>0){v[d+188>>2]=0;f=0;b=w[d+340|0]|w[d+341|0]<<8;if(b){b=Fb(v[m>>2],b-1|0);v[d+188>>2]=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+80;b=w[d+340|0]|w[d+341|0]<<8}else{b=0}u[d+104>>1]=b;u[d+32>>1]=3999;n=a+480190|0;g=x[Lc(d+104|0,d+32|0)>>1];u[n>>1]=g;k=c&2;p=d+124|0;r=a+1298464|0;while(1){V:{W:{X:{Y:{Z:{_:{$:{aa:{if((g&65535)>>>0>f>>>0){b=Fb(v[m>>2],f);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!b){break W}v[22452]=0;b=Q(146,h|0,b|0)|0;e=v[22452];v[22452]=0;ba:{ca:{da:{ea:{fa:{if((e|0)==1){break fa}if(!b){break W}v[22452]=0;b=Q(372,h|0,d+104|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break fa}if(!b){break W}v[22452]=0;g=f+1|0;e=B(g,104)+a|0;b=e+484380|0;i=Q(373,d+104|0,b|0)|0;o=v[22452];v[22452]=0;if((o|0)==1){break ea}zq(d+88|0,p);v[22452]=0;W(213,d+32|0,v[d+88>>2],v[d+92>>2],w[d+96|0]);o=v[22452];v[22452]=0;if((o|0)==1){break da}o=d+32|0;sc(((g<<5)+a|0)+946304|0,o);pb(o);v[22452]=0;i=Q(146,h|0,i|0)|0;o=v[22452];v[22452]=0;if((o|0)==1){break ea}if(!i){break W}e=x[e+484414>>1];if(!(e&512)){break ca}v[22452]=0;e=Q(374,h|0,d+32|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break aa}if(!e){break ba}v[d+16>>2]=v[d+40>>2];e=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=e;fl(b,1,d+8|0);break ba}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}if(!(e&16384)){e=w[d+344|0]|w[d+345|0]<<8;i=Gc(d+32|0,w[d+122|0]&2?16:8,1,0,(w[d+150|0]^-1)&1);g=w[d+122|0];if(!(!(g&4)|e>>>0<532)){eo(i,3);g=w[d+122|0]}ga:{ha:{if(g&8){g=w[d+150|0]&4?5:4;break ha}e=w[d+150|0];if(!(g&2)){g=10;if((e|0)==255){break ha}}if(e&2){t[i+2|0]=1;e=w[d+150|0]}if(e&4){nf(i,2);e=w[d+150|0]}if(!(e&8)){break ga}g=9;if(!(w[d+122|0]&2)){break ga}}nf(i,g)}if(k){g=0;v[22452]=0;Y(210,d+32|0,b|0,h|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){break Y}break V}g=1;e=w[d+35|0];if(e>>>0>17){break X}e=1<<e;if(!(e&63503)){if(!(e&198144)){break X}break Z}if(w[d+32|0]){break Z}break Y}v[22452]=0;R(375,h|0,d+84|0);b=v[22452];v[22452]=0;if((b|0)==1){break _}b=v[d+84>>2];if(!(!k|!b)){e=Bb(d+32|0);v[22452]=0;U(262,h|0,e|0,b|0);b=v[22452];v[22452]=0;ia:{ja:{ka:{la:{ma:{na:{oa:{if((b|0)!=1){v[22452]=0;R(376,d+72|0,16361);b=v[22452];v[22452]=0;if((b|0)==1){break oa}v[d+68>>2]=g;v[22452]=0;U(11,d+56|0,0,e|0);b=v[22452];v[22452]=0;if((b|0)==1){break na}v[22452]=0;W(377,d+88|0,d+72|0,d+68|0,d+56|0);b=v[22452];v[22452]=0;if((b|0)==1){break ma}b=v[r>>2];v[22452]=0;U(364,b|0,2,d+88|0);b=v[22452];v[22452]=0;if((b|0)==1){break la}pb(d+88|0);pb(d+56|0);yb(d+72|0);pb(e);break ba}b=P()|0;O()|0;break ia}b=P()|0;O()|0;break ia}b=P()|0;O()|0;break ja}b=P()|0;O()|0;break ka}b=P()|0;O()|0;pb(d+88|0)}pb(d+56|0)}yb(d+72|0)}pb(e);break R}v[22452]=0;Q(179,h|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break _}}g=0;break X}u[d+104>>1]=1;u[d+32>>1]=g;I=a+480190|0,J=x[Ne(d+104|0,d+32|0)>>1],u[I>>1]=J;if(!(q&1)|(w[d+344|0]|w[d+345|0]<<8)!=516|(w[d+350|0]|w[d+351|0]<<8|(w[d+346|0]|w[d+347|0]<<8)!=512)){break $}if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)|((w[d+348|0]|w[d+349|0]<<8)&65527)!=21|(w[d+352|0]!=128|w[d+353|0]!=48)){break $}if(w[d+357|0]|w[d+356|0]!=128|(w[d+358|0]|w[d+359|0]<<8)){break $}b=d+432|0;g=d+368|0;f=1;while(1)if((b|0)==(g|0)){b=d+496|0;g=d+432|0;while(1)if((b|0)==(g|0)){g=20;while(1){if((g|0)==26){pa:{if(!(f&1)){break $}v[22452]=0;b=Q(1,d+104|0,9840)|0;e=v[22452];v[22452]=0;if((e|0)==1){break pa}tb(j,b);pb(b);break $}}else{f=!w[(d+g|0)+308|0]&f;g=g+1|0;continue}break}b=P()|0;O()|0;break R}else{f=w[g|0]==64&f;g=g+1|0;continue}}else{f=(w[g|0]&127)==32&f;g=g+1|0;continue}}b=P()|0;O()|0;break R}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;b=nc(v[l>>2],v[l+4>>2]);u[d+104>>1]=b;q=x[Lc(d+104|0,v[a+8>>2]+10|0)>>1];u[d+84>>1]=q;qa:{ra:{sa:{ta:{if((b|0)!=(q|0)){v[22452]=0;Z(378,d+32|0);b=v[22452];v[22452]=0;if((b|0)==1){break qa}b=v[l+4>>2];e=v[l>>2];v[22452]=0;I=d,J=nc(e,b),v[I+88>>2]=J;W(379,d+104|0,d+32|0,d+88|0,d+84|0);b=v[22452];v[22452]=0;if((b|0)==1){break sa}b=v[a+1298464>>2];v[22452]=0;U(364,b|0,2,d+104|0);b=v[22452];v[22452]=0;if((b|0)==1){break ta}pb(d+104|0);yb(d+32|0)}if(!(c&1)){u[d+84>>1]=0;q=0}g=a+480188|0;b=0;ua:{va:{wa:{xa:{ya:{za:{while(1){Aa:{if((b|0)==(q|0)){Ba:{Ca:{b=v[d+188>>2];if(!b){break Ca}v[22452]=0;Q(146,h|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Ba}if(!C){break Ca}while(1){Da:{v[22452]=0;b=Q(147,h|0,4)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Da}if(!b){break Ca}v[22452]=0;b=Q(359,h|0,13804)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Da}Ea:{if(!b){v[22452]=0;b=Q(359,h|0,13809)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Da}if(!b){break Ea}}v[22452]=0;b=T(148,h|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){gg(h,8);if(!(b&1616928864)|b&-2139062144){break Ea}break Ca}b=P()|0;O()|0;break R}v[22452]=0;b=T(185,h|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Da}v[22452]=0;Q(179,h|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){continue}}break}b=P()|0;O()|0;break R}v[22452]=0;b=Q(380,a|0,h|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Ba}b=b|w[d+303|0];t[d+303|0]=b;if(!(!b|E)){It(a+1074312|0);t[a+1074368|0]=0}v[22452]=0;W(381,a|0,h|0,0,d+303|0);b=v[22452];v[22452]=0;if((b|0)==1){break Ba}v[22452]=0;n=a+484344|0;R(216,n|0,q|0);b=v[22452];v[22452]=0;if((b|0)==1){break Ba}p=a+480188|0;H=a+480183|0;f=0;Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{while(1){Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{if((f|0)!=(q|0)){b=Fb(v[l>>2],f);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(b){v[22452]=0;b=Q(146,h|0,b|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Va}if(b){break Ua}}v[22452]=0;b=Y(217,n|0,f&65535,64)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Va}if(b){break Wa}u[d+68>>1]=f;v[22452]=0;Z(382,d+32|0);b=v[22452];v[22452]=0;if((b|0)==1){break _a}v[22452]=0;U(383,d+104|0,d+32|0,d+68|0);b=v[22452];v[22452]=0;if((b|0)==1){break Za}b=v[a+1298464>>2];v[22452]=0;U(364,b|0,2,d+104|0);b=v[22452];v[22452]=0;if((b|0)==1){break Ya}pb(d+104|0);yb(d+32|0)}$a:{if(!v[a+1074308>>2]){f=w[d+344|0]|w[d+345|0]<<8;if((f|0)!=2184){break $a}v[a+1074308>>2]=18284544}if(pd(j)){break Sa}f=w[d+344|0]|w[d+345|0]<<8}b=f&65535;if((b|0)!=8191){break Ta}g=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24);break Ha}b=P()|0;O()|0;break R}b=P()|0;O()|0;break Xa}b=P()|0;O()|0;pb(d+104|0)}yb(d+32|0);break R}b=Rb(n,f);v[22452]=0;R(384,b|0,A|0);b=v[22452];v[22452]=0;if((b|0)!=1){break Qa}}b=P()|0;O()|0;break R}v[22452]=0;b=T(185,h|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Ia}v[22452]=0;F=T(185,h|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Ja}v[22452]=0;c=Q(179,h|0,4)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Ja}if(!c){break Qa}v[22452]=0;c=Y(217,n|0,f&65535,F|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Ja}if(!c){break Qa}v[22452]=0;U(181,d+32|0,h|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break Ka}b=d+32|0;k=bc(d+104|0,b);qb(b);b=Rb(n,f);v[22452]=0;R(384,b|0,A|0);b=v[22452];v[22452]=0;if((b|0)==1){break Ma}b=x[p>>1];v[22452]=0;r=Q(385,d+32|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Na}b=x[p>>1];c=d+72|0;kh(c);v[22452]=0;o=Y(386,d+88|0,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Pa}I=d,J=vg(Rb(n,f)),v[I+56>>2]=J;C=0;while(1){ab:{bb:{cb:{db:{if(C>>>0>=F>>>0){break db}v[22452]=0;b=Q(147,d+104|0,1)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Ra}if(!b){break db}v[22452]=0;b=T(197,k|0)|0;c=v[22452];v[22452]=0;eb:{if((c|0)!=1){b=b<<24>>24;if(b){break eb}DS(d+56|0,x[p>>1]);C=C+1|0;continue}break Ra}fb:{c=b&127;i=c?c-1&65535:0;if(Ic(v[d+32>>2],v[d+36>>2])>>>0>i>>>0){break fb}v[22452]=0;t[d+72|0]=0;c=i+1|0;U(387,r|0,c|0,d+72|0);e=v[22452];v[22452]=0;if((e|0)==1){break Ra}e=d+72|0;kh(e);v[22452]=0;U(388,o|0,c|0,e|0);c=v[22452];v[22452]=0;if((c|0)!=1){break fb}break Ra}if((b|0)<0){v[22452]=0;b=T(197,k|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Ra}I=Cb(v[d+32>>2],i),J=b,t[I|0]=J}g=d+72|0;kh(g);if(i>>>0<x[p>>1]){g=ud(v[d+56>>2],i)}b=Cb(v[d+32>>2],i);e=w[b|0];if(e&16){I=g,J=w[ud(v[d+88>>2],i)|0],t[I|0]=J;e=w[b|0]}if(e&32){I=g,J=w[ud(v[d+88>>2],i)+1|0],t[I+1|0]=J;e=w[b|0]}if(e&64){c=ud(v[d+88>>2],i);t[g+2|0]=w[c+2|0];t[g+4|0]=w[c+4|0];e=w[b|0]}if(e<<24>>24<0){c=ud(v[d+88>>2],i);t[g+3|0]=w[c+3|0];t[g+5|0]=w[c+5|0];e=w[b|0]}if(e&1){v[22452]=0;b=T(197,k|0)|0;c=v[22452];v[22452]=0;gb:{hb:{if((c|0)!=1){b=b+(((b^-1)&128)>>>7|0)|0;if(!(t[H|0]&1)){break hb}c=b;break gb}break Ra}c=253;if((b-121&255)>>>0<132){break gb}c=(b&255)==253?0:b}t[g|0]=c;I=ud(v[d+88>>2],i),J=c,t[I|0]=J;b=Cb(v[d+32>>2],i)}if(w[b|0]&2){v[22452]=0;b=T(197,k|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Ra}t[g+1|0]=b;I=ud(v[d+88>>2],i),J=b,t[I+1|0]=J;b=Cb(v[d+32>>2],i)}if(!(w[b|0]&4)){break ab}v[22452]=0;b=T(197,k|0)|0;c=v[22452];v[22452]=0;ib:{jb:{if((c|0)!=1){if(b>>>0>64){break jb}t[g+4|0]=b;e=1;break ib}break Ra}if(b<<24>>24<=-64){e=2;t[g+2|0]=2;b=b^-128;t[g+4|0]=b;break bb}if(b>>>0<=74){e=5;t[g+2|0]=5;b=b-65|0;t[g+4|0]=b;break bb}if(b>>>0<=84){e=6;t[g+2|0]=6;b=b-75|0;t[g+4|0]=b;break bb}if(b>>>0<=94){e=3;t[g+2|0]=3;b=b-85|0;t[g+4|0]=b;break bb}if(b>>>0<=104){e=4;t[g+2|0]=4;b=b-95|0;t[g+4|0]=b;break bb}if(b>>>0<=114){e=13;t[g+2|0]=13;b=b-105|0;t[g+4|0]=b;break bb}if(b>>>0<=124){e=12;t[g+2|0]=12;b=b-115|0;t[g+4|0]=b;break bb}c=b+63|0;if((c&255)>>>0<=9){t[g+4|0]=c;e=11;t[g+2|0]=11;b=c;break bb}c=b+53|0;G=c&255;if(G>>>0<=9){t[g+4|0]=c;e=8;t[g+2|0]=8;if(!G){b=0;break bb}if(v[a+1074308>>2]-1>>>0>18285139){break cb}e=7;t[g+2|0]=7;break cb}b=b+33|0;if((b&255)>>>0>=10){b=w[g+4|0];e=w[g+2|0];break bb}t[g+4|0]=b;e=15}t[g+2|0]=e;break bb}Eh(o);Xb(r);qb(d+104|0);break Qa}b=c}c=ud(v[d+88>>2],i);t[c+4|0]=b;t[c+2|0]=e;b=Cb(v[d+32>>2],i)}if(!(w[b|0]&8)){continue}v[22452]=0;R(254,d+24|0,k|0);b=v[22452];v[22452]=0;if((b|0)!=1){b=d+24|0;t[g+3|0]=w[b|0];I=g,J=w[Zc(b)|0],t[I+5|0]=J;CA(g,1);b=ud(v[d+88>>2],i);t[b+3|0]=w[g+3|0];t[b+5|0]=w[g+5|0];continue}break}break Ra}g=b-4176|0;kb:{switch(b>>>12|0){case 0:if(E){v[22452]=0;b=Q(1,d+104|0,8327)|0;c=v[22452];v[22452]=0;if((c|0)!=1){tb(j,b);pb(b);break Ga}b=P()|0;O()|0;break R}lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{yb:{if((f&65535)==532){g=w[d+346|0]|w[d+347|0]<<8;zb:{if((g|0)!=512){break zb}if((w[d+348|0]|w[d+349|0]<<8)==9){Ab:{if(w[d+335|0]|(w[d+350|0]|w[d+351|0]<<8)|(w[d+334|0]|(w[d+338|0]|w[d+339|0]<<8))){break Ab}if(((w[d+342|0]|w[d+343|0]<<8)+1|0)!=(w[d+336|0]|w[d+337|0]<<8)|w[d+352|0]!=128|(w[d+353|0]!=100|w[d+354|0]!=1)){break Ab}if(w[d+357|0]|w[d+356|0]!=128|(w[d+358|0]|w[d+359|0]<<8|(w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24)))){break Ab}if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)){break Ab}v[22452]=0;b=Q(1,d+104|0,9821)|0;c=v[22452];v[22452]=0;if((c|0)!=1){tb(j,b);pb(b);break Ga}b=P()|0;O()|0;break R}g=w[d+346|0]|w[d+347|0]<<8;if((g|0)!=512){break zb}}if(!(w[d+335|0]|w[d+334|0]|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){v[a+1074308>>2]=16777381;v[22452]=0;b=Q(1,d+104|0,14881)|0;c=v[22452];v[22452]=0;if((c|0)!=1){tb(j,b);pb(b);t[d+303|0]=1;break Ga}b=P()|0;O()|0;break R}g=w[d+346|0]|w[d+347|0]<<8}f=532;Bb:{if((g&65535)!=532){break Bb}if(Ib(d+364|0,14069,4)){break Bb}v[22452]=0;b=Q(1,d+104|0,8365)|0;c=v[22452];v[22452]=0;if((c|0)!=1){tb(j,b);pb(b);v[22452]=0;Q(259,a+1074312|0,38)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break Ga}break Fa}b=P()|0;O()|0;break R}g=w[d+346|0]|w[d+347|0]<<8;if((g|0)!=532){break xb}if((w[d+350|0]|w[d+351|0]<<8)>>>0>1){break wb}if(w[d+357|0]|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24))|(!x[a+480190>>1]|((w[d+348|0]|w[d+349|0]<<8)&4294)!=4)){break yb}v[22452]=0;e=Q(55,d+104|0,13451)|0;b=v[22452];v[22452]=0;if((b|0)==1){break ub}b=ab-16|0;ab=b;c=ab-16|0;ab=c;Lu(c+8|0,a+484527|0);$R(b+8|0,v[c+8>>2],v[c+12>>2]);ab=c+16|0;qe(b,e);c=yc(v[b+8>>2],v[b+12>>2],v[b>>2],v[b+4>>2]);ab=b+16|0;pb(e);if(c){break vb}f=w[d+344|0]|w[d+345|0]<<8}if(f&65535){break yb}if(pd(j)){break sb}}g=w[d+346|0]|w[d+347|0]<<8}if((g&65535)>>>0>767){break Ga}}if(!pd(j)){break Ga}if((g&65535)>>>0<533){break qb}v[22452]=0;b=Q(1,d+104|0,14914)|0;c=v[22452];v[22452]=0;if((c|0)==1){break rb}tb(j,b);pb(b);break pb}v[22452]=0;b=Q(1,d+104|0,8391)|0;c=v[22452];v[22452]=0;if((c|0)==1){break tb}tb(j,b);pb(b);break Ga}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}v[22452]=0;b=Q(1,d+104|0,9711)|0;c=v[22452];v[22452]=0;if((c|0)!=1){tb(j,b);pb(b);break Ga}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}if((f&65535)>>>0>=533){v[22452]=0;R(389,d+32|0,3976);b=v[22452];v[22452]=0;Cb:{if((b|0)!=1){b=w[d+344|0]|w[d+345|0]<<8;v[22452]=0;v[d+88>>2]=b-532;U(390,d+104|0,d+32|0,d+88|0);b=v[22452];v[22452]=0;if((b|0)==1){break Cb}b=d+104|0;tb(j,b);pb(b);yb(d+32|0);break pb}b=P()|0;O()|0;break R}b=P()|0;O()|0;yb(d+32|0);break R}v[22452]=0;R(260,d+32|0,4275);b=v[22452];v[22452]=0;if((b|0)==1){break ob}b=w[d+344|0]|w[d+345|0]<<8;v[d+72>>2]=b>>>8&15;v[22452]=0;v[d+56>>2]=b&255;R(391,d+88|0,d+56|0);b=v[22452];v[22452]=0;if((b|0)==1){break nb}v[22452]=0;W(377,d+104|0,d+32|0,d+72|0,d+88|0);b=v[22452];v[22452]=0;if((b|0)==1){break mb}b=d+104|0;tb(j,b);pb(b);pb(d+88|0);yb(d+32|0)}b=a+1298408|0;if(!jc(v[b>>2],v[a+1298412>>2])){break Ga}c=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24);if(!c){break Ga}c=EC(w[d+344|0]|w[d+345|0]<<8,c);e=bq(d+104|0);v[e+44>>2]=c;v[22452]=0;R(392,b|0,e|0);b=v[22452];v[22452]=0;if((b|0)!=1){break Ga}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break lb}b=P()|0;O()|0;pb(d+88|0)}yb(d+32|0);break R;case 4:v[22452]=0;Z(393,d+32|0);b=v[22452];v[22452]=0;Db:{Eb:{Fb:{if((b|0)!=1){b=w[d+344|0]|w[d+345|0]<<8;v[d+72>>2]=b>>>8&15;v[22452]=0;v[d+56>>2]=b&255;R(391,d+88|0,d+56|0);b=v[22452];v[22452]=0;if((b|0)==1){break Fb}v[22452]=0;W(377,d+104|0,d+32|0,d+72|0,d+88|0);b=v[22452];v[22452]=0;if((b|0)==1){break Eb}b=d+104|0;tb(j,b);pb(b);pb(d+88|0);yb(d+32|0);break Ga}b=P()|0;O()|0;break R}b=P()|0;O()|0;break Db}b=P()|0;O()|0;pb(d+88|0)}yb(d+32|0);break R;case 6:v[22452]=0;b=Q(1,d+104|0,8327)|0;c=v[22452];v[22452]=0;if((c|0)!=1){tb(j,b);pb(b);break Ga}b=P()|0;O()|0;break R;case 7:if(!((f&65535)!=32767|(w[d+346|0]|w[d+347|0]<<8)!=533)){v[22452]=0;b=Q(1,d+104|0,5003)|0;c=v[22452];v[22452]=0;if((c|0)!=1){tb(j,b);pb(b);break Ga}b=P()|0;O()|0;break R}v[22452]=0;R(128,d+32|0,4111);b=v[22452];v[22452]=0;Gb:{if((b|0)!=1){b=w[d+344|0]|w[d+345|0]<<8;v[d+88>>2]=b>>>8&15;v[d+72>>2]=b>>>4&15;v[22452]=0;v[d+56>>2]=b&15;ga(129,d+104|0,d+32|0,d+88|0,d+72|0,d+56|0);b=v[22452];v[22452]=0;if((b|0)==1){break Gb}b=d+104|0;tb(j,b);pb(b);yb(d+32|0);break Ga}b=P()|0;O()|0;break R}b=P()|0;O()|0;yb(d+32|0);break R;case 1:break Ha;case 13:break kb;default:break Ga}}v[22452]=0;b=Q(1,d+104|0,6084)|0;c=v[22452];v[22452]=0;if((c|0)!=1){tb(j,b);pb(b);break Ga}b=P()|0;O()|0;break R}v[22452]=0;c=Q(1,d+32|0,17558)|0;b=v[22452];v[22452]=0;Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{if((b|0)!=1){b=v[a+1074308>>2];v[22452]=0;R(131,d+88|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break Mb}v[22452]=0;U(2,d+104|0,c|0,d+88|0);b=v[22452];v[22452]=0;if((b|0)==1){break Lb}e=d+104|0;b=tb(j,e);pb(e);pb(d+88|0);pb(c);if(!Ib(d+364|0,13593,4)|((w[d+344|0]|w[d+345|0]<<8)&61440)!=20480){break Hb}v[22452]=0;c=Q(1,d+104|0,16825)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Jb}v[22452]=0;Q(89,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Ib}pb(c);break Ga}b=P()|0;O()|0;break R}b=P()|0;O()|0;break Kb}b=P()|0;O()|0;pb(d+88|0)}pb(c);break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;pb(c);break R}if(!UD(v[a+1074308>>2])){break Ga}v[22452]=0;c=Q(1,d+104|0,17061)|0;e=v[22452];v[22452]=0;Nb:{if((e|0)!=1){v[22452]=0;Q(89,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Nb}pb(c);break Ga}b=P()|0;O()|0;break R}b=P()|0;O()|0;pb(c);break R}b=P()|0;O()|0;u[d+68>>1]=f;Eh(o);break Oa}f=f+1|0;continue}break}b=P()|0;O()|0;u[d+68>>1]=f}Xb(r);break La}b=P()|0;O()|0;u[d+68>>1]=f;break La}b=P()|0;O()|0;u[d+68>>1]=f}qb(d+104|0);break R}b=P()|0;O()|0;u[d+68>>1]=f;break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}b=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24);v[22452]=0;U(394,d+104|0,f&65535,b|0);b=v[22452];v[22452]=0;Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{if((b|0)!=1){b=d+104|0;tb(j,b);pb(b);if((g|0)>1915){break Tb}f=v[a+480208>>2];if(!(f&16)){break Sb}v[22452]=0;Q(259,a+1074312|0,7)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Fa}break Rb}b=P()|0;O()|0;break R}if(g>>>0>4200){break Pb}f=v[a+480208>>2]}if(!(f&16)){v[22452]=0;Q(259,a+1074312|0,7)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Fa}}if((g|0)>2385){break Qb}}v[22452]=0;Q(259,a+1074312|0,38)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Fa}}v[22452]=0;b=Q(259,a+1074312|0,102)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Fa}v[22452]=0;Q(259,b|0,48)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Fa}break Ob}if(g>>>0>4383){break Ga}}v[22452]=0;b=Y(258,a+1074312|0,116,1)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Fa}v[22452]=0;Q(259,b|0,115)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Fa}}Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{_b:{b=v[a+480180>>2];f=(b|0)==16777216;if(!f){break _b}$b:{if((w[d+344|0]|w[d+345|0]<<8)>>>0<=2185){f=(b|0)==16777216;break $b}v[22452]=0;b=Q(146,h|0,z|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Ba}if(b){b=w[d+344|0]|w[d+345|0]<<8;v[22452]=0;U(395,a|0,h|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break Ba}}b=v[a+480180>>2];f=(b|0)==16777216;if((b|0)!=16777216){break _b}}v[22452]=0;Q(1,d+104|0,13777)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break Zb}b=P()|0;O()|0;break R}v[22452]=0;R(260,d+32|0,4275);b=v[22452];v[22452]=0;if((b|0)==1){break Yb}b=w[d+346|0]|w[d+347|0]<<8;v[d+72>>2]=b>>>8;v[22452]=0;v[d+56>>2]=b&255;R(391,d+88|0,d+56|0);b=v[22452];v[22452]=0;if((b|0)==1){break Xb}v[22452]=0;W(377,d+104|0,d+32|0,d+72|0,d+88|0);b=v[22452];v[22452]=0;if((b|0)==1){break Wb}}b=d+104|0;tb(a+1298344|0,b);pb(b);if(!f){pb(d+88|0);yb(d+32|0)}ac:{if(v[a+480180>>2]==16777216){v[22452]=0;Q(1,d+104|0,10085)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break ac}break Ub}v[22452]=0;Q(1,d+104|0,6088)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Ub}}b=d+104|0;tb(a+1298356|0,b);pb(b);tb(a+1298368|0,j);v[a+1298404>>2]=v[a+1074308>>2]?8:5;qb(D);qb(A);f=1;break u}b=P()|0;O()|0;break R}b=P()|0;O()|0;break Vb}b=P()|0;O()|0;pb(d+88|0)}yb(d+32|0);break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}bc:{c=Fb(v[l>>2],b);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);cc:{if(!c){break cc}v[22452]=0;c=Q(146,h|0,c|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break za}if(!c){break cc}v[22452]=0;c=T(185,h|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break ua}v[22452]=0;n=T(185,h|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break va}if((n-1025&65535)>>>0<64512){break cc}v[22452]=0;e=Q(179,h|0,4)|0;f=v[22452];v[22452]=0;if((f|0)==1){break va}if(!e){break cc}v[22452]=0;U(181,d+32|0,h|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break wa}c=d+32|0;p=bc(d+104|0,c);qb(c);e=x[g>>1];i=0;v[22452]=0;k=Q(385,c|0,e|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break ya}dc:{while(1){if(i>>>0>=n>>>0){break dc}v[22452]=0;c=Q(147,d+104|0,1)|0;e=v[22452];v[22452]=0;if((e|0)==1){break bc}if(!c){break dc}v[22452]=0;c=T(197,p|0)|0;e=v[22452];v[22452]=0;ec:{if((e|0)!=1){e=c<<24>>24;if(e){break ec}i=i+1|0;continue}break Aa}fc:{c=e&127;r=c?c-1|0:0;c=r&65535;if(Ic(v[d+32>>2],v[d+36>>2])>>>0>c>>>0){break fc}v[22452]=0;t[d+88|0]=0;U(387,k|0,c+1|0,d+88|0);f=v[22452];v[22452]=0;if((f|0)!=1){break fc}break Aa}gc:{if((e|0)<0){v[22452]=0;e=T(197,p|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break gc}I=Cb(v[d+32>>2],c),J=e,t[I|0]=J}f=Cb(v[d+32>>2],c);e=w[f|0];if(!(!(e&15)|c>>>0<x[g>>1])){u[g>>1]=r+1;e=w[f|0]}if(e&1){v[22452]=0;Q(179,d+104|0,1)|0;e=v[22452];v[22452]=0;if((e|0)==1){break gc}f=Cb(v[d+32>>2],c)}if(w[f|0]&2){v[22452]=0;Q(179,d+104|0,1)|0;e=v[22452];v[22452]=0;if((e|0)==1){break gc}f=Cb(v[d+32>>2],c)}if(w[f|0]&4){v[22452]=0;Q(179,d+104|0,1)|0;e=v[22452];v[22452]=0;if((e|0)==1){break gc}f=Cb(v[d+32>>2],c)}if(!(w[f|0]&8)){continue}v[22452]=0;Q(179,d+104|0,2)|0;c=v[22452];v[22452]=0;if((c|0)!=1){continue}}break}break Aa}v[d+88>>2]=v[h+8>>2];I=d,J=v[Pc(d+188|0,d+88|0)>>2],v[I+188>>2]=J;Xb(k);qb(d+104|0)}b=b+1|0;continue}}break}b=P()|0;O()|0;Xb(k);break xa}b=P()|0;O()|0;break R}b=P()|0;O()|0}qb(d+104|0);break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;pb(d+104|0);break ra}b=P()|0;O()|0}yb(d+32|0);break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}g=0;e=BA(d+32|0,v[b>>2]);v[22452]=0;Q(179,h|0,e|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break V}}if(w[d+35|0]!=1){break X}q=v[b>>2]!=0|q}v[d+32>>2]=v[h+8>>2];I=d,J=v[Pc(d+188|0,d+32|0)>>2],v[I+188>>2]=J;C=(g|0)!=0}f=f+1|0;g=x[n>>1];continue}break}b=P()|0;O()|0;break R}hc:{b=Fb(v[s>>2],f);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);ic:{if(!b){break ic}v[22452]=0;b=Q(146,h|0,b|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break hc}if(!b){break ic}v[22452]=0;b=Q(147,h|0,554)|0;g=v[22452];v[22452]=0;if((g|0)==1){break hc}if(!b){break ic}v[22452]=0;b=Y(245,a|0,f+1&65535,0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break U}if(!b){break ic}g=w[d+346|0]|w[d+347|0]<<8;v[22452]=0;W(396,a|0,h|0,b|0,g|0);g=v[22452];v[22452]=0;if((g|0)==1){break U}t[b+33|0]=w[d+357|0]}f=f+1|0;g=x[e>>1];continue}break}b=P()|0;O()|0;break R}b=P()|0;O()|0}qb(D);break z}b=P()|0;O()|0}qb(A);break v}b=P()|0;O()|0;break v}b=P()|0;O()|0;break v}}}}}b=P()|0;O()|0}ec(l);ec(m);ec(s);break a}ec(l);ec(m);ec(s)}pb(j)}ab=d+496|0;return f|0}b=P()|0;O()|0}pb(j);S(b|0);L()}function vfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,_=0;d=ab-1664|0;ab=d;qc(b);a:{if(!Mh(b,d+1656|0)){break a}if(!lR(d+1656|0)){break a}if(!c){f=1;break a}p=w[d+1656|3];t[d+1655|0]=p;v[d+1648>>2]=-1;v[d+1644>>2]=1048576;if(p>>>0>=5){g=jg(b);v[d+1648>>2]=g;if(!Hb(b,g)){break a}v[d+224>>2]=134217727;X=d,_=v[zb(d+224|0,d+1648|0)>>2]<<5,v[X+1644>>2]=_}A=Pb(d+1632|0);g=d+1656|4;v[d+224>>2]=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);e=v[zb(d+1644|0,d+224|0)>>2];v[22452]=0;R(501,A|0,e|0);e=v[22452];v[22452]=0;b:{c:{d:{e:{f:{if((e|0)!=1){g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);v[22452]=0;g=Y(502,b|0,A|0,g|0)|0;e=v[22452];v[22452]=0;g:{if((e|0)==1){break g}if(!g){break b}if(p>>>0>=5){v[22452]=0;Q(146,b|0,v[d+1648>>2]+12|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break g}}v[22452]=0;R(240,a|0,0);g=v[22452];v[22452]=0;if((g|0)==1){break g}wg(a);de(d+1600|0,v[A>>2],v[A+4>>2]);g=Vd(d+1592|0);e=v[g+4>>2];g=v[g>>2];v[22452]=0;m=ea(503,d+1608|0,v[d+1600>>2],v[d+1604>>2],g|0,e|0)|0;g=v[22452];v[22452]=0;h:{i:{if((g|0)!=1){v[22452]=0;U(347,m|0,a+1298308|0,-1);g=v[22452];v[22452]=0;if((g|0)==1){break i}v[22452]=0;U(347,m|0,a+1298332|0,-1);g=v[22452];v[22452]=0;if((g|0)==1){break i}v[22452]=0;g=Q(504,m|0,d+1168|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break f}if(!g){break c}o=d+1168|0;h=t[o|0];if((h|0)<=0){break c}g=d+1177|0;if((w[g|0]|w[g+1|0]<<8)>>>0>255){break c}e=d+1179|0;if((w[e|0]|w[e+1|0]<<8)>>>0<=3999){break h}break c}h=P()|0;O()|0;break d}h=P()|0;O()|0;break e}D=a+480188|0;u[D>>1]=h&255;i=a+484360|0;f=d+1168|3;Re(Kb(i),w[f|0]|w[f+1|0]<<8);u[a+480192>>1]=w[g|0]|w[g+1|0]<<8;u[a+480190>>1]=w[e|0]|w[e+1|0]<<8;g=w[d+1181|0];v[a+480196>>2]=g?g:6;g=w[d+1182|0];v[a+480204>>2]=B(g?g:125,1e4);k=d+1183|0;g=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);j:{if(g&256){v[22452]=0;R(362,a|0,32);g=v[22452];v[22452]=0;if((g|0)!=1){break j}break f}if(g&2){v[22452]=0;R(362,a|0,2);g=v[22452];v[22452]=0;if((g|0)==1){break f}break j}if(g&128){v[22452]=0;R(362,a|0,1);g=v[22452];v[22452]=0;if((g|0)==1){break f}break j}if(g&8){v[22452]=0;R(362,a|0,16);g=v[22452];v[22452]=0;if((g|0)==1){break f}break j}v[22452]=0;R(362,a|0,4);g=v[22452];v[22452]=0;if((g|0)==1){break f}}g=v[a+480208>>2];e=g|16777216;v[a+480208>>2]=e;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);if(f&1){e=g|16777232;v[a+480208>>2]=e;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24)}if(!(!(f&16)|v[a+480180>>2]!=2)){e=e|65536;v[a+480208>>2]=e;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24)}if(!(!(f&4)|v[a+480180>>2]!=2)){e=e|2;v[a+480208>>2]=e;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24)}if(!(f&2048|v[a+480180>>2]!=32)){e=e|4;v[a+480208>>2]=e;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24)}if(!(f&1024|v[a+480180>>2]!=32)){e=e|8;v[a+480208>>2]=e;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24)}if(f&2097152){v[a+480208>>2]=e|32768;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24)}if(f&524288){v[22452]=0;Y(258,a+1074312|0,5,1)|0;g=v[22452];v[22452]=0;if((g|0)==1){break f}}g=v[a+480180>>2];k:{if((g|0)!=2){if((g|0)!=32){break k}t[d+224|0]=w[d+1187|0];t[d+144|0]=128;X=a,_=w[Qb(d+224|0,d+144|0)|0]<<1,v[X+480200>>2]=_;break k}t[d+224|0]=w[d+1187|0];t[d+144|0]=64;X=a,_=w[Qb(d+224|0,d+144|0)|0]<<2,v[X+480200>>2]=_}e=t[d+1189|0];l:{if((e|0)<0){e=e+52|0;break l}J=dx(+(e|0)*3.1/20);m:{if(J<4294967296&J>=0){e=~~J>>>0;break m}e=0}e=e+51|0}v[a+480228>>2]=e;u[d+224>>1]=64;h=x[Lc(D,d+224|0)>>1];e=0;n=(g|0)==4;j=(g|0)!=32;f=0;while(1)if((f|0)==(h|0)){f=0;h=0;while(1){if((e|0)!=16){h=w[(d+e|0)+1318|0]!=0|h;e=e+1|0;continue}break}while(1){if((f|0)!=128){h=w[((f<<1)+d|0)+1335|0]!=0|h;f=f+1|0;continue}break}n:{if(!(h&1)){break n}g=a+901692|0;f=0;while(1){if((f|0)==16){g=a+902204|0;f=0;while(1){if((f|0)==128){break n}e=(d+1168|0)+(f<<1)|0;o:{if(w[e+167|0]){v[22452]=0;Z(505,d+144|0);h=v[22452];v[22452]=0;p:{q:{r:{s:{t:{if((h|0)!=1){h=w[e+167|0];v[22452]=0;v[d+168>>2]=h-1;R(506,d+1112|0,d+168|0);h=v[22452];v[22452]=0;if((h|0)==1){break t}e=w[e+166|0];v[22452]=0;t[d+112|0]=e;R(507,d+1088|0,d+112|0);e=v[22452];v[22452]=0;if((e|0)==1){break s}v[22452]=0;W(508,d+224|0,d+144|0,d+1112|0,d+1088|0);e=v[22452];v[22452]=0;if((e|0)==1){break r}e=d+224|0;qe(d+1144|0,e);Ie(ie(g,f),v[d+1144>>2],v[d+1148>>2]);pb(e);pb(d+1088|0);pb(d+1112|0);yb(d+144|0);break o}h=P()|0;O()|0;break e}h=P()|0;O()|0;break p}h=P()|0;O()|0;break q}h=P()|0;O()|0;pb(d+1088|0)}pb(d+1112|0)}yb(d+144|0);break e}kc(d+1136|0,21598);Ie(ie(g,f),v[d+1136>>2],v[d+1140>>2])}f=f+1|0;continue}}u:{e=(d+f|0)+1318|0;v:{if(w[e|0]){v[22452]=0;Z(509,d+144|0);h=v[22452];v[22452]=0;if((h|0)==1){break u}e=w[e|0];v[22452]=0;v[d+1088>>2]=e-1;R(506,d+1112|0,d+1088|0);e=v[22452];v[22452]=0;w:{x:{if((e|0)!=1){v[22452]=0;U(282,d+224|0,d+144|0,d+1112|0);e=v[22452];v[22452]=0;if((e|0)==1){break x}e=d+224|0;qe(d+1160|0,e);Ie(ie(g,f),v[d+1160>>2],v[d+1164>>2]);pb(e);pb(d+1112|0);yb(d+144|0);break v}h=P()|0;O()|0;break w}h=P()|0;O()|0;pb(d+1112|0)}yb(d+144|0);break e}kc(d+1152|0,21598);Ie(ie(g,f),v[d+1152>>2],v[d+1156>>2])}f=f+1|0;continue}break}h=P()|0;O()|0;break e}g=Kb(i);e=d+1168|1;e=w[e|0]|w[e+1|0]<<8;v[22452]=0;ea(337,g|0,m|0,e|0,255,254)|0;g=v[22452];v[22452]=0;if((g|0)!=1){g=w[o|0];j=d+1168|5;e=w[j|0]|w[j+1|0]<<8;v[22452]=0;U(181,d+224|0,m|0,B(e,g)<<1);g=v[22452];v[22452]=0;if((g|0)!=1){g=d+224|0;K=bc(d+1112|0,g);qb(g);e=w[j|0]|w[j+1|0]<<8;v[22452]=0;U(181,g|0,m|0,e<<1);g=v[22452];v[22452]=0;y:{if((g|0)!=1){g=d+224|0;M=bc(d+1088|0,g);qb(g);g=d+1168|7;g=w[g|0]|w[g+1|0]<<8;v[22452]=0;C=Q(209,d+1072|0,g|0)|0;g=v[22452];v[22452]=0;z:{if((g|0)!=1){X=d,_=wb(v[C>>2]),v[X+168>>2]=_;g=wb(v[C+4>>2]);A:{B:{C:{while(1){e=v[d+168>>2];if(!Tb(e,g)){q=a+480180|0;g=v[q>>2];s=c&1;if(!s){break B}e=w[j|0]|w[j+1|0]<<8;v[22452]=0;R(216,a+484344|0,e|0);e=v[22452];v[22452]=0;if((e|0)!=1){break B}h=P()|0;O()|0;break A}v[22452]=0;f=T(148,m|0)|0;h=v[22452];v[22452]=0;if((h|0)!=1){v[22452]=0;U(181,d+144|0,m|0,f|0);f=v[22452];v[22452]=0;if((f|0)==1){break C}h=e;e=d+224|0;f=d+144|0;Mc(h,bc(e,f));qb(e);qb(f);jh(d+168|0);continue}break}h=P()|0;O()|0;break A}h=P()|0;O()|0;break A}F=(g|0)==16?14:(g|0)==32?1:13;G=a+484344|0;n=1;while(1){D:{E:{F:{G:{H:{I:{if((w[j|0]|w[j+1|0]<<8)>>>0<=l>>>0){switch(v[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}v[22452]=0;g=T(185,M|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break H}v[d+144>>2]=g;if(!s){break D}v[22452]=0;g=Y(217,G|0,l&65535,g|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break H}r=0;if(!g){break D}while(1){f=r&65535;if(f>>>0>=w[o|0]){break D}v[22452]=0;g=T(185,K|0)|0;e=v[22452];v[22452]=0;J:{if((e|0)!=1){e=v[C>>2];if(Ef(e,v[C+4>>2])>>>0<=g>>>0){break J}z=tg(e,g);qc(z);e=0;f=Qc(Rb(G,l),0,f);K:while(1){if(y[d+144>>2]<=e>>>0){break J}v[22452]=0;g=T(197,z|0)|0;h=v[22452];v[22452]=0;if((h|0)!=1){if(!g){break J}H=g>>>4|0;N=g&15;kh(d+224|0);h=0;while(1){L:{M:{N:{if(N>>>0>(h&255)>>>0){v[22452]=0;R(510,z|0,d+168|0);g=v[22452];v[22452]=0;if((g|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{g=w[d+168|0];switch(g-1|0){case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;default:break ea}}switch(g-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}g=w[d+169|0];fa:{if(g>>>0<=119){g=g+F|0;break fa}ga:{switch(g-254|0){case 1:g=255;break fa;case 0:g=254;break fa;default:break ga}}g=253}t[d+224|0]=g;n=IA(g)&n;break L}t[d+225|0]=w[d+169|0]+1;break L}ha:{if(w[d+226|0]){break ha}g=v[q>>2];if((g|0)!=32){if((g|0)!=4){break ha}g=w[d+169|0];if(g&15){break ha}t[d+226|0]=11;t[d+228|0]=g>>>4;break L}i=0;g=w[d+169|0];while(1){if((i|0)==10){break ha}if((g|0)==w[i+43904|0]){t[d+228|0]=i;t[d+226|0]=11;break L}else{i=i+1|0;continue}}}t[d+227|0]=4;t[d+229|0]=w[d+169|0];break L}g=w[d+169|0];if(!(w[d+226|0]|g>>>0>9|v[q>>2]!=32)){t[d+228|0]=g;t[d+226|0]=8;break L}t[d+229|0]=g;t[d+227|0]=5;break L}if(w[d+226|0]){i=w[d+169|0];break M}g=v[q>>2];E=(g|0)!=32;i=w[d+169|0];if(!(E|(i|0)!=255)){t[d+228|0]=64;t[d+226|0]=2;break L}ia:{if(!E){if(i&3){break M}break ia}if(i&15|(g|0)!=4){break M}}t[d+226|0]=2;t[d+228|0]=(i&252)>>>2;break L}g=w[d+169|0];if(!(w[d+226|0]|g>>>0>64|v[q>>2]==1)){t[d+228|0]=g;t[d+226|0]=1;break L}t[d+229|0]=g;t[d+227|0]=13;break L}t[d+227|0]=14;g=w[d+169|0];t[d+229|0]=g;if(v[q>>2]==32){break L}t[d+229|0]=B((g&240)>>>4|0,10)+(g&15);break L}g=w[d+169|0];t[d+229|0]=g;if(g>>>0<=31){t[d+227|0]=16;break L}t[d+227|0]=17;break L}i=w[d+169|0];if(i>>>0>=16){t[d+228|0]=i>>>4;t[d+226|0]=(g|0)==20?3:5;break L}t[d+228|0]=i;t[d+226|0]=(g|0)==20?4:6;break L}g=w[d+169|0];if(g>>>0>=16){t[d+226|0]=10;t[d+228|0]=g>>>4;break L}t[d+228|0]=g;t[d+226|0]=9;break L}t[d+227|0]=28;t[d+229|0]=w[d+169|0]|16;break L}t[d+227|0]=28;t[d+229|0]=w[d+169|0]|32;break L}t[d+228|0]=w[d+169|0];t[d+226|0]=w[g+26816|0];break L}t[d+229|0]=w[d+169|0];g=w[d+227|0];t[d+227|0]=(g|0)==4?6:(g|0)==5?7:11;break L}g=w[d+169|0];t[d+228|0]=(g>>>0)%10;if(g>>>0<=9){t[d+226|0]=5;break L}if(g>>>0<=19){t[d+226|0]=6;break L}if(g>>>0<=29){t[d+226|0]=3;break L}if(g>>>0>39){break L}t[d+226|0]=4;break L}t[d+228|0]=w[d+169|0];t[d+226|0]=w[g+26816|0];break L}g=w[d+169|0]+33|0;if((g&255)>>>0>9){break L}t[d+228|0]=g;t[d+226|0]=15;break L}if(g>>>0>57){break L}t[d+229|0]=w[d+169|0];t[d+227|0]=w[g+26816|0];break L}v[d+168>>2]=e+H;g=v[zb(d+168|0,d+144|0)>>2];g=e>>>0>g>>>0?e:g;while(1){if((e|0)!=(g|0)){h=v[d+224>>2];t[f|0]=h;t[f+1|0]=h>>>8;t[f+2|0]=h>>>16;t[f+3|0]=h>>>24;h=x[d+228>>1];t[f+4|0]=h;t[f+5|0]=h>>>8;e=e+1|0;f=B(w[o|0],6)+f|0;continue}break}e=g;continue K}h=P()|0;O()|0;break A}t[d+229|0]=i;t[d+227|0]=9}h=h+1|0;continue}}break}h=P()|0;O()|0;break A}h=P()|0;O()|0;break A}r=r+1|0;continue}}f=x[a+480192>>1];g=0;break E}h=P()|0;O()|0;break A}if((n^1)&1|x[D>>1]!=4){break F}v[a+480208>>2]=v[a+480208>>2]|8454144}f=0;g=!((w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24))&512)}v[22452]=0;z=Q(511,d+1056|0,f|0)|0;e=v[22452];v[22452]=0;ja:{ka:{la:{ma:{na:{if((e|0)!=1){q=a+480192|0;n=p>>>0<5;j=a+480180|0;h=1;oa:{while(1){i=h&65535;if(i>>>0>x[q>>1]){break oa}pa:{qa:{ra:{sa:{if(!g){v[22452]=0;f=Y(245,a|0,i|0,0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break sa}if(f){break ra}}while(1){v[22452]=0;e=T(197,m|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break ka}if(e){continue}break}if(!n){while(1){v[22452]=0;e=T(197,m|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){h=P()|0;O()|0;break ja}if(e){continue}break}}v[22452]=0;Q(179,m|0,826)|0;e=v[22452];v[22452]=0;if((e|0)!=1){break qa}}h=P()|0;O()|0;break ja}e=Bb(d+144|0);v[22452]=0;U(347,m|0,e|0,-1);l=v[22452];v[22452]=0;if((l|0)==1){break pa}sc(f+492|0,e);if(!n){v[22452]=0;U(347,m|0,e|0,-1);l=v[22452];v[22452]=0;if((l|0)==1){break pa}sc(f+524|0,e)}v[22452]=0;l=Q(512,m|0,d+224|0)|0;o=v[22452];v[22452]=0;if((o|0)==1){break la}if(!l){break na}l=v[j>>2];v[22452]=0;U(513,d+224|0,f|0,l|0);f=v[22452];v[22452]=0;if((f|0)==1){break la}if(v[j>>2]==4){f=Fb(v[z>>2],i-1|0);i=x[d+1026>>1]|x[d+1028>>1]<<16;t[f|0]=i;t[f+1|0]=i>>>8;t[f+2|0]=i>>>16;t[f+3|0]=i>>>24}pb(e)}h=h+1|0;continue}break}break la}if(!g){break ma}u[a+480192>>1]=0;break ma}h=P()|0;O()|0;break A}pb(e)}g=x[a+480190>>1];v[22452]=0;q=Q(514,d+208|0,g|0)|0;g=v[22452];v[22452]=0;n=1;if((g|0)!=1){n=p>>>0<=4?!(t[k|0]&1):n;s=c&2;N=a+480180|0;h=1;c=0;while(1){g=c;ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{l=h&65535;if(l>>>0<=x[a+480190>>1]){j=Bb(d+192|0);v[22452]=0;U(347,m|0,j|0,-1);c=v[22452];v[22452]=0;if((c|0)==1){break Oa}i=B(l,104)+a|0;sc(((l<<5)+a|0)+946304|0,j);c=p>>>0<5;if(!c){v[22452]=0;U(347,m|0,j|0,-1);e=v[22452];v[22452]=0;if((e|0)==1){break Oa}ke(i+484423|0,j)}v[22452]=0;e=Q(515,m|0,d+224|0)|0;f=v[22452];v[22452]=0;Pa:{Qa:{if((f|0)==1){break Qa}if(!e){break Pa}e=v[N>>2];v[22452]=0;f=i+484380|0;W(516,d+224|0,f|0,e|0,n|0);e=v[22452];v[22452]=0;if((e|0)==1){break Qa}F=0;Ra:{if(((w[d+244|0]|w[d+245|0]<<8)&61440)!=28672|c){break Ra}v[22452]=0;F=T(517,m|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break Ra}h=P()|0;O()|0;break wa}if(!s){break ua}e=w[d+259|0]|w[d+260|0]<<8|(w[d+261|0]<<16|w[d+262|0]<<24);c=w[d+244|0]|w[d+245|0]<<8;o=c&61440;if(!(e|o)){c=Gc(d+144|0,c&1?16:8,c&1024?3:1,0,0);v[22452]=0;Y(210,c|0,f|0,b|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break ua}h=P()|0;O()|0;break wa}if((e|0)<0){c=e+l|0;if((c|0)<=0){break ua}kR(f,(B(c,104)+a|0)+484380|0);break ua}if((e|0)<=0){break ua}if(c&1){e=i+484414|0;u[e>>1]=x[e>>1]|1;e=w[d+244|0]|w[d+245|0]<<8}else{e=c}if(e&1024){e=i+484414|0;u[e>>1]=x[e>>1]|64}e=w[d+259|0]|w[d+260|0]<<8|(w[d+261|0]<<16|w[d+262|0]<<24);v[22452]=0;U(181,d+144|0,b|0,e|0);e=v[22452];v[22452]=0;Sa:{Ta:{Ua:{Va:{Wa:{Xa:{if((e|0)!=1){r=d+144|0;e=bc(d+168|0,r);qb(r);E=i+484414|0;r=qd(x[E>>1]);V=(o|0)==16384;if(!V&(o|0)!=8192){break Va}v[22452]=0;H=T(151,d+168|0)|0;I=v[22452];v[22452]=0;if((I|0)==1){break Sa}I=4/(r>>>0)|0;oia(I,0,H,0);mc(f,db?-1:B(I,H));if((o|0)==8192){break Xa}if(!V){break Va}if(!sg(f)){break Ua}if(!(t[d+244|0]&1)){break Wa}c=v[i+484400>>2];f=v[f>>2];v[22452]=0;W(518,e|0,c|0,f|0,r|0);e=v[22452];v[22452]=0;c=g;if((e|0)==1){break ya}break Ta}h=P()|0;O()|0;break wa}if(!sg(f)){break Ua}if(t[d+244|0]&1){c=v[i+484400>>2];f=v[f>>2];v[22452]=0;W(519,e|0,c|0,f|0,r|0);e=v[22452];v[22452]=0;c=g;if((e|0)!=1){break Ta}break ya}c=v[i+484400>>2];f=v[f>>2];v[22452]=0;W(520,e|0,c|0,f|0,r|0);e=v[22452];v[22452]=0;c=g;if((e|0)==1){break ya}break Ta}c=v[i+484400>>2];f=v[f>>2];v[22452]=0;W(521,e|0,c|0,f|0,r|0);e=v[22452];v[22452]=0;c=g;if((e|0)==1){break ya}break Ta}if((c&45056)==12288){c=jR(d+144|0,e,w[d+263|0]|w[d+264|0]<<8,F);e=_k(v[q>>2],l-1|0);Mc(e,c);v[e+20>>2]=v[c+20>>2];qb(c);break Ua}if((o|0)!=32768){c=1;if((o|0)!=4096){break Ta}c=_d(d+144|0,e);v[22452]=0;Q(522,d+136|0,e|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){Ya:{Za:{if(!w[d+141|0]){break Za}o=w[d+263|0]|w[d+264|0]<<8;e=x[d+138>>1]<<1;if(o>>>0<(e&65535)>>>0){break Za}e=o-e|0;t[d+263|0]=e;t[d+264|0]=e>>>8;v[22452]=0;Q(146,d+168|0,x[d+136>>1])|0;e=v[22452];v[22452]=0;if((e|0)==1){break Ya}v[22452]=0;e=T(193,d+168|0)|0;o=v[22452];v[22452]=0;if((o|0)==1){break Ya}v[22452]=0;U(181,d+88|0,d+168|0,e|0);e=v[22452];v[22452]=0;if((e|0)==1){break Ya}e=d+112|0;o=d+88|0;Mc(c,bc(e,o));qb(e);qb(o)}v[22452]=0;e=ea(523,a|0,l|0,c|0,1,1)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Ya}c=1;if(e){c=w[d+263|0]|w[d+264|0]<<8;_a:{if(!c){break _a}e=x[E>>1];l=mj(v[f>>2],e);if(l>>>0<=c>>>0){break _a}e=hk(e);i=v[i+484400>>2];Wi(i,c+i|0,l-c|0);v[f>>2]=v[f>>2]-((c>>>0)/(e>>>0)|0)}c=v[d+232>>2];v[d+84>>2]=c;v[d+4>>2]=c;c=d+4|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if(c>>>0<y[f>>2]){v[f>>2]=c}c=g}qb(d+144|0);break Ta}}h=P()|0;O()|0;qb(d+144|0);break xa}v[22452]=0;c=Q(374,e|0,d+144|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Na}if(!c){break Ua}v[d+16>>2]=v[d+152>>2];c=v[d+148>>2];v[d+8>>2]=v[d+144>>2];v[d+12>>2]=c;fl(f,1,d+8|0)}c=g}qb(d+168|0);break ta}h=P()|0;O()|0;break xa}h=P()|0;O()|0;break wa}pb(j)}$a:{if(!s){break $a}j=1;while(1){f=j&65535;if(f>>>0>x[a+480190>>1]){break $a}b=v[q>>2];v[22452]=0;b=_k(b,f-1|0);c=T(169,b|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Ma}ab:{bb:{if(!c){break bb}cb:{db:{c=x[b+22>>1];if(!c){break db}e=c+j&65535;if(!e|e>>>0>x[a+480190>>1]){break db}i=x[b+20>>1];if(!i){break db}c=1;e=_k(v[q>>2],e-1|0);break cb}c=0;v[22452]=0;i=T(151,b|0)|0;h=v[22452];v[22452]=0;e=b;if((h|0)==1){break La}}qc(e);eb:{if(c){h=x[b+20>>1];v[22452]=0;h=Q(147,e|0,h|0)|0;n=v[22452];v[22452]=0;if((n|0)==1){break La}if(!h){break bb}v[d+144>>2]=0;v[d+168>>2]=0;v[22452]=0;U(194,d+224|0,e|0,i|0);h=v[22452];v[22452]=0;fb:{if((h|0)!=1){n=Wz(Sd(d+224|0),oi(v[d+224>>2]),d+144|0,d+168|0);v[22452]=0;Q(179,e|0,v[d+144>>2])|0;e=v[22452];v[22452]=0;if((e|0)==1){break fb}rc(d+224|0);break eb}h=P()|0;O()|0;break va}h=P()|0;O()|0;rc(d+224|0);break va}n=0;v[d+144>>2]=0;v[d+168>>2]=0}v[22452]=0;R(524,d+224|0,b|0);e=v[22452];v[22452]=0;gb:{hb:{if((e|0)!=1){i=Sd(d+224|0);h=v[d+224>>2];if(!c){n=Wz(i,oi(h),d+144|0,d+168|0);v[22452]=0;c=v[d+144>>2];Q(179,b|0,c|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break ab}i=c+i|0;h=h-c|0}if(n){break hb}g=1;break gb}h=P()|0;O()|0;break va}c=B(f,104)+a|0;l=c+484380|0;sg(l);o=c+484400|0;r=c+484414|0;e=0;f=v[d+168>>2];while(1){ib:{if(y[l>>2]<=e>>>0|(!h|(f|0)!=1?f:0)){break ib}if(!Fd(l)){break ib}v[d+112>>2]=0;v[d+88>>2]=0;p=iR(n,i,oi(h),d+112|0,d+192|0,d+88|0);v[22452]=0;v[d+144>>2]=p;Q(179,b|0,p|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break za}Jh(d+88|0,oi(v[l>>2]-e|0));c=v[d+88>>2];jb:{if((c|0)<=0){break jb}f=v[d+112>>2];s=x[r>>1];if((qd(s)|0)!=(f|0)){break jb}if(s&1){ag(d+72|0,v[o>>2]+(B(e,f)<<1)|0,f,c);ag(d+56|0,v[d+192>>2],v[d+112>>2],c);v[22452]=0;ka(525,v[d+72>>2],v[d+76>>2],v[d+80>>2],v[d+56>>2],v[d+60>>2],v[d+64>>2]);f=v[22452];v[22452]=0;if((f|0)!=1){break jb}break za}ag(d+40|0,v[o>>2]+B(e,f)|0,f,c);ag(d+24|0,v[d+192>>2],v[d+112>>2],c);v[22452]=0;ka(526,v[d+40>>2],v[d+44>>2],v[d+48>>2],v[d+24>>2],v[d+28>>2],v[d+32>>2]);f=v[22452];v[22452]=0;if((f|0)==1){break za}}h=h-p|0;i=i+p|0;f=hR(n);v[d+168>>2]=f;e=c+e|0;continue}break}gR(n)}rc(d+224|0)}j=j+1|0;continue}break}break za}kb:{if(v[a+480180>>2]!=4){break kb}f=0;c=a+480192|0;while(1){if(x[c>>1]<=f>>>0){break kb}b=Fb(v[z>>2],f);e=w[b|0];h=w[b+1|0];i=w[b+2|0];b=w[b+3|0];v[22452]=0;f=f+1|0;ka(527,a|0,f&65535,e|0,h|0,i|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){continue}break}h=P()|0;O()|0;break va}if(!(w[k+2|0]&16)){break Ha}v[22452]=0;b=Q(147,m|0,1)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Ja}if(!b){break Ha}f=0;v[22452]=0;b=T(197,m|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Ka}if(!(b&1)){break Ia}while(1){if(x[D>>1]<=f>>>0){break Ia}v[22452]=0;b=T(148,m|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){t[((f<<5)+a|0)+480288|0]=b;f=f+1|0;continue}break}h=P()|0;O()|0;break va}h=P()|0;O()|0;break wa}h=P()|0;O()|0;break xa}h=P()|0;O()|0;break va}h=P()|0;O()|0;break va}h=P()|0;O()|0;break va}h=P()|0;O()|0;break va}while(1){v[22452]=0;b=Q(147,m|0,1)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Aa}if(!b){break Ha}v[22452]=0;b=T(197,m|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Fa}if(!b){break Ha}v[22452]=0;c=T(148,m|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Ga}v[22452]=0;U(181,d+144|0,m|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break Ga}c=d+144|0;e=bc(d+224|0,c);qb(c);lb:{if(b>>>0<=250){v[22452]=0;R(397,e|0,(B(b,160)+a|0)+906140|0);b=v[22452];v[22452]=0;if((b|0)==1){break lb}}qb(d+224|0);continue}break}h=P()|0;O()|0;qb(d+224|0);break va}h=a+901404|0;c=Bb(d+112|0);i=a+480180|0;e=0;n=0;while(1){v[22452]=0;b=Q(147,m|0,8)|0;f=v[22452];v[22452]=0;mb:{nb:{ob:{pb:{qb:{if((f|0)!=1){if(b){v[22452]=0;f=T(148,m|0)|0;b=v[22452];v[22452]=0;rb:{sb:{tb:{ub:{vb:{wb:{xb:{yb:{if((b|0)!=1){v[22452]=0;b=T(148,m|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break yb}v[22452]=0;U(181,d+224|0,m|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break xb}j=d+224|0;b=bc(d+144|0,j);qb(j);if((f|0)==1229211981){break ub}if((f|0)==1229476432){break vb}if((f|0)==1397900630){break wb}if((f|0)!=1414548815){break mb}v[22452]=0;f=Q(359,b|0,13830)|0;j=v[22452];v[22452]=0;if((j|0)==1){break Ea}if(!f){break nb}v[22452]=0;f=T(148,b|0)|0;j=v[22452];v[22452]=0;if((j|0)!=1){v[22452]=0;U(181,d+224|0,d+144|0,f|0);f=v[22452];v[22452]=0;if((f|0)!=1){break tb}}h=P()|0;O()|0;break Da}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;break Ba}zb:{Ab:{Bb:{f=v[i>>2];switch(f-2|0){case 1:break mb;case 0:break sb;case 2:break Ab;default:break Bb}}if((f|0)==16){break zb}if((f|0)!=32){break mb}v[22452]=0;e=T(185,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break Ea}v[22452]=0;n=T(185,b|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break mb}break Ea}v[d+224>>2]=32;v[22452]=0;f=T(151,d+144|0)|0;j=v[22452];v[22452]=0;if((j|0)!=1){v[d+168>>2]=f;f=v[zb(d+224|0,d+168|0)>>2];v[22452]=0;U(528,b|0,c|0,f|0);b=v[22452];v[22452]=0;if((b|0)!=1){break mb}}h=P()|0;O()|0;break Da}v[22452]=0;b=T(197,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break rb}v[22452]=0;R(529,d+168|0,4172);f=v[22452];v[22452]=0;Cb:{if((f|0)!=1){v[d+88>>2]=b>>>4;v[22452]=0;v[d+192>>2]=b&15;W(295,d+224|0,d+168|0,d+88|0,d+192|0);b=v[22452];v[22452]=0;if((b|0)==1){break Cb}b=d+224|0;tb(c,b);pb(b);yb(d+168|0);break mb}h=P()|0;O()|0;break Da}h=P()|0;O()|0;yb(d+168|0);break Da}v[22452]=0;f=T(197,b|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break Ea}v[a+480216>>2]=f;v[22452]=0;b=T(197,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break Ea}v[a+480220>>2]=b;break mb}v[22452]=0;Q(369,b|0,h|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Ea}EA(h);break mb}f=d+168|0;j=d+224|0;p=bc(f,j);qb(j);v[22452]=0;f=T(151,f|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break ob}u[d+224>>1]=f>>>5;X=d,_=lf(G),u[X+88>>1]=_;j=x[Lc(d+224|0,d+88|0)>>1];f=0;while(1){if((f|0)==(j|0)){qb(d+168|0);break nb}v[22452]=0;R(530,p|0,d+224|0);l=v[22452];v[22452]=0;Db:{if((l|0)==1){break Db}l=Rb(G,f);v[22452]=0;Q(531,l|0,d+224|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break Db}f=f+1|0;continue}break}break ob}v[22452]=0;e=T(185,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Ea}break mb}h=P()|0;O()|0;break Da}b=v[a+480180>>2];Eb:{Fb:{Gb:{if((b|0)!=32){break Gb}f=e&65535;if(f>>>0<256){break Gb}if(f>>>0<532){break Fb}}b=(b|0)!=2;Hb:{if(b){break Hb}f=e&65535;if(f>>>0<12544){break Hb}if(f>>>0<12820){break Fb}}if(b){break Eb}b=e&65535;if(b>>>0<4864|b>>>0>4895){break Eb}}Pp(h)}f=1;Ib:{if(!(t[k+2|0]&1)){break Ib}e=v[a+1074308>>2];if(!e){e=a+480192|0;h=a+480180|0;while(1){b=f&65535;if(b>>>0<=x[e>>1]){b=v[((b<<2)+a|0)+900380>>2];if(b){k=v[h>>2];v[22452]=0;R(532,zi(b,2)|0,k|0);k=v[22452];v[22452]=0;if((k|0)==1){break qb}t[b+19|0]=w[b+19|0]+3>>>2}f=f+1|0;continue}break}e=v[a+1074308>>2]}if(e>>>0<=18350079){v[22452]=0;b=Q(259,a+1074312|0,27)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Ca}v[22452]=0;Q(259,b|0,57)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Ca}e=v[a+1074308>>2]}if(e>>>0<=19070975){v[22452]=0;Q(259,a+1074312|0,73)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Ca}e=v[a+1074308>>2]}if(e>>>0>19267583){break Ib}v[22452]=0;Q(259,a+1074312|0,50)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Ca}}Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{if(pd(c)){v[22452]=0;Z(533,d+144|0);b=v[22452];v[22452]=0;Xb:{if((b|0)!=1){v[22452]=0;U(498,d+224|0,d+144|0,d+1655|0);b=v[22452];v[22452]=0;if((b|0)==1){break Xb}break Wb}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;yb(d+144|0);break Ba}v[22452]=0;Z(534,d+144|0);b=v[22452];v[22452]=0;if((b|0)==1){break Vb}v[22452]=0;W(535,d+224|0,d+144|0,d+1655|0,c|0);b=v[22452];v[22452]=0;if((b|0)==1){break Ub}}b=d+224|0;tb(c,b);pb(b);b=d+144|0;yb(b);v[22452]=0;R(497,b|0,3960);b=v[22452];v[22452]=0;if((b|0)==1){break Sb}v[22452]=0;U(498,d+224|0,d+144|0,d+1655|0);b=v[22452];v[22452]=0;if((b|0)==1){break Rb}b=d+224|0;tb(a+1298344|0,b);pb(b);yb(d+144|0);v[22452]=0;b=Q(1,b|0,14968)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Qb}tb(a+1298356|0,b);pb(b);b=v[a+480180>>2];switch(b-1|0){case 2:break pb;case 1:break Mb;case 3:break Nb;case 0:break Ob;default:break Tb}}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;yb(d+144|0);break Ba}if((b|0)==16){break Pb}if((b|0)==32){break Lb}if((b|0)!=16777216){break pb}v[22452]=0;b=Q(1,d+224|0,10085)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Kb}tb(a+1298392|0,b);pb(b);v[22452]=0;b=Q(1,d+224|0,13777)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Jb}tb(a+1298380|0,b);pb(b);break pb}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;yb(d+144|0);break Ba}h=P()|0;O()|0;break Ba}v[22452]=0;b=Q(1,d+224|0,10090)|0;e=v[22452];v[22452]=0;Yb:{if((e|0)!=1){tb(a+1298392|0,b);pb(b);v[22452]=0;b=Q(1,d+224|0,8352)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Yb}tb(a+1298380|0,b);pb(b);break pb}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;break Ba}v[22452]=0;b=Q(1,d+224|0,12292)|0;e=v[22452];v[22452]=0;Zb:{if((e|0)!=1){tb(a+1298392|0,b);pb(b);v[22452]=0;b=Q(1,d+224|0,14240)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Zb}tb(a+1298380|0,b);pb(b);break pb}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;break Ba}v[22452]=0;b=Q(1,d+224|0,10063)|0;e=v[22452];v[22452]=0;_b:{if((e|0)!=1){tb(a+1298392|0,b);pb(b);v[22452]=0;b=Q(1,d+224|0,15197)|0;e=v[22452];v[22452]=0;if((e|0)==1){break _b}tb(a+1298380|0,b);pb(b);break pb}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;break Ba}v[22452]=0;b=Q(1,d+224|0,10435)|0;e=v[22452];v[22452]=0;$b:{if((e|0)!=1){tb(a+1298392|0,b);pb(b);v[22452]=0;b=Q(1,d+224|0,15008)|0;e=v[22452];v[22452]=0;if((e|0)==1){break $b}tb(a+1298380|0,b);pb(b);break pb}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;break Ba}v[22452]=0;b=Q(1,d+224|0,6088)|0;e=v[22452];v[22452]=0;ac:{bc:{cc:{dc:{ec:{if((e|0)!=1){tb(a+1298392|0,b);pb(b);if(!(n&65535)){break ac}v[22452]=0;R(260,d+144|0,4275);b=v[22452];v[22452]=0;if((b|0)==1){break ec}v[d+88>>2]=(n&65280)>>>8;v[22452]=0;v[d+192>>2]=n&255;R(391,d+168|0,d+192|0);b=v[22452];v[22452]=0;if((b|0)==1){break dc}v[22452]=0;W(377,d+224|0,d+144|0,d+88|0,d+168|0);b=v[22452];v[22452]=0;if((b|0)==1){break cc}b=d+224|0;tb(a+1298380|0,b);pb(b);pb(d+168|0);yb(d+144|0);break pb}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;break bc}h=P()|0;O()|0;pb(d+168|0)}yb(d+144|0);break Ba}v[22452]=0;b=Q(1,d+224|0,8528)|0;e=v[22452];v[22452]=0;if((e|0)!=1){tb(a+1298380|0,b);pb(b);break pb}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;break Ba}tb(a+1298368|0,c);fc:{if(v[a+1074308>>2]){v[a+1298404>>2]=8;break fc}if(v[a+480180>>2]==1){v[a+1298404>>2]=2;break fc}v[a+1298404>>2]=5}f=1;gc:{hc:{if(g&1){v[22452]=0;b=Q(1,d+224|0,16573)|0;g=v[22452];v[22452]=0;if((g|0)==1){break hc}a=v[a+1298464>>2];v[22452]=0;U(364,a|0,2,b|0);a=v[22452];v[22452]=0;if((a|0)==1){break gc}pb(b)}pb(c);Rz(q);ec(z);Yc(C);qb(M);qb(K);break c}h=P()|0;O()|0;break Ba}h=P()|0;O()|0;pb(b);break Ba}h=P()|0;O()|0;qb(d+168|0);break Da}v[22452]=0;f=Q(359,b|0,13835)|0;j=v[22452];v[22452]=0;if((j|0)==1){break Ea}ic:{if(!f){break ic}v[22452]=0;f=T(148,b|0)|0;j=v[22452];v[22452]=0;jc:{if((j|0)!=1){v[22452]=0;U(181,d+168|0,d+144|0,f|0);f=v[22452];v[22452]=0;if((f|0)!=1){break jc}}h=P()|0;O()|0;break Da}f=d+224|0;j=d+168|0;p=bc(f,j);qb(j);v[22452]=0;f=T(151,f|0)|0;j=v[22452];v[22452]=0;if((j|0)!=1){u[d+168>>1]=(f>>>0)/20;u[d+88>>1]=x[D>>1];j=x[Lc(d+168|0,d+88|0)>>1];f=0;while(1){if((f|0)==(j|0)){qb(d+224|0);break ic}v[22452]=0;U(370,p|0,((f<<5)+a|0)+480289|0,20);l=v[22452];v[22452]=0;if((l|0)!=1){f=f+1|0;continue}break}}h=P()|0;O()|0;qb(d+224|0);break Da}v[22452]=0;Q(380,a|0,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break Ea}v[22452]=0;W(381,a|0,b|0,1,0);f=v[22452];v[22452]=0;if((f|0)==1){break Ea}if((e-2186&65535)>>>0<=117){v[i>>2]=16777216;v[22452]=0;U(395,a|0,b|0,e&65535);b=v[22452];v[22452]=0;if((b|0)==1){break Ea}}if(!v[a+1074308>>2]){break mb}v[22452]=0;b=Q(1,d+168|0,17558)|0;f=v[22452];v[22452]=0;kc:{lc:{mc:{if((f|0)!=1){f=v[a+1074308>>2];v[22452]=0;R(131,d+88|0,f|0);f=v[22452];v[22452]=0;if((f|0)==1){break mc}v[22452]=0;U(2,d+224|0,b|0,d+88|0);f=v[22452];v[22452]=0;if((f|0)==1){break lc}f=d+224|0;tb(c,f);pb(f);pb(d+88|0);pb(b);break mb}h=P()|0;O()|0;break Da}h=P()|0;O()|0;break kc}h=P()|0;O()|0;pb(d+88|0)}pb(b);break Da}qb(d+144|0);continue}}h=P()|0;O()|0;break va}h=P()|0;O()|0;break va}h=P()|0;O()|0}qb(d+144|0);break Ba}h=P()|0;O()|0}pb(c);break va}h=P()|0;O()|0;break va}h=P()|0;O()|0;rc(d+224|0);break va}h=P()|0;O()|0}qb(d+168|0)}pb(j)}Rz(q);break ja}c=g}pb(j);h=h+1|0;continue}}h=P()|0;O()|0;break ja}h=P()|0;O()|0;pb(e);break ja}h=P()|0;O()|0}ec(z);break A}l=l+1|0;continue}}Yc(C);break z}h=P()|0;O()|0}qb(M);break y}h=P()|0;O()|0}qb(K);break e}h=P()|0;O()|0;break e}h=P()|0;O()|0;break e}else{nc:{if(n){break nc}if(!j){t[d+224|0]=w[(d+f|0)+1190|0];t[d+144|0]=64;X=((f<<5)+a|0)+480286|0,_=w[Qb(d+224|0,d+144|0)|0],u[X>>1]=_}oc:{g=w[(d+f|0)+1254|0];if((g|0)!=255){if((g|0)!=127){break oc}v[((f<<5)+a|0)+480280>>2]=256;break nc}u[((f<<5)+a|0)+480284>>1]=256;break nc}u[((f<<5)+a|0)+480284>>1]=g}f=f+1|0;continue}}h=P()|0;O()|0;break d}h=P()|0;O()|0;break d}h=P()|0;O()|0}qb(m)}Xb(A);S(h|0);L()}qb(m)}Xb(A)}ab=d+1664|0;return f|0}function Ifa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;e=ab-912|0;ab=e;qc(b);a:{if(!vR(b,e+856|0)){break a}if(!zR(e+856|0)){break a}if(!Hb(b,Fc(yR(e+856|0),db))){break a}if(!c){d=1;break a}vd(a,8);wg(a);j=w[e+856|3]-48|0;t[e+855|0]=j;Nc(b,Wb(w[e+864|0]|w[e+865|0]<<8|(w[e+866|0]<<16|w[e+867|0]<<24)));f=e+544|0;Md(f,b,504);ga=bc(e+832|0,f);qb(f);v[22452]=0;R(470,b|0,f|0);f=v[22452];v[22452]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){if(w[e+827|0]>63){break b}if(Ab(w[e+544|0]|w[e+545|0]<<8)<<16>>16<0){break b}Jb(e+464|0,0,80);h:{d=Wb(w[e+888|0]|w[e+889|0]<<8|(w[e+890|0]<<16|w[e+891|0]<<24));if(!d){break h}v[22452]=0;f=Q(146,b|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){if(!f){break h}v[22452]=0;R(471,b|0,e+464|0);d=v[22452];v[22452]=0;if((d|0)!=1){break h}}h=P()|0;O()|0;break e}v[22452]=0;U(472,e+456|0,b|0,j&255);d=v[22452];v[22452]=0;if((d|0)!=1){f=e+456|0;ha=Me(f);d=0;f=x[f>>1];if((f-128&65535)>>>0<65409){break b}u[a+480188>>1]=f;ba=Pb(e+440|0);d=Wb(w[e+880|0]|w[e+881|0]<<8|(w[e+882|0]<<16|w[e+883|0]<<24));i:{if(d){v[22452]=0;Q(146,b|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break g}d=w[e+827|0];v[22452]=0;U(473,b|0,ba|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break g}d=w[e+827|0];break i}d=0;if(w[e+827|0]){break c}}h=d&255;u[a+480192>>1]=h;u[a+480190>>1]=h;ca=1;C=c&2;ca=(j&255)>>>0>=2?t[e+808|0]>=0:ca;D=!ca;d=e+56|0;J=d|2;F=d|7;K=d|6;V=d|5;o=d|4;y=e+16|4;H=1;E=1;while(1){j:{k:{l:{m:{n:{o:{j=E&65535;if(j>>>0<=(h&65535)>>>0){v[22452]=0;M=H&65535;f=Y(245,a|0,j|0,M|0)|0;d=v[22452];v[22452]=0;p:{if((d|0)!=1){if(f){break p}break d}h=P()|0;O()|0;break f}A=v[((j<<2)+a|0)+900380>>2];u[e+20>>1]=0;v[e+16>>2]=0;v[22452]=0;X=T(165,e+128|0)|0;d=v[22452];v[22452]=0;q:{if((d|0)!=1){d=Fb(v[ba>>2],j-1|0);d=Wb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));r:{if(!d){break r}v[22452]=0;f=Q(146,b|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break k}if(!f){break r}v[22452]=0;R(474,b|0,e+16|0);d=v[22452];v[22452]=0;if((d|0)==1){break k}d=w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24);v[22452]=0;U(181,e+416|0,b|0,Wb(d)|0);d=v[22452];v[22452]=0;if((d|0)==1){break k}f=e+56|0;d=e+416|0;Mc(X,bc(f,d));qb(f);qb(d)}d=Ab(w[y|0]|w[y+1|0]<<8);f=d&15;r=d<<16>>16;if((r|0)>=0){break q}At(A,0);ia=1;break o}h=P()|0;O()|0;break f}if(f>>>0>6){break o}z=w[f+26694|0];if(!f){break m}u[a+480190>>1]=(x[a+480190>>1]+z|0)-1;k=A+108|0;s=A+236|0;p=z-2|0;g=4;s:while(1){d=1;if((g|0)==10){break n}l=B(g,12);d=(p<<3)+g|0;i=w[d+26700|0]+H|0;j=w[d+26748|0];d=0;while(1)if((d|0)==12){g=g+1|0;continue s}else{f=d+l|0;ja=Yb(s,f),ka=i,u[ja>>1]=ka;f=Cb(k,f);t[f|0]=j+w[f|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=e+464|4;d=Wb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));if(!d){break D}if(!Ab(w[e+472|0]|w[e+473|0]<<8)){break D}v[22452]=0;f=Q(146,b|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break C}if(!f){break D}ja=e,ka=Ab(w[e+472|0]|w[e+473|0]<<8),u[ja+128>>1]=ka;u[e+56>>1]=w[e+827|0];d=e+128|0;f=e+56|0;V=x[Lc(d,f)>>1];F=d|5;o=d|3;K=d|1;d=e- -64|0;k=f|4;D=Ab(w[e+474|0]|w[e+475|0]<<8);s=D>>>0<19;p=D>>>0<21;l=D>>>0<15;i=D>>>0<6;h=0;while(1){if((h|0)==(V|0)){break D}v[22452]=0;U(475,b|0,e+128|0,D|0);f=v[22452];v[22452]=0;E:{F:{G:{if((f|0)!=1){h=h+1|0;r=v[((h<<2)+a|0)+900380>>2];if(w[e+128|0]){g=Qn(e+56|0,0,64);Qn(k,w[e+128|0]-1&65535,64);j=w[e+128|0];f=w[K|0];if(f){f=64/(f>>>0)|0}else{f=0}Qn(d,f+j|0,0);v[22452]=0;C=r+48|0;U(476,C|0,g|0,3);f=v[22452];v[22452]=0;if((f|0)==1){break G}if(w[e+128|0]==1){$b(e+408|0,wb(v[C>>2]));j=v[e+408>>2];f=wb(v[C>>2]);f=v[C>>2]+(yt(j,f)<<2)|0;Hd(C,Ci(f+4|0,v[C+4>>2],f));wb(f)}f=w[K|0];v[r>>2]=f?f<<9:32767;t[r+60|0]=w[r+60|0]|1;Z=1}H:{if(s){break H}v[r+4>>2]=w[e+146|0]+1>>>1;if(p){break H}u[r+28>>1]=w[e+148|0]|w[e+149|0]<<8}g=B(x[Yb(r+236|0,61)>>1],104)+a|0;t[g+484417|0]=w[o|0]<<4;if(l){break F}ja=g+484384|0,ka=Wb(w[e+138|0]|w[e+139|0]<<8|(w[e+140|0]<<16|w[e+141|0]<<24)),v[ja>>2]=ka;ja=g+484388|0,ka=Wb(w[e+138|0]|w[e+139|0]<<8|(w[e+140|0]<<16|w[e+141|0]<<24))+Wb(w[e+142|0]|w[e+143|0]<<8|(w[e+144|0]<<16|w[e+145|0]<<24))|0,v[ja>>2]=ka;break E}h=P()|0;O()|0;break f}h=P()|0;O()|0;break f}if(i){continue}}j=g+484414|0;f=x[j>>1]&-3|w[F|0]<<1&2;u[j>>1]=f;u[j>>1]=f&65531|w[F|0]>>>1&4;if(!(w[F|0]&4)){continue}u[g+484412>>1]=0;continue}}I:{d=Wb(w[e+484|0]|w[e+485|0]<<8|(w[e+486|0]<<16|w[e+487|0]<<24));if(!d){break I}if(!Ab(w[e+488|0]|w[e+489|0]<<8)){break I}v[22452]=0;f=Q(146,b|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break C}if(!f){break I}ja=e,ka=Ab(w[e+488|0]|w[e+489|0]<<8),u[ja+128>>1]=ka;u[e+56>>1]=w[e+827|0];p=x[Lc(e+128|0,e+56|0)>>1];l=Ab(w[e+490|0]|w[e+491|0]<<8);d=0;J:while(1){if((d|0)==(p|0)){break I}v[22452]=0;U(477,b|0,e+128|0,l|0);f=v[22452];v[22452]=0;if((f|0)==1){break t}KS(e+416|0,e+128|0);v[22452]=0;W(213,e+56|0,v[e+416>>2],v[e+420>>2],w[e+424|0]);f=v[22452];v[22452]=0;if((f|0)==1){break u}d=d+1|0;s=((d<<2)+a|0)+900380|0;j=e+56|0;sc(v[s>>2]+492|0,j);pb(j);f=v[s>>2];v[22452]=0;R(478,j|0,f|0);f=v[22452];v[22452]=0;if((f|0)==1){break v}f=e+56|0;ja=e,ka=al(f),v[ja+416>>2]=ka;i=Af(f);while(1)if(Tb(v[e+416>>2],i)){g=e+416|0;k=(x[Jp(g)>>1]<<5)+a|0;j=k+946328|0;o=v[s>>2];f=v[o+520>>2];v[j>>2]=v[o+516>>2];v[j+4>>2]=f;f=v[o+512>>2];j=k+946320|0;v[j>>2]=v[o+508>>2];v[j+4>>2]=f;f=v[o+504>>2];j=k+946312|0;v[j>>2]=v[o+500>>2];v[j+4>>2]=f;f=v[o+496>>2];j=k+946304|0;v[j>>2]=v[o+492>>2];v[j+4>>2]=f;On(g);continue}else{dA(e+56|0);continue J}}}Pp(a+901404|0);d=kc(e+400|0,4901);Ie(ie(a+901692|0,0),v[d>>2],v[d+4>>2]);qc(b);r=c&1;N=a+484344|0;_=a+1298332|0;H=a+1298308|0;y=a+484360|0;c=e+128|0;C=c|1;q=c|4;c=e+40|0;j=c|4;A=c|2;D=c|3;G=e+544|2;c=0;while(1){K:{f=c&255;if(f>>>0<w[ha|0]){v[22452]=0;W(479,b|0,e+856|0,e+464|0,e+544|0);d=v[22452];v[22452]=0;L:{M:{N:{O:{P:{if((d|0)==1){break P}Q:{if(!f){d=0;break Q}v[22452]=0;f=T(266,y|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break P}d=c;if((f|0)==255){break d}}n=jj(y,d&255);I=Rg(e+384|0);uc(n);$=w[e+855|0];if($>>>0>1){break N}m=0;if(Ab(w[G|0]|w[G+1|0]<<8)>>>0>256|x[a+480188>>1]>16){break L}f=e+128|0;sR(f,e+544|0);d=w[G|0]|w[G+1|0]<<8;v[22452]=0;U(480,n|0,f|0,Ab(d)|0);d=v[22452];v[22452]=0;if((d|0)==1){break O}ja=e,ka=wb(v[n>>2]),v[ja+128>>2]=ka;d=wb(v[n+4>>2]);while(1){f=v[e+128>>2];if(Tb(f,d)){u[f>>1]=x[f>>1]+aa;Ke(e+128|0);continue}else{lh(a,1);f=x[a+480188>>1];d=0;while(1)if((d|0)==(f|0)){d=32;break M}else{t[e+128|0]=w[(d+e|0)+810|0];t[e+56|0]=64;ja=((d<<5)+a|0)+480286|0,ka=w[Qb(e+128|0,e+56|0)|0],u[ja>>1]=ka;d=d+1|0;continue}}}}h=P()|0;O()|0;break f}h=P()|0;O()|0;break w}sR(e+128|0,e+544|0);R:{S:{T:{U:{if(!((Ab(w[e+140|0]|w[e+141|0]<<8)-65&65535)>>>0<65472|x[a+480188>>1]>64)){k=Wb(w[e+148|0]|w[e+149|0]<<8|(w[e+150|0]<<16|w[e+151|0]<<24));d=Ab(w[e+152|0]|w[e+153|0]<<8);if(d){u[e+56>>1]=d;u[e+416>>1]=800;f=Fc(((x[Lc(e+56|0,e+416|0)>>1]<<5)+50>>>0)/100|0,0)}else{f=32}d=w[e+136|0]|w[e+137|0]<<8|(w[e+138|0]<<16|w[e+139|0]<<24);v[22452]=0;g=Q(146,b|0,Wb(d)|0)|0;d=v[22452];v[22452]=0;V:{if((d|0)==1){break V}d=0;W:{if(!g){break W}while(1){if(x[a+480188>>1]<=d>>>0){break W}v[22452]=0;i=T(197,b|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){t[e+56|0]=i;t[e+416|0]=64;ja=((d<<5)+a|0)+480286|0,ka=w[Qb(e+56|0,e+416|0)|0],u[ja>>1]=ka;d=d+1|0;continue}break}h=P()|0;O()|0;break w}X:{Y:{d=Wb(w[e+144|0]|w[e+145|0]<<8|(w[e+146|0]<<16|w[e+147|0]<<24));if(!d){break Y}v[22452]=0;g=Q(146,b|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break V}d=0;if(!g){break Y}while(1){if(x[a+480188>>1]<=d>>>0){break X}v[22452]=0;i=T(481,b|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){ja=((d<<5)+a|0)+480284|0,ka=(Sb(i,-16,16)<<3)+128|0,u[ja>>1]=ka;d=d+1|0;continue}break}h=P()|0;O()|0;break w}lh(a,1)}o=Pb(e+112|0);d=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);v[22452]=0;g=Q(146,b|0,Wb(d)|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break U}m=1;d=0;if(!g){break R}g=w[G|0]|w[G+1|0]<<8;v[22452]=0;i=Q(147,b|0,Ab(g)<<1)|0;g=v[22452];v[22452]=0;if((g|0)==1){break U}if(!i){break R}g=w[G|0]|w[G+1|0]<<8;v[22452]=0;i=Y(482,b|0,o|0,Ab(g)|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break U}if(!i){break R}ja=e,ka=wb(v[e+112>>2]),v[ja+104>>2]=ka;s=wb(v[e+116>>2]);while(1){d=v[e+104>>2];if(!Tb(d,s)){m=0;d=1;break R}g=Ab(w[d|0]|w[d+1|0]<<8);Z:{if(Ab(w[e+142|0]|w[e+143|0]<<8)>>>0<g>>>0){break Z}d=w[e+128|0]|w[e+129|0]<<8|(w[e+130|0]<<16|w[e+131|0]<<24);v[22452]=0;Q(146,b|0,Wb(d)+(g<<2)|0)|0;d=v[22452];v[22452]=0;_:{$:{aa:{ba:{ca:{if((d|0)==1){break ca}v[22452]=0;g=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break ca}v[22452]=0;g=Q(146,b|0,g|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break ca}if(!g){break Z}v[22452]=0;g=Q(147,b|0,42)|0;d=v[22452];v[22452]=0;if((d|0)==1){break ca}if(!g){break Z}v[22452]=0;R(483,b|0,e+56|0);d=v[22452];v[22452]=0;da:{if((d|0)!=1){if(jc(v[n>>2],v[n+4>>2])){break da}v[22452]=0;R(484,n|0,65534);d=v[22452];v[22452]=0;if((d|0)!=1){break da}}h=P()|0;O()|0;break S}d=w[e+96|0]|w[e+97|0]<<8;v[22452]=0;d=Ab(d);v[e+52>>2]=d;g=Q(147,b|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break ba}if(!g){v[22452]=0;g=T(193,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break ba}mc(e+52|0,g)}mc(e+52|0,65534);i=v[n+4>>2];g=v[n>>2];d=0;v[22452]=0;p=v[e+52>>2];l=wc(g,i);R(485,n|0,p+l|0);g=v[22452];v[22452]=0;if((g|0)==1){break $}while(1){ea:{if((d|0)==(p|0)){if(w[e+56|0]){break ea}break aa}v[22452]=0;i=T(265,b|0)|0;g=v[22452];v[22452]=0;fa:{if((g|0)!=1){g=i<<16>>16;if((g|0)<0){break fa}v[22452]=0;R(484,n|0,g+aa&65535);g=v[22452];v[22452]=0;if((g|0)!=1){break fa}}h=P()|0;O()|0;break S}d=d+1|0;continue}break}sm(e+40|0,e+56|0);v[22452]=0;U(486,e+16|0,v[e+40>>2],v[e+44>>2]);d=v[22452];v[22452]=0;ga:{ha:{ia:{if((d|0)!=1){v[22452]=0;U(11,e+416|0,2,e+16|0);d=v[22452];v[22452]=0;if((d|0)==1){break ia}v[22452]=0;R(267,n|0,e+416|0);d=v[22452];v[22452]=0;if((d|0)==1){break ha}pb(e+416|0);pb(e+16|0);break aa}h=P()|0;O()|0;break S}h=P()|0;O()|0;break ga}h=P()|0;O()|0;pb(e+416|0)}pb(e+16|0);break S}h=P()|0;O()|0;break S}h=P()|0;O()|0;break S}d=Wb(w[e+88|0]|w[e+89|0]<<8|(w[e+90|0]<<16|w[e+91|0]<<24));if(!d){break Z}v[22452]=0;g=Q(146,b|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){break _}}h=P()|0;O()|0;break S}if(!g){break Z}ja:{while(1){ka:{v[22452]=0;g=Q(487,b|0,e+40|0)|0;d=v[22452];v[22452]=0;la:{ma:{na:{oa:{if((d|0)!=1){if(!g){break Z}d=w[D|0];v[22452]=0;U(181,e+16|0,b|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break oa}d=e+16|0;g=bc(e+416|0,d);qb(d);d=Wt(Ab(w[e+40|0]|w[e+41|0]<<8)+l|0);u[e+16>>1]=d;if((Ab(w[e+40|0]|w[e+41|0]<<8)|0)==65535){break ja}h=v[n>>2];if(wc(h,v[n+4>>2])>>>0<=d>>>0){break ka}m=65535;switch(w[A|0]-1|0){case 0:break ma;case 1:break na;default:break la}}h=P()|0;O()|0;break S}h=P()|0;O()|0;break S}v[22452]=0;i=T(265,g|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break T}v[22452]=0;g=Q(488,I|0,e+16|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break T}u[g>>1]=i;h=v[n>>2];m=65534;d=x[e+16>>1]}ja=Yb(h,d),ka=m,u[ja>>1]=ka}qb(e+416|0);continue}break}qb(e+416|0);break Z}qb(e+416|0)}Ke(e+104|0);continue}}h=P()|0;O()|0;break w}m=0;break L}h=P()|0;O()|0;break S}h=P()|0;O()|0;qb(e+416|0)}_c(o);break w}_c(o);if(d){d=f>>>(k>>>1&1)|0;break M}xt(I);if(!m){break d}break K}g=Ab(w[e+804|0]|w[e+805|0]<<8);l=w[e+807|0];F=l&64;f=w[e+808|0];J=f&32;z=(f&31)+1|0;ja=a,ka=pR(g,F>>>6|0,J>>>5|0,z),v[ja+480204>>2]=ka;ja=a,ka=Ld(w[e+809|0],1,32),v[ja+480196>>2]=ka;if(J){v[a+480216>>2]=z;v[a+480220>>2]=z<<2}f=w[e+826|0];if(f){t[e+128|0]=f;t[e+56|0]=64;ja=a,ka=w[Qb(e+128|0,e+56|0)|0]<<2,v[ja+480200>>2]=ka}v[a+480228>>2]=d;v[a+480232>>2]=d;v[a+480208>>2]=v[a+480208>>2]&-3|(w[e+807|0]>>>4^-1)&2;pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{d=Wb(w[e+508|0]|w[e+509|0]<<8|(w[e+510|0]<<16|w[e+511|0]<<24));if(!d){break za}v[22452]=0;f=Q(146,b|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break ya}if(!f){break za}d=w[e+512|0]|w[e+513|0]<<8|(w[e+514|0]<<16|w[e+515|0]<<24);v[22452]=0;U(262,b|0,H|0,Wb(d)|0);d=v[22452];v[22452]=0;if((d|0)==1){break ya}if(w[ha|0]<2){break za}v[22452]=0;U(11,e+128|0,2,H|0);d=v[22452];v[22452]=0;Aa:{if((d|0)!=1){v[22452]=0;R(267,n|0,e+128|0);d=v[22452];v[22452]=0;if((d|0)==1){break Aa}pb(e+128|0);break za}h=P()|0;O()|0;break w}h=P()|0;O()|0;pb(e+128|0);break w}Ba:{if(Wb(w[e+480|0]|w[e+481|0]<<8|(w[e+482|0]<<16|w[e+483|0]<<24))>>>0<2){break Ba}d=w[e+476|0]|w[e+477|0]<<8|(w[e+478|0]<<16|w[e+479|0]<<24);v[22452]=0;f=Q(146,b|0,Wb(d)|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break ya}if(!f){break Ba}d=w[e+480|0]|w[e+481|0]<<8|(w[e+482|0]<<16|w[e+483|0]<<24);v[22452]=0;W(326,_|0,b|0,Wb(d)-1|0,4);d=v[22452];v[22452]=0;if((d|0)==1){break ya}}d=Wb(w[e+520|0]|w[e+521|0]<<8|(w[e+522|0]<<16|w[e+523|0]<<24));if(!d){break pa}v[22452]=0;f=Q(146,b|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break ya}if(!f){break pa}v[22452]=0;f=Q(147,b|0,12)|0;d=v[22452];v[22452]=0;if((d|0)==1){break ya}if(!f){break pa}v[22452]=0;Q(179,b|0,6)|0;d=v[22452];v[22452]=0;if((d|0)==1){break ya}v[22452]=0;f=T(265,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break ya}if((f|0)!=1){break pa}v[22452]=0;g=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break wa}if(!g){break pa}v[22452]=0;f=Q(147,b|0,g|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break wa}if(f){break xa}break pa}h=P()|0;O()|0;break w}Ac(e+128|0,_);v[22452]=0;W(326,_|0,b|0,g|0,4);d=v[22452];v[22452]=0;if((d|0)==1){break ra}if(!pd(e+128|0)){v[22452]=0;f=Y(489,e+416|0,2,13)|0;d=v[22452];v[22452]=0;if((d|0)==1){break va}v[22452]=0;U(490,e+56|0,e+128|0,f|0);d=v[22452];v[22452]=0;if((d|0)==1){break ua}v[22452]=0;U(491,e|0,e+56|0,_|0);d=v[22452];v[22452]=0;if((d|0)==1){break ta}tb(_,e);pb(e);pb(e+56|0);pb(f)}pb(e+128|0);break pa}h=P()|0;O()|0;break w}h=P()|0;O()|0;break qa}h=P()|0;O()|0;break sa}h=P()|0;O()|0;pb(e+56|0)}pb(f);break qa}h=P()|0;O()|0}pb(e+128|0);break w}Ca:{if($>>>0<2){break Ca}m=0;if(!Wb(w[e+532|0]|w[e+533|0]<<8|(w[e+534|0]<<16|w[e+535|0]<<24))){break Ca}while(1){if(x[a+480188>>1]<=m>>>0){break Ca}d=w[e+532|0]|w[e+533|0]<<8|(w[e+534|0]<<16|w[e+535|0]<<24);v[22452]=0;f=Q(146,b|0,Wb(d)+(m<<2)|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break x}Da:{if(!f){break Da}v[22452]=0;f=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break x}v[22452]=0;f=Q(146,b|0,f|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break x}g=0;d=0;if(!f){break Da}while(1){Ea:{v[22452]=0;i=Q(147,b|0,8)|0;f=v[22452];v[22452]=0;Fa:{Ga:{Ha:{if((f|0)!=1){if(!i){break Ea}v[22452]=0;R(492,b|0,e+128|0);f=v[22452];v[22452]=0;if((f|0)==1){break Ha}f=Wb(w[e+128|0]|w[e+129|0]<<8|(w[e+130|0]<<16|w[e+131|0]<<24));if(!f){break Ea}switch((f&536870911)-1|0){case 1:break Fa;case 0:break Ga;default:continue}}h=P()|0;O()|0;break w}h=P()|0;O()|0;break w}g=Wb(w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24));continue}d=Wb(w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24));continue}break}if(!g|!d){break Da}v[22452]=0;g=Q(146,b|0,g|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break y}if(!g){break Da}v[22452]=0;U(370,b|0,((m<<5)+a|0)+480289|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break y}}m=m+1|0;continue}}d=w[e+544|0]|w[e+545|0]<<8;v[22452]=0;g=Ab(d);R(216,N|0,aa+g&65535);d=v[22452];v[22452]=0;if((d|0)==1){break z}K=l&16;V=aa&65535;E=0;Ia:{Ja:{while(1){if((g|0)==(E|0)){ja=e,ka=al(I),v[ja+56>>2]=ka;ja=e,ka=Af(I),v[ja+416>>2]=ka;while(1){if(!Qg(e+56|0,e+416|0)){m=1;d=Wb(w[e+464|0]|w[e+465|0]<<8|(w[e+466|0]<<16|w[e+467|0]<<24));if(!d){break L}v[22452]=0;f=Q(146,b|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break z}if(!f){break L}aa=g+aa|0;xt(I);break K}d=Jp(e+56|0);l=d;i=Me(d);Ka:{La:{Ma:{Na:{d=x[d>>1];if(!d){d=0;break Na}v[22452]=0;f=Q(304,n|0,d-1&65535)|0;d=v[22452];v[22452]=0;if((d|0)==1){break Ka}d=x[l>>1];if(!f){break Na}v[22452]=0;d=Q(357,n|0,d-1&65535)|0;f=v[22452];v[22452]=0;if((f|0)==1){break Ka}break Ma}if(x[i>>1]==((d&65535)+1|0)){break La}v[22452]=0;d=Y(356,N|0,1,0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break Ka}if((d|0)==65535){break La}ja=Yb(v[n>>2],x[l>>1]),ka=d,u[ja>>1]=ka}je(Rb(N,d),dm(Ae(ve(e+128|0,12,Pt(x[i>>1])),v[Rb(N,d)+12>>2]-1|0)));g=(g&65535)>>>0>d>>>0?g:d+1|0}Uj(e+56|0);continue}break}h=P()|0;O()|0;break w}Oa:{Pa:{if(!r){break Pa}d=w[e+872|0]|w[e+873|0]<<8|(w[e+874|0]<<16|w[e+875|0]<<24);v[22452]=0;f=Q(146,b|0,Wb(d)+(E<<2)|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break Ja}if(!f){break Pa}v[22452]=0;f=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break Ja}v[22452]=0;f=Q(146,b|0,f|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break Ja}if(!f){break Pa}da=Bb(e+112|0);v[22452]=0;M=T(165,e+56|0)|0;d=v[22452];v[22452]=0;Qa:{Ra:{if((d|0)!=1){if($){break Ra}v[22452]=0;R(493,b|0,e+128|0);d=v[22452];v[22452]=0;if((d|0)==1){break Oa}u[e+104>>1]=w[e+128|0];ea=w[C|0]+1|0;f=48;break Qa}h=P()|0;O()|0;break A}p=t[e+806|0];v[22452]=0;R(494,b|0,e+40|0);d=v[22452];v[22452]=0;Sa:{Ta:{if((d|0)!=1){l=Ab(w[e+40|0]|w[e+41|0]<<8);u[e+104>>1]=l;ea=Ab(w[A|0]|w[A+1|0]<<8)+1|0;d=Wb(w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24));if(!d){break Sa}i=v[b+8>>2];v[22452]=0;Q(146,b|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break B}v[22452]=0;R(495,b|0,e+128|0);d=v[22452];v[22452]=0;if((d|0)==1){break B}d=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);v[22452]=0;f=Q(146,b|0,Wb(d)|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break B}if(!f){break Ta}d=w[e+136|0]|w[e+137|0]<<8|(w[e+138|0]<<16|w[e+139|0]<<24);v[22452]=0;U(262,b|0,da|0,Wb(d)|0);d=v[22452];v[22452]=0;if((d|0)!=1){break Ta}break B}break B}d=Wb(w[e+144|0]|w[e+145|0]<<8|(w[e+146|0]<<16|w[e+147|0]<<24));Ua:{if(!d){break Ua}v[22452]=0;f=Q(146,b|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break B}if(!f){break Ua}v[22452]=0;f=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break B}v[22452]=0;f=Q(146,b|0,f|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break B}if(!f){break Ua}v[22452]=0;U(181,e+16|0,b|0,B(l,ea)|0);d=v[22452];v[22452]=0;if((d|0)==1){break B}f=e+416|0;d=e+16|0;Mc(M,bc(f,d));qb(f);qb(d)}v[22452]=0;Q(146,b|0,i|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break B}}f=p+($>>>0<3?48:24)|0}v[22452]=0;l=E+V|0;i=Y(217,N|0,l&65535,ea|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break B}Va:{if(!i){break Va}X=Rb(N,l);v[22452]=0;R(275,X|0,da|0);d=v[22452];v[22452]=0;if((d|0)==1){break Ia}lg(e+104|0,x[a+480188>>1]);fa=0;o=x[e+104>>1];Wa:while(1){if((ea|0)==(fa|0)){break Va}m=0;d=Qc(X,fa,0);while(1){if((m&65535)>>>0>=o>>>0){fa=fa+1|0;continue Wa}Xa:{if(!$){v[22452]=0;R(496,e+128|0,b|0);i=v[22452];v[22452]=0;if((i|0)!=1){p=e+128|0;l=w[p|0];i=Zc(p);t[d+1|0]=l>>>3&16|w[i|0]>>>4|l>>>1&32;t[d+3|0]=w[i|0]&15;ja=d,ka=w[Me(p)|0],t[ja+5|0]=ka;i=l&63;h=i?i+f|0:0;break Xa}break B}v[22452]=0;R(346,e+128|0,b|0);i=v[22452];v[22452]=0;Ya:{Za:{if((i|0)!=1){i=e+128|0;k=Zc(i);s=Me(i);p=vi(i);v[22452]=0;l=T(197,M|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break B}t[d+4|0]=l;l=w[e+128|0];i=l&127;if(!i){break Za}h=f+i|0;break Ya}break B}h=0;if((l|0)!=128){break Ya}t[d|0]=254}t[d+1|0]=w[k|0]&63;t[d+3|0]=w[s|0];t[d+5|0]=w[p|0]}if(h-1>>>0<=119){t[d|0]=h}Z=(h|0)>84&ca|Z;s=(F|0)!=0;p=(J|0)!=0;l=(K|0)!=0;k=ab-16|0;ab=k;_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{i=w[d+3|0];switch(i-4|0){case 42:break ab;case 37:break bb;case 28:break cb;case 27:break db;case 26:break eb;case 25:break fb;case 24:break gb;case 23:break hb;case 22:break ib;case 21:break jb;case 20:break kb;case 18:break lb;case 17:break mb;case 16:break nb;case 14:break ob;case 13:break pb;case 12:break qb;case 11:break rb;case 10:break sb;case 9:break tb;case 8:break ub;case 5:break vb;case 4:break wb;case 0:break xb;default:break $a}}t[d+3|0]=5;l=w[d+5|0];t[k+15|0]=l>>>3;t[k+14|0]=15;i=w[Qb(k+15|0,k+14|0)|0];t[k+13|0]=l<<1&30;t[k+12|0]=15;ja=d,ka=w[Qb(k+13|0,k+12|0)|0]|i<<4,t[ja+5|0]=ka;break _a}t[d+3|0]=0;break _a}if((w[d+5|0]-1&255)>>>0<=19){t[d+3|0]=16;break _a}t[d+3|0]=0;break _a}t[d+3|0]=13;i=w[d+5|0];yb:{if(!l){if(i>>>0>152){break yb}t[d+5|0]=B((i&240)>>>4|0,10)+(i&15);break _a}t[d+5|0]=(i&127)+1>>>1;break _a}t[d+3|0]=0;break _a}t[d+3|0]=11;break _a}t[d+3|0]=0;break _a}i=w[d+5|0];if(!i){t[d+3|0]=14;break _a}if(i>>>0<=240){t[d+3|0]=17;if(i>>>0<=2){t[d+5|0]=112;break _a}ja=d,ka=Nn(+(pR(i,s,p,z)>>>0)/1e4),t[ja+5|0]=ka;break _a}t[d+3|0]=0;break _a}t[d+3|0]=31;t[d+5|0]=w[d+5|0]|128;break _a}t[d+3|0]=19;t[k+11|0]=15;ja=d,ka=w[Qb(d+5|0,k+11|0)|0]|16,t[ja+5|0]=ka;break _a}t[d+3|0]=19;t[k+10|0]=15;ja=d,ka=w[Qb(d+5|0,k+10|0)|0]|32,t[ja+5|0]=ka;break _a}t[d+3|0]=5;i=w[d+5|0];t[k+9|0]=(i>>>4|0)+1;t[k+8|0]=15;ja=d,ka=i&15|w[Qb(k+9|0,k+8|0)|0]<<4,t[ja+5|0]=ka;break _a}t[d+3|0]=19;t[d+5|0]=w[d+5|0]&15|80;break _a}t[d+3|0]=19;t[k+7|0]=15;ja=d,ka=w[Qb(d+5|0,k+7|0)|0]|96,t[ja+5|0]=ka;break _a}t[d+3|0]=19;t[k+6|0]=15;ja=d,ka=w[Qb(d+5|0,k+6|0)|0]|192,t[ja+5|0]=ka;break _a}t[d+3|0]=10;break _a}t[d+3|0]=19;t[k+5|0]=15;ja=d,ka=w[Qb(d+5|0,k+5|0)|0]|160,t[ja+5|0]=ka;break _a}t[d+3|0]=19;t[k+4|0]=15;ja=d,ka=w[Qb(d+5|0,k+4|0)|0]|176,t[ja+5|0]=ka;break _a}i=(w[d+5|0]<<24)-16777216>>24;if((i|0)>=0){t[d+5|0]=i;t[d+3|0]=31;break _a}t[d+3|0]=0;break _a}t[d+3|0]=14;break _a}t[d+3|0]=19;t[k+3|0]=15;ja=d,ka=w[Qb(d+5|0,k+3|0)|0]|224,t[ja+5|0]=ka;break _a}i=w[d+5|0];if(i&240){t[d+3|0]=19;t[d+5|0]=i>>>4|208;break _a}if(i&15){t[d+3|0]=19;t[d+5|0]=i|144;break _a}t[d+3|0]=0;break _a}if(!(w[d+5|0]|w[d+4|0])){if(!Kc(w[d|0])){break _a}t[d+5|0]=159;t[d+3|0]=20;break _a}t[d+3|0]=0;break _a}i=w[d+4|0];if(i){t[d+3|0]=44;ja=d,ka=pm(Fc(((w[d+5|0]<<8&65280)>>>0)/(i>>>0)|0,0)),t[ja+5|0]=ka;break _a}t[d+3|0]=0;break _a}i=w[d+5|0];if((i+16&255)>>>0<=32){t[d+3|0]=9;ja=d,ka=pi(((i^128)<<3)-896|0),t[ja+5|0]=ka;break _a}t[d+3|0]=0;break _a}if(i>>>0<=15){Mf(d);break _a}t[d+3|0]=0}ab=k+16|0;d=d+6|0;m=m+1|0;continue}}}qb(e+56|0);pb(da)}E=E+1|0;continue}break}break B}h=P()|0;O()|0;break w}break B}xt(I);d=0;if(!m){break c}}si(y,0);d=1;zb:{if(Z&1){break zb}while(1){b=d&65535;if(b>>>0>x[a+480192>>1]){u[a+480192>>1]=0;break zb}b=((b<<2)+a|0)+900380|0;c=v[b>>2];if(c){zt(c)}xb(c);v[b>>2]=0;d=d+1|0;continue}}Ab:{if(!ia){break Ab}v[22452]=0;c=Q(1,e+128|0,16314)|0;b=v[22452];v[22452]=0;Bb:{if((b|0)!=1){b=v[a+1298464>>2];v[22452]=0;U(364,b|0,2,c|0);b=v[22452];v[22452]=0;if((b|0)==1){break Bb}pb(c);break Ab}h=P()|0;O()|0;break f}h=P()|0;O()|0;pb(c);break f}h=21598;Cb:{Db:{switch(w[e+855|0]){case 0:h=x[a+480188>>1]>4?17209:17195;break Cb;case 1:h=17177;break Cb;case 2:h=17159;break Cb;case 3:break Db;default:break Cb}}h=17132}v[22452]=0;R(497,e+56|0,16747);b=v[22452];v[22452]=0;Eb:{Fb:{Gb:{if((b|0)!=1){v[22452]=0;U(498,e+128|0,e+56|0,e+855|0);b=v[22452];v[22452]=0;if((b|0)==1){break Gb}b=e+128|0;tb(a+1298344|0,b);pb(b);yb(e+56|0);v[22452]=0;c=Q(1,b|0,12612)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Fb}tb(a+1298356|0,c);pb(c);v[22452]=0;Q(127,a+1298368|0,h|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Eb}v[a+1298404>>2]=2;d=1;break c}h=P()|0;O()|0;break f}h=P()|0;O()|0;yb(e+56|0);break f}h=P()|0;O()|0;break f}h=P()|0;O()|0;break f}c=c+1|0;continue}}h=P()|0;O()|0;break f}h=P()|0;O()|0;qb(e+56|0)}pb(da);break w}h=P()|0;O()|0;break w}h=P()|0;O()|0;break w}h=P()|0;O()|0}xt(I);break f}h=P()|0;O()|0;break f}h=P()|0;O()|0;break f}h=P()|0;O()|0;break f}z=1;if((f|0)!=7){break m}d=A+108|0;f=d+128|0;while(1){if((d|0)!=(f|0)){ja=d,ka=cm(w[d|0]-24|0),t[ja|0]=ka;d=d+1|0;continue}break}d=0}g=d;Z=1;break l}g=0;Hb:{if(D|(r|0)<0){break Hb}l=A+108|0;m=7;Ib:while(1){if((m|0)==10){break Hb}i=B(m,12);j=B(m,-12)+72|0;d=0;while(1)if((d|0)==12){m=m+1|0;continue Ib}else{f=Cb(l,d+i|0);t[f|0]=j+w[f|0];d=d+1|0;continue}}}}v[22452]=0;R(499,ga|0,e+56|0);d=v[22452];v[22452]=0;if((d|0)!=1){Jb:{d=w[o|0];if((d-1&255)>>>0<=15){t[A+31|0]=d;Z=1}d=w[V|0];if((d<<24)-16777216>>24>=0){t[A+30|0]=d}d=0;Kb:{while(1){if((d|0)==(z|0)){if(!C){break j}if((r|0)>=0){break Kb}break j}v[22452]=0;j=B(d+M|0,104)+a|0;R(271,j+484380|0,8);f=v[22452];v[22452]=0;if((f|0)!=1){t[e+416|0]=w[K|0];t[e+384|0]=64;ja=j+484410|0,ka=w[Qb(e+416|0,e+384|0)|0]<<2,u[ja>>1]=ka;t[j+484416|0]=w[F|0];d=d+1|0;continue}break}break k}l=Gc(e+416|0,8,1,1,0);j=Ab(w[J|0]|w[J+1|0]<<8);m=Ab(w[e+56|0]|w[e+57|0]<<8);v[22452]=0;h=T(151,e+128|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){d=Ab(w[y|0]|w[y+1|0]<<8);if(d&16){vh(l,16);h=h>>>1|0;d=Ab(w[y|0]|w[y+1|0]<<8)}if(d&32){eo(l,3);h=h>>>1|0;d=Ab(w[y|0]|w[y+1|0]<<8)}if(d&64){nf(l,2)}h=g?(h>>>0)/((-1<<z^-1)>>>0)|0:h;g=j+m|0;d=0;while(1){if((d|0)==(z|0)){break j}i=B(d+M|0,104)+a|0;f=i+484380|0;v[f>>2]=h;v[22452]=0;Y(210,l|0,f|0,X|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break Jb}m=m<<1;g=g<<1;if(j>>>0>=2){v[i+484388>>2]=g;v[i+484384>>2]=m;f=i+484414|0;u[f>>1]=x[f>>1]|2}d=d+1|0;h=h<<1;continue}}}}}h=P()|0;O()|0;qb(e+128|0);break f}E=E+1|0;H=z+H|0;qb(e+128|0);h=x[a+480192>>1];continue}}h=P()|0;O()|0;break e}h=P()|0;O()|0;break e}h=P()|0;O()|0}ec(ba)}qb(ga);S(h|0);L()}d=0}ec(ba)}qb(ga)}ab=e+912|0;return d|0}function lda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=C(0),D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,_=0,$=0,aa=0,ba=0,ca=0,fa=C(0),ga=0,ha=0,ia=0,ja=0,ka=0;e=ab-432|0;ab=e;qc(b);a:{b:{c:{if(!Mh(b,e+424|0)){break c}if(!kP(e+424|0)){break c}if((hm(b)|0)>=0){break c}if(!c){j=1;break c}vd(a,16777216);v[a+480208>>2]=v[a+480208>>2]|1681e4;uz(e+160|0,32);h=v[e+172>>2];d=a+1074320|0;v[d>>2]=v[e+168>>2];v[d+4>>2]=h;d=v[e+164>>2];v[a+1074312>>2]=v[e+160>>2];v[a+1074316>>2]=d;Cf(a+1074312|0,38);p=Pb(e+408|0);q=Pb(e+392|0);s=Pb(e+376|0);m=Pb(e+360|0);gg(b,4);k=a+480190|0;J=c&1;I=a+1298332|0;o=2500;G=!(c&2);E=a+1298464|0;d:{e:{f:{while(1){v[22452]=0;c=Q(147,b|0,4)|0;d=v[22452];v[22452]=0;g:{h:{i:{j:{k:{l:{m:{n:{if((d|0)!=1){o:{if(c){v[22452]=0;d=T(651,b|0)|0;c=v[22452];v[22452]=0;p:{if((c|0)==1){break p}j=0;q:{switch(d+21|0){case 20:v[22452]=0;c=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){d=c&65535;if(x[a+480188>>1]|d-1>>>0>126){continue}u[a+480188>>1]=c;ja=a,ka=Sb(512/(d>>>0)|0,16,128),v[ja+480228>>2]=ka;continue}i=P()|0;O()|0;break a;case 19:v[22452]=0;K=T(273,b|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break p}if(K>>>0<=1024){continue}break m;case 16:v[22452]=0;c=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){if((c&65535)==4){continue}break m}i=P()|0;O()|0;break a;case 15:v[22452]=0;c=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){v[e+160>>2]=c;v[e+56>>2]=800;ja=a,ka=xe(+y[zb(e+160|0,e+56|0)>>2]*1.24*1e4),v[ja+480204>>2]=ka;continue}i=P()|0;O()|0;break a;case 17:case 18:v[22452]=0;Q(179,b|0,4)|0;c=v[22452];v[22452]=0;if((c|0)!=1){continue}break p;case 31:v[22452]=0;c=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break p}X=1;o=Ld(c,0,1e4);continue;case 32:case 33:v[22452]=0;c=T(273,b|0)|0;d=v[22452];v[22452]=0;r:{s:{if((d|0)!=1){X=1;if(!c){continue}v[22452]=0;c=Q(1,e+160|0,12521)|0;d=v[22452];v[22452]=0;if((d|0)==1){break s}d=v[E>>2];v[22452]=0;U(364,d|0,2,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break r}pb(c);continue}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;pb(c);break a;case 14:v[22452]=0;Q(179,b|0,4)|0;c=v[22452];v[22452]=0;if((c|0)==1){break p}i=!x[k>>1]|i;continue;case 11:t:{if(!J){break t}if(!jc(v[p>>2],v[p+4>>2])){break t}v[22452]=0;R(652,e+160|0,b|0);c=v[22452];v[22452]=0;if((c|0)!=1){if(v[p>>2]){uc(p);c=v[p>>2];Mn(p);xb(c);ja=vb(p),ka=0,v[ja>>2]=ka;v[p>>2]=0;v[p+4>>2]=0}c=e+160|0;v[p>>2]=v[c>>2];v[p+4>>2]=v[c+4>>2];d=vb(c);ja=vb(p),ka=v[d>>2],v[ja>>2]=ka;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;ni(c);continue}i=P()|0;O()|0;break a}v[22452]=0;c=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break p}v[22452]=0;Q(179,b|0,c|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){continue}break p;case 3:case 4:case 10:g=eh(v[m>>2],v[m+4>>2]);c=x[k>>1];if(g>>>0<=c>>>0){continue}u:{if((i|G)&1){break u}if(!Dh(a)){break u}h=c+1|0;u[k>>1]=h;r=Pb(e+344|0);v[22452]=0;c=T(165,e+160|0)|0;g=v[22452];v[22452]=0;v:{w:{x:{if((g|0)!=1){if((d|0)==-17){break x}if((d|0)!=-11){break w}v[22452]=0;d=T(273,b|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break v}v[22452]=0;U(181,e+320|0,b|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break v}d=e+56|0;g=e+320|0;Mc(c,bc(d,g));qb(d);qb(g);break g}i=P()|0;O()|0;break d}v[22452]=0;R(653,e+56|0,b|0);d=v[22452];v[22452]=0;y:{if((d|0)!=1){d=e+56|0;bm(r,d);Xb(d);de(e+312|0,v[e+344>>2],v[e+348>>2]);Vd(e+304|0);v[22452]=0;d=ea(323,d|0,v[e+312>>2],v[e+316>>2],v[e+304>>2],v[e+308>>2])|0;g=v[22452];v[22452]=0;if((g|0)==1){break y}Mc(c,d);qb(e+56|0);break g}i=P()|0;O()|0;break e}i=P()|0;O()|0;break e}v[22452]=0;R(654,e+56|0,b|0);d=v[22452];v[22452]=0;z:{if((d|0)!=1){d=e+56|0;bm(r,d);Xb(d);de(e+296|0,v[e+344>>2],v[e+348>>2]);Vd(e+288|0);v[22452]=0;d=ea(323,d|0,v[e+296>>2],v[e+300>>2],v[e+288>>2],v[e+292>>2])|0;g=v[22452];v[22452]=0;if((g|0)==1){break z}Mc(c,d);qb(e+56|0);break g}i=P()|0;O()|0;break e}i=P()|0;O()|0;break e}i=P()|0;O()|0;break e}v[22452]=0;c=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break p}v[22452]=0;Q(179,b|0,c|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){continue}break p;case 9:if(!Dh(a)){continue}u[k>>1]=x[k>>1]+1;continue;case 8:A:{if(!J){break A}if(!jc(v[s>>2],v[s+4>>2])){break A}v[22452]=0;R(655,e+160|0,b|0);c=v[22452];v[22452]=0;if((c|0)!=1){c=e+160|0;jP(s,c);ec(c);continue}i=P()|0;O()|0;break a}v[22452]=0;c=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break p}v[22452]=0;Q(179,b|0,c|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){continue}break p;case 7:if(jc(v[m>>2],v[m+4>>2])){v[22452]=0;R(656,e+160|0,b|0);c=v[22452];v[22452]=0;if((c|0)!=1){if(v[m>>2]){uc(m);c=v[m>>2];mz(m);xb(c);ja=vb(m),ka=0,v[ja>>2]=ka;v[m>>2]=0;v[m+4>>2]=0}c=e+160|0;v[m>>2]=v[c>>2];v[m+4>>2]=v[c+4>>2];d=vb(c);ja=vb(m),ka=v[d>>2],v[ja>>2]=ka;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;ht(c);continue}i=P()|0;O()|0;break a}v[22452]=0;c=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break p}v[22452]=0;Q(179,b|0,c|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){continue}break p;case 6:B:{if(!J){break B}if(!jc(v[q>>2],v[q+4>>2])){break B}v[22452]=0;R(657,e+160|0,b|0);c=v[22452];v[22452]=0;if((c|0)!=1){if(v[q>>2]){uc(q);c=v[q>>2];cr(q);xb(c);ja=vb(q),ka=0,v[ja>>2]=ka;v[q>>2]=0;v[q+4>>2]=0}c=e+160|0;v[q>>2]=v[c>>2];v[q+4>>2]=v[c+4>>2];d=vb(c);ja=vb(q),ka=v[d>>2],v[ja>>2]=ka;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Vj(c);continue}i=P()|0;O()|0;break a}v[22452]=0;c=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break p}v[22452]=0;Q(179,b|0,c|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){continue}break p;case 5:v[22452]=0;R(658,e+160|0,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break o}C:{c=v[e+160>>2];d=v[e+164>>2];if(jc(c,d)){break C}v[22452]=0;W(332,I|0,c|0,Ic(c,d)|0,1);c=v[22452];v[22452]=0;if((c|0)!=1){break C}i=P()|0;O()|0;Xb(e+160|0);break a}Xb(e+160|0);continue;case 0:case 1:case 2:break q;default:break m}}v[22452]=0;c=T(273,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break p}v[22452]=0;Q(179,b|0,c|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){continue}}i=P()|0;O()|0;break a}j=0;if(!x[a+480188>>1]|!K){break m}b=v[m>>2];c=v[m+4>>2];if(jc(b,c)){break m}if(J){if(jc(v[p>>2],v[p+4>>2])){break m}if(jc(v[s>>2],v[s+4>>2])){break m}if(jc(v[q>>2],v[q+4>>2])){break m}}b=eh(b,c);if(b>>>0>=256){v[22452]=0;R(659,m|0,255);b=v[22452];v[22452]=0;if((b|0)==1){break b}b=eh(v[m>>2],v[m+4>>2])}u[a+480192>>1]=b;j=a+480192|0;ja=a,ka=x[Ne(k,j)>>1],u[ja+480190>>1]=ka;if(i&1){v[22452]=0;b=Q(1,e+160|0,16403)|0;c=v[22452];v[22452]=0;if((c|0)==1){break h}c=v[a+1298464>>2];v[22452]=0;U(364,c|0,2,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break i}pb(b)}i=0;D:while(1){if((i|0)==2){break n}b=1;while(1){g=b&65535;if(g>>>0>x[j>>1]){i=i+1|0;continue D}E:{h=Ul(v[m>>2],g-1|0);if(w[h|0]){c=t[h+128|0]<0}else{c=1}if(c){break E}if((ft(h)|0)==((i|0)!=1|0)){break E}c=0;F:{if(!ft(h)){break F}if(Ab(w[h+6|0]|w[h+7|0]<<8)){break F}if(Ab(w[h+14|0]|w[h+15|0]<<8)>>>0>20){break F}c=(Ab(w[h+18|0]|w[h+19|0]<<8)|0)==4}G:{H:{if(c){c=w[h+23|0];d=w[h+140|0];v[22452]=0;d=ea(660,h|0,a|0,(d&2)>>>1|0,(B(g,104)+a|0)+484380|0,o&65535)|0;f=v[22452];v[22452]=0;I:{J:{if((f|0)!=1){if(!d){break I}v[22452]=0;d=Q(55,e+160|0,10687)|0;f=v[22452];v[22452]=0;if((f|0)==1){break J}sc(((g<<5)+a|0)+946304|0,d);pb(d);f=v[m>>2];d=b;if(eh(f,v[m+4>>2])>>>0<=c>>>0){break G}c=Ul(f,c);t[h+143|0]=w[h+143|0]+w[c+143|0];break H}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}d=c+1|0;break G}c=0;K:{if(!ft(h)){break K}if((Ab(w[h+6|0]|w[h+7|0]<<8)|0)!=1){break K}if((Ab(w[h+14|0]|w[h+15|0]<<8)|0)!=2){break K}c=(Ab(w[h+18|0]|w[h+19|0]<<8)|0)==10}d=b;if(!c){break G}gc(e+160|0,h,128);if(Ab(w[e+180|0]|w[e+181|0]<<8)>>>0>=x[k>>1]){break H}v[22452]=0;d=T(649,e+56|0)|0;c=v[22452];v[22452]=0;L:{M:{if((c|0)!=1){c=Ab(w[e+180|0]|w[e+181|0]<<8);f=w[e+196|0]|w[e+197|0]<<8;n=x[a+480190>>1];v[22452]=0;r=B(c,104);c=a+484380|0;f=Ab(f);c=da(661,e+160|0,(r+c|0)+104|0,(f>>>0<n>>>0?(c+B(f,104)|0)+104|0:d)|0,c+B(g,104)|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break M}if(!c){break H}v[22452]=0;c=Q(55,e+320|0,11227)|0;d=v[22452];v[22452]=0;if((d|0)==1){break L}sc(((g<<5)+a|0)+946304|0,c);pb(c);t[h+139|0]=w[h+139|0]+12;break H}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}d=b}v[22452]=0;c=d&65535;d=Y(245,a|0,g|0,c|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){if(!d|c>>>0>x[k>>1]){break E}v[22452]=0;W(662,h|0,d|0,(B(c,104)+a|0)+484380|0,a|0);c=v[22452];v[22452]=0;if((c|0)!=1){break E}}i=P()|0;O()|0;break a}b=b+1|0;continue}}}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}I=Rg(e+56|0);r=Rg(e+320|0);b=nc(v[s>>2],v[s+4>>2]);_=B(x[a+480188>>1],K);$=Wt((b>>>0)/(_>>>0)|0);v[22452]=0;N=a+484344|0;R(216,N|0,$|0);b=v[22452];v[22452]=0;if((b|0)==1){break k}aa=a+484360|0;uc(Kb(aa));b=x[a+480188>>1];v[22452]=0;E=Q(663,e+344|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break l}ja=e,ka=wb(v[q>>2]),v[ja+48>>2]=ka;ga=a+902204|0;ha=wb(v[q+4>>2]);while(1){N:{O:{P:{n=v[e+48>>2];if(!Tb(n,ha)){break P}b=Ab(w[n+6|0]|w[n+7|0]<<8);if((b|0)==1){break N}if((b|0)==65535){break P}h=Ab(w[n|0]|w[n+1|0]<<8);b=v[p>>2];g=v[p+4>>2];c=$f(b,g);if(h>>>0>=c>>>0){break N}d=Ab(w[n+2|0]|w[n+3|0]<<8);if(d>>>0>c>>>0|!d|h>>>0>c-d>>>0){break N}c=b+($f(b,g)<<5)|0;v[e+160>>2]=b;v[e+164>>2]=c-b>>5;b=v[e+160>>2];Zb(e+40|0,b+(Ab(w[n|0]|w[n+1|0]<<8)<<5)|0,Ab(w[n+2|0]|w[n+3|0]<<8));Q:{H=Kb(aa);if(jc(v[H>>2],v[H+4>>2])){break Q}v[22452]=0;R(484,H|0,65534);b=v[22452];v[22452]=0;if((b|0)!=1){break Q}break O}h=v[e+40>>2];ia=ie(h,v[e+44>>2]);while(1){if((h|0)==(ia|0)){break N}b=Ab(Ab(w[n+8|0]|w[n+9|0]<<8)+Ab(w[h+16|0]|w[h+17|0]<<8)&65535);t[h+16|0]=b;t[h+17|0]=b>>>8;b=Kd(I);while(1){R:{c=0;if(!b){break R}d=b+14|0;if(!ct(h,d)){c=1;if(!ct(d,h)){break R}b=b+4|0}b=v[b>>2];continue}break}S:{T:{U:{if(c){v[22452]=0;b=Q(664,I|0,h|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break O}D=x[b>>1];break U}D=0;if(!J){break U}b=w[h+12|0]|w[h+13|0]<<8;v[22452]=0;D=Y(356,N|0,Ab(b)|0,0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break O}if((D|0)==65535){break N}v[22452]=0;b=Q(664,I|0,h|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break O}u[b>>1]=D;if(Ab(w[h+8|0]|w[h+9|0]<<8)>>>0>=$>>>0){break T}if(Ab(w[h+10|0]|w[h+11|0]<<8)>>>0>=K>>>0){break T}o=Ab(w[h+14|0]|w[h+15|0]<<8);ja=e,ka=wb(v[s>>2]),v[ja+16>>2]=ka;b=e+16|0;ja=e,ka=Wk(b,B(Ab(w[h+8|0]|w[h+9|0]<<8),_)),v[ja+160>>2]=ka;ja=e,ka=Wk(e+160|0,B(x[a+480188>>1],Ab(w[h+10|0]|w[h+11|0]<<8))),v[ja+32>>2]=ka;M=0;v[e+28>>2]=0;Fh(b);V:while(1){W:{c=Ab(w[h+12|0]|w[h+13|0]<<8);b=Rb(N,D);if(c>>>0<=M>>>0){break W}c=0;V=Qc(b,M,0);j=0;while(1){if(x[a+480188>>1]<=c>>>0){M=M+1|0;continue V}b=wb(v[s+4>>2]);d=v[e+32>>2];k=Tb(d,b)?d:e+28|0;b=wb(v[s+4>>2]);if(Tb(v[e+32>>2],b)){hP(e+32|0)}d=B(c,6)+V|0;g=w[k+1|0];b=(g>>>0<85?g+25|0:-1)<<24>>24;i=0;f=v[m>>2];F=eh(f,v[m+4>>2]);G=w[k+3|0];X:{if(F>>>0<=G>>>0){break X}i=G+1|0;if(t[Ul(f,G)+142|0]&1|(b|0)<0){break X}b=cm(Ab(w[h+16|0]|w[h+17|0]<<8)+b<<24>>24)}Y:{if(!w[d|0]|!(w[k+2|0]?1:G|(w[k|0]|(g|0)!=255))){break Y}g=w[d+1|0];if(!g|g>>>0>F>>>0){break Y}if(w[Ul(f,g-1|0)+132|0]!=2){break Y}Kn(d)}f=jt(v[E>>2],c);Z:{if(j&1){g=v[e+16>>2];t[d|0]=g;t[d+1|0]=g>>>8;t[d+2|0]=g>>>16;t[d+3|0]=g>>>24;g=x[e+20>>1];t[d+4|0]=g;t[d+5|0]=g>>>8;_:{if(w[d+3|0]){break _}j=w[f+21|0];g=w[jt(v[E>>2],c-1|0)+21|0];if((j|0)==(g|0)){break _}t[d+3|0]=21;t[f+21|0]=g;t[d+5|0]=g}j=0;g=1;F=w[k|0];if(!(F-24>>>0<2|(F|0)==9|!F&(w[k+2|0]+7&255)>>>0<2?g:0)){break Z}}$:{aa:{ba:{ca:{da:{ea:{switch(w[k|0]){case 5:g=w[f+17|0];break da;case 0:fa:{g=w[k+2|0];if(g>>>0>=201){j=0;ga:{switch(g-242|0){case 11:t[d+4|0]=1;t[d+2|0]=14;t[f+16|0]=0;break aa;case 9:if(!w[d|0]){t[d|0]=w[f+17|0]}t[d+4|0]=1;t[d+2|0]=15;break aa;case 8:if((o&255)>>>0<2){break aa}o=o-1|0;break ba;case 7:if((o&255)==255){o=255;break aa}o=o+1|0;break ba;case 6:t[f+17|0]=b;if(w[f+18|0]!=(i&255)){break aa}t[d|0]=b;t[d+5|0]=255;t[d+3|0]=4;u[f+32>>1]=0;v[f+8>>2]=0;break aa;case 5:t[d+5|0]=242;t[d+3|0]=2;break aa;case 4:t[d+5|0]=242;t[d+3|0]=3;break aa;case 3:t[d+5|0]=244;t[d+3|0]=2;break aa;case 2:t[d+5|0]=244;t[d+3|0]=3;break aa;case 1:t[d+5|0]=248;t[d+3|0]=2;break aa;case 12:break fa;case 0:break ga;default:break aa}}t[d+5|0]=248;t[d+3|0]=3;break aa}j=0;F=t[k+1|0];if((F|0)<0&g>>>0>99){break aa}if((F|0)>=0){t[f+17|0]=b;t[d|0]=b;t[f+18|0]=i;t[d+1|0]=i;u[f+32>>1]=0;v[f+8>>2]=0;g=w[k+2|0]}b=g&255;if(!b){break aa}ja=f,ka=Nn(+(b>>>0)*.64),t[ja+19|0]=ka;l=z[f>>2];v[f>>2]=0;j=l!=C(0);break aa}t[d+4|0]=0;t[d+2|0]=14;t[f+16|0]=1;break aa;case 1:v[f+4>>2]=0;z[f>>2]=C(w[k+2|0])*C(.0333000011742115);break $;case 2:v[f+4>>2]=0;z[f>>2]=C(w[k+2|0])*C(-.0333000011742115);break $;case 12:t[e+160|0]=15;t[e+12|0]=w[k+3|0]>>>3;b=w[Qb(e+160|0,e+12|0)|0];t[e+160|0]=15;t[e+12|0]=w[k+2|0]>>>3;ja=f,ka=w[Qb(e+160|0,e+12|0)|0]|b<<4,t[ja+24|0]=ka;break $;case 3:v[f+12>>2]=0;b=w[k+2|0];u[f+32>>1]=0;z[f+8>>2]=C(b>>>0)*C(.0333000011742115);break $;case 4:v[f+12>>2]=0;b=w[k+2|0];u[f+32>>1]=0;z[f+8>>2]=C(b>>>0)*C(-.0333000011742115);break $;case 15:if(!w[k+2|0]|(b|0)<0){break $}j=b-w[f+17|0]|0;g=j>>31;g=g^g+(j<<5);v[e+160>>2]=g;t[f+17|0]=b;v[f+8>>2]=0;t[d|0]=b;t[d+3|0]=4;b=pi((g>>>0)/(w[k+2|0]<<1>>>0)|0);t[d+5|0]=b;t[f+27|0]=b;v[e+12>>2]=B(b,(o&255)-1|0);ja=f,ka=g-v[jd(e+160|0,e+12|0)>>2]|0,u[ja+32>>1]=ka;break $;case 10:case 11:t[d+3|0]=0;t[d+5|0]=0;break $;case 13:t[e+160|0]=15;t[e+12|0]=w[k+3|0]>>>3;b=w[Qb(e+160|0,e+12|0)|0];t[e+160|0]=15;t[e+12|0]=w[k+2|0];ja=f,ka=w[Qb(e+160|0,e+12|0)|0]|b<<4,t[ja+23|0]=ka;break $;case 18:b=w[k+2|0]+w[f+17|0]&255;b=b?b>>>0<120?b:120:1;t[f+17|0]=b;t[d|0]=b;t[d+5|0]=255;t[d+3|0]=4;break ca;case 23:case 24:case 25:b=Kd(r);while(1){ha:{g=0;if(!b){break ha}j=b+13|0;if(!dt(k,j)){g=1;if(!dt(j,k)){break ha}b=b+4|0}b=v[b>>2];continue}break};if(g){t[d+3|0]=31;v[22452]=0;b=Q(665,r|0,k|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break O}t[d+5|0]=w[b|0];break $}b=v[vb(r)>>2];if(b>>>0>127){break $}v[e+8>>2]=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);v[22452]=0;v[e>>2]=v[e+8>>2];g=Y(666,e|0,ie(ga,b&255)|0,a|0)|0;j=v[22452];v[22452]=0;ia:{if((j|0)==1){break ia}if(!g){break $}t[d+3|0]=31;v[22452]=0;g=Q(665,r|0,k|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break ia}b=b|-128;t[g|0]=b;t[d+5|0]=b;ba=(w[k|0]&254)==24|ba;break $}break O;case 16:if(!w[k+2|0]){break $}t[d+3|0]=15;v[e+160>>2]=15;v[e+12>>2]=w[k+3|0]+1;ja=d,ka=v[jd(e+160|0,e+12|0)>>2],t[ja+5|0]=ka;u[f+30>>1]=B(w[k+2|0],w[k+3|0]+1|0);break $;case 9:t[d+3|0]=16;b=w[k+2|0];o=b?b:4;t[d+5|0]=o;break $;case 19:ja:{b=w[k+1|0];switch(b|0){case 0:case 4:break ja;default:break $}}i=128;i=(b|0)==4?w[k+3|0]:i;t[e+7|0]=i;t[e+160|0]=w[k+2|0];t[e+12|0]=100;b=e+160|0;j=e+12|0;g=w[Qb(b,j)|0];v[e+160>>2]=128;v[e+12>>2]=256-(i&255);j=v[jd(b,j)>>2];t[e+160|0]=128;b=w[Qb(b,e+7|0)|0];j=(B(g,j)|0)/128|0;i=j&255;if((i|0)!=w[f+20|0]){t[f+20|0]=j;t[d+3|0]=21;j=Fc(((B(i,w[f+19|0])+50&65535)>>>0)/100|0,0);t[f+21|0]=j;t[d+5|0]=j}if(w[k+1|0]!=4|(x[a+480188>>1]-1|0)<=(c|0)){break $}j=c+1|0;i=jt(v[E>>2],j);b=B(b,g)>>>7|0;if(w[i+20|0]==(b&255)){break $}t[i+20|0]=b;b=B(j,6)+V|0;t[b+3|0]=21;g=Fc(((B(w[f+20|0],w[f+19|0])+50&65535)>>>0)/100|0,0);t[f+21|0]=g;t[b+5|0]=g;break $;case 17:case 20:t[d+3|0]=0;break $;case 7:b=w[k+2|0];t[f+25|0]=0;t[f+26|0]=0;t[f+22|0]=b;break $;case 8:t[f+22|0]=w[f+22|0]+w[k+2|0];break $;case 14:t[f+25|0]=w[k+3|0];t[f+26|0]=w[k+2|0];break $;case 6:break ea;default:break $}}t[f+18|0]=i;t[f+17|0]=b;t[d+1|0]=i;g=b}t[d|0]=g;if((b|0)>=0){t[f+18|0]=i;t[d+1|0]=i}if(w[k|0]==5){t[d+4|0]=1;t[d+2|0]=11}g=w[f+22|0];b=w[f+26|0];if(!(b?1:g|w[k+2|0])){break ca}if(b){ca=(ki(+x[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{ca=0}t[d+3|0]=44;ja=d,ka=Nn(ca+ +(g+w[k+2|0]|0)),t[ja+5|0]=ka}u[f+32>>1]=0;break $}t[d+5|0]=o;t[d+3|0]=16}b=Fc(((B(w[f+20|0],w[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!j&w[f+21|0]==(b&255))){t[f+21|0]=b;t[d+5|0]=b;t[d+3|0]=21}if(c&1|t[k+1|0]<=0|(x[a+480188>>1]-1|0)<=(c|0)){break $}b=v[m>>2];if(eh(b,v[m+4>>2])>>>0<=G>>>0){break $}if(w[Ul(b,G)+132|0]!=1){break $}j=c+1|0;b=B(j,6)+V|0;g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[b|0]=g;t[b+1|0]=g>>>8;t[b+2|0]=g>>>16;t[b+3|0]=g>>>24;g=w[d+4|0]|w[d+5|0]<<8;t[b+4|0]=g;t[b+5|0]=g>>>8;t[b+1|0]=w[b+1|0]+1;b=jt(v[E>>2],j);t[b+19|0]=w[f+19|0];z[b>>2]=z[f>>2];z[b+4>>2]=z[f+4>>2];z[b+8>>2]=z[f+8>>2];z[b+12>>2]=z[f+12>>2];u[b+30>>1]=x[f+30>>1]}ka:{if(w[d|0]){t[f+16|0]=0;break ka}j=0;if(w[f+16|0]){break Z}}la:{if(!x[f+30>>1]){break la}b=o&255;u[e+160>>1]=b;g=f+30|0;ja=g,ka=x[Ne(g,e+160|0)>>1]-b|0,u[ja>>1]=ka;if(w[d+3|0]){break la}t[d+3|0]=15;t[d+5|0]=0}l=z[f>>2];ma:{if(l==C(0)){break ma}b=o&255;l=C(C(l*C(b>>>0))+z[f+4>>2]);z[f+4>>2]=l;if(w[d+3|0]){break ma}na:{oa:{pa:{qa:{if(b>>>0>=2){g=b-1|0;A=C(g|0);if(!(A<=l)){break qa}t[e+160|0]=15;ja=e,ka=Ng(C(l/A)),t[ja+12|0]=ka;b=w[Qb(e+160|0,e+12|0)|0];z[f+4>>2]=l-C(B(b,g)|0);t[d+3|0]=22;i=b<<4;break na}if(!(l>=C(1))){break pa}break oa}if(l>=C(1)){break oa}if(!(l<=C(1-b|0))){break pa}t[e+160|0]=15;ja=e,ka=Ng(C(C(-l)/A)),t[ja+12|0]=ka;i=w[Qb(e+160|0,e+12|0)|0];z[f+4>>2]=l+C(B(g,i)|0);t[d+3|0]=22;break na}if(!(l<=C(-1))){break ma}t[e+160|0]=14;ja=e,ka=Ng(C(-l)),t[ja+12|0]=ka;b=w[Qb(e+160|0,e+12|0)|0];z[f+4>>2]=l+C(b>>>0);t[d+3|0]=22;i=b|-16;break na}t[e+160|0]=15;ja=e,ka=Ng(l),t[ja+12|0]=ka;b=w[Qb(e+160|0,e+12|0)|0];z[f+4>>2]=l-C(b>>>0);t[d+3|0]=22;i=b<<4|15}t[d+5|0]=i}l=z[f+8>>2];ra:{if(l==C(0)){break ra}b=o&255;l=C(C(l*C(b>>>0))+z[f+12>>2]);z[f+12>>2]=l;sa:{if(!w[d+3|0]){ta:{ua:{if(b>>>0>=2){g=b-1|0;A=C(g|0);if(!(A<=l)){break ua}t[e+160|0]=223;ja=e,ka=Ng(C(l/A)),t[ja+12|0]=ka;b=w[Qb(e+160|0,e+12|0)|0];z[f+12>>2]=l-C(B(b,g)|0);t[d+3|0]=2;t[d+5|0]=b;break ra}if(!(l>=C(1))){break ta}break sa}if(l>=C(1)){break sa}if(!(l<=C(1-b|0))){break ta}t[e+160|0]=223;ja=e,ka=Ng(C(C(-l)/A)),t[ja+12|0]=ka;b=w[Qb(e+160|0,e+12|0)|0];z[f+12>>2]=l+C(B(b,g)|0);t[d+3|0]=3;t[d+5|0]=b;break ra}if(!(l<=C(-1))){break ra}t[e+160|0]=14;ja=e,ka=Ng(C(-l)),t[ja+12|0]=ka;b=w[Qb(e+160|0,e+12|0)|0];z[f+12>>2]=l+C(b>>>0);t[d+3|0]=3;t[d+5|0]=b|240;break ra}if(w[d+2|0]|b>>>0<2){break ra}fa=C(l*C(.25));g=b-1|0;A=C(g|0);if(fa>=A){t[e+160|0]=9;ja=e,ka=Ng(C(l/A))>>>2|0,t[ja+12|0]=ka;b=w[Qb(e+160|0,e+12|0)|0];z[f+12>>2]=l-C(B(b,g)<<2);t[d+2|0]=12;t[d+4|0]=b;break ra}if(!(C(1-b|0)>=fa)){break ra}t[e+160|0]=9;ja=e,ka=Ng(C(C(-l)/A))>>>2|0,t[ja+12|0]=ka;b=w[Qb(e+160|0,e+12|0)|0];z[f+12>>2]=l+C(B(b,g)<<2);t[d+2|0]=13;t[d+4|0]=b;break ra}t[e+160|0]=15;ja=e,ka=Ng(l),t[ja+12|0]=ka;b=w[Qb(e+160|0,e+12|0)|0];z[f+12>>2]=l-C(b>>>0);t[d+3|0]=2;t[d+5|0]=b|240}va:{wa:{xa:{ya:{za:{Aa:{Ba:{b=w[d+3|0];switch(b|0){case 4:break va;case 0:break Ba;default:break Aa}}Ca:{b=w[f+23|0];if(!b){b=w[f+24|0];if(b){break Ca}if(!x[f+32>>1]){break va}j=f+32|0;break za}t[d+3|0]=5;t[d+5|0]=b;if(!x[f+32>>1]){break va}break ya}t[d+3|0]=8;t[d+5|0]=b;if(x[f+32>>1]){break ya}break va}if(!x[f+32>>1]){break va}j=f+32|0;if(b){break xa}}t[d+3|0]=4;break wa}j=f+32|0}t[d+2|0]=11}u[e+160>>1]=B(w[f+27|0],(o&255)-1|0);ja=f,ka=x[f+32>>1]-x[Lc(j,e+160|0)>>1]|0,u[ja+32>>1]=ka}u[f+28>>1]=x[f+28>>1]+B(w[f+25|0],o&255)&1023;j=0;if(c&1){break Z}b=w[f+18|0];if(!b){break Z}g=v[m>>2];if(eh(g,v[m+4>>2])>>>0<b>>>0){break Z}b=Ul(g,b-1|0);if(!(w[b+142|0]&4)){break Z}v[e+16>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[e+20>>1]=w[d+4|0]|w[d+5|0]<<8;d=w[e+17|0];if(!d){j=1;break Z}j=1;if(w[b+132|0]!=1){break Z}t[e+17|0]=d+1}c=c+1|0;continue}}break}je(b,mh(Ae(ve(e+160|0,16,Ab(w[h+14|0]|w[h+15|0]<<8)&255),0)))}b=el(H);ja=e,ka=Ab(w[h+4|0]|w[h+5|0]<<8),u[ja+160>>1]=ka;u[e+16>>1]=1;c=x[Ne(e+160|0,e+16|0)>>1];v[22452]=0;W(667,H|0,b|0,c|0,D&65535);b=v[22452];v[22452]=0;if((b|0)==1){break S}b=Ab(w[n+8|0]|w[n+9|0]<<8);b=Ab(Ab(w[h+16|0]|w[h+17|0]<<8)-b&65535);t[h+16|0]=b;t[h+17|0]=b>>>8}h=h+32|0;continue}break}break O}c=ba&1;if(c){v[22452]=0;Z(278,a+906300|0);b=v[22452];v[22452]=0;if((b|0)==1){break O}b=a+906316|0;v[b>>2]=1299020115;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[e+160>>2]=0;d=a+906348|0;b=e+160|0;mB(a+906332|0,d,b);v[22452]=0;b=Q(55,b|0,9527)|0;h=v[22452];v[22452]=0;if((h|0)==1){break O}bu(d,b);pb(b);v[22452]=0;b=Q(55,e+160|0,9520)|0;d=v[22452];v[22452]=0;if((d|0)==1){break O}gq(a+906380|0,b);pb(b);v[22452]=0;b=Q(55,e+160|0,9512)|0;d=v[22452];v[22452]=0;if((d|0)==1){break O}bu(a+906508|0,b);pb(b)}b=0;while(1){if(x[a+480188>>1]>b>>>0){UA(a,b&65535);d=(b<<5)+a|0;t[d+480288|0]=c;u[d+480284>>1]=b<<8&256;b=b+1|0;continue}break}v[22452]=0;b=Q(1,e+160|0,12071)|0;c=v[22452];v[22452]=0;Da:{Ea:{Fa:{if((c|0)!=1){tb(a+1298344|0,b);pb(b);v[22452]=0;b=Q(1,e+160|0,12289)|0;c=v[22452];v[22452]=0;if((c|0)==1){break O}tb(a+1298356|0,b);pb(b);if(X){break Fa}v[22452]=0;b=Q(1,e+160|0,12071)|0;c=v[22452];v[22452]=0;if((c|0)==1){break O}break Ea}break O}if(eh(v[m>>2],v[m+4>>2])>>>0<=128){v[22452]=0;b=Q(1,e+160|0,9269)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break Ea}break O}v[22452]=0;b=Q(1,e+160|0,14772)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Da}}tb(a+1298368|0,b);pb(b);v[a+1298404>>2]=2;rz(E);$O(r);_O(I);j=1;break m}}i=P()|0;O()|0;rz(E);break j}In(e+48|0);continue}}ht(m);ec(s);Vj(q);ni(p);break c}i=P()|0;O()|0;break j}i=P()|0;O()|0}$O(r);_O(I);break a}i=P()|0;O()|0;pb(b);break a}i=P()|0;O()|0;break a}v[22452]=0;d=h&65535;h=Y(668,a|0,d|0,c|0)|0;g=v[22452];v[22452]=0;Ga:{Ha:{Ia:{Ja:{if((g|0)==1){break Ja}if(h){break Ga}v[22452]=0;h=ea(669,a|0,d|0,c|0,0,0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break Ja}if(h){break Ga}v[22452]=0;h=da(670,a|0,d|0,c|0,0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break Ja}if(h){break Ga}v[22452]=0;c=Q(671,(B(d,104)+a|0)+484380|0,c|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break Ja}if(c){break Ga}v[22452]=0;c=Q(1,e+56|0,16109)|0;h=v[22452];v[22452]=0;if((h|0)==1){break Ia}h=v[E>>2];v[22452]=0;U(364,h|0,2,c|0);h=v[22452];v[22452]=0;if((h|0)==1){break Ha}pb(c);break Ga}i=P()|0;O()|0;break e}i=P()|0;O()|0;break e}i=P()|0;O()|0;pb(c);break e}Ka:{La:{Ma:{D=B(d,104)+a|0;if(w[D+484414|0]&64){if(Dh(a)){break Ma}}c=v[m>>2];if(eh(c,v[m+4>>2])>>>0<=d>>>0){break La}if(w[Ul(c,d)+132|0]!=2){break La}if(!Dh(a)){break La}u[k>>1]=x[k>>1]+1;break La}c=x[a+480190>>1]+1|0;u[a+480190>>1]=c;H=B(c&65535,104)+a|0;n=H+484380|0;f=D+484380|0;Na:{if(!Fd(f)){break Na}c=x[f+34>>1];if((f|0)==(n|0)|(qd(c)|0)!=2){break Na}h=(f|0)==(n|0);if(!(Fd(n)?h:1)){break Na}Fd(f);if((f|0)==(n|0)){d=v[f+20>>2]}else{d=et(v[f>>2],xm(c))}g=v[f+20>>2];if(!(g?d:0)){if(!h){az(d)}break Na}Oa:{Pa:{switch(xm(x[f+34>>1])-1|0){case 1:c=d;h=g;i=v[f+20>>2];j=v[f>>2];while(1){if(j){u[c>>1]=x[i>>1];u[h>>1]=x[i+2>>1];i=i+4|0;h=h+2|0;c=c+2|0;j=j-1|0;continue}break};break Oa;case 0:break Pa;default:break Oa}}c=d;h=g;i=v[f+20>>2];j=v[f>>2];while(1){if(j){t[c|0]=w[i|0];t[h|0]=w[i+1|0];i=i+2|0;h=h+1|0;c=c+1|0;j=j-1|0;continue}break}}h=Ln(n,f);v[h+20>>2]=d;u[h+34>>1]=x[h+34>>1]&65471;d=Ln(f,f);v[d+20>>2]=g;u[d+34>>1]=x[d+34>>1]&65471;g=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(g|0)){j=v[c+104>>2];if(!((j|0)!=(h|0)&(d|0)!=(j|0))){v[c+88>>2]=v[c+88>>2]&-65}c=c+872|0;continue}break}ii(h,a);ii(d,a)}v[22452]=0;c=Q(55,e+56|0,6281)|0;d=v[22452];v[22452]=0;if((d|0)==1){break Ka}ke(H+484423|0,c);pb(c);v[22452]=0;c=Q(55,e+56|0,6184)|0;d=v[22452];v[22452]=0;if((d|0)==1){break f}ke(D+484423|0,c);pb(c)}qb(e+160|0);Xb(r);i=0;continue}break}i=P()|0;O()|0;break e}i=P()|0;O()|0}qb(e+160|0)}Xb(r);break a}ab=e+432|0;return j|0}i=P()|0;O()|0}ht(m);ec(s);Vj(q);ni(p);S(i|0);L()}function tt(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,T=0,V=0,X=0,_=0,$=0,aa=0,ba=0,ca=0,fa=0,ha=0,ia=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Ba=0,Ca=0,Da=C(0),Ea=0,Fa=0,Ga=C(0),Ha=0;i=ab-208|0;ab=i;aa=Pb(a);q=i+176|0;t[q+26|0]=0;u[q+24>>1]=0;v[q+16>>2]=0;v[q+20>>2]=-1;v[q+8>>2]=-1;v[q+12>>2]=-1;v[q>>2]=0;v[q+4>>2]=0;K=v[d+16>>2];$=w[d+6|0];la=b+484360|0;if($>>>0>=dj(la)>>>0){$=w[b+484376|0]}E=jj(la,$);v[22452]=0;r=Q(546,i+144|0,b|0)|0;a=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{if((a|0)!=1){k=v[r+4>>2];v[22452]=0;I=Y(547,i+104|0,b|0,$|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break f}ha=c&7;a=x[d+4>>1];while(1){g=a&65535;if(wc(v[E>>2],v[E+4>>2])>>>0<=g>>>0){break d}v[22452]=0;g=Q(304,E|0,g|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break e}if(g){break d}v[d>>2]=0;a=a+1|0;u[d+4>>1]=a;continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}g=v[d>>2];v[k+52>>2]=g;J=k+48|0;v[J>>2]=g;v[q+16>>2]=g;u[k+74>>1]=a;u[k+72>>1]=a;u[q+24>>1]=a;ma=i+96|0;Vd(ma);pa=Ap(i+88|0);g:{if((ha|0)!=7){break g}Ok(Ok(Ok(Ok(Ok(Ok(Ok(Ok(ma,1),2),3),28),38),40),39),41);JM(JM(pa,12),13);if((K|0)!=2){break g}a=v[E>>2];e=wc(a,v[E+4>>2]);g=x[d+12>>1];if(e>>>0<=g>>>0){break g}e=b+484344|0;a=x[Yb(a,g)>>1];if(!he(e,a)){break g}g=Rb(e,a);e=v[d+8>>2];if(y[g+12>>2]<=e>>>0){break g}a=0;m=Qc(g,e,0);g=x[b+480188>>1];e=v[r+8>>2];p=b+480192|0;while(1){if((a|0)==(g|0)){break g}h:{i:{j:{k:{f=w[m|0];switch(f-253|0){case 1:case 2:break i;case 0:break k;default:break j}}if(x[p>>1]){break i}}if(!Kc(f)){break h}if(Js(m)){break h}}Ea=He(e,a),Fa=-1,v[Ea>>2]=Fa}m=m+6|0;a=a+1|0;continue}}ba=c&1;if(ba){IM(k+223860|0)}V=k+74|0;wa=(K|0)!=3;X=k+80|0;xa=b+901692|0;ya=b+902204|0;za=k+44|0;ca=k+223860|0;fa=k+20|0;F=b+1074312|0;qa=k+616|0;N=b+484344|0;ia=32768;ra=A[d+8>>3];o(+ra);a=j(1)|0;Ba=j(0)|0;na=a;sa=(K|0)!=2;ka=b+480188|0;G=b+480180|0;ta=b+480192|0;Ca=(ha|0)!=7;p=0;l:{m:{n:{o:{p:{q:{r:while(1){g=na;while(1){HM(i+24|0,b,k,h&1);if(!(!(A[r+24>>3]>=ra)|wa)){break n}e=w[i+24|0];a=65535;f=v[E>>2];l=wc(f,v[E+4>>2]);d=x[k+72>>1];if(l>>>0>d>>>0){a=x[Yb(f,d)>>1]}u[k+70>>1]=a;f=a&65535;if(!(he(N,f)|(f|0)==65535|sa)&(d|0)==(g&65535)){break n}s:{t:{while(1){d=a&65535;if(lf(N)>>>0>d>>>0){break s}a=x[k+72>>1];u:{v:{if((d|0)!=65535){f=v[E>>2];m=wc(f,v[E+4>>2]);if(a>>>0<m>>>0){break v}}d=x[E+28>>1];if((a|0)==(d|0)){break s}f=v[E>>2];m=wc(f,v[E+4>>2]);break u}d=a+1|0}u[k+72>>1]=d;a=65535;l=d&65535;if(l>>>0<m>>>0){a=x[Yb(f,l)>>1]}u[k+74>>1]=d;u[k+70>>1]=a;if(he(N,a&65535)){continue}a=lp(i+24|0,qa);v[22452]=0;a=ea(548,I|0,d&65535,0,a|0,(e|0)!=0|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){if(a){break t}a=x[k+70>>1];continue}break}a=P()|0;O()|0;break c}if(K>>>0<2){a=x[k+72>>1];v[q+8>>2]=0;u[q+20>>1]=a;if(!K){break s}}v[22452]=0;a=da(549,I|0,V|0,J|0,1)|0;d=v[22452];v[22452]=0;if((d|0)==1){break o}if(!a){break s}A[q>>3]=A[r+24>>3];v[22452]=0;R(550,aa|0,q|0);a=v[22452];v[22452]=0;if((a|0)==1){break o}v[q+16>>2]=v[J>>2];u[q+24>>1]=x[V>>1];v[22452]=0;Z(551,r|0);a=v[22452];v[22452]=0;if((a|0)==1){break o}a=x[k+74>>1];u[k+72>>1]=a;Ea=k,Fa=x[Yb(v[E>>2],a)>>1],u[Ea+70>>1]=Fa;v[k+52>>2]=v[k+48>>2]}if(x[V>>1]==65535){break m}a=x[k+70>>1];if(!he(N,a)){a=x[k+72>>1];if((a|0)==x[E+28>>1]){if(!K){break m}v[22452]=0;a=da(549,I|0,V|0,J|0,1)|0;d=v[22452];v[22452]=0;if((d|0)==1){break o}if(!a){break m}A[q>>3]=A[r+24>>3];v[22452]=0;R(550,aa|0,q|0);a=v[22452];v[22452]=0;if((a|0)==1){break o}v[q+16>>2]=v[J>>2];u[q+24>>1]=x[V>>1];v[22452]=0;Z(551,r|0);a=v[22452];v[22452]=0;if((a|0)==1){break o}v[k+52>>2]=v[k+48>>2];continue}u[V>>1]=a+1;continue}d=v[J>>2];if(d>>>0>=y[Rb(N,a)+12>>2]){v[J>>2]=0;d=0}if(!(x[k+72>>1]!=(g&65535)|sa)&(d|0)==(Ba|0)){break n}a=0;if(!((K|0)==3|y[i+132>>2]<ia>>>0)){v[r+24>>2]=0;v[r+28>>2]=2146435072;ia=ia>>>(ia>>>0>256)|0;v[i+132>>2]=0;d=v[J>>2];a=1}f=x[k+72>>1];l=lp(i+24|0,qa);v[22452]=0;d=ea(548,I|0,f|0,d|0,l|0,(e|0)!=0|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break q}if((a|d)==1){if(K>>>0<2){u[q+20>>1]=x[k+72>>1];v[q+8>>2]=v[k+48>>2];if(!K){break m}}v[22452]=0;a=da(549,I|0,V|0,J|0,1)|0;d=v[22452];v[22452]=0;if((d|0)==1){break p}if(!a){break m}A[q>>3]=A[r+24>>3];v[22452]=0;R(550,aa|0,q|0);a=v[22452];v[22452]=0;if((a|0)==1){break p}v[q+16>>2]=v[J>>2];u[q+24>>1]=x[V>>1];v[22452]=0;Z(551,r|0);a=v[22452];v[22452]=0;if((a|0)==1){break p}v[k+52>>2]=v[k+48>>2];continue}u[q+22>>1]=x[k+72>>1];v[q+12>>2]=v[k+48>>2];GM(b,k,0);d=v[k+48>>2];f=x[k+70>>1];if(d>>>0>=y[Rb(N,f)+12>>2]){v[J>>2]=0;d=0}if(e){continue}break}a=0;d=Qc(Rb(N,f),d,0);rb(i+24|0,F,77);h=sb(v[v[i+24>>2]>>2],v[i+28>>2]);w:{while(1){m=x[ka>>1];if(m>>>0>a>>>0){x:{if(!(!zy(d)&(!h|!(w[((a<<5)+b|0)+480281|0]&4)))){Kn((k+B(a,872)|0)+1404|0);break x}if(Lg(w[d|0])){y:{if(!FM(ca)){break y}g=w[d+1|0];if(g-251>>>0<5|!g){break y}f=w[d+5|0];l=w[d+3|0];s=Lj(w[d+2|0],w[d+4|0]);e=i+24|0;t[e|0]=g-1;v[e+4>>2]=s&65535;v[22452]=0;g=Q(552,ca+12|0,e|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break w}Ea=g,Ga=C(C(Lj(l,f)>>>0)/C(999)),z[Ea>>2]=Ga}Kn((k+B(a,872)|0)+1404|0);break x}g=k+B(a,872)|0;e=g+1408|0;f=w[d+4|0]|w[d+5|0]<<8;t[e|0]=f;t[e+1|0]=f>>>8;g=g+1404|0;e=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[g|0]=e;t[g+1|0]=e>>>8;t[g+2|0]=e>>>16;t[g+3|0]=e>>>24;z:{switch(w[d+3|0]-16|0){case 0:yy(b,k,w[d+5|0]);break x;case 1:rb(i+24|0,F,5);if(!sb(v[v[i+24>>2]>>2],v[i+28>>2])){break x}g=w[d+5|0];if(!g){break x}yy(b,k,g);break x;case 4:g=w[d+5|0];e=g&240;if((e|0)!=224){if((e|0)!=96){break x}v[k+24>>2]=v[k+24>>2]+(g&15);break x}if(v[fa>>2]){break x}g=g&15;if(g?0:w[G|0]&2){break x}v[fa>>2]=g+1;break x;case 3:break z;default:break x}}g=w[d+5|0];if((g&240)!=224){break x}v[fa>>2]=(g&15)+1}d=d+6|0;a=a+1|0;continue}break}g=Nk(k);v[i+24>>2]=1;a=v[Pc(fa,i+24|0)>>2];u[k+68>>1]=65535;v[k+60>>2]=-1;v[k+64>>2]=-1;T=g-1|0;a=g-a|0;oa=B(a,1e4);d=0;while(1){if((m&65535)>>>0<=d>>>0){if(v[G>>2]==4&v[k+40>>2]==65535){break m}v[k+32>>2]=v[b+480216>>2];a=x[k+70>>1];d=Rb(N,a);if(DM(v[d+16>>2],v[d+20>>2])){Ea=k,Fa=v[Rb(N,a)+16>>2],v[Ea+32>>2]=Fa}e=CM(b,k);a=B(e,g);A[r+24>>3]=A[r+24>>3]+ +(a>>>0)/+y[b+24620>>2];v[k>>2]=a+v[k>>2];A:{B:{if(Ca){break B}m=0;oa=(p|0)!=0&(e|0)!=(p|0);while(1){if(x[ka>>1]<=m>>>0){break B}H=He(v[r+8>>2],m);C:{if(v[H>>2]==-1){break C}n=k+B(m,872)|0;M=n+1404|0;_=v[n+1316>>2];if(!_){if(zy(M)){break C}}l=n+1409|0;D=1;D:{E:{T=n+1407|0;h=w[T|0];switch(h-4|0){case 0:case 2:break D;default:break E}}D=w[n+1406|0]==11}a=w[l|0];if(w[n+1405|0]){v[n+1276>>2]=0}f=n+616|0;d=a&15;s=0;F:{G:{H:{if(!Kc(w[M|0])){break H}if(!(!D|!w[H+4|0])){xy(i+24|0,b,f,_,0);h=v[i+28>>2];v[n+624>>2]=v[i+24>>2];v[n+628>>2]=h}t[n+1418|0]=w[n+1415|0];H=n+1308|0;_=v[H>>2];h=w[n+1419|0];if(h){kp(b,f,h,D,1,1)}h=w[M|0];v[22452]=0;ja(553,b|0,f|0,h|0,D|0,1,0,65535);h=v[22452];v[22452]=0;if((h|0)==1){break G}a=a>>>4|0;AM(b,k,m&65535);ua=He(v[r+8>>2],m);t[ua+4|0]=1;h=w[T|0];I:{if(!((w[l|0]&240)!=208|(h-19&255)>>>0>1)){s=d;if(d>>>0<g>>>0){break I}}s=(h|0)==33?a>>>0<g>>>0?a:0:0}va=v[fa>>2];if(!(!(v[G>>2]&16777250)|(!s|va>>>0<2))){s=B(va-1|0,v[k+24>>2]+v[k+40>>2]|0)+s|0}if(!D){v[ua>>2]=0}J:{if((h|0)==9){break J}K:{if((h|0)!=19){if((h|0)!=20|(a|0)!=8){break K}break J}if((a|0)==8){break J}}if(w[n+1406|0]!=2){break H}}v[H>>2]=_}L:{if(!Kc(w[M|0])){rb(i+24|0,F,114);if(!sb(v[v[i+24>>2]>>2],v[i+28>>2])){break L}h=w[T|0]}M:{N:{O:{P:{a=h&255;switch(a-42|0){case 1:break M;case 0:break N;case 2:break O;default:break P}}if((a|0)!=10){break M}a=x[k+70>>1];h=v[k+48>>2];v[22452]=0;ga(554,b|0,f|0,m&65535,h|0,a|0);a=v[22452];v[22452]=0;if((a|0)!=1){break L}break A}H=oia(w[l|0],0,v[n+692>>2],0);h=db;a=h>>>8|0;yn(b,f,Fc((h&255)<<24|H>>>8,a));break L}if(!v[n+720>>2]){break M}v[22452]=0;W(555,r|0,m&65535,p|0,-1);a=v[22452];v[22452]=0;if((a|0)==1){break A}yM(f,w[l|0]);s=v[k+40>>2]-1|0;break L}if(w[n+1406|0]!=15){break L}h=v[n+720>>2];if(!h){break L}a=w[n+1408|0];if(a>>>0>9){break L}Q:{if(!a){h=v[n+1280>>2];break Q}h=v[Fb(h+68|0,a-1|0)>>2];v[n+1280>>2]=h}yn(b,f,h)}R:{S:{T:{switch(w[M|0]-253|0){case 0:if(x[ta>>1]){break S}break;case 1:case 2:break S;default:break T}}a=w[T|0];if(!((w[l|0]&240)!=192|(a-19&255)>>>0>1)&d>>>0<g>>>0){break S}h=0;if((a|0)==33&(d|0)!=0&g>>>0>d+s>>>0){break S}if((a|0)!=25){break R}}a=w[T|0];h=1}H=n+1304|0;U:{if((a|0)!=13){if(w[n+1406|0]!=1){break U}d=n+1408|0}else{d=l}v[H>>2]=w[d|0]<<2}V:{if(!(!v[n+720>>2]|h)){h=0;W:{X:{Y:{if(a>>>0>45){break Y}rb(i+24|0,ma,a);if(sb(v[v[i+24>>2]>>2],v[i+28>>2])){break X}if(w[T|0]!=19){break Y}a=w[l|0]&240;h=(a|0)==16|(a|0)==32}a=w[n+1406|0];if(a>>>0<16){break W}if(h){break V}break F}h=1;a=w[n+1406|0];if(a>>>0>=16){break V}}vk(i+24|0,pa,a);a=sb(v[v[i+24>>2]>>2],v[i+28>>2]);if(h){break V}if(!a){break F}break V}if(!h){break F}}qO(f);Ea=He(v[r+8>>2],m),Fa=0,v[Ea>>2]=Fa;break C}a=P()|0;O()|0;break c}if(oa){v[22452]=0;W(555,r|0,m&65535,p|0,-1);a=v[22452];v[22452]=0;if((a|0)==1){break A}}Z:{_:{$:{aa:{ba:{a=w[T|0];if(a-6>>>0>=2){ca:{switch(a-19|0){case 1:break aa;case 0:break ba;default:break ca}}if(a-35>>>0<2){break _}if((a|0)==45){break $}if((a|0)!=11){break Z}}if(!w[l|0]&v[G>>2]==1){break Z}a=n+1467|0;d=0;while(1){if((d|0)==(g|0)){break Z}t[a|0]=!d|w[a|0]&254;xn(b,f,w[l|0]);d=d+1|0;continue}}d=w[l|0];a=d&15;if(!(v[G>>2]&1048580?1:a)){break Z}h=n+1467|0;t[h|0]=w[h|0]|1;d=d&240;if((d|0)!=176){if((d|0)!=160){break Z}wn(b,f,a,0);break Z}vn(b,f,a,0);break Z}da:{ea:{fa:{a=w[l|0];switch(a-158|0){case 1:break ea;case 0:break fa;default:break da}}v[22452]=0;W(555,r|0,m&65535,p|0,-1);a=v[22452];v[22452]=0;if((a|0)==1){break A}v[n+704>>2]=v[n+704>>2]&-129;break Z}v[22452]=0;W(555,r|0,m&65535,p|0,-1);a=v[22452];v[22452]=0;if((a|0)==1){break A}a=v[n+704>>2];v[n+704>>2]=a|128;if(v[f+4>>2]){break Z}d=v[n+692>>2];if(!d){break Z}if(!(Ea=Kc(w[M|0]),Fa=1,Ha=a&2,Ha?Ea:Fa)){break Z}v[f>>2]=-1;v[f+4>>2]=d-1;break Z}if((a&240)!=112|a>>>0<115){break Z}nO(f,a,b);break Z}xM(f,w[l|0]);break Z}v[22452]=0;a=m&65535;W(555,r|0,a|0,p|0,-1);d=v[22452];v[22452]=0;if((d|0)==1){break A}wM(b,a,k,0)}d=n+1467|0;a=w[d|0]|1;t[d|0]=a;ga:{ha:{ia:{ja:{ka:{l=n+1406|0;switch(w[l|0]-3|0){case 11:break ha;case 0:case 1:break ia;case 3:break ja;case 2:break ka;default:break ga}}a=w[n+1408|0];rb(i+24|0,F,41);wn(b,f,a,sb(v[v[i+24>>2]>>2],v[i+28>>2]));break ga}a=w[n+1408|0];rb(i+24|0,F,41);vn(b,f,a,sb(v[v[i+24>>2]>>2],v[i+28>>2]));break ga}h=w[n+1408|0];la:{if(h){break la}rb(i+24|0,F,41);h=0;if(!sb(v[v[i+24>>2]>>2],v[i+28>>2])){break la}h=w[n+1450|0];if(!h){break ga}}h=w[l|0]==3?h<<4:h;a=0;while(1){if((a|0)==(g|0)){break ga}t[d|0]=!a|w[d|0]&254;xn(b,f,h&255);a=a+1|0;continue}}h=w[n+1408|0];if(h>>>0>1){break ga}t[d|0]=a&247|!h<<3}if(w[d|0]&8){break C}if(D){d=He(v[r+8>>2],m);a=v[d>>2];v[d>>2]=a+g;v[22452]=0;W(555,r|0,m&65535,e|0,(a+s|0)+1|0);a=v[22452];v[22452]=0;if((a|0)!=1){break C}a=P()|0;O()|0;break c}a=He(v[r+8>>2],m);v[a>>2]=v[a>>2]+(g-s|0)}m=m+1|0;continue}}h=vM(b,k,E,0);p=e;continue r}a=P()|0;O()|0;break c}l=k+B(d,872)|0;m=l+1404|0;ma:{if(zy(m)){break ma}s=l+616|0;M=l+1409|0;f=w[M|0];H=l+1407|0;n=w[H|0];na:{oa:{if(!ba){break oa}e=w[m|0];D=w[l+1405|0];if(D){t[l+1415|0]=0;t[l+1419|0]=D;Ea=He(v[r+8>>2],d),Fa=255,t[Ea+5|0]=Fa;h=w[m|0]}else{h=e}pa:{qa:{if(Kc(h)){t[l+1415|0]=e;break qa}if(!D){break pa}}_=l+1419|0;D=w[_|0];ra:{if(!D){D=0;break ra}if(x[ta>>1]<D>>>0){break ra}h=v[((D<<2)+b|0)+900380>>2];if(!h|!(t[h+15|0]&1)){break ra}xp(s,v[h+8>>2],b);D=w[_|0]}e=wy(b,e,D);if(!e){break pa}e=B(e,104)+b|0;if(!(w[e+484414|0]&32)){break pa}xp(s,x[e+484408>>1],b)}sa:{ta:{ua:{e=w[l+1406|0];switch(e-1|0){case 1:break oa;case 2:case 3:break ta;case 0:break ua;default:break sa}}Ea=He(v[r+8>>2],d),Fa=w[l+1408|0],t[Ea+5|0]=Fa;break oa}e=w[l+1408|0];if(!e){break oa}t[l+1450|0]=e;break oa}if(!w[l+1408|0]|(e|0)!=11){break oa}e=i+24|0;vy(e,b,m,0);u[l+1384>>1]=x[e>>1];if(w[Me(e)|0]){break na}}va:{wa:{switch(n-12|0){case 0:uM(b,k,d&65535);break va;case 2:e=tM(b,k,d&65535,f);if((e|0)==-1){break va}v[k+60>>2]=e;break va;case 5:rb(i+24|0,F,5);if(sb(v[v[i+24>>2]>>2],v[i+28>>2])){break va}m=B(un(b,x[k+70>>1],v[k+48>>2],d&65535,0),1e4);xa:{if(!ba|!(v[G>>2]&16777250)){break xa}if(m>>>0>=1e4){t[l+1451|0]=(m>>>0)/1e4;break xa}m=B(w[l+1451|0],1e4)}h=(m>>>0)/1e4|0;ya:{if(m>>>0>319999){break ya}m=B(oa,h&15);e=v[k+44>>2];if((h&240)==16){m=e+m|0;break ya}h=e-m|0;m=e>>>0<h>>>0?0:h}v[k+44>>2]=m;e=v[b+8>>2];h=v[e+20>>2];e=v[e+24>>2];rb(i+24|0,F,8);jo(za,B(h,1e4),sb(v[v[i+24>>2]>>2],v[i+28>>2])?255e4:B(e,1e4));break va;case 8:za:{switch((f&240)-144>>>4|0){case 0:if(f>>>0>145){break va}v[l+704>>2]=v[l+704>>2]&-257|((f|0)==145)<<8;break va;case 1:t[l+1452|0]=f&15;break va;case 2:Hs(b,k,s,f&15);break va;case 6:break za;default:break va}}t[l+1460|0]=f&15;break va;case 7:e=f&240;if((e|0)!=240){if((e|0)!=96){break va}Hs(b,k,s,f&15);break va}t[l+1460|0]=f&15;break va;case 1:case 3:case 4:case 6:break va;default:break wa}}if((n|0)!=28|(f&240)!=160){break va}rb(i+24|0,F,58);if(sb(v[v[i+24>>2]>>2],v[i+28>>2])){break va}t[l+1452|0]=f&15}if(!ba){break ma}Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{switch(n-2|0){case 0:if(!f){break na}rb(i+24|0,F,90);if(!sb(v[v[i+24>>2]>>2],v[i+28>>2])){t[l+1428|0]=f}t[l+1427|0]=f;break na;case 1:if(!f){break na}rb(i+24|0,F,90);if(!sb(v[v[i+24>>2]>>2],v[i+28>>2])){t[l+1427|0]=f}t[l+1428|0]=f;break na;case 2:if(!f){break na}u[l+1384>>1]=f;break na;case 8:if(!f){break na}v[l+1280>>2]=f<<8;break na;case 4:case 9:if(!f){break na}t[l+1425|0]=f;break na;case 11:Ea=He(v[r+8>>2],d),Fa=f,t[Ea+5|0]=Fa;break na;case 21:e=v[G>>2];h=f<<(!(e&59593760)&f<<24>>24>=0)&255;if(h>>>0<=128){v[X>>2]=h<<1;break na}if(e&16777250){break na}v[X>>2]=256;break na;case 22:rb(i+24|0,F,9);Ia:{if(sb(v[v[i+24>>2]>>2],v[i+28>>2])){e=l+1433|0;if(f){t[e|0]=f;break Ia}f=w[e|0];break Ia}if(f){t[k+1433|0]=f;break Ia}f=w[k+1433|0]}e=f&240;h=f&15;Ja:{if(!(!e|(h|0)!=15)){m=v[X>>2]+(e>>>4<<!(v[G>>2]&59593760)<<1)|0;break Ja}m=v[X>>2]-(h<<(v[G>>2]&59593760?1:2))|0;if(!(!h|(e|0)!=240)){break Ja}m=v[X>>2]+B(a,(f>>>3&30)<<!(v[G>>2]&59593760))|0;if(e){break Ja}m=v[X>>2]-B(a,h<<(v[G>>2]&59593760?1:2))|0}v[X>>2]=m;ce(X,0,256);break na;case 19:if(f>>>0>64){break na}v[l+1364>>2]=f;break na;case 20:e=l+1432|0;Ka:{if(f){t[e|0]=f;break Ka}f=w[e|0]}m=f&255;n=l+1364|0;e=v[n>>2];D=f&240;h=f&15;La:{if(!(!D|(h|0)!=15)){v[i+24>>2]=e+(m>>>4|0);break La}if(!(!h|(D|0)!=240)){v[i+24>>2]=e-h;break La}if(h){v[i+24>>2]=e-B(a,h);break La}v[i+24>>2]=e+B(a,m>>>4|0)}ce(i+24|0,0,64);v[n>>2]=v[i+24>>2];break na;case 7:Nl(b,s,f,8);break na;case 29:case 30:break Aa;case 25:break Ba;case 6:break Ca;case 24:break Da;case 3:break Ea;case 5:break Fa;case 18:break Ga;case 17:break Ha;default:break na}}if(f>>>0>15){break Ga}e=(f&1)<<14;h=x[ka>>1];m=0;while(1){if((h|0)==(m|0)){break Ga}n=k+B(m,872)|0;v[n+704>>2]=(e|v[n+704>>2]&-16385)^16384;m=m+1|0;continue}}if((f&240)!=128){break na}Nl(b,s,f&15,4);break na}if(f){t[l+1425|0]=f}f=0}Mk(s,f);break na}sM(b,s,f);break na}rM(s,f);break na}qM(s,f);break na}if(f<<24>>24>=0){e=w[l+1460|0];h=w[M|0];v[22452]=0;ja(556,b|0,k|0,d&65535,0,ie(xa,e)|0,h|0,0);e=v[22452];v[22452]=0;if((e|0)!=1){break na}break l}e=w[M|0];v[22452]=0;ja(556,b|0,k|0,d&65535,0,ie(ya,f&127)|0,e|0,0);e=v[22452];v[22452]=0;if((e|0)==1){break l}}Ma:{Na:{switch(w[l+1406|0]-2|0){case 0:Nl(b,s,w[l+1408|0],6);break Ma;case 5:rb(i+24|0,F,53);e=w[l+1408|0];if(sb(v[v[i+24>>2]>>2],v[i+28>>2])){t[l+1439|0]=e&15;break Ma}Mk(s,e<<4);break Ma;case 6:break Na;default:break Ma}}Mk(s,w[l+1408|0])}Oa:{Pa:{Qa:{Ra:{e=w[H|0];switch(e-5|0){case 1:break ma;case 3:break Pa;case 0:case 2:break Qa;default:break Ra}}switch(e-26|0){case 1:break Oa;case 0:break Qa;default:break ma}}Sa:{if(v[G>>2]&16777248){e=g;if(!(w[b+480208|0]&4)){break Sa}}e=a}h=w[l+1439|0];rb(i+24|0,F,21);f=l+1435|0;l=w[f|0];e=B(e,h);Ea=f,Fa=(sb(v[v[i+24>>2]>>2],v[i+28>>2])?e<<2:e)+l|0,t[Ea|0]=Fa;break ma}Ta:{if(v[G>>2]&16777248){e=g;if(!(w[b+480208|0]&4)){break Ta}}e=a}h=w[l+1442|0];rb(i+24|0,F,21);f=l+1436|0;l=w[f|0];e=B(e,h);Ea=f,Fa=(sb(v[v[i+24>>2]>>2],v[i+28>>2])?e<<2:e)+l|0,t[Ea|0]=Fa;break ma}e=l+1437|0;t[e|0]=w[e|0]+B(T,w[l+1445|0]);oM(b,s)}d=d+1|0;m=x[ka>>1];continue}}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}t[q+26|0]=1}Ua:{if((ha|0)!=7){break Ua}a=0;d=b+480188|0;while(1){if(x[d>>1]<=a>>>0){break Ua}Va:{if(v[He(v[r+8>>2],a)>>2]==-1){break Va}v[22452]=0;W(555,r|0,a&65535,p|0,-1);g=v[22452];v[22452]=0;if((g|0)!=1){break Va}a=P()|0;O()|0;break c}a=a+1|0;continue}}if(w[q+26|0]){u[q+20>>1]=x[k+72>>1];v[q+8>>2]=v[k+48>>2]}A[q>>3]=A[r+24>>3];v[22452]=0;R(550,aa|0,q|0);a=v[22452];v[22452]=0;Wa:{Xa:{Ya:{if((a|0)!=1){if(!ba){break Wa}if(!(K?w[q+26|0]:1)){break Ya}e=i+56|0;a=e;aM(a);if(zd(w[ca+24|0])){cM(a,ca)}uy(ca);a=gc(b+1074376|0,k,614);d=0;while(1){if((d|0)==256){bm(a+223848|0,k+223848|0);d=a+223860|0;p=w[d+24|0];g=k+223860|0;Za:{if((zd(w[g+24|0])|0)==(p|0)){if(!p){break Za}p=ac(d);Ds(d,v[p>>2]);v[d>>2]=v[g>>2];v[d+4>>2]=v[g+4>>2];v[d+8>>2]=v[g+8>>2];_a:{if(!v[vb(d)>>2]){v[d>>2]=p;break _a}v[v[p>>2]+8>>2]=p;p=ac(g);v[g>>2]=p;v[p>>2]=0;Ea=vb(g),Fa=0,v[Ea>>2]=Fa}d=d+12|0;p=ac(d);Cs(d,v[p>>2]);g=g+12|0;v[d>>2]=v[g>>2];v[d+4>>2]=v[g+4>>2];v[d+8>>2]=v[g+8>>2];$a:{if(!v[vb(d)>>2]){v[d>>2]=p;break $a}v[v[p>>2]+8>>2]=p;d=ac(g);v[g>>2]=d;v[d>>2]=0;Ea=vb(g),Fa=0,v[Ea>>2]=Fa}break Za}if(p){uy(d);break Za}cM(d,g)}}else{g=B(d,872);hp((g+a|0)+616|0,(g+k|0)+616|0);d=d+1|0;continue}break}ty(a);a=0;v[b+1074400>>2]=0;t[b+1074476|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];ab:{bb:{d=b+1298300|0;if(!td(d)){break bb}g=v[d>>2];v[22452]=0;Z(557,g|0);g=v[22452];v[22452]=0;if((g|0)!=1){break bb}break ab}while(1){if(x[b+480188>>1]<=a>>>0){a=Fz(i+24|0);d=e+12|0;Ea=i,Fa=al(d),v[Ea+16>>2]=Fa;Ea=i,Fa=Af(d),v[Ea+8>>2]=Fa;while(1){if(!Qg(i+16|0,i+8|0)){cb:{f=250;d=a;db:{while(1){if(f>>>0>=32){if(v[a>>2]){a=1;break db}else{f=f-32|0;a=a+4|0;continue}}break}a=(v[d+28>>2]&67108863)!=0}if(!a){break cb}a=0;while(1){if((a|0)==250){break cb}rb(i,d,a);eb:{if(!sb(v[v[i>>2]>>2],v[i+4>>2])){break eb}g=v[(B(a,160)+b|0)+906300>>2];p=v[v[g>>2]+176>>2];v[22452]=0;Z(p|0,g|0);g=v[22452];v[22452]=0;if((g|0)!=1){break eb}break ab}a=a+1|0;continue}}Ea=i,Fa=al(e),v[Ea>>2]=Fa;Ea=i,Fa=Af(e),v[Ea+16>>2]=Fa;while(1)if(Qg(i,i+16|0)){a=id(i);Ea=(B(w[a|0],160)+b|0)+906444|0,Ga=z[ac(a)>>2],z[Ea>>2]=Ga;Uj(i);continue}else{jp(e);break Xa}}g=id(i+16|0);h=vb(g);fb:{p=w[g|0];d=v[(B(p,160)+b|0)+906300>>2];if(d){rb(i,a,p);if(!sb(v[v[i>>2]>>2],v[i+4>>2])){v[22452]=0;Q(558,a|0,p|0)|0;p=v[22452];v[22452]=0;if((p|0)==1){break fb}p=v[v[d>>2]+172>>2];v[22452]=0;R(p|0,d|0,-1);p=v[22452];v[22452]=0;if((p|0)==1){break fb}}Da=z[h>>2];g=v[g+4>>2];p=v[v[d>>2]+44>>2];v[22452]=0;Aa(p|0,d|0,g|0,C(Da));d=v[22452];v[22452]=0;if((d|0)==1){break fb}}Uj(i+16|0);continue}break}break ab}g=B(a,872)+b|0;p=w[g+1075791|0];if(p){t[g+1075794|0]=p}g=He(v[r+8>>2],a);if(!((ha|0)==7|w[g+5|0]==255)){t[i+24|0]=64;Ea=(B(a,872)+b|0)+1075680|0,Fa=w[Qb(g+5|0,i+24|0)|0]<<2,v[Ea>>2]=Fa}gb:{p=B(a,872)+b|0;g=v[p+1075096>>2];hb:{if(!g|!(w[g+35|0]&2)){break hb}if(!td(d)){break hb}h=v[d>>2];v[22452]=0;na=h;h=a&65535;U(559,na|0,h|0,g+68|0);g=v[22452];v[22452]=0;if((g|0)==1){break gb}g=v[d>>2];v[22452]=0;U(560,g|0,h|0,1);g=v[22452];v[22452]=0;if((g|0)==1){break gb}}v[p+1075008>>2]=0;a=a+1|0;continue}break}}a=P()|0;O()|0;jp(e);break c}a=P()|0;O()|0;break c}if((c|0)==3){break Xa}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074456>>2]=v[b+480200>>2]}if(w[b+484376|0]==($|0)){break Wa}si(la,$)}if(c&9){a=b+1298264|0;if(v[a>>2]){mN(a);b=v[a>>2];lk(a);xb(b);Ea=vb(a),Fa=0,v[Ea>>2]=Fa;v[a>>2]=0;v[a+4>>2]=0}v[a>>2]=v[I>>2];v[a+4>>2]=v[I+4>>2];b=vb(I);Ea=vb(a),Fa=v[b>>2],v[Ea>>2]=Fa;v[b>>2]=0;v[I>>2]=0;v[I+4>>2]=0;a=a+12|0;c=ac(a);qp(a,v[c>>2]);b=I+12|0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];ib:{if(!v[vb(a)>>2]){v[a>>2]=c;break ib}v[v[c>>2]+8>>2]=c;a=ac(b);v[b>>2]=a;v[a>>2]=0;Ea=vb(b),Fa=0,v[Ea>>2]=Fa}}ip(i+104|0);nM(r);ab=i+208|0;return}a=P()|0;O()|0}ip(i+104|0)}nM(r)}ni(aa);S(a|0);L()}function Eea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0;d=ab-1728|0;ab=d;qc(b);h=ab-16|0;ab=h;i=d+1600|0;EQ(h+8|0,i);n=b;b=v[h+12>>2];_b(h,n,v[h+8>>2],b);l=v[h+4>>2];if((l|0)==(b|0)){Ob(n,v[h+12>>2])}ab=h+16|0;b=(b|0)==(l|0);if(!b){DQ(i)}a:{if(!b){break a}if(!FQ(d+1600|0)){break a}if(!Hb(n,Fc(256,0))){break a}b:{if(!c){break b}vd(a,1048576);wg(a);b=ab-16|0;ab=b;e=Mb(b,4191);Ac(d+1344|0,e);pb(e);ab=b+16|0;r=d+1608|0;b=w[r|0]|w[r+1|0]<<8;v[d+160>>2]=b>>>8;v[22452]=0;v[d+16>>2]=b&255;R(391,d+88|0,d+16|0);b=v[22452];v[22452]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((b|0)!=1){v[22452]=0;W(377,d+240|0,d+1344|0,d+160|0,d+88|0);b=v[22452];v[22452]=0;if((b|0)==1){break m}b=d+240|0;tb(a+1298344|0,b);pb(b);h=d+88|0;pb(h);e=d+1344|0;yb(e);i=Mb(b,15097);tb(a+1298356|0,i);pb(i);Qe(h,2,d+1610|0);tc(e,v[d+88>>2],v[d+92>>2],w[d+96|0]);v[22452]=0;U(11,b|0,8,e|0);b=v[22452];v[22452]=0;if((b|0)==1){break i}b=d+240|0;tb(a+1298368|0,b);pb(b);e=d+1344|0;pb(e);v[a+1298404>>2]=8;Gz(e,2,d+1642|0);tc(b,v[d+1344>>2],v[d+1348>>2],w[d+1352|0]);tb(a+1298308|0,b);pb(b);h=d+1712|0;u[a+480188>>1]=w[h|0]|w[h+1|0]<<8;h=w[d+1716|0];v[a+480204>>2]=125e4;v[a+480208>>2]=32792;V=a,X=Ld(h,1,31),v[V+480196>>2]=X;F=d+1722|0;u[a+480192>>1]=w[F|0]|w[F+1|0]<<8;A=d+1724|0;u[a+480190>>1]=w[A|0]|w[A+1|0]<<8;h=Ld(w[d+1717|0],1,32);v[a+480216>>2]=h;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=h<<2;Cu(n,e);C=a+484360|0;G=d+1706|0;rq(Kb(C),e,w[G|0]|w[G+1|0]<<8,65535,65535);e=d+1708|0;Re(Kb(C),w[e|0]|w[e+1|0]<<8);D=xg(n);Md(b,n,D?274:0);I=bc(d+1320|0,b);qb(b);v[22452]=0;b=T(148,n|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break k}v[22452]=0;U(181,d+240|0,n|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break k}b=d+240|0;H=bc(d+1296|0,b);qb(b);b=a+480188|0;i=x[b>>1];if(D){u[b>>1]=i+8}E=c&1;if(!E){break j}b=d+1710|0;b=w[b|0]|w[b+1|0]<<8;v[22452]=0;R(216,a+484344|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break j}f=P()|0;O()|0;break e}f=P()|0;O()|0;break l}f=P()|0;O()|0;pb(d+88|0)}yb(d+1344|0);break c}f=P()|0;O()|0;break d}o=a+484344|0;l=d+1718|0;q=d+1710|0;K=a+480188|0;while(1){n:{o:{p:{q:{r:{s:{if((w[q|0]|w[q+1|0]<<8)>>>0<=z>>>0){b=d+1714|0;b=w[b|0]|w[b+1|0]<<8;if((b-2&65535)>>>0>=4998){break q}if(!(f&1)){break s}g=0;b=vc(((b>>>1|0)+11025e5>>>0)/(b>>>0)|0,0);break r}v[22452]=0;b=T(185,n|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break f}v[d+160>>2]=b;v[22452]=0;b=T(148,n|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break g}v[22452]=0;U(181,d+88|0,n|0,b+1&-2);b=v[22452];v[22452]=0;if((b|0)==1){break g}b=d+88|0;m=bc(d+240|0,b);qb(b);mc(d+160|0,1024);if(!E){break o}s=v[d+160>>2];if(!s){break o}v[22452]=0;b=Y(217,o|0,z&65535,s|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){if(!b){break o}k=0;e=0;if(t[l|0]&1){break p}t:while(1){if((k|0)==(s|0)){break o}e=0;b=Of(Rb(o,z),k);while(1){if((e|0)==(i|0)){k=k+1|0;continue t}v[22452]=0;R(567,m|0,d+88|0);h=v[22452];v[22452]=0;if((h|0)!=1){f=CQ(b+B(e,6)|0,d+88|0)|f;e=e+1|0;continue}break}break}break h}break h}g=2;b=xe(2646e3/+(B(b,B(v[a+480216>>2],v[a+480196>>2]))>>>0)*1e4)}t[a+480224|0]=g;v[a+480204>>2]=b}k=a+480188|0;b=x[k>>1];v[22452]=0;t[d+240|0]=0;z=Y(568,d+1280|0,b|0,d+240|0)|0;b=v[22452];v[22452]=0;u:{v:{if((b|0)!=1){m=a+1298320|0;s=a+1298332|0;p=d+240|3;h=0;w:{x:{y:{z:{A:{while(1){v[22452]=0;b=Q(147,H|0,8)|0;e=v[22452];v[22452]=0;B:{if((e|0)!=1){if(b){break B}g=0;k=a+480188|0;while(1){e=x[k>>1];if(e>>>0<=g>>>0){C:{v[d+232>>2]=0;v[d+236>>2]=0;v[d+224>>2]=0;v[d+228>>2]=0;v[d+216>>2]=0;v[d+220>>2]=0;v[d+208>>2]=0;v[d+212>>2]=0;if(D){break C}break v}}else{b=t[Cb(v[z>>2],g)|0];D:{if((b|0)<=(g|0)|(b|0)>=(e|0)){break D}f=w[((b<<5)+a|0)+480288|0];if(!f){break D}b=((g<<5)+a|0)+480288|0;e=w[b|0];if(!e){t[b|0]=f;break D}e=e-1|0;while(1){b=(B(e&255,160)+a|0)+906300|0;e=vm(b);if((e|0)!=255){continue}break}b=b+28|0;e=f-1&255;e=e>>>0<250?e+128|0:0;t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24}g=g+1|0;continue}break}v[22452]=0;R(569,I|0,d+240|0);b=v[22452];v[22452]=0;if((b|0)!=1){e=0;while(1){if((e|0)==8){b=w[d+240|0]|w[d+241|0]<<8;v[22452]=0;m=Q(209,d+16|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){e=0;E:{F:{G:{H:{while(1){if((w[d+240|0]|w[d+241|0]<<8)>>>0<=e>>>0){b=w[q|0]|w[q+1|0]<<8;v[22452]=0;s=Y(570,d+88|0,b|0,26924)|0;b=v[22452];v[22452]=0;if((b|0)==1){break F}D=a+480188|0;k=0;break G}v[22452]=0;b=T(185,n|0)|0;f=v[22452];v[22452]=0;if((f|0)!=1){v[22452]=0;U(181,d+160|0,n|0,b<<5);b=v[22452];v[22452]=0;if((b|0)==1){break H}b=d+88|0;f=d+160|0;g=bc(b,f);Mc(tg(v[m>>2],e),g);e=e+1|0;qb(b);qb(f);continue}break}f=P()|0;O()|0;break E}f=P()|0;O()|0;break E}while(1){if((w[G|0]|w[G+1|0]<<8)>>>0<=k>>>0){_c(s);Yc(m);break v}I:{f=d+k|0;e=w[f+258|0];if(e>>>0>=(w[d+240|0]|w[d+241|0]<<8)>>>0){break I}if(x[Yb(v[Kb(C)>>2],k)>>1]>=(w[q|0]|w[q+1|0]<<8)>>>0){break I}J:{g=v[s>>2];b=x[Yb(v[Kb(C)>>2],k)>>1];g=Yb(g,b);p=x[g>>1];K:{if((p|0)==65535){u[g>>1]=e;break K}if((e|0)==(p|0)){break K}v[22452]=0;e=Y(571,o|0,b|0,0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break J}if((e|0)==65535){break K}V=Yb(v[Kb(C)>>2],k),X=e,u[V>>1]=X;b=e}if(!he(o,b)){break I}j=tg(v[m>>2],w[f+258|0]);qc(j);v[22452]=0;e=T(151,j|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break J}E=e>>>5|0;g=0;L:while(1){if(y[Rb(o,b)+12>>2]<=g>>>0){break I}f=0;e=Qc(Rb(o,b),g,x[D>>1]-8&65535);while(1){if((f|0)==8){g=g+1|0;continue L}kh(d+160|0);p=x[d+164>>1];t[e+4|0]=p;t[e+5|0]=p>>>8;p=v[d+160>>2];t[e|0]=p;t[e+1|0]=p>>>8;t[e+2|0]=p>>>16;t[e+3|0]=p>>>24;M:{if(g>>>0>=E>>>0){break M}v[22452]=0;Q(572,j|0,d+160|0)|0;p=v[22452];v[22452]=0;if((p|0)==1){break J}if(t[d+160|0]>=0){break M}t[e|0]=61;t[e+1|0]=w[(d+224|0)+(f<<1)|0];p=w[d+160|0]&31;t[d+64|0]=p;if(p){jf(d- -64|0,15);t[e+3|0]=20;t[e+5|0]=w[d+64|0]|208}t[e+2|0]=1;t[e+4|0]=w[d+161|0]+3>>>2}e=e+6|0;f=f+1|0;continue}}}f=P()|0;O()|0;_c(s);break E}k=k+1|0;continue}}f=P()|0;O()|0}Yc(m);break u}f=P()|0;O()|0;break u}f=e<<1;g=f+(d+224|0)|0;b=x[a+480192>>1]+1&65535;k=x[v[a+8>>2]+58>>1];while(1){N:{O:{m=b&65535;if(m>>>0<=k>>>0){if(v[((m<<2)+a|0)+900380>>2]){break O}}else{b=65535}b=b&65535;break N}b=b+1|0;continue}break}u[g>>1]=b;j=f+(d+208|0)|0;f=d+f|0;f=w[f+242|0]|w[f+243|0]<<8;u[j>>1]=f;P:{if((b|0)!=65535){v[22452]=0;b=Y(245,a|0,b|0,f+1&65535)|0;f=v[22452];v[22452]=0;Q:{R:{if((f|0)!=1){if(!b){break P}v[22452]=0;R(280,d+160|0,4436);f=v[22452];v[22452]=0;if((f|0)==1){break R}v[22452]=0;v[d+16>>2]=e+1;U(573,d+88|0,d+160|0,d+16|0);f=v[22452];v[22452]=0;if((f|0)==1){break Q}f=b+492|0;b=d+88|0;sc(f,b);pb(b);yb(d+160|0);break P}f=P()|0;O()|0;break u}f=P()|0;O()|0;break u}f=P()|0;O()|0;yb(d+160|0);break u}u[g>>1]=0}e=e+1|0;continue}}f=P()|0;O()|0;break u}f=P()|0;O()|0;break u}v[22452]=0;g=T(148,H|0)|0;b=v[22452];v[22452]=0;S:{T:{U:{V:{W:{X:{Y:{Z:{_:{if((b|0)!=1){v[22452]=0;b=T(148,H|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break _}v[22452]=0;U(181,d+240|0,H|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break _}e=d+240|0;b=bc(d+88|0,e);qb(e);if((g|0)==4674381){break W}if((g|0)==5068115){break V}if((g|0)==726487106){break Z}if((g|0)==844387158){break U}e=0;if((g|0)==1280004692){break Y}if((g|0)==1314144592){break X}if((g|0)!=1397445204){break T}v[22452]=0;e=T(185,b|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break x}e=e>>>0<256?48:e>>>8|0;v[a+480228>>2]=e;v[a+480232>>2]=e>>>1;e=0;while(1){if(x[k>>1]<=e>>>0){break T}v[22452]=0;g=Q(574,b|0,d+240|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break A}if(g){u[((e<<5)+a|0)+480286>>1]=(w[d+240|0]|w[d+241|0]<<8)>>>10;V=Cb(v[z>>2],e),X=w[p|0],t[V|0]=X}e=e+1|0;continue}}f=P()|0;O()|0;break u}f=P()|0;O()|0;break u}if(f&1){break T}t[a+480224|0]=2;v[22452]=0;J=+na(575,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break S}if(!(J>1e-8)){break T}V=a,X=xe(2646e3/(J*+(B(v[a+480216>>2],v[a+480196>>2])>>>0))*1e4),v[V+480204>>2]=X;break T}while(1){$:{if(x[k>>1]<=e>>>0){break T}v[22452]=0;g=Q(147,d+88|0,1)|0;j=v[22452];v[22452]=0;if((j|0)==1){break z}if(!g){break T}g=Bb(d+240|0);v[22452]=0;U(347,b|0,g|0,-1);j=v[22452];v[22452]=0;if((j|0)!=1){Se(d+16|0,3,Eb(g),ub(g));v[22452]=0;W(213,d+160|0,v[d+16>>2],v[d+20>>2],w[d+24|0]);j=v[22452];v[22452]=0;if((j|0)==1){break $}j=d+160|0;jm(((e<<5)+a|0)+480289|0,j);pb(j);pb(g);e=e+1|0;continue}}break}f=P()|0;O()|0;pb(g);break w}while(1){if((w[q|0]|w[q+1|0]<<8)>>>0<=e>>>0){break T}v[22452]=0;g=Q(147,d+88|0,1)|0;j=v[22452];v[22452]=0;if((j|0)==1){break y}if(!g){break T}if(!lm(o,e&65535)){break T}g=Bb(d+240|0);v[22452]=0;U(347,b|0,g|0,-1);j=v[22452];v[22452]=0;aa:{if((j|0)==1){break aa}j=Rb(o,e);v[22452]=0;R(275,j|0,g|0);j=v[22452];v[22452]=0;if((j|0)==1){break aa}pb(g);e=e+1|0;continue}break}f=P()|0;O()|0;pb(g);break w}v[22452]=0;Q(179,d+88|0,1)|0;e=v[22452];v[22452]=0;if((e|0)==1){break x}v[22452]=0;e=T(193,d+88|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break x}v[22452]=0;W(326,s|0,b|0,e|0,2);b=v[22452];v[22452]=0;if((b|0)!=1){break T}break x}v[22452]=0;Q(576,b|0,d+16|0)|0;e=v[22452];v[22452]=0;ba:{if((e|0)!=1){e=Bb(d+240|0);v[22452]=0;U(347,b|0,e|0,-1);b=v[22452];v[22452]=0;if((b|0)==1){break ba}if(Sp(e,12588)){v[22452]=0;U(11,d+160|0,8,e|0);b=v[22452];v[22452]=0;if((b|0)==1){break ba}b=d+160|0;tb(m,b);pb(b)}pb(e);break T}f=P()|0;O()|0;break w}f=P()|0;O()|0;pb(e);break w}v[22452]=0;h=T(148,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break x}}qb(d+88|0);continue}break}f=P()|0;O()|0;break w}f=P()|0;O()|0;break w}f=P()|0;O()|0;break w}f=P()|0;O()|0;break w}f=P()|0;O()|0}qb(d+88|0);break u}f=P()|0;O()|0;break e}ca:{da:{b=l;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(b&2)){break da}if(b&8){i=x[a+480188>>1]}h=(((w[r|0]|w[r+1|0]<<8)>>>0>591?h:0)+i|0)+(b>>>4&1)|0;b=0;ea:while(1){e=0;if((w[q|0]|w[q+1|0]<<8)>>>0<=b>>>0){break da}while(1){fa:{if((e|0)!=(h|0)){v[22452]=0;i=Q(147,n|0,4)|0;l=v[22452];v[22452]=0;if((l|0)==1){break ca}if(i){break fa}}b=b+1|0;continue ea}i=w[r|0]|w[r+1|0]<<8;v[22452]=0;R(577,i|0,n|0);i=v[22452];v[22452]=0;if((i|0)==1){break ca}e=e+1|0;continue}}}v[22452]=0;m=Q(209,d+192|0,255)|0;b=v[22452];v[22452]=0;if((b|0)!=1){b=d+88|0;G=b|7;s=b|1;C=b|4;q=b|2;p=b|3;j=a+480208|0;h=0;while(1){ga:{b=h;ha:{if((b|0)==255){r=Fz(d+88|0);h=d+16|4;q=Fz(d+160|0);f=0;while(1){ia:{ja:{ka:{if((f|0)==256){k=0;break ka}v[22452]=0;R(578,n|0,d+240|0);b=v[22452];v[22452]=0;if((b|0)==1){break ja}v[22452]=0;b=T(148,n|0)|0;e=v[22452];v[22452]=0;la:{ma:{na:{if((e|0)!=1){v[22452]=0;U(181,d+16|0,n|0,b|0);e=v[22452];v[22452]=0;if((e|0)==1){break na}e=d+16|0;i=bc(d- -64|0,e);qb(e);if((w[A|0]|w[A+1|0]<<8)>>>0>f>>>0){Qe(d+48|0,2,d+240|0);v[22452]=0;W(213,d+16|0,v[d+48>>2],v[d+52>>2],w[d+56|0]);e=v[22452];v[22452]=0;if((e|0)==1){break la}e=d+16|0;sc(((f<<5)+a|0)+946336|0,e);pb(e)}if(!b){break ia}if((w[A|0]|w[A+1|0]<<8)>>>0>f>>>0){break ma}break ia}f=P()|0;O()|0;break ha}f=P()|0;O()|0;break ha}v[22452]=0;b=B(f+1|0,104)+a|0;e=b+484380|0;R(271,e|0,32);l=v[22452];v[22452]=0;oa:{pa:{qa:{if((l|0)!=1){fo(e);v[22452]=0;R(579,i|0,d+16|0);i=v[22452];v[22452]=0;if((i|0)==1){break la}g=w[d+16|0]|w[d+17|0]<<8|(w[d+18|0]<<16|w[d+19|0]<<24);v[e>>2]=g;v[b+484404>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);if(w[d+24|0]>=2){i=b+484414|0;u[i>>1]=x[i>>1]|1;g=g>>>1|0;v[e>>2]=g}if(w[d+25|0]>=2){i=b+484414|0;u[i>>1]=x[i>>1]|64;v[e>>2]=g>>>1}g=2;switch(w[d+27|0]-1|0){case 0:break pa;case 1:break qa;default:break oa}}break la}g=6}e=b+484414|0;u[e>>1]=x[e>>1]|g}v[b+484384>>2]=w[d+28|0]|w[d+29|0]<<8|(w[d+30|0]<<16|w[d+31|0]<<24);v[b+484388>>2]=w[d+32|0]|w[d+33|0]<<8|(w[d+34|0]<<16|w[d+35|0]<<24);u[b+484410>>1]=(w[d+36|0]|w[d+37|0]<<8)>>>7;e=w[d+38|0];ra:{if((e|0)==128){e=b+484414|0;k=x[e>>1]|256;u[e>>1]=k;break ra}u[b+484408>>1]=(e<<24>>24)+128;k=x[b+484414>>1]}i=b+484414|0;u[i>>1]=k|32;t[b+484416|0]=w[d+39|0];e=w[d+26|0];if(e&2){b=d+48|0;rb(b,q,f);Zl(b);e=w[d+26|0]}if(e&5){u[i>>1]=x[i>>1]|16384;e=w[d+26|0]}if(!(e&8)){break ia}b=d+48|0;rb(b,r,f);Zl(b);e=0;while(1){if((e|0)==8){break ia}b=e<<1;sa:{if(x[b+(d+208|0)>>1]!=(f|0)){break sa}b=v[((x[b+(d+224|0)>>1]<<2)+a|0)+900380>>2];if(!b){break sa}t[b+14|0]=0}e=e+1|0;continue}}f=P()|0;O()|0;qb(d- -64|0);break ha}while(1){ta:{ua:{if((w[F|0]|w[F+1|0]<<8)>>>0<=k>>>0){if(!(c&2)){break ua}e=a+1298404|0;h=a+1298464|0;f=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{while(1){if(x[a+480190>>1]<=f>>>0){break ua}f=f+1|0;c=B(f,104)+a|0;i=c+484380|0;b=c+484416|0;Tp(i,(+(t[b|0]-49|0)+ +t[c+484417|0]*-.0078125)/-12);u[b>>1]=0;b=x[c+484414>>1];if(!(b&16384)){b=Gc(d+240|0,b&1?16:8,b&64?3:1,0,11);v[22452]=0;Y(210,b|0,i|0,n|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){continue}f=P()|0;O()|0;break ha}v[22452]=0;i=T(148,n|0)|0;b=v[22452];v[22452]=0;Da:{if((b|0)==1){break Da}v[22452]=0;Q(179,n|0,12)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Da}b=Bb(d+240|0);v[22452]=0;U(262,n|0,b|0,i|0);i=v[22452];v[22452]=0;if((i|0)==1){break Ca}ke(c+484423|0,b);v[22452]=0;R(376,d- -64|0,16361);c=v[22452];v[22452]=0;if((c|0)==1){break Ba}v[d+12>>2]=f;c=v[e>>2];v[22452]=0;U(11,d+48|0,c|0,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break Aa}v[22452]=0;W(377,d+16|0,d- -64|0,d+12|0,d+48|0);c=v[22452];v[22452]=0;if((c|0)==1){break za}c=v[h>>2];v[22452]=0;U(364,c|0,2,d+16|0);c=v[22452];v[22452]=0;if((c|0)==1){break ya}pb(d+16|0);pb(d+48|0);yb(d- -64|0);pb(b);continue}break}f=P()|0;O()|0;break ha}f=P()|0;O()|0;break va}f=P()|0;O()|0;break va}f=P()|0;O()|0;break wa}f=P()|0;O()|0;break xa}f=P()|0;O()|0;pb(d+16|0)}pb(d+48|0)}yb(d- -64|0)}pb(b);break ha}b=v[m>>2];v[22452]=0;b=T(151,tg(b,k)|0)|0;e=v[22452];v[22452]=0;Ea:{Fa:{if((e|0)!=1){if(!b){k=k+1|0;continue}b=tg(v[m>>2],k);qc(b);v[22452]=0;R(580,b|0,d+240|0);b=v[22452];v[22452]=0;if((b|0)==1){break Fa}i=Pb(d+16|0);b=w[d+240|0]|w[d+241|0]<<8;v[22452]=0;U(581,n|0,i|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break Ea}k=k+1|0;b=v[((k<<2)+a|0)+900380>>2];if(!b|w[b+34|0]){break ta}v[b+4>>2]=32;e=0;At(b,0);g=b+108|0;o=b+236|0;while(1){if((e|0)==96){break ta}h=w[(d+e|0)+242|0];Ga:{if(h>>>0>=(w[d+240|0]|w[d+241|0]<<8)>>>0){break Ga}l=He(v[d+16>>2],h);A=e+12|0;j=Yb(o,A);h=w[l|0];f=h+1|0;u[j>>1]=f;if(h>>>0>=x[a+480190>>1]){break Ga}h=B(f,104)+a|0;t[h+484418|0]=w[d+338|0]&3;t[h+484419|0]=w[d+339|0];t[h+484420|0]=w[d+340|0];t[h+484421|0]=w[d+341|0];u[h+484412>>1]=w[l+1|0]<<1;t[h+484417|0]=w[l+2|0];h=f-1|0;rb(d- -64|0,r,h);if(sb(v[v[d+64>>2]>>2],v[d+68>>2])){t[b+14|0]=0}rb(d- -64|0,q,h);if(!sb(v[v[d+64>>2]>>2],v[d+68>>2])){break Ga}V=Cb(g,A),X=61,t[V|0]=X}e=e+1|0;continue}}f=P()|0;O()|0;break ha}f=P()|0;O()|0;break ha}f=P()|0;O()|0;Ud(i);break ha}Yc(m);Xb(z);qb(H);qb(I);break b}Ud(i);continue}}f=P()|0;O()|0;break ha}f=f+1|0;qb(d- -64|0);continue}}v[22452]=0;R(578,n|0,d+160|0);e=v[22452];v[22452]=0;Ha:{Ia:{Ja:{Ka:{if((e|0)!=1){v[22452]=0;e=T(148,n|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break Ka}h=w[r|0]|w[r+1|0]<<8;v[22452]=0;e=(e|0)==32?428:e;e=e?h>>>0>513?e+4|0:e:e;U(181,d+88|0,n|0,e|0);h=v[22452];v[22452]=0;if((h|0)==1){break Ja}h=b+1|0;i=d+240|0;l=d+88|0;f=bc(i,l);f=_d(d+16|0,Mc(tg(v[m>>2],b),f));qb(i);qb(l);if(b>>>0>=(w[F|0]|w[F+1|0]<<8)>>>0){break ga}v[22452]=0;b=h&65535;i=Y(245,a|0,b|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break Ia}break Ha}f=P()|0;O()|0;break ha}f=P()|0;O()|0;break ha}f=P()|0;O()|0;break ha}if(!i){break ga}Qe(d+88|0,2,d+160|0);v[22452]=0;W(213,d+240|0,v[d+88>>2],v[d+92>>2],w[d+96|0]);b=v[22452];v[22452]=0;La:{if((b|0)!=1){b=d+240|0;sc(i+492|0,b);pb(b);if(!e){break ga}v[22452]=0;R(580,f|0,d+240|0);b=v[22452];v[22452]=0;if((b|0)!=1){b=3;g=0;if((w[r|0]|w[r+1|0]<<8)>>>0<513){k=0;break La}v[22452]=0;k=T(185,f|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Ha}if((w[r|0]|w[r+1|0]<<8)>>>0<514){break La}v[22452]=0;b=T(148,f|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){break La}break Ha}break Ha}break Ha}v[i>>2]=w[d+342|0]|w[d+343|0]<<8;t[i+16|0]=w[((w[d+344|0]|w[d+345|0]<<8)&3)+26926|0];t[i+17|0]=w[(w[d+345|0]&3)+26926|0];t[i+18|0]=w[((w[d+344|0]|w[d+345|0]<<8)>>>12&3)+26930|0];while(1){Ma:{Na:{if((g|0)==4){if(!(t[i+60|0]&1|w[i+16|0]==3)){v[i>>2]=32767}rm(i,127,1);qm(i,0,1);if(!k){break ga}v[22452]=0;R(582,f|0,d+88|0);b=v[22452];v[22452]=0;if((b|0)==1){break Ha}if(k&2){rm(i,yQ(v[j>>2],+((w[q|0]|w[q+1|0]<<8)>>>0)),1);qm(i,w[C|0],1)}t[i+25|0]=w[s|0]==1;if(!(k&4)){break ga}t[i+31|0]=w[G|0]+1;t[i+34|0]=w[d+96|0]+1;if(t[d+96|0]<0){t[i+30|0]=w[d+103|0]+1}if(!w[d+100|0]){break Na}l=i+108|0;e=0;while(1){if((e|0)==128){break Na}b=e+1|0;v[d+64>>2]=b+t[d+100|0];xQ(d- -64|0);V=Cb(l,e),X=v[d+64>>2],t[V|0]=X;e=b;continue}}if(!(b&1)){break Ma}v[22452]=0;R(583,f|0,d+88|0);e=v[22452];v[22452]=0;Oa:{if((e|0)!=1){l=zi(i,w[g+26934|0]);Pa:{if((g|0)!=3){e=d+88|0;o=w[l+12|0]&-17;break Pa}e=d+88|0;o=w[l+12|0]&-17|w[e|0]<<4&16}t[l+12|0]=o;o=o&-2|t[e|0]&1;t[l+12|0]=o;o=o&-5|w[e|0]<<1&4;t[l+12|0]=o;t[l+12|0]=o&253|w[e|0]>>>1&2;t[d+64|0]=w[s|0];t[d+48|0]=16;e=w[Qb(d- -64|0,d+48|0)|0];v[22452]=0;R(285,l|0,e|0);e=v[22452];v[22452]=0;if((e|0)==1){break Oa}e=w[q|0];t[l+15|0]=e;t[l+16|0]=e;t[l+13|0]=w[p|0];t[l+14|0]=w[C|0];D=v[l>>2];e=0;while(1){if(Td(l)>>>0<=e>>>0){break Ma}E=Fb(D,e);o=(d+88|0)+(e<<2)|0;u[E>>1]=w[o+8|0]|w[o+9|0]<<8;V=E,X=Ld(w[o+10|0]|w[o+11|0]<<8,0,64),t[V+2|0]=X;e=e+1|0;continue}}break Ha}break Ha}At(i,0);break ga}g=g+1|0;b=b>>>1|0;continue}}f=P()|0;O()|0;qb(d+16|0)}Yc(m);break u}qb(d+16|0);continue}}f=P()|0;O()|0;break u}f=P()|0;O()|0}Xb(z);break e}while(1){v[22452]=0;b=Q(147,d+240|0,1)|0;h=v[22452];v[22452]=0;Qa:{if((h|0)!=1){if(!b){break o}v[22452]=0;g=T(197,m|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break h}p=0;if((g|0)!=255){break Qa}v[22452]=0;p=T(197,m|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){v[22452]=0;g=T(197,m|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break Qa}}break h}break h}if(g&127){h=Qc(Rb(o,z),e,k&65535);mu(d+88|0);if(g&1){v[22452]=0;b=T(197,m|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break n}t[d+88|0]=b}if(g&2){v[22452]=0;b=T(197,m|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break n}t[d+89|0]=b}if(g&4){v[22452]=0;b=T(197,m|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break n}t[d+90|0]=b}if(g&8){v[22452]=0;b=T(197,m|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break n}t[d+91|0]=b}if(g&16){v[22452]=0;b=T(197,m|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break n}t[d+92|0]=b}if(g&32){v[22452]=0;b=T(197,m|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break n}t[d+93|0]=b}if(g&64){v[22452]=0;b=T(197,m|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break n}t[d+94|0]=b}M=CQ(h,d+88|0);v[d+16>>2]=p;v[d+64>>2]=s+(e^-1);N=v[zb(d+16|0,d- -64|0)>>2];g=0;b=h;while(1){if((g|0)!=(N|0)){b=B(x[K>>1],6)+b|0;j=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[b|0]=j;t[b+1|0]=j>>>8;t[b+2|0]=j>>>16;t[b+3|0]=j>>>24;j=w[h+4|0]|w[h+5|0]<<8;t[b+4|0]=j;t[b+5|0]=j>>>8;g=g+1|0;continue}break}f=f|M}e=(e+p|0)+1|0;while(1){if(e>>>0>=s>>>0){k=k+1|0;e=e-s|0;continue}break}if(i>>>0>(k&65535)>>>0){continue}break}}z=z+1|0;qb(d+240|0);continue}break}break h}f=P()|0;O()|0;pb(d+1344|0);break c}f=P()|0;O()|0;qb(d+240|0);break e}f=P()|0;O()|0;break e}f=P()|0;O()|0}qb(H)}qb(I)}S(f|0);L()}e=1}ab=d+1728|0;return e|0}function iR(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=C(0),s=0,A=C(0),D=0,E=0,F=0,G=C(0),H=C(0),I=C(0),J=0,K=C(0),M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=C(0),X=C(0),Y=0,Z=0,_=C(0),$=C(0),aa=C(0),ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;Z=ab-16|0;ab=Z;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;e=v[a+1420>>2];d=(e|0)>0?e:0;while(1){if((d|0)!=(g|0)){v[(B(g,20)+a|0)+1436>>2]=0;g=g+1|0;continue}break}b:{c:{d:{if((e|0)>3){break d}g=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{j=b+d|0;if(w[j|0]!=79){break f}if(Ib(j,89320,4)){break f}n=d+26|0;if((n|0)>=(c|0)){break e}q=d+27|0;i=b+n|0;f=w[i|0];if((q+f|0)>=(c|0)){break e}h=f+27|0;g=0;O=0;while(1)if((f|0)==(O|0)){O=0;while(1){f=22;if((g|0)!=22){O=yw(O,w[(d+g|0)+b|0]);g=g+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;O=yw(O,0);continue}break}v[a+1420>>2]=e+1;e=B(e,20)+a|0;v[e+1432>>2]=O;v[e+1428>>2]=h-26;v[e+1424>>2]=w[j+22|0]|w[j+23|0]<<8|(w[j+24|0]<<16|w[j+25|0]<<24);f=w[(n+w[i|0]|0)+b|0]==255?-1:w[j+6|0]|w[j+7|0]<<8|(w[j+8|0]<<16|w[j+9|0]<<24);v[e+1436>>2]=n;v[e+1440>>2]=f;e=v[a+1420>>2];if((e|0)!=4){break f}e=4;break d}else{h=w[(q+O|0)+b|0]+h|0;O=O+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){q=(d|0)>(e|0)?d:e;while(1){if((d|0)==(q|0)){break b}g=0;f=B(d,20)+a|0;h=v[f+1436>>2];j=c-h|0;i=f+1428|0;n=v[i>>2];j=(j|0)<(n|0)?j:n;o=(j|0)>0?j:0;k=f+1432|0;O=v[k>>2];while(1){if((g|0)!=(o|0)){O=yw(O,w[(g+h|0)+b|0]);g=g+1|0;continue}break}g=n-j|0;v[i>>2]=g;v[k>>2]=O;if(g){d=d+1|0;continue}else{f=f+1424|0;if(v[f>>2]==(O|0)){v[a+1380>>2]=-1;v[a+992>>2]=0;v[a+1420>>2]=-1;b=v[(B(d,20)+a|0)+1440>>2];v[a+1060>>2]=b;v[a+1064>>2]=(b|0)!=-1;g=h+j|0;break c}e=e-1|0;v[a+1420>>2]=e;e=B(e,20)+a|0;v[f+16>>2]=v[e+1440>>2];g=e+1432|0;j=v[g+4>>2];v[f+8>>2]=v[g>>2];v[f+12>>2]=j;e=e+1424|0;g=v[e+4>>2];v[f>>2]=v[e>>2];v[f+4>>2]=g;e=v[a+1420>>2];continue g}}}}c=g}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!XG(a)){v[f>>2]=0;c=0;break a}ga=ab-16|0;ab=ga;ja=Z+4|0;v[a+1504>>2]=0;v[a+1508>>2]=0;h:{if(v[a+96>>2]){break h}i:{j:{k:{if(v[a+1380>>2]!=-1){break k}c=De(a);if(v[a+96>>2]){break i}if((c|0)!=79){break j}if((De(a)|0)!=103){break j}if((De(a)|0)!=103){break j}if((De(a)|0)!=83){break j}if(!WG(a)){break i}if(!(t[a+1375|0]&1)){break k}t[a+1376|0]=0;v[a+1384>>2]=0;Vb(a,32);break i}j=vw(a);break i}Vb(a,30)}if(!j){break h}if(hc(a,1)){Vb(a,35);break h}l:{m:{if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){c=hc(a,Bl(v[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=v[a+408>>2]){break h}v[ga+12>>2]=c;h=B(c,6)+a|0;if(!w[h+412|0]){g=v[a+112>>2];j=g>>1;break m}g=v[a+116>>2];j=g>>1;c=hc(a,1);n=hc(a,1);if(c|!w[h+412|0]){break m}v[ja>>2]=g-v[a+112>>2]>>2;c=v[a+112>>2]+g>>2;break l}ca(6286,13164,3152,10695);L()}v[ja>>2]=0;c=j}v[ga+8>>2]=c;n:{if(!(!w[h+412|0]|n)){c=B(g,3);v[Z+8>>2]=c-v[a+112>>2]>>2;g=c+v[a+112>>2]>>2;break n}v[Z+8>>2]=j}v[ga+4>>2]=g;g=1}if(g){ba=v[ja>>2];la=v[Z+8>>2];ka=v[ga+4>>2];P=ab-2368|0;ab=P;F=v[a+404>>2];oa=B(v[ga+12>>2],6)+a|0;E=w[oa+413|0];R=F+B(E,40)|0;V=v[((w[oa+412|0]<<2)+a|0)+104>>2];da=V>>1;ra=0-da|0;o:{while(1){c=v[a+4>>2];if((c|0)>(q|0)){c=w[(v[R+4>>2]+B(q,3)|0)+2|0];Q=(P+1344|0)+(q<<2)|0;v[Q>>2]=0;g=w[(c+R|0)+9|0];if(!x[((g<<1)+a|0)+132>>1]){Vb(a,21);c=0;break o}j=v[a+260>>2];p:{q:{if(!hc(a,1)){break q}c=2;h=v[((q<<2)+a|0)+996>>2];j=j+B(g,1596)|0;k=v[(w[j+1588|0]<<2)+68700>>2];g=Bl(k)-1|0;ta=h,ua=hc(a,g),u[ta>>1]=ua;ta=h,ua=hc(a,g),u[ta+2>>1]=ua;m=0;while(1){if(w[j|0]>m>>>0){N=w[(j+m|0)+1|0];g=N+j|0;D=w[g+49|0];o=-1<<D;p=w[g+33|0];r:{if(!D){n=0;break r}g=v[a+124>>2]+B(w[g+65|0],2096)|0;if(v[a+1396>>2]<=9){Bk(a)}i=v[a+1392>>2];n=u[(g+((i&1023)<<1)|0)+36>>1];s:{if((n|0)>=0){s=i;i=w[n+v[g+8>>2]|0];v[a+1392>>2]=s>>>i;S=v[a+1396>>2]-i|0;i=(S|0)<0;v[a+1396>>2]=i?0:S;n=i?-1:n;break s}n=Al(a,g)}if(!w[g+23|0]){break r}n=v[v[g+2088>>2]+(n<<2)>>2]}S=o^-1;g=c+p|0;while(1){if((c|0)!=(g|0)){o=0;i=u[((j+(N<<4)|0)+((n&S)<<1)|0)+82>>1];t:{if((i|0)<0){break t}i=v[a+124>>2]+B(i&65535,2096)|0;if(v[a+1396>>2]<=9){Bk(a)}p=v[a+1392>>2];o=u[(i+((p&1023)<<1)|0)+36>>1];u:{if((o|0)>=0){s=p;p=w[o+v[i+8>>2]|0];v[a+1392>>2]=s>>>p;J=v[a+1396>>2]-p|0;p=(J|0)<0;v[a+1396>>2]=p?0:J;o=p?-1:o;break u}o=Al(a,i)}if(!w[i+23|0]){break t}o=v[v[i+2088>>2]+(o<<2)>>2]}n=n>>D;u[h+(c<<1)>>1]=o;c=c+1|0;continue}break}m=m+1|0;c=g;continue}break}if(v[a+1396>>2]==-1){break q}u[P+320>>1]=257;n=j+1592|0;c=2;while(1){o=v[n>>2];if((o|0)<=(c|0)){c=0;while(1){if((c|0)>=(o|0)){break p}if(!w[(P+320|0)+c|0]){u[h+(c<<1)>>1]=65535;o=v[n>>2]}c=c+1|0;continue}}else{g=j+338|0;i=c<<1;D=i+j|0;p=w[D+1088|0];m=p<<1;o=x[g+m>>1];Q=w[D+1089|0];N=Q<<1;S=u[h+m>>1];D=u[N+h>>1]-S|0;m=D>>31;g=(B(x[g+i>>1]-o|0,m^m+D)|0)/(x[g+N>>1]-o|0)|0;o=S+((D|0)<0?0-g|0:g)|0;m=h+i|0;i=x[m>>1];v:{w:{if(i){g=P+320|0;t[g+Q|0]=1;t[g+p|0]=1;t[c+g|0]=1;g=i<<16>>16;D=k-o|0;if((g|0)>=((o|0)>(D|0)?D:o)<<1){if((o|0)<(D|0)){break v}o=k+(i^-1)|0;break w}if(g&1){o=o-(g+1>>>1|0)|0;break w}o=(g>>1)+o|0;break w}t[(P+320|0)+c|0]=0}u[m>>1]=o}c=c+1|0;continue}}}v[Q>>2]=1}q=q+1|0;continue}break}if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){gc(P+320|0,P+1344|0,c<<2);j=x[R>>1];c=0;while(1){if((c|0)==(j|0)){ha=F+B(E,40)|0}else{h=v[R+4>>2]+B(c,3)|0;g=w[h+1|0];o=P+1344|0;h=o+(w[h|0]<<2)|0;if(!(v[(g<<2)+o>>2]?v[h>>2]:0)){v[(P+1344|0)+(g<<2)>>2]=0;v[h>>2]=0}c=c+1|0;continue}break}n=0;while(1){x:{if(w[ha+8|0]>n>>>0){o=0;c=v[a+4>>2];h=(c|0)>0?c:0;c=0;while(1){if((c|0)==(h|0)){break x}if(w[(v[R+4>>2]+B(c,3)|0)+2|0]==(n|0)){i=o+P|0;j=c<<2;y:{if(v[j+(P+1344|0)>>2]){j=0;g=1;break y}j=v[(a+j|0)+800>>2];g=0}t[i|0]=g;v[(P+256|0)+(o<<2)>>2]=j;o=o+1|0}c=c+1|0;continue}}if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){h=(da|0)>0?da:0;g=x[R>>1];j=a+800|0;z:while(1){if((g|0)<=0){Q=da<<2;o=0;c=0;while(1){n=v[a+4>>2];if((n|0)<=(c|0)){while(1){if((o|0)<(n|0)){Q=w[oa+412|0];R=V>>1;g=R<<2;ha=v[a+92>>2];k=V>>3;S=V>>2;j=v[((o<<2)+a|0)+800>>2];c=R<<2;p=j+c|0;A:{if(v[a+80>>2]){n=Ym(a,g);break A}n=yd(g)}g=(n+c|0)-8|0;h=v[((Q<<2)+a|0)+1068>>2];i=h;c=j;while(1){if((c|0)!=(p|0)){z[g+4>>2]=C(z[c>>2]*z[i>>2])-C(z[i+4>>2]*z[c+8>>2]);z[g>>2]=C(z[c>>2]*z[i+4>>2])+C(z[c+8>>2]*z[i>>2]);c=c+16|0;i=i+8|0;g=g-8|0;continue}break}c=((R<<2)+j|0)-12|0;while(1){if(g>>>0>=n>>>0){z[g+4>>2]=C(z[c>>2]*z[i+4>>2])-C(z[c+8>>2]*z[i>>2]);z[g>>2]=C(C(-z[c+8>>2])*z[i+4>>2])-C(z[i>>2]*z[c>>2]);c=c-16|0;i=i+8|0;g=g-8|0;continue}break}c=S<<2;m=c+j|0;g=c+n|0;i=(h+(R<<2)|0)-32|0;c=n;q=j;while(1){if(h>>>0<=i>>>0){l=z[c>>2];r=z[g>>2];A=z[g+4>>2];G=z[c+4>>2];z[m+4>>2]=A+G;z[m>>2]=z[g>>2]+z[c>>2];A=C(A-G);l=C(r-l);z[q+4>>2]=C(A*z[i+16>>2])-C(z[i+20>>2]*l);z[q>>2]=C(l*z[i+16>>2])+C(A*z[i+20>>2]);l=z[c+8>>2];r=z[g+8>>2];A=z[g+12>>2];G=z[c+12>>2];z[m+12>>2]=A+G;z[m+8>>2]=z[g+8>>2]+z[c+8>>2];A=C(A-G);l=C(r-l);z[q+12>>2]=C(A*z[i>>2])-C(z[i+4>>2]*l);z[q+8>>2]=C(l*z[i>>2])+C(A*z[i+4>>2]);c=c+16|0;g=g+16|0;q=q+16|0;m=m+16|0;i=i-32|0;continue}break}g=Bl(V);c=V>>4;q=R-1|0;i=0-k|0;TG(c,j,q,i,h);TG(c,j,q-S|0,i,h);N=V>>5;c=0-c|0;Ho(N,j,q,c,h,16);Ho(N,j,q-k|0,c,h,16);Ho(N,j,q-(k<<1)|0,c,h,16);Ho(N,j,q+B(k,-3)|0,c,h,16);c=g-4>>1;m=(c|0)>2?c:2;c=2;while(1){B:{C:{D:{if((c|0)==(m|0)){c=g-7|0;ea=(c|0)<(m|0)?m:c;break D}i=0;k=2<<c;k=(k|0)>0?k:0;D=8<<c;E=V>>c+4;F=V>>c+2;J=0-(F>>1)|0;while(1){if((i|0)==(k|0)){break C}Ho(E,j,q-B(i,F)|0,J,h,D);i=i+1|0;continue}}while(1){E:{if((m|0)!=(ea|0)){D=2<<m;J=8<<m;ma=J<<2;i=V>>m+6;Y=V>>m+2;fa=0-(Y>>1)|0;g=q;c=h;while(1){if((i|0)<=0){break E}k=D;E=(g<<2)+j|0;F=E+(fa<<2)|0;T=B(J,12)+c|0;l=z[T>>2];M=(J<<3)+c|0;r=z[M>>2];s=(J<<2)+c|0;A=z[s>>2];G=z[T+4>>2];I=z[M+4>>2];W=z[s+4>>2];X=z[c+4>>2];aa=z[c>>2];T=0-Y<<2;while(1){if((k|0)>0){M=F-4|0;K=z[M>>2];_=z[E>>2];$=z[F>>2];z[E>>2]=_+$;s=E-4|0;H=z[s>>2];z[s>>2]=H+z[M>>2];H=C(H-K);K=C(_-$);z[M>>2]=C(H*aa)+C(X*K);z[F>>2]=C(K*aa)-C(X*H);M=F-12|0;_=z[M>>2];s=E-8|0;H=z[s>>2];U=s;s=F-8|0;$=z[s>>2];z[U>>2]=H+$;U=E-12|0;K=z[U>>2];z[U>>2]=K+z[M>>2];K=C(K-_);H=C(H-$);z[M>>2]=C(K*A)+C(W*H);z[s>>2]=C(H*A)-C(W*K);M=F-20|0;_=z[M>>2];s=E-16|0;H=z[s>>2];U=s;s=F-16|0;$=z[s>>2];z[U>>2]=H+$;U=E-20|0;K=z[U>>2];z[U>>2]=K+z[M>>2];K=C(K-_);H=C(H-$);z[M>>2]=C(K*r)+C(I*H);z[s>>2]=C(H*r)-C(I*K);M=F-28|0;_=z[M>>2];s=E-24|0;H=z[s>>2];U=s;s=F-24|0;$=z[s>>2];z[U>>2]=H+$;U=E-28|0;K=z[U>>2];z[U>>2]=K+z[M>>2];K=C(K-_);H=C(H-$);z[M>>2]=C(K*l)+C(G*H);z[s>>2]=C(H*l)-C(G*K);k=k-1|0;F=F+T|0;E=E+T|0;continue}break}i=i-1|0;g=g-8|0;c=(ma<<2)+c|0;continue}}c=(q<<2)+j|0;q=c-(N<<6)|0;l=z[h+(V>>3<<2)>>2];aa=C(-l);while(1){if(c>>>0>q>>>0){I=z[c>>2];g=c-32|0;W=z[g>>2];z[c>>2]=I+W;h=c-4|0;r=z[h>>2];i=h;h=c-36|0;X=z[h>>2];z[i>>2]=r+X;i=c-8|0;A=z[i>>2];k=i;i=c-40|0;H=z[i>>2];z[k>>2]=A+H;k=c-12|0;G=z[k>>2];s=k;k=c-44|0;K=z[k>>2];z[s>>2]=G+K;z[g>>2]=I-W;z[h>>2]=r-X;h=c-16|0;r=z[h>>2];s=h;h=c-48|0;_=z[h>>2];z[s>>2]=r+_;A=C(A-H);G=C(G-K);z[i>>2]=l*C(A+G);z[k>>2]=l*C(G-A);i=c-28|0;A=z[i>>2];k=c-60|0;G=z[k>>2];D=c-24|0;I=z[D>>2];m=c-56|0;W=z[m>>2];E=c-20|0;X=z[E>>2];s=E;E=c-52|0;H=z[E>>2];z[s>>2]=X+H;z[D>>2]=I+W;z[i>>2]=A+G;z[h>>2]=X-H;z[E>>2]=-C(r-_);r=C(A-G);A=C(I-W);z[m>>2]=l*C(r-A);z[k>>2]=C(A+r)*aa;SG(c);SG(g);c=c+-64|0;continue}break}k=R-4|0;g=n+(k<<2)|0;i=(n+(S<<2)|0)-16|0;c=v[((Q<<2)+a|0)+1100>>2];while(1){if(i>>>0>=n>>>0){h=(x[c>>1]<<2)+j|0;z[g+12>>2]=z[h>>2];z[g+8>>2]=z[h+4>>2];z[i+12>>2]=z[h+8>>2];z[i+8>>2]=z[h+12>>2];h=(x[c+2>>1]<<2)+j|0;z[g+4>>2]=z[h>>2];z[g>>2]=z[h+4>>2];z[i+4>>2]=z[h+8>>2];z[i>>2]=z[h+12>>2];c=c+4|0;g=g-16|0;i=i-16|0;continue}break}c=v[((Q<<2)+a|0)+1084>>2];i=n;g=i+(R<<2)|0;h=g;while(1){q=h-16|0;if(q>>>0>i>>>0){l=z[i+4>>2];D=h-4|0;r=z[D>>2];A=C(l-r);G=z[c+4>>2];l=C(l+r);r=z[i>>2];m=h-8|0;I=z[m>>2];W=C(r-I);X=z[c>>2];aa=C(C(G*l)-C(W*X));z[i+4>>2]=A+aa;r=C(r+I);l=C(C(G*W)+C(l*X));z[i>>2]=r+l;z[D>>2]=aa-A;z[m>>2]=r-l;l=z[i+8>>2];r=z[q>>2];A=C(l+r);G=z[c+12>>2];l=C(l-r);r=z[i+12>>2];h=h-12|0;I=z[h>>2];W=C(r+I);X=z[c+8>>2];aa=C(C(G*l)+C(W*X));z[i+8>>2]=A+aa;r=C(r-I);l=C(C(G*W)-C(l*X));z[i+12>>2]=r+l;z[q>>2]=A-aa;z[h>>2]=l-r;i=i+16|0;c=c+16|0;h=q;continue}break}i=v[((Q<<2)+a|0)+1076>>2]+(R<<2)|0;c=(k<<2)+j|0;h=((V<<2)+j|0)-16|0;while(1){q=g-32|0;if(q>>>0>=n>>>0){l=z[g-8>>2];r=z[i-4>>2];A=z[i-8>>2];G=z[g-4>>2];I=C(C(l*r)-C(A*G));z[j>>2]=I;z[c+12>>2]=-I;l=C(C(A*C(-l))-C(r*G));z[p>>2]=l;z[h+12>>2]=l;l=z[g-16>>2];r=z[i-12>>2];A=z[i-16>>2];G=z[g-12>>2];I=C(C(l*r)-C(A*G));z[j+4>>2]=I;z[c+8>>2]=-I;l=C(C(A*C(-l))-C(r*G));z[p+4>>2]=l;z[h+8>>2]=l;l=z[g-24>>2];r=z[i-20>>2];A=z[i-24>>2];G=z[g-20>>2];I=C(C(l*r)-C(A*G));z[j+8>>2]=I;z[c+4>>2]=-I;l=C(C(A*C(-l))-C(r*G));z[p+8>>2]=l;z[h+4>>2]=l;l=z[q>>2];r=z[i-28>>2];i=i-32|0;A=z[i>>2];G=z[g-28>>2];I=C(C(l*r)-C(A*G));z[j+12>>2]=I;z[c>>2]=-I;l=C(C(A*C(-l))-C(r*G));z[p+12>>2]=l;z[h>>2]=l;h=h-16|0;c=c-16|0;p=p+16|0;j=j+16|0;g=q;continue}break}if(!v[a+80>>2]){xb(n)}v[a+92>>2]=ha;break B}m=m+1|0;continue}}c=c+1|0;continue}break}o=o+1|0;n=v[a+4>>2];continue}break}}else{j=c<<2;g=j+a|0;F:{if(v[j+(P+320|0)>>2]){Jb(v[g+800>>2],0,Q);break F}m=v[g+800>>2];F=v[g+996>>2];G:{g=w[(w[(v[R+4>>2]+B(c,3)|0)+2|0]+R|0)+9|0];if(!x[((g<<1)+a|0)+132>>1]){Vb(a,21);break G}q=V>>1;D=v[a+260>>2]+B(g,1596)|0;N=D+1592|0;S=D+1588|0;j=B(w[D+1588|0],u[F>>1]);i=1;g=0;while(1){if(v[N>>2]>(i|0)){h=w[(i+D|0)+838|0]<<1;n=u[h+F>>1];if((n|0)>=0){n=B(w[S|0],n&65535);h=x[(h+D|0)+338>>1];if((h|0)!=(g|0)){k=n-j|0;p=h-g|0;E=(k|0)/(p|0)|0;H:{J=(h|0)>(q|0)?q:h;if((J|0)<=(g|0)){break H}s=k;k=k>>31;T=E>>31;T=(s+k^k)-B(p,T+E^T)|0;M=k|1;k=m+(g<<2)|0;z[k>>2]=z[((j&255)<<2)+68720>>2]*z[k>>2];J=J-1|0;k=0;while(1){if((g|0)==(J|0)){break H}g=g+1|0;ha=m+(g<<2)|0;k=k+T|0;ea=(k|0)<(p|0);j=(j+E|0)+(ea?0:M)|0;z[ha>>2]=z[((j&255)<<2)+68720>>2]*z[ha>>2];k=k-(ea?0:p)|0;continue}}g=h}j=n}i=i+1|0;continue}break}if((g|0)>=(q|0)){break G}j=(j<<2)+68720|0;while(1){if((g|0)==(q|0)){break G}h=m+(g<<2)|0;z[h>>2]=z[j>>2]*z[h>>2];g=g+1|0;continue}}}c=c+1|0;continue}break}VG(a);I:{if(w[a+1377|0]){v[a+1060>>2]=ra;t[a+1377|0]=0;v[a+1064>>2]=1;v[a+1412>>2]=V-ka;break I}c=v[a+1412>>2];if(!c){break I}g=la-ba|0;if((g|0)<=(c|0)){v[a+1412>>2]=c-g;v[ja>>2]=la;ba=la;break I}ba=c+ba|0;v[ja>>2]=ba;v[a+1412>>2]=0}c=v[a+1064>>2];J:{K:{L:{M:{if(v[a+1388>>2]==v[a+1404>>2]){N:{if(!c|!(w[a+1375|0]&4)){break N}c=v[a+1408>>2];g=v[a+1060>>2];if(c>>>0>=g+(ka-ba|0)>>>0){break N}g=c-g|0;c=(c>>>0<g>>>0?0:g)+ba|0;c=(c|0)>(ka|0)?ka:c;v[Z+12>>2]=c;v[a+1060>>2]=c+v[a+1060>>2];break K}v[a+1064>>2]=1;c=v[a+1408>>2]+(ba-da|0)|0;break M}if(!c){break L}c=v[a+1060>>2]}v[a+1060>>2]=c+(la-ba|0)}if(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0){break J}v[Z+12>>2]=ka}c=1;break o}ca(6286,13164,3451,5595);L()}g=g-1|0;c=v[R+4>>2]+B(g,3)|0;n=v[j+(w[c+1|0]<<2)>>2];q=v[j+(w[c|0]<<2)>>2];c=0;while(1){if((c|0)==(h|0)){continue z}i=c<<2;o=i+n|0;A=z[o>>2];i=i+q|0;l=z[i>>2];O:{if(l>C(0)){if(A>C(0)){r=C(l-A);break O}r=l;l=C(l+A);break O}if(A>C(0)){r=C(l+A);break O}r=l;l=C(l-A)}z[i>>2]=l;z[o>>2]=r;c=c+1|0;continue}}}ca(6286,13164,3335,5595);L()}S=P+256|0;q=0;F=ab-16|0;ab=F;p=v[a+4>>2];m=v[a+396>>2];h=w[(n+ha|0)+24|0];D=m+B(h,24)|0;g=v[D+4>>2];ea=x[((h<<1)+a|0)+268>>1];c=da<<((ea|0)==2);i=c>>>0>g>>>0?g:c;g=v[D>>2];Q=(i-(c>>>0>g>>>0?g:c)>>>0)/y[D+8>>2]|0;j=Q<<2;c=B(p,j+4|0);M=v[v[a+124>>2]+B(w[D+13|0],2096)>>2];U=v[a+92>>2];P:{if(v[a+80>>2]){g=Ym(a,c);p=v[a+4>>2];break P}g=yd(c)}i=(o|0)>0?o:0;E=da<<2;c=0;N=(p|0)>0?p:0;k=(p<<2)+g|0;while(1){if((c|0)!=(N|0)){v[(c<<2)+g>>2]=k;c=c+1|0;k=j+k|0;continue}break}j=g;c=0;while(1){if((c|0)!=(i|0)){if(!w[c+P|0]){Jb(v[S+(c<<2)>>2],0,E)}c=c+1|0;continue}break}Q:{if(!((o|0)==1|(ea|0)!=2)){c=0;while(1){R:{if((c|0)!=(i|0)){if(w[c+P|0]){break R}}else{c=i}if((c|0)==(o|0)){break Q}k=m+B(h,24)|0;E=(o|0)!=2;N=(o|0)<3;while(1){if((q|0)==8){break Q}S:{if(!E){g=0;m=0;while(1){if((m|0)>=(Q|0)){break S}c=v[D>>2]+B(v[D+8>>2],m)|0;v[F+12>>2]=c&1;v[F+8>>2]=c>>1;c=0;if(!q){i=v[a+124>>2]+B(w[D+13|0],2096)|0;if(v[a+1396>>2]<=9){Bk(a)}p=v[a+1392>>2];h=u[(i+((p&1023)<<1)|0)+36>>1];T:{if((h|0)>=0){s=p;p=w[h+v[i+8>>2]|0];v[a+1392>>2]=s>>>p;J=v[a+1396>>2]-p|0;p=(J|0)<0;v[a+1396>>2]=p?0:J;h=p?-1:h;break T}h=Al(a,i)}h=w[i+23|0]?v[v[i+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break Q}v[v[j>>2]+(g<<2)>>2]=v[v[k+16>>2]+(h<<2)>>2]}while(1){if(!((c|0)>=(M|0)|(m|0)>=(Q|0))){h=v[D+8>>2];i=u[(v[k+20>>2]+(w[v[v[j>>2]+(g<<2)>>2]+c|0]<<4)|0)+(q<<1)>>1];U:{if((i|0)>=0){if(UG(a,v[a+124>>2]+B(i&65535,2096)|0,S,2,F+12|0,F+8|0,da,h)){break U}break Q}h=v[D>>2]+(h+B(h,m)|0)|0;v[F+8>>2]=h>>1;v[F+12>>2]=h&1}m=m+1|0;c=c+1|0;continue}break}g=g+1|0;continue}}if(N){break S}g=0;m=0;while(1){if((m|0)>=(Q|0)){break S}h=v[D>>2]+B(v[D+8>>2],m)|0;c=(h|0)/(o|0)|0;v[F+12>>2]=h-B(c,o);v[F+8>>2]=c;c=0;if(!q){i=v[a+124>>2]+B(w[D+13|0],2096)|0;if(v[a+1396>>2]<=9){Bk(a)}p=v[a+1392>>2];h=u[(i+((p&1023)<<1)|0)+36>>1];V:{if((h|0)>=0){s=p;p=w[h+v[i+8>>2]|0];v[a+1392>>2]=s>>>p;J=v[a+1396>>2]-p|0;p=(J|0)<0;v[a+1396>>2]=p?0:J;h=p?-1:h;break V}h=Al(a,i)}h=w[i+23|0]?v[v[i+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break Q}v[v[j>>2]+(g<<2)>>2]=v[v[k+16>>2]+(h<<2)>>2]}while(1){if(!((c|0)>=(M|0)|(m|0)>=(Q|0))){h=v[D+8>>2];i=u[(v[k+20>>2]+(w[v[v[j>>2]+(g<<2)>>2]+c|0]<<4)|0)+(q<<1)>>1];W:{if((i|0)>=0){if(!UG(a,v[a+124>>2]+B(i&65535,2096)|0,S,o,F+12|0,F+8|0,da,h)){break Q}break W}h=v[D>>2]+(h+B(h,m)|0)|0;i=(h|0)/(o|0)|0;v[F+8>>2]=i;v[F+12>>2]=h-B(i,o)}m=m+1|0;c=c+1|0;continue}break}g=g+1|0;continue}}q=q+1|0;continue}}c=c+1|0;continue}}ma=m+B(h,24)|0;o=0;while(1){if((o|0)==8){break Q}q=0;J=0;X:while(1){if((q|0)<(Q|0)){g=0;c=0;Y:{if(o){break Y}while(1){if((c|0)==(i|0)){break Y}if(!w[c+P|0]){k=v[a+124>>2]+B(w[D+13|0],2096)|0;if(v[a+1396>>2]<=9){Bk(a)}m=v[a+1392>>2];h=u[(k+((m&1023)<<1)|0)+36>>1];Z:{if((h|0)>=0){s=m;m=w[h+v[k+8>>2]|0];v[a+1392>>2]=s>>>m;p=v[a+1396>>2]-m|0;m=(p|0)<0;v[a+1396>>2]=m?0:p;h=m?-1:h;break Z}h=Al(a,k)}h=w[k+23|0]?v[v[k+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break Q}v[v[j+(c<<2)>>2]+(J<<2)>>2]=v[v[ma+16>>2]+(h<<2)>>2]}c=c+1|0;continue}}while(1){_:{$:{if((g|0)>=(M|0)){break $}c=0;if((q|0)>=(Q|0)){break $}while(1){if((c|0)==(i|0)){break _}aa:{if(w[c+P|0]){break aa}h=c<<2;k=u[(v[ma+20>>2]+(w[v[v[h+j>>2]+(J<<2)>>2]+g|0]<<4)|0)+(o<<1)>>1];if((k|0)<0){break aa}m=v[a+124>>2]+B(k&65535,2096)|0;Y=v[h+S>>2];T=v[D+8>>2];N=v[D>>2]+B(T,q)|0;ba:{ca:{if(ea){p=0;while(1){h=1;if((p|0)>=(T|0)){break ba}fa=Y+(N<<2)|0;h=T-p|0;E=0;l=C(0);da:{s=RG(a,m);if((s|0)<0){break da}k=v[m>>2];h=(h|0)>(k|0)?k:h;s=B(k,s);if(w[m+22|0]){k=0;h=(h|0)>0?h:0;E=1;while(1){if((h|0)==(k|0)){break da}ia=fa+(k<<2)|0;l=C(l+z[v[m+28>>2]+(k+s<<2)>>2]);z[ia>>2]=z[ia>>2]+l;k=k+1|0;l=C(l+z[m+12>>2]);continue}}k=0;h=(h|0)>0?h:0;E=1;while(1){if((h|0)==(k|0)){break da}ia=fa+(k<<2)|0;z[ia>>2]=z[ia>>2]+C(z[v[m+28>>2]+(k+s<<2)>>2]+C(0));k=k+1|0;continue}}if(!E){break ca}h=v[m>>2];N=h+N|0;p=h+p|0;continue}}p=0;fa=(T|0)/v[m>>2]|0;s=(fa|0)>0?fa:0;ia=Y+(N<<2)|0;h=1;while(1){if((p|0)==(s|0)){break ba}k=p+N|0;E=p<<2;p=p+1|0;sa=E+ia|0;Y=T-k|0;k=0;l=C(0);ea:{na=RG(a,m);if((na|0)<0){break ea}E=0;k=v[m>>2];Y=(k|0)<(Y|0)?k:Y;Y=(Y|0)>0?Y:0;na=B(k,na);k=1;while(1){if((E|0)==(Y|0)){break ea}qa=sa+(B(E,fa)<<2)|0;r=C(l+z[v[m+28>>2]+(E+na<<2)>>2]);z[qa>>2]=z[qa>>2]+r;l=w[m+22|0]?r:l;E=E+1|0;continue}}if(k){continue}break}}h=0}if(!h){break Q}}c=c+1|0;continue}}J=J+1|0;continue X}q=q+1|0;g=g+1|0;continue}}break}o=o+1|0;continue}}if(!v[a+80>>2]){xb(j)}v[a+92>>2]=U;ab=F+16|0;n=n+1|0;continue}}ca(6286,13164,3302,5595);L()}ab=P+2368|0}else{c=0}ab=ga+16|0;if(!c){fa:{ga:{ha:{c=v[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}v[a+100>>2]=0;while(1){if(ta=0,ua=(ah(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;c=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break fa}v[a+100>>2]=0;while(1){if(ta=0,ua=(ah(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;c=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;c=1;break a}h=v[Z+12>>2];q=v[Z+4>>2];j=v[Z+8>>2];ia:{ja:{n=v[a+992>>2];if(n){g=n<<1;ka:{if((g|0)==v[a+112>>2]){c=a+1092|0}else{c=0;if((g|0)!=v[a+116>>2]){break ka}c=a+1096|0}c=v[c>>2]}g=c;if(!g){break ja}o=(n|0)>0?n:0;while(1){if(v[a+4>>2]>(O|0)){i=(O<<2)+a|0;c=0;while(1){if((c|0)!=(o|0)){k=v[i+800>>2]+(c+q<<2)|0;s=k;l=z[k>>2];k=c<<2;z[s>>2]=C(l*z[k+g>>2])+C(z[k+v[i+928>>2]>>2]*z[g+(n+(c^-1)<<2)>>2]);c=c+1|0;continue}break}O=O+1|0;continue}break}O=v[a+992>>2]}v[a+992>>2]=h-j;n=(h|0)<(j|0);i=(n?j:h)-j|0;while(1){if(v[a+4>>2]>(pa|0)){g=(pa<<2)+a|0;c=0;while(1){if((c|0)!=(i|0)){z[v[g+928>>2]+(c<<2)>>2]=z[v[g+800>>2]+(c+j<<2)>>2];c=c+1|0;continue}break}pa=pa+1|0;continue}break}if(!O){break ja}c=(n?h:j)-q|0;v[a+1416>>2]=c+v[a+1416>>2];break ia}c=0}g=c;v[Z+12>>2]=c;c=0;j=v[a+4>>2];h=(j|0)>0?j:0;while(1){if((c|0)!=(h|0)){n=(c<<2)+a|0;v[n+864>>2]=v[n+800>>2]+(q<<2);c=c+1|0;continue}break}if(d){v[d>>2]=j}v[f>>2]=g;v[e>>2]=a+864;c=v[a+32>>2]-b|0}ab=Z+16|0;return c}function q8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,U=0,V=0,X=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;n=ab-1152|0;ab=n;qc(b);a:{if(!Rq(b,n+1128|0)){break a}if(!CK(n+1128|0)){break a}d=n+1136|0;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=(jk(b)|0)){break a}m=n+1144|0;if((w[m|0]|w[m+1|0]<<8|(w[m+2|0]<<16|w[m+3|0]<<24))!=(Ze(b)|0)){break a}if(!c){h=1;break a}g=n+1072|0;Jb(g,0,56);k=-2;b:{if(!g){break b}v[g+44>>2]=0;v[g+48>>2]=0;v[g+52>>2]=0;v[g+20>>2]=0;v[g+24>>2]=0;v[g+8>>2]=0;d=v[g+32>>2];if(!d){v[g+32>>2]=1068;d=1068}if(!v[g+36>>2]){v[g+36>>2]=1069}d=eb[d|0](v[g+40>>2],1,43784)|0;k=-4;if(!d){break b}v[g+28>>2]=d;v[d+43780>>2]=1;v[d+10992>>2]=0;v[d+10996>>2]=0;v[d>>2]=0;v[d+11008>>2]=15;v[d+11e3>>2]=1;v[d+11004>>2]=0;k=0}if(k){break a}h=w[m|0]|w[m+1|0]<<8|(w[m+2|0]<<16|w[m+3|0]<<24);v[n+1068>>2]=h;d=n+1148|0;I=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);T=pS(n+1056|0,I);c:{d:{while(1){if(!(!h|!I|(e|0)==1)){v[n+16>>2]=1024;e=n+16|0;U=v[zb(e,n+1068|0)>>2];Zb(n+24|0,n+32|0,U);v[22452]=0;W(156,e|0,b|0,v[n+24>>2],v[n+28>>2]);e=v[22452];v[22452]=0;if((e|0)==1){break d}d=n+32|0;e=d;h=U;g=aa^-1;while(1){if(h>>>0<4){while(1){if(h){g=v[((w[e|0]^g&255)<<2)+59136>>2]^g>>>8;h=h-1|0;e=e+1|0;continue}break}e=g^-1}else{g=v[((w[e|0]^g&255)<<2)+59136>>2]^g>>>8;g=g>>>8^v[((w[e+1|0]^g&255)<<2)+59136>>2];g=g>>>8^v[((w[e+2|0]^g&255)<<2)+59136>>2];g=g>>>8^v[((w[e+3|0]^g&255)<<2)+59136>>2];h=h-4|0;e=e+4|0;continue}break}aa=e;v[n+1076>>2]=U;v[n+1072>>2]=d;v[n+1088>>2]=I;v[n+1084>>2]=v[T>>2]+ba;F=ab-16|0;ab=F;e=-2;p=n+1072|0;e:{if(!p){break e}i=v[p+28>>2];if(!i){break e}da=v[p+4>>2];v[i+11e3>>2]=0;f:{if(v[i+43780>>2]<0){break f}if(v[i+11004>>2]){break e}g=v[i+11008>>2];e=0;v[i+11004>>2]=0;d=v[i+10996>>2];if(!d){z=(g|0)>0?11:10;J=i+11012|0;h=v[p+4>>2];k=v[i+10992>>2];while(1){v[F+12>>2]=h;v[F+8>>2]=32768-k;E=v[p>>2];d=0;h=0;m=0;G=0;K=0;V=0;_=0;$=ab-144|0;ab=$;g:{h:{D=k+J|0;if(J>>>0<=D>>>0){e=v[F+8>>2];X=z&4;Z=X?-1:e+((J^-1)+D|0)|0;s=Z+1|0;if(!(s&Z)){break h}}v[F+8>>2]=0;v[F+12>>2]=0;o=-3;break g}M=e+D|0;r=v[F+12>>2];C=r+E|0;N=v[i+60>>2];A=v[i+40>>2];e=v[i+36>>2];q=v[i+32>>2];g=v[i+56>>2];f=v[i+4>>2];o=-1;j=E;l=D;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{k=v[i>>2];switch(k|0){case 36:break l;case 39:break n;case 10:break o;case 35:break p;case 17:break q;case 21:break r;case 37:break s;case 34:break t;case 42:break x;case 41:break y;case 53:break z;case 52:break A;case 51:break B;case 38:break C;case 27:break D;case 26:break E;case 25:break F;case 24:break G;case 23:break H;case 18:break I;case 16:break J;case 14:break K;case 11:break L;case 9:break M;case 7:break N;case 6:break O;case 3:break P;case 32:break Q;case 5:break R;case 2:break T;case 1:break U;case 0:break V;default:break k}}v[i+28>>2]=1;g=0;v[i+8>>2]=0;v[i+12>>2]=0;v[i+16>>2]=1;A=0;e=0;q=0;f=0;if(z&1){break U}break S}if((r|0)<=0){v[i>>2]=1;break j}v[i+8>>2]=w[E|0];j=E+1|0}if(j>>>0>=C>>>0){v[i>>2]=2;o=z&2?1:-4;break i}e=w[j|0];v[i+12>>2]=e;j=j+1|0;W:{h=v[i+8>>2];X:{if(!(((e|h<<8)>>>0)%31|e&32)){d=h&15;if(X){break W}d=(d|0)!=8;break X}k=36;d=1;if(X){break m}}k=36;e=256<<(h>>>4);if(e>>>0>32768|e>>>0>s>>>0){break m}e=0;if(d){break m}break S}e=0;k=36;if((d|0)!=8){break m}}d=0;break w}if((r|0)<=0){v[i>>2]=5;break j}V=f+8|0;j=E+1|0;g=w[E|0]<<f|g;d=2;break w}if((r|0)<=0){v[i>>2]=32;break j}j=E+1|0;g=w[E|0]<<f|g;f=f+8|0;break v}d=1;break w}d=4;break w}d=3;break w}d=7;break w}d=9;break w}d=10;break w}d=11;break w}d=12;break w}d=13;break w}d=14;break w}d=15;break w}d=16;break w}d=17;break w}d=8;break w}d=5;break w}d=6;break w}d=18;break w}k=2;break u}k=1;break u}Y:while(1){Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{switch(d|0){case 0:if(f>>>0>2){break Ea}d=1;continue;case 4:break Ba;case 3:break Ca;case 2:break Da;case 1:break Fa;case 9:break ia;case 10:break ja;case 11:break ka;case 12:break la;case 13:break ma;case 14:break na;case 15:break oa;case 16:break pa;case 17:break qa;case 8:break wa;case 7:break xa;case 6:break ya;case 5:break za;default:break ra}}while(1){if(j>>>0>=C>>>0){v[i>>2]=3;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}}d=g&7;v[i+20>>2]=d;k=d>>>1|0;v[i+24>>2]=k;f=f-3|0;g=g>>>3|0;if(d>>>0>=2){break va}V=f;break sa}f=V&-8;g=g>>>(V&7)|0;e=0;d=0;break ua}if(j>>>0<C>>>0){break Aa}v[i>>2]=7;o=z&2?1:-4;break i}while(1){if(j>>>0>=C>>>0){v[i>>2]=6;o=z&2?1:-4;break i}g=w[j|0]<<f|g;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}d=1;break ua}t[(e+i|0)+10528|0]=w[j|0];j=j+1|0;d=2;break ua}while(1){if(j>>>0>=C>>>0){v[i>>2]=51;o=z&2?1:-4;break i}g=w[j|0]<<f|g;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}break aa}if(l>>>0<M>>>0){t[l|0]=q;e=e-1|0;l=l+1|0;break ba}o=2;k=52;break l}if(l>>>0<M>>>0){break ta}o=2;k=9;break l}if(j>>>0<C>>>0){d=M-l|0;h=C-j|0;d=d>>>0<h>>>0?d:h;d=d>>>0<e>>>0?d:e;e=e-d|0;l=gc(l,j,d)+d|0;j=d+j|0;break $}v[i>>2]=38;o=z&2?1:-4;break i}h=0;Ga:{switch(k-1|0){case 0:v[i+44>>2]=288;v[i+48>>2]=32;d=i+3552|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3560|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3568|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3576|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i- -64|0;k=0;while(1){h=144;if((k|0)==144){while(1){k=256;if((h|0)==256){while(1){h=280;if((k|0)==280){while(1){if((h|0)==288){break fa}t[d|0]=8;h=h+1|0;d=d+1|0;continue}}else{t[d|0]=7;k=k+1|0;d=d+1|0;continue}}}else{t[d|0]=9;h=h+1|0;d=d+1|0;continue}}}else{t[d|0]=8;k=k+1|0;d=d+1|0;continue}};case 2:break o;default:break Ga}}d=0;break ha}while(1){Ha:{Ia:{Ja:{Ka:{La:{switch(d|0){case 0:if(e>>>0>3){break Ka}if(!f){f=0;d=3;continue Y}if(f>>>0>7){break Ia}d=4;continue Y;case 1:t[(e+i|0)+10528|0]=g;f=f-8|0;g=g>>>8|0;break Ha;default:break La}}e=e+1|0;break Ja}e=x[i+10528>>1];if((e|0)==(x[i+10530>>1]^65535)){break ba}break n}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(l>>>0>=M>>>0){o=2;k=53;break l}t[l|0]=w[(N-q&Z)+J|0];l=l+1|0;N=N+1|0;d=7;break ca}while(1){if(j>>>0>=C>>>0){v[i>>2]=27;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;if(A>>>0>f>>>0){continue}break}d=6;break ca}if(j>>>0>=C>>>0){v[i>>2]=26;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;d=4;if(f>>>0<15){break ca}d=5;break ca}while(1){if(j>>>0>=C>>>0){v[i>>2]=25;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;if(A>>>0>f>>>0){continue}break}d=3;break ca}if(l>>>0>=M>>>0){o=2;k=24;break l}t[l|0]=e;l=l+1|0;break da}if(j>>>0>=C>>>0){v[i>>2]=23;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;d=0;if(f>>>0<15){break ca}d=1;break ca}while(1){if(j>>>0>=C>>>0){v[i>>2]=18;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;if(A>>>0>f>>>0){continue}break}_=q-16|0;d=3;break ea}if(j>>>0>=C>>>0){v[i>>2]=16;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;d=1;if(f>>>0<15){break ea}d=2;break ea}while(1){if(j>>>0>=C>>>0){v[i>>2]=14;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}d=1;break ga}d=e+21579|0;while(1){if(j>>>0>=C>>>0){v[i>>2]=11;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;K=t[d|0];if(f>>>0<K>>>0){continue}break}h=e;d=1}while(1){Ma:{Na:{Oa:{if(!d){if(h>>>0>2){break Oa}e=h;K=t[e+21579|0];if(K>>>0<=f>>>0){break Ma}d=9;continue Y}e=h<<2;v[(e+i|0)+44>>2]=v[e+60672>>2]+((-1<<K^-1)&g);h=h+1|0;f=f-K|0;g=g>>>K|0;break Na}e=0;Jb(i+7040|0,0,288);d=0;break ga}d=0;continue}d=1;continue}}while(1){Pa:{Qa:{Ra:{if(!d){if(y[i+52>>2]<=e>>>0){break Ra}if(f>>>0>2){break Pa}d=10;continue Y}t[(w[e+60688|0]+i|0)+7040|0]=g&7;e=e+1|0;f=f-3|0;g=g>>>3|0;break Qa}v[i+52>>2]=19;break fa}d=0;continue}d=1;continue}}G=v[i+24>>2];d=0}while(1){Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{switch(d|0){case 0:d=0;if((G|0)<0){break da}Q=Jb($,0,64);k=B(G,3488)+i|0;Jb(k+352|0,0,3200);H=v[i+24>>2];h=v[((H<<2)+i|0)+44>>2];while(1){if((d|0)!=(h|0)){r=(w[(d+k|0)- -64|0]<<2)+Q|0;v[r>>2]=v[r>>2]+1;d=d+1|0;continue}break};v[Q+64>>2]=0;v[Q+68>>2]=0;s=0;d=1;k=0;while(1){if((d|0)!=16){r=d<<2;d=d+1|0;r=v[r+Q>>2];k=r+k<<1;v[(Q- -64|0)+(d<<2)>>2]=k;s=s+r|0;continue}break};R=0;r=-1;if((k|0)!=65536&s>>>0>=2){break p}while(1){if(h>>>0>R>>>0){s=w[((B(G,3488)+i|0)+R|0)- -64|0];bb:{if(!s){break bb}d=(Q- -64|0)+(s<<2)|0;k=v[d>>2];v[d>>2]=k+1;d=0;h=s;while(1){if(h){d=k&1|d<<1;k=k>>>1|0;h=h-1|0;continue}break}if(s>>>0<=10){h=1<<s;k=s<<9|R;s=B(G,3488)+i|0;while(1){if(d>>>0>1023){break bb}u[(s+(d<<1)|0)+352>>1]=k;d=d+h|0;continue}}H=B(G,3488)+i|0;k=H+((d&1023)<<1)|0;h=u[k+352>>1];cb:{if(h){k=r;r=h;break cb}u[k+352>>1]=r;k=r-2|0}d=d>>>9|0;while(1){d=d>>>1|0;h=d&1;if(s>>>0>=12){h=(H+(h+(r^-1)<<1)|0)+2400|0;r=u[h>>1];if(!r){u[h>>1]=k;r=k;k=k-2|0}s=s-1|0;continue}break}u[((B(G,3488)+i|0)+(h+(r^-1)<<1)|0)+2400>>1]=R;r=k}R=R+1|0;H=v[i+24>>2];h=v[((H<<2)+i|0)+44>>2];continue}break};d=0;if((H|0)!=2){break Va}break Za;case 1:d=u[(((g&1023)<<1)+i|0)+7328>>1];db:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break db}break Ya}if(f>>>0<11){break db}h=10;while(1){d=u[(((g>>>h&1)+(d^-1)<<1)+i|0)+9376>>1];if((d|0)<0){k=h+2|0;h=h+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break Ya}}d=11;continue Y;case 2:q=u[(((g&1023)<<1)+i|0)+7328>>1];if((q|0)>=0){break $a}d=10;while(1){h=g>>>d|0;d=d+1|0;q=u[(((h&1)+(q^-1)<<1)+i|0)+9376>>1];if((q|0)<0){continue}break};break _a;default:break ab}}d=t[_+17788|0]+((-1<<A^-1)&g)|0;f=f-A|0;g=g>>>A|0;h=e+i|0;Jb(h+10532|0,(q|0)==16?w[h+10531|0]:0,d);d=d+e|0;break Za}d=q>>9;q=q&511}f=f-d|0;g=g>>>d|0;if(q>>>0>15){break Xa}t[(e+i|0)+10532|0]=q;d=e+1|0}h=v[i+48>>2];e=v[i+44>>2];k=h+e|0;if(k>>>0<=d>>>0){break Wa}if(f>>>0<=14){if((C-j|0)<=1){e=d;d=1;continue}g=w[j|0]<<f|g|w[j+1|0]<<f+8;j=j+2|0;f=f+16|0}e=d}d=2;continue}if(!((q|0)!=16|e)){e=0;q=16;break q}A=t[q+21554|0];if(A>>>0>f>>>0){break Ua}_=q-16|0;break Sa}if((d|0)!=(k|0)){e=d;break r}k=i+10532|0;gc(i- -64|0,k,e);gc(i+3552|0,e+k|0,h);H=v[i+24>>2];e=d}G=H-1|0;v[i+24>>2]=G;break Ta}d=12;continue Y}d=0;continue}d=3;continue}}m=g;d=2}eb:while(1){fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{switch(d|0){case 0:d=u[(((g&1023)<<1)+i|0)+352>>1];ub:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break ub}break fb}if(f>>>0<11){break ub}h=10;while(1){d=u[(((g>>>h&1)+(d^-1)<<1)+i|0)+2400>>1];if((d|0)<0){k=h+2|0;h=h+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break fb}}d=13;continue Y;case 1:e=u[(((g&1023)<<1)+i|0)+352>>1];if((e|0)>=0){break sb}d=10;while(1){h=g>>>d|0;d=d+1|0;e=u[(((h&1)+(e^-1)<<1)+i|0)+2400>>1];if((e|0)<0){continue}break};break rb;case 3:break ib;case 4:break jb;case 5:break nb;case 6:break ob;case 2:break tb;default:break pb}}while(1){d=C-j|0;if(!((M-l|0)>1&(d|0)>=4)){if(f>>>0>14){g=m;break fb}if((d|0)<=1){g=m;d=0;continue eb}g=w[j|0]<<f|m|w[j+1|0]<<f+8;f=f+16|0;j=j+2|0;break fb}if(f>>>0>14){k=j}else{m=(w[j|0]|w[j+1|0]<<8)<<f|m;f=f+16|0;k=j+2|0}e=u[(((m&1023)<<1)+i|0)+352>>1];vb:{if((e|0)<0){d=10;while(1){g=m>>>d|0;d=d+1|0;e=u[(((g&1)+(e^-1)<<1)+i|0)+2400>>1];if((e|0)<0){continue}break}break vb}d=e>>9}f=f-d|0;g=m>>>d|0;if(e&256){j=k;break qb}if(!(f>>>0>14)){g=(w[k|0]|w[k+1|0]<<8)<<f|g;k=k+2|0;f=f+16|0}s=f;j=k;h=u[(((g&1023)<<1)+i|0)+352>>1];wb:{if((h|0)<0){d=10;while(1){m=g>>>d|0;d=d+1|0;h=u[(((m&1)+(h^-1)<<1)+i|0)+2400>>1];if((h|0)<0){continue}break}break wb}d=h>>9}t[l|0]=e;f=s-d|0;m=g>>>d|0;if(!(h&256)){t[l+1|0]=h;l=l+2|0;continue}break}l=l+1|0;g=m;e=h;break qb}d=e>>9;e=e&511}f=f-d|0;g=g>>>d|0;if(e>>>0>255){break qb}d=14;continue Y}h=e&511;e=256;if((h|0)==256){break _}d=h<<2;e=v[d+59132>>2];A=0;if(h-285>>>0<4294967276){break hb}A=v[d+59260>>2];if(A>>>0>f>>>0){d=15;continue Y}d=3;continue}if(!e){m=g;e=-1;break lb}e=e-1|0;d=18;continue Y}f=f-A|0;m=g>>>A|0;q=((-1<<A^-1)&g)+q|0;break mb}d=u[(((g&1023)<<1)+i|0)+3840>>1];xb:{if((d|0)<0){h=10;while(1){k=g>>>h|0;h=h+1|0;d=u[(((k&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){continue}break}break xb}h=d>>9;d=d&511}f=f-h|0;g=g>>>h|0;h=d<<2;q=v[h+60416>>2];A=0;if(d-30>>>0<4294967270){m=g;break mb}A=v[h+60544>>2];if(A>>>0<=f>>>0){break kb}d=17;continue Y}N=l-J|0;if(!(!X|(q|0)!=0&N>>>0>=q>>>0)){g=m;break s}d=(N-q&Z)+J|0;if((d>>>0<l>>>0?l:d)+e>>>0>M>>>0){g=m;d=7;continue}while(1){if(e>>>0>=3){t[l|0]=w[d|0];t[l+1|0]=w[d+1|0];t[l+2|0]=w[d+2|0];e=e-3|0;d=d+3|0;l=l+3|0;continue}break}if(!e){e=0;break lb}t[l|0]=w[d|0];if((e|0)!=1){t[l+1|0]=w[d+1|0]}l=e+l|0}d=2;continue}d=6;continue}d=u[(((g&1023)<<1)+i|0)+3840>>1];yb:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break yb}break gb}if(f>>>0<11){break yb}h=10;while(1){d=u[(((g>>>h&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){k=h+2|0;h=h+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break gb}}d=16;continue Y}f=f-A|0;e=((-1<<A^-1)&g)+e|0;g=g>>>A|0}if(f>>>0>14){break gb}if((C-j|0)<=1){d=4;continue}g=w[j|0]<<f|g|w[j+1|0]<<f+8;f=f+16|0;j=j+2|0}d=5;continue}d=1;continue}}if(!e|!f){break $}if(f>>>0>7){break aa}d=5;continue}f=f-8|0;q=g&255;g=g>>>8|0;d=6;continue}if(e){break Z}e=0}if(t[i+20|0]&1){break v}d=0;continue}d=7;continue}}h=0;m=f>>>3|0;d=j-E|0;d=d>>>0>j>>>0?0:d;m=d?d>>>0>m>>>0?m:d:0;d=(f&-8)-(m<<3)|0;if(!d){j=j-m|0;g=(((d&63)>>>0>=32?0:-1<<d)^-1)&g>>>(f&7);d=0;f=0;if(!(z&1)){break t}k=0;break u}ca(6800,13142,2797,6810);L()}while(1){zb:{Ab:{Bb:{Cb:{Db:{Eb:{switch(k|0){case 0:if(h>>>0>3){e=h;f=d;break t}if(d){break Db}f=0;e=h;k=1;continue;case 1:break Eb;default:break Cb}}if(j>>>0<C>>>0){break Ab}v[i>>2]=42;o=z&2?1:-4;break i}e=h;f=d;if(d>>>0>7){break Bb}k=2;continue}while(1){if(j>>>0>=C>>>0){v[i>>2]=41;o=z&2?1:-4;break i}g=w[j|0]<<f|g;h=f>>>0>4294967287;j=j+1|0;d=f+8|0;f=d;if(h){continue}break}h=e}k=g&255;g=g>>>8|0;d=d-8|0;break zb}k=w[j|0];j=j+1|0;h=e;d=f}v[i+16>>2]=v[i+16>>2]<<8|k;h=h+1|0;k=0;continue}}o=0;k=34;break l}k=37;break l}k=21;break l}k=17;break l}k=35;break l}k=10;break l}k=39;break l}e=1}v[i>>2]=k}d=f-7|0;h=(d>>>0>f>>>0?0:d)+7>>>3|0;d=j-E|0;d=d>>>0>j>>>0?0:d;d=d?d>>>0>h>>>0?h:d:0;j=j-d|0;f=f-(d<<3)|0;break i}o=z&2?1:-4}v[i+4>>2]=f;v[i+60>>2]=N;v[i+40>>2]=A;v[i+36>>2]=e;v[i+32>>2]=q;v[i+56>>2]=(((f&63)>>>0>=32?0:-1<<f)^-1)&g;v[F+12>>2]=j-E;g=l-D|0;v[F+8>>2]=g;if(!(z&9)|(o|0)<0){break g}f=(g>>>0)%5552|0;e=v[i+28>>2];d=e>>>16|0;h=e&65535;while(1){k=0;if(g){while(1){if((k|7)>>>0<f>>>0){e=w[D|0]+h|0;m=e+w[D+1|0]|0;j=m+w[D+2|0]|0;r=j+w[D+3|0]|0;s=r+w[D+4|0]|0;l=s+w[D+5|0]|0;E=l+w[D+6|0]|0;h=E+w[D+7|0]|0;d=h+(E+(l+(s+(r+(j+(m+(d+e|0)|0)|0)|0)|0)|0)|0)|0;D=D+8|0;k=k+8|0;continue}break}e=f&7;k=f&8184;j=D;while(1){if((f|0)!=(k|0)){k=k+1|0;h=w[j|0]+h|0;d=h+d|0;j=j+1|0;continue}break}g=g-f|0;d=(d>>>0)%65521|0;h=(h>>>0)%65521|0;D=e+D|0;f=5552;continue}else{e=d<<16|h;v[i+28>>2]=e;if(o){break g}o=0;if(!(z&1)){break g}e=(e|0)==v[i+16>>2]?0:-2}break}o=e}ab=$+144|0;v[i+43780>>2]=o;e=v[F+12>>2];v[p>>2]=e+v[p>>2];v[p+4>>2]=v[p+4>>2]-e;v[p+8>>2]=e+v[p+8>>2];v[p+48>>2]=v[i+28>>2];e=v[F+8>>2];v[i+10996>>2]=e;d=v[p+16>>2];e=d>>>0>e>>>0?e:d;gc(v[p+12>>2],v[i+10992>>2]+J|0,e);v[p+12>>2]=e+v[p+12>>2];v[p+16>>2]=v[p+16>>2]-e;v[p+20>>2]=e+v[p+20>>2];d=v[i+10996>>2]-e|0;v[i+10996>>2]=d;k=e+v[i+10992>>2]&32767;v[i+10992>>2]=k;if((o|0)<0){break f}if(!((o|0)!=1|da)){e=-5;break e}if(o){e=0;h=v[p+4>>2];if(!h|!v[p+16>>2]){break e}if(!d){continue}break e}break}e=!d;break e}g=v[p+16>>2];d=d>>>0<g>>>0?d:g;gc(v[p+12>>2],(v[i+10992>>2]+i|0)+11012|0,d);v[p+12>>2]=d+v[p+12>>2];v[p+16>>2]=v[p+16>>2]-d;v[p+20>>2]=d+v[p+20>>2];g=v[i+10996>>2]-d|0;v[i+10996>>2]=g;v[i+10992>>2]=d+v[i+10992>>2]&32767;if(v[i+43780>>2]){break e}e=!g;break e}e=-3}ab=F+16|0;h=v[n+1068>>2]-U|0;v[n+1068>>2]=h;d=I+ba|0;I=v[n+1088>>2];ba=d-I|0;continue}break}b=n+1072|0;Fb:{if(!b){break Fb}d=v[b+28>>2];if(!d){break Fb}eb[v[b+36>>2]](v[b+40>>2],d);v[b+28>>2]=0}h=0;Gb:{Hb:{b=n+1140|0;if(!((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=(aa|0)|I|(e|0)!=1)){de(n+8|0,v[T>>2],v[T+4>>2]);b=Vd(n);e=v[b+4>>2];b=v[b>>2];v[22452]=0;b=ea(503,n+32|0,v[n+8>>2],v[n+12>>2],b|0,e|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Hb}v[22452]=0;h=Y(847,a|0,b|0,c|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break Gb}qb(b)}Xb(T);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;qb(b);break c}a=P()|0;O()|0}Xb(T);S(a|0);L()}ab=n+1152|0;return h|0}function bfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=C(0),A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,T=C(0),U=C(0),W=0,Z=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=C(0),na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=C(0);p=ab-11360|0;ab=p;qc(c);a:{b:{c:{d:{while(1){e:{if(!Hb(c,4)){break e}f=p+16|0;g=ab-16|0;ab=g;f:{if(!Hb(c,3)){d=f;h=f+3|0;while(1){if((d|0)!=(h|0)){rf(d);d=d+1|0;continue}break}break f}Wu(g+8|0,f);fd(g,c,v[g+8>>2],v[g+12>>2])}ab=g+16|0;g:{h:{if(!Ib(f,15e3,3)){d=p+4648|0;f=ab-16|0;ab=f;i:{if(!Hb(c,7)){g=d+7|0;while(1){if((d|0)!=(g|0)){rf(d);d=d+1|0;continue}break}break i}_n(f+8|0,d);fd(f,c,v[f+8>>2],v[f+12>>2])}ab=f+16|0;d=0;A=3;while(1){if((A|0)==7){break g}f=w[(p+4648|0)+A|0];if(f&128){break h}A=A+1|0;d=f|d<<7;continue}}j:{if(Ib(p+16|0,14173,3)){break j}if(!RQ(c,13537)){break j}Ob(c,jg(c)+16|0);continue}if(!Ib(p+16|0,30222,3)){continue}if(!Ib(p+16|0,30226,3)){continue}d=w[p+16|0];if(!d){gg(c,2);continue}if(AO(d,w[p+17|0],w[p+18|0])){break e}}A=0;break d}Ob(c,d);continue}break}qc(c);d=p+11336|0;xA(d,c);ca=v[p+11336>>2];A=Sd(d);W=Pb(p+11320|0);c=p+4648|0;Jb(c,0,6668);Jy(c);c=p+4640|0;v[c>>2]=0;v[c+4>>2]=0;c=p+4632|0;v[c>>2]=0;v[c+4>>2]=0;v[p+4624>>2]=0;v[p+4628>>2]=0;d=0;c=0;k:{while(1){g=vc(ca,da);aa=p+16|0;N=p+4624|0;f=0;n=ab-17168|0;ab=n;v[n+17164>>2]=0;l:{m:{H=p+4648|0;n:{if(w[H+6152|0]!=255|(g|0)<5){break n}if(!Ko(H+6152|0,A)){break n}o=Dw(w[A+1|0],w[A+2|0],v[H+6148>>2])+Jo(A)|0;v[n+17164>>2]=o;if((g|0)==(o|0)){o=g;break m}o:{if((g|0)>=(o+4|0)){if(Ko(A,o+A|0)){break o}}v[n+17164>>2]=0;break n}if(o){break m}}i=A;m=Jb(H,0,6668)+6148|0;s=n+17164|0;q=0;k=0;J=g-4|0;D=(J|0)>0?J:0;while(1){p:{q:{r:{s:{if((q|0)==(D|0)){q=g;break s}if(!bH(i)){break q}l=Dw(w[i+1|0],w[i+2|0],v[m>>2]);f=l+Jo(i)|0;h=4;r=q+4|0;t:{while(1){if(!(h>>>0>2303|l)){if((J|0)<=((h<<1)+q|0)){break t}l=0;o=h+i|0;u:{if(!Ko(i,o)){break u}j=h-Jo(i)|0;E=Jo(o)+j|0;if((g|0)<(E+(h+r|0)|0)){break u}if(!Ko(i,o+E|0)){break u}v[m>>2]=j;l=j;f=h}h=h+1|0;continue}break}if(!l|(g|0)<(f+q|0)){break t}r=g-q|0;h=0;o=0;while(1){v:{w:{if((o|0)!=10){j=(o|0)!=0;G=h;h=h+i|0;h=(G+Dw(w[h+1|0],w[h+2|0],l)|0)+Jo(h)|0;if((r|0)<(h+4|0)){break v}if(Ko(i,h+i|0)){break w}j=0}else{j=1}break v}o=o+1|0;continue}break}if(!j){break t}k=f;break s}if((f|0)!=(g|0)|q){break r}q=0;k=g}v[s>>2]=k;f=q;break p}v[m>>2]=0}i=i+1|0;q=q+1|0;continue}break}o=v[n+17164>>2];if((g|0)>=(f+o|0)?o:0){break m}v[N>>2]=f;q=0;break l}g=f+A|0;v[H+6152>>2]=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);v[N+4>>2]=f;v[N>>2]=f+o;v[N+8>>2]=w[g+3|0]>191?1:2;sa=N,ta=eH(w[g+1|0],w[g+2|0]),v[sa+12>>2]=ta;v[N+16>>2]=4-(w[g+1|0]>>>1&3);sa=N,ta=Cw(w[g+1|0],w[g+2|0]),v[sa+20>>2]=ta;if(!aa){q=Bw(w[g+1|0]);break l}dH(n+17152|0,g+4|0,o-4|0);if(!(t[g+1|0]&1)){Zd(n+17152|0,16)}x:{if(v[N+16>>2]==3){q=0;k=n+17152|0;f=n+3740|0;i=0;h=w[g+1|0];l=B((h>>>3&1)+(h>>>4&1)|0,3)+(w[g+2|0]>>>2&3)|0;j=l-((l|0)!=0)|0;J=g;g=w[g+3|0]>191?1:2;y:{if(h&8){l=Zd(k,9);g=g<<1;i=Zd(k,g+7|0);break y}l=Zd(k,g|8)>>>g|0}h=B(j,40);s=h+61008|0;D=h+61328|0;r=B(j,23)+60816|0;m=-1;o=0;z:{while(1){h=w[J+3|0];E=Zd(k,12);u[f+4>>1]=E;j=Zd(k,9);u[f+6>>1]=j;if((j&65535)>>>0>288){break z}h=h>>>0>191?i<<4:i;sa=f,ta=Zd(k,8),t[sa+10|0]=ta;i=Zd(k,w[J+1|0]&8?4:9);t[f+13|0]=22;t[f+14|0]=0;v[f>>2]=r;u[f+8>>1]=i;A:{if(Zd(k,1)){i=Zd(k,2);t[f+11|0]=i;if(!(i&255)){break z}i=Zd(k,1);u[f+18>>1]=65287;t[f+12|0]=i;if(w[f+11|0]==2){B:{if(!(i&255)){v[f>>2]=s;t[f+18|0]=8;j=39;i=0;break B}v[f>>2]=D;j=30;i=w[J+1|0]&8?8:6}t[f+14|0]=j;t[f+13|0]=i;h=h&3855}i=Zd(k,10);sa=f,ta=Zd(k,3),t[sa+21|0]=ta;sa=f,ta=Zd(k,3),t[sa+22|0]=ta;sa=f,ta=Zd(k,3),t[sa+23|0]=ta;i=i<<5;break A}t[f+11|0]=0;t[f+12|0]=0;i=Zd(k,15);sa=f,ta=Zd(k,4),t[sa+18|0]=ta;j=Zd(k,3);t[f+20|0]=255;t[f+19|0]=j}t[f+17|0]=i&31;t[f+15|0]=i>>>10;t[f+16|0]=i>>>5&31;o=(E&65535)+o|0;C:{if(w[J+1|0]&8){i=Zd(k,1);break C}i=x[f+8>>1]>499}t[f+24|0]=i;sa=f,ta=Zd(k,1),t[sa+25|0]=ta;i=Zd(k,1);t[f+27|0]=h>>>12&15;t[f+26|0]=i;f=f+28|0;i=h<<4;g=g-1|0;if(g){continue}break}m=(v[k+4>>2]+o|0)>(v[k+8>>2]+(l<<3)|0)?-1:l}if(!((m|0)<0|v[n+17156>>2]>v[n+17160>>2])){f=n+17152|0;l=v[f+4>>2];k=v[f+8>>2];i=n+912|0;g=v[H+6144>>2];h=g-m|0;g=(g|0)>(m|0)?m:g;h=gc(i+12|0,(((h|0)>0?h:0)+H|0)+6156|0,g);j=v[f>>2]+(v[f+4>>2]/8|0)|0;f=(k-l|0)/8|0;gc(g+h|0,j,f);dH(i,h,f+g|0);D:{o=v[H+6144>>2]>=(m|0);if(!o){break D}na=H+2304|0;oa=n+8620|0;pa=n+3852|0;while(1){if((w[J+1|0]&8?2:1)>>>0<=q>>>0){break D}qa=Jb(pa,0,4608);f=v[N+8>>2];E=(B(B(f,q),28)+n|0)+3740|0;F=0;ja=(f|0)>0?f:0;K=n+912|0;D=K+7548|0;ba=H+6152|0;while(1){if((F|0)!=(ja|0)){g=B(F,28)+E|0;$=x[g+4>>1];Z=v[K+4>>2];l=D;k=ab-48|0;ab=k;s=!w[g+13|0]+(w[g+14|0]!=0)|0;M=w[g+25|0];r=(K+B(F,39)|0)+16156|0;j=k;ea=j+44|0;E:{if(w[ba+1|0]&8){f=w[g+27|0];h=w[x[g+8>>1]+61744|0];i=h&3;t[k+47|0]=i;t[k+46|0]=i;h=h>>>2|0;t[k+45|0]=h;t[k+44|0]=h;h=B(s,28)+61648|0;break E}f=(w[ba+3|0]&16)>>>4&(F|0)!=0;m=f?12:0;i=x[g+8>>1]>>>f|0;while(1){if((i|0)>=0){f=3;h=1;while(1){if((f|0)>=0){I=w[(f+m|0)+61760|0];t[(k+44|0)+f|0]=((i|0)/(h|0)|0)%(I|0);f=f-1|0;h=B(h,I);continue}break}m=m+4|0;i=i-h|0;continue}break}f=-16;h=(B(s,28)+m|0)+61648|0}i=0;while(1){F:{G:{H:{if((i|0)==4){break H}s=w[h+i|0];if(!s){break H}if(f&8){gc(j,r,s);break G}I=w[i+ea|0];if(!I){Jb(j,0,s);Jb(r,0,s);break G}ga=(f|0)>=0?-1:-1<<I^-1;m=0;while(1){if((m|0)==(s|0)){break G}G=Zd(K,I);t[m+r|0]=(G|0)==(ga|0)?-1:G;t[j+m|0]=G;m=m+1|0;continue}}t[j+2|0]=0;t[j|0]=0;t[j+1|0]=0;break F}f=f<<1;i=i+1|0;j=j+s|0;r=r+s|0;continue}break}I:{h=w[g+14|0];if(h){f=2-M|0;j=w[g+23|0]<<f;m=w[g+22|0]<<f;s=w[g+21|0]<<f;r=w[g+13|0];f=0;while(1){if(f>>>0>=h>>>0){break I}i=k+(f+r|0)|0;t[i|0]=s+w[i|0];t[i+1|0]=m+w[i+1|0];t[i+2|0]=j+w[i+2|0];f=f+3|0;continue}}if(!w[g+24|0]){break I}f=0;while(1){if((f|0)==10){break I}i=f+k|0;t[i+11|0]=w[i+11|0]+w[f+61784|0];f=f+1|0;continue}}i=M+1|0;f=0;y=Aw(C(2048),((((w[ba+3|0]&224)==96)<<1)-w[g+10|0]|0)+258|0);while(1){if(w[g+13|0]+(h&255)>>>0>f>>>0){sa=(f<<2)+l|0,ua=Aw(y,w[f+k|0]<<i),z[sa>>2]=ua;f=f+1|0;h=w[g+14|0];continue}break}ab=k+48|0;m=(K+B(F,2304)|0)+2940|0;ga=$+Z|0;y=C(0);k=v[K+4>>2];f=v[K>>2]+((k|0)/8|0)|0;h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);h=(h<<24|h<<8&16711680|(h>>>8&65280|h>>>24))<<(k&7);j=k|-8;r=f+4|0;s=g;M=v[g>>2];I=x[g+6>>1];g=0;while(1){J:{K:{if((I|0)>0){k=g+1|0;g=g+s|0;f=w[g+15|0];ka=(u[(f<<1)+66208>>1]<<1)+61824|0;$=w[g+18|0];if(f>>>0>=16){ha=w[f+66272|0];ra=32-ha|0;while(1){ia=w[M|0]>>>1|0;G=I>>>0>ia>>>0?ia:I;y=z[l>>2];while(1){f=h>>>27|0;g=5;while(1){f=u[ka+(f<<1)>>1];if((f|0)<0){h=h<<g;i=f&7;f=(h>>>32-i|0)-(f>>3)|0;j=g+j|0;g=i;continue}break}g=f>>8;j=g+j|0;h=h<<g;i=0;while(1){if((i|0)!=2){Z=f&15;L:{if((Z|0)==15){j=j+ha|0;g=h<<ha;while(1){if((j|0)>=0){g=w[r|0]<<j|g;r=r+1|0;j=j-8|0;continue}break}Z=(h>>>ra|0)+15|0;h=Z;M:{if((h|0)<=128){T=z[(h<<2)+66368>>2];break M}la=h>>>0<1024;h=la?h<<3:h;ea=h<<1&64;U=C(C((h&63)-ea|0)/C(ea+(h&-64)|0));T=C((la?C(16):C(256))*C(C(C(U*C(C(U*C(.2222222238779068))+C(1.3333333730697632)))+C(1))*z[(h+ea>>6<<2)+66368>>2]))}T=C(C(y*T)*C(g>>31|1));break L}g=h;T=C(y*z[(((g>>>27&16|Z)^16)<<2)+66304>>2])}z[m>>2]=T;f=f>>4;m=m+4|0;i=i+1|0;h=(Z|0)!=0;j=h+j|0;h=g<<h;continue}break}while(1){if((j|0)>=0){h=w[r|0]<<j|h;r=r+1|0;j=j-8|0;continue}break}G=G-1|0;if(G){continue}break}l=l+4|0;M=M+1|0;I=I-ia|0;if((I|0)<=0){break K}f=($|0)>0;$=$-1|0;if(f){continue}break}break K}while(1){G=w[M|0]>>>1|0;Z=G>>>0<I>>>0?G:I;y=z[l>>2];while(1){g=h>>>27|0;f=5;while(1){g=u[ka+(g<<1)>>1];if((g|0)<0){h=h<<f;i=g&7;g=(h>>>32-i|0)-(g>>3)|0;j=f+j|0;f=i;continue}break}f=g>>8;j=f+j|0;h=h<<f;f=0;while(1){if((f|0)!=2){i=g&15;z[m>>2]=y*z[(((i|h>>>27&16)^16)<<2)+66304>>2];g=g>>4;m=m+4|0;f=f+1|0;i=(i|0)!=0;j=i+j|0;h=h<<i;continue}break}while(1){if((j|0)>=0){h=w[r|0]<<j|h;r=r+1|0;j=j-8|0;continue}break}Z=Z-1|0;if(Z){continue}break}l=l+4|0;M=M+1|0;I=I-G|0;if((I|0)<=0){break K}f=($|0)>0;$=$-1|0;if(f){continue}break}break K}f=1-I|0;while(1){N:{k=w[s+26|0]?66192:66160;g=w[k+(h>>>28|0)|0];if(!(g&8)){g=w[k+((h<<4>>>32-(g&3))+(g>>>3)|0)|0]}k=g&7;j=k+j|0;if((ga|0)<((j+(r-v[K>>2]<<3)|0)-24|0)){break N}f=f-1|0;if(!f){f=w[M|0];if(f>>>0<2){break N}M=M+1|0;y=z[l>>2];l=l+4|0;f=f>>>1|0}h=h<<k;if(g&128){z[m>>2]=(h|0)<0?C(-y):y;j=j+1|0;h=h<<1}if(g&64){z[m+4>>2]=(h|0)<0?C(-y):y;j=j+1|0;h=h<<1}f=f-1|0;if(!f){f=w[M|0];if(f>>>0<2){break N}M=M+1|0;y=z[l>>2];l=l+4|0;f=f>>>1|0}if(g&32){z[m+8>>2]=(h|0)<0?C(-y):y;j=j+1|0;h=h<<1}if(g&16){z[m+12>>2]=(h|0)<0?C(-y):y;j=j+1|0;h=h<<1}while(1){if((j|0)>=0){h=w[r|0]<<j|h;r=r+1|0;j=j-8|0;continue}break}m=m+16|0;continue}break}v[K+4>>2]=ga;break J}g=k;continue}break}F=F+1|0;continue}break}f=w[H+6155|0];O:{if(f&16){j=ab-16|0;ab=j;g=K+2940|0;h=g+2304|0;s=v[E>>2];D=w[E+14|0];l=D+w[E+13|0]|0;f=0;m=j+4|0;v[m+8>>2]=-1;v[m>>2]=-1;v[m+4>>2]=-1;while(1){if((f|0)!=(l|0)){r=f+s|0;i=w[r|0];k=0;P:{while(1){if(i>>>0<=k>>>0){break P}F=k<<2;if(z[F+h>>2]==C(0)){k=k+2|0;if(z[(F|4)+h>>2]==C(0)){continue}}break}v[m+((f>>>0)%3<<2)>>2]=f;i=w[r|0]}f=f+1|0;h=(i<<2)+h|0;continue}break}if(w[E+13|0]){f=v[j+12>>2];h=v[j+8>>2];k=v[j+4>>2];h=(h|0)>(k|0)?h:k;f=(f|0)>(h|0)?f:h;v[j+12>>2]=f;v[j+8>>2]=f;v[j+4>>2]=f}i=K+16195|0;h=D?3:1;k=l-h|0;f=0;while(1){if((f|0)!=(h|0)){m=f+k|0;l=m-h|0;if((l|0)<=v[(j+4|0)+(f<<2)>>2]){l=w[ba+1|0]<<28>>31&3}else{l=w[i+l|0]}t[i+m|0]=l;f=f+1|0;continue}break}m=v[E>>2];s=j+4|0;D=u[E+36>>1]&1;f=0;r=w[ba+1|0]&8?7:64;while(1){F=f+m|0;h=w[F|0];if(h){k=w[ba+3|0]&32;Q:{R:{if(v[s+((f>>>0)%3<<2)>>2]>=(f|0)){break R}l=w[f+i|0];if(l>>>0>=r>>>0){break R}T=k?C(1.4142135381698608):C(1);S:{if(w[ba+1|0]&8){l=l<<3;y=z[l+66900>>2];U=z[l+66896>>2];break S}U=Aw(C(1),l+1>>>1<<D);l=l&1;y=l?C(1):U;U=l?U:C(1)}U=C(T*U);T=C(T*y);k=0;while(1){if((h|0)!=(k|0)){l=(k<<2)+g|0;y=z[l>>2];z[l+2304>>2]=y*T;z[l>>2]=y*U;k=k+1|0;continue}break}break Q}if(!k){break Q}aH(g,h)}f=f+1|0;g=(w[F|0]<<2)+g|0;continue}break}ab=j+16|0;break O}if((f&224)!=96){break O}aH(K+2940|0,576)}l=K+7708|0;F=0;while(1){if((F|0)!=(ja|0)){f=w[H+6153|0];i=(w[E+12|0]!=0)<<1<<((B((f>>>3&1)+(f>>>4&1)|0,3)+(w[H+6154|0]>>>2&3)|0)==2);k=(K+B(F,2304)|0)+2940|0;h=k;if(w[E+14|0]){m=v[E>>2]+w[E+13|0]|0;D=((K+B(F,2304)|0)+B(i,72)|0)+2940|0;G=D;g=l;while(1){j=w[m|0];if(j){s=j<<1;f=0;while(1){if((f|0)!=(j|0)){z[g>>2]=z[G>>2];z[g+4>>2]=z[(j<<2)+G>>2];z[g+8>>2]=z[(s<<2)+G>>2];G=G+4|0;f=f+1|0;g=g+12|0;continue}break}m=m+3|0;G=(s<<2)+G|0;continue}break}gc(D,l,g-l|0);f=i-1|0}else{f=31}while(1){g=0;if((f|0)>0){while(1){if((g|0)!=8){j=g<<2;m=j+h|0;y=z[m+72>>2];U=z[j+66960>>2];T=z[j+66992>>2];j=(17-g<<2)+h|0;ma=z[j>>2];z[m+72>>2]=C(y*U)-C(T*ma);z[j>>2]=C(y*T)+C(ma*U);g=g+1|0;continue}break}h=h+72|0;f=f-1|0;continue}break}g=k;f=B(F,1152)+H|0;h=w[E+11|0];if(i){$G(g,f,67024,i);g=B(i,72)+g|0;f=B(i,36)+f|0}T:{if((h|0)==2){i=32-i|0;h=ab-80|0;ab=h;m=h|8;s=h|4;while(1){if((i|0)>0){j=gc(h,g,72);D=v[f+20>>2];v[g+16>>2]=v[f+16>>2];v[g+20>>2]=D;D=v[f+12>>2];v[g+8>>2]=v[f+8>>2];v[g+12>>2]=D;D=v[f+4>>2];v[g>>2]=v[f>>2];v[g+4>>2]=D;D=j;j=f+24|0;zw(D,g+24|0,j);zw(s,g+48|0,j);zw(m,f,j);g=g+72|0;f=f+36|0;i=i-1|0;continue}break}ab=h+80|0;break T}$G(g,f,B((h|0)==3,72)+67024|0,32-i|0)}g=0;f=k+72|0;while(1){i=1;if(g>>>0<=31){while(1){if(i>>>0<=17){h=(i<<2)+f|0;z[h>>2]=-z[h>>2];i=i+2|0;continue}break}f=f+144|0;g=g+2|0;continue}break}E=E+28|0;F=F+1|0;continue}break}cH(na,qa,18,v[N+8>>2],aa,oa);q=q+1|0;aa=B(v[N+8>>2],1152)+aa|0;continue}}f=n+912|0;q=v[f+8>>2]>>>3|0;k=v[f+4>>2]+7>>>3|0;g=q-k|0;h=(g|0)>511;l=h?511:g;if((g|0)>0){Wi(H+6156|0,(f+(h?q-511|0:k)|0)+12|0,l)}v[H+6144>>2]=l;break x}Jy(H);break l}j=n+17152|0;i=0;h=0;l=0;o=0;q=g;U:{V:{W:{f=w[g+3|0];k=f>>>6|0;switch(k-1|0){case 2:break U;case 0:break W;default:break V}}h=(f>>>2&12)+4|0;break U}h=32}f=w[q+1|0];X:{if((f&6)==6){g=32;f=68428;break X}if(!(f&8)){g=30;f=68431;break X}m=w[q+2|0];g=m>>>2&3;f=Cw(f,m)>>>((k|0)!=3)|0;f=f?f:192;if(f>>>0<=55){g=(g|0)==2?12:8;f=68452;break X}g=f>>>0>95?(g|0)!=1?30:27:27;f=68440}t[n+768|0]=g;t[n+769|0]=g>>>0<h>>>0?g:h;g=f;k=68336;while(1){h=w[n+768|0];if(i>>>0>=h>>>0){i=0;while(1){g=h<<1&510;if(g>>>0>i>>>0){f=i+n|0;Y:{if(!w[f+770|0]){g=6;break Y}g=2;if((w[q+1|0]&6)==6){break Y}g=Zd(j,2);h=w[n+768|0]}t[f+834|0]=g;i=i+1|0;continue}break}h=n+770|0;k=n+834|0;f=n;i=0;l=g;while(1){if((i|0)!=(l|0)){o=w[h|0];q=o?19>>>w[i+k|0]&3|4:0;h=h+1|0;o=B(o,3)-6|0;y=C(0);g=4;while(1){if(g){if(g&q){m=Zd(j,6);J=(m|0)/3|0;y=C(z[(o+(B(J,-3)+m|0)<<2)+68464>>2]*C(2097152>>>J|0))}z[f>>2]=y;g=g>>>1|0;f=f+4|0;continue}break}i=i+1|0;continue}break}i=w[n+769|0];f=w[n+768|0];f=f>>>0<i>>>0?i:f;while(1){if((f|0)!=(i|0)){t[((i<<1)+n|0)+771|0]=0;i=i+1|0;continue}break}}else{if((i|0)==(o|0)){k=w[g|0]+68336|0;o=w[g+2|0]+i|0;l=w[g+1|0];g=g+3|0}f=i<<1;h=w[Zd(j,l)+k|0];t[(f+n|0)+770|0]=h;m=w[n+769|0];if(m>>>0>i>>>0){h=w[Zd(j,l)+k|0];m=w[n+769|0]}t[((f|1)+n|0)+770|0]=m?h:0;i=i+1|0;continue}break}k=0;g=Jb(n+3852|0,0,4608);E=H+2304|0;F=n+8620|0;q=0;Z:{while(1){if((q|0)==3){break Z}K=((k<<2)+n|0)+3852|0;s=n+17152|0;i=0;J=v[N+16>>2]|1;D=(J|0)>0?J:0;m=576;while(1){if((i|0)!=4){h=K+(B(i,J)<<2)|0;l=0;while(1){if(w[n+768|0]<<1>>>0>l>>>0){_:{j=w[(l+n|0)+770|0];if(!j){break _}if(j>>>0<=16){o=(-1<<j-1)+1|0;f=0;while(1){if((f|0)==(D|0)){break _}sa=(f<<2)+h|0,ua=C(Zd(s,j)+o|0),z[sa>>2]=ua;f=f+1|0;continue}}j=2<<j-17;M=j>>>1|0;r=j|1;f=0;o=Zd(s,(j-(j>>>3|0)|0)+3|0);while(1){if((f|0)==(D|0)){break _}j=o;o=(o>>>0)/(r>>>0)|0;z[(f<<2)+h>>2]=j-(M+B(r,o)|0)|0;f=f+1|0;continue}}l=l+1|0;h=(m<<2)+h|0;m=18-m|0;continue}break}i=i+1|0;continue}break}k=(J<<2)+k|0;if((k|0)==12){k=(q<<2)+n|0;f=g;h=w[n+769|0];l=f+B(h,72)|0;gc(l+2304|0,l,B(w[n+768|0]-h|0,72));h=0;while(1){if(w[n+768|0]>h>>>0){i=0;while(1){if((i|0)!=12){l=(i<<2)+f|0;z[l>>2]=z[k>>2]*z[l>>2];l=l+2304|0;z[l>>2]=z[k+12>>2]*z[l>>2];i=i+1|0;continue}break}k=k+24|0;f=f+72|0;h=h+1|0;continue}break}cH(E,g,12,v[N+8>>2],aa,F);Jb(g,0,4608);aa=B(v[N+8>>2],768)+aa|0;k=0}q=q+1|0;if(v[n+17156>>2]<=v[n+17160>>2]){continue}break}Jy(H);q=0;break l}o=1}q=B(Bw(w[H+6153|0]),o)}ab=n+17168|0;f=v[p+4624>>2];if((f|0)<0|(f?0:q)|!(f|q)){break k}$:{if(f){g=v[p+4636>>2];if((g|0)!=(d|0)?d:0){break k}f=v[p+4632>>2];if((f|0)!=(c|0)?c:0){break k}if(f-3>>>0<4294967294|(g|0)<=0){break $}v[p+12>>2]=0;sa=p,ta=vc(ca,da),v[sa+8>>2]=ta;c=v[nj(p+4624|0,p+12|0,p+8|0)>>2];v[p+12>>2]=0;sa=p,ta=vc(ca,da),v[sa+8>>2]=ta;A=c+A|0;c=ca;d=v[nj(p+4624|0,p+12|0,p+8|0)>>2];ca=c-d|0;da=da-((d>>31)+(c>>>0<d>>>0)|0)|0;aa:{if(!q){break aa}v[22452]=0;c=p+16|0;Y(540,W|0,c|0,c+(B(f,q)<<1)|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break aa}A=V(88408)|0;if((O()|0)!=(fa(88408)|0)){break a}_(A|0)|0;v[22452]=0;X(17);h=v[22452];v[22452]=0;d=g;c=f;if((h|0)!=1){break k}A=P()|0;O()|0;break a}d=g;c=f}if((wc(v[W>>2],v[W+4>>2])>>>0)/(c>>>0)>>>0>268435456){break k}if(!!ca&(da|0)>=0|(da|0)>0){continue}break k}break}d=g;c=f}A=0;ba:{if(!d|!c){break ba}f=v[W>>2];g=v[W+4>>2];if(jc(f,g)){break ba}if((wc(f,g)>>>0)/(c>>>0)>>>0>268435456){break ba}Ls(a,b);if(!e){v[22452]=0;f=Q(55,p+16|0,21598)|0;g=v[22452];v[22452]=0;if((g|0)==1){break b}sc(((b<<5)+a|0)+946304|0,f);pb(f);v[22452]=0;f=B(b,104)+a|0;R(271,f+484380|0,0);g=v[22452];v[22452]=0;if((g|0)==1){break c}v[f+484404>>2]=d}d=B(b,104)+a|0;b=d+484380|0;sa=b,ta=(wc(v[W>>2],v[W+4>>2])>>>0)/(c>>>0)|0,v[sa>>2]=ta;g=d+484414|0;f=x[g>>1];u[g>>1]=(c|0)==2?f|65:f&65470|1;sg(b);if(Fd(b)){zn(wb(v[W>>2]),wb(v[W+4>>2]),v[d+484400>>2])}if(!e){Ws(b,v[a+480180>>2]);ii(b,a)}A=Fd(b)}_c(W);rc(p+11336|0)}ab=p+11360|0;return A|0}A=P()|0;O()|0;break a}A=P()|0;O()|0}_c(W);rc(p+11336|0);S(A|0);L()}function Wz(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),A=0,E=0,F=0,G=0,I=C(0),J=0,K=0,M=0,N=0,O=C(0);r=ab-1520|0;ab=r;e=r+8|0;M=Jb(e,0,1512),N=-1,v[M+1420>>2]=N;t[r+56|0]=1;v[r+48>>2]=a+b;v[r+40>>2]=a;l=ab-1024|0;ab=l;t[e+1377|0]=1;a:{if(!Gr(e)){break a}b=w[e+1375|0];if(!(b&2)){Vb(e,34);break a}if(b&4){Vb(e,34);break a}if(b&1){Vb(e,34);break a}if(v[e+1116>>2]!=1){Vb(e,34);break a}b=w[e+1120|0];if((b|0)!=30){b:{if((b|0)!=64){break b}if(!ww(e,l+1018|0,6)|w[l+1018|0]!=102|(w[l+1019|0]!=105|w[l+1020|0]!=115)){break b}if(w[l+1021|0]!=104|w[l+1022|0]!=101|w[l+1023|0]!=97){break b}if((De(e)|0)!=100){break b}if(De(e)){break b}Vb(e,38);break a}Vb(e,34);break a}if((De(e)|0)!=1){Vb(e,34);break a}if(!ww(e,l+1018|0,6)){Vb(e,10);break a}if(!uw(l+1018|0)){Vb(e,34);break a}if(Si(e)){Vb(e,34);break a}b=De(e);v[e+4>>2]=b;if(!b){Vb(e,34);break a}if(b>>>0>=17){Vb(e,5);break a}b=Si(e);v[e>>2]=b;if(!b){Vb(e,34);break a}Si(e);Si(e);Si(e);b=De(e);i=b>>>4|0;v[e+116>>2]=1<<i;g=b&15;v[e+112>>2]=1<<g;if(g-14>>>0<=4294967287){Vb(e,20);break a}if((b<<24)+536870912>>24>=0){Vb(e,20);break a}c:{if(g>>>0>i>>>0){Vb(e,20);break c}if(!(De(e)&1)){Vb(e,34);break c}if(!Gr(e)){break a}if(!vw(e)){break a}if(!xw(e)){break a}if((ah(e)|0)==3){while(1){if((f|0)!=6){M=(l+1018|0)+f|0,N=ah(e),t[M|0]=N;f=f+1|0;continue}break}if(!uw(l+1018|0)){Vb(e,20);break c}b=tw(e);f=Yd(e,b+1|0);v[e+20>>2]=f;if(f){f=0;g=(b|0)>0?b:0;while(1){if((f|0)!=(g|0)){i=ah(e);t[v[e+20>>2]+f|0]=i;f=f+1|0;continue}break}t[b+v[e+20>>2]|0]=0;b=tw(e);v[e+28>>2]=0;v[e+24>>2]=b;d:{if((b|0)<=0){break d}b=Yd(e,b<<2);v[e+28>>2]=b;if(b){break d}Vb(e,3);break c}while(1){e:{f:{if(v[e+24>>2]>(h|0)){b=tw(e);f=Yd(e,b+1|0);g=h<<2;v[g+v[e+28>>2]>>2]=f;if(!v[g+v[e+28>>2]>>2]){break f}f=0;i=(b|0)>0?b:0;while(1){if((f|0)==(i|0)){break e}j=ah(e);t[v[g+v[e+28>>2]>>2]+f|0]=j;f=f+1|0;continue}}if(!(ah(e)&1)){Vb(e,20);break c}QG(e,w[e+1376|0]);t[e+1376|0]=0;while(1){b=xw(e);QG(e,b);t[e+1376|0]=0;if(b){continue}break}f=0;if(!vw(e)){break a}if(!XG(e)){if(v[e+100>>2]!=21){break a}v[e+100>>2]=20;break a}b=0;while(1){if((b|0)!=256){h=b<<24;i=0;while(1){if((i|0)!=8){h=h>>31&79764919^h<<1;i=i+1|0;continue}break}v[(b<<2)+458688>>2]=h;b=b+1|0;continue}break}if((ah(e)|0)==5){while(1){if((f|0)!=6){M=(l+1018|0)+f|0,N=ah(e),t[M|0]=N;f=f+1|0;continue}break}if(!uw(l+1018|0)){Vb(e,20);break c}b=hc(e,8)+1|0;v[e+120>>2]=b;b=Yd(e,B(b,2096));v[e+124>>2]=b;if(!b){Vb(e,3);break c}Jb(b,0,B(v[e+120>>2],2096));g:{h:{while(1){i:{if(v[e+120>>2]>(p|0)){b=v[e+124>>2];if((hc(e,8)&255)!=66){Vb(e,20);break c}if((hc(e,8)&255)!=67){Vb(e,20);break c}if((hc(e,8)&255)!=86){Vb(e,20);break c}g=b+B(p,2096)|0;M=g,N=hc(e,8)&255|hc(e,8)<<8,v[M>>2]=N;M=g,N=hc(e,8)&255|(hc(e,8)<<8&65280|hc(e,8)<<16),v[M+4>>2]=N;m=g+4|0;f=0;k=hc(e,1);if(!k){f=hc(e,1)}t[g+23|0]=f;h=v[m>>2];if(v[g>>2]){b=h;break i}b=0;if(!h){break i}Vb(e,20);break c}b=hc(e,6)+1&255;f=0;j:{while(1){if((b|0)==(f|0)){break j}f=f+1|0;if(!hc(e,16)){continue}break}Vb(e,20);break c}b=hc(e,6)+1|0;v[e+128>>2]=b;b=Yd(e,B(b,1596));v[e+260>>2]=b;k:{if(b){k=0;m=0;l:while(1){if(v[e+128>>2]<=(m|0)){break k}b=hc(e,16);u[((m<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){Vb(e,20);break c}if(!b){b=v[e+260>>2]+B(m,1596)|0;M=b,N=hc(e,8),t[M|0]=N;M=b,N=hc(e,16),u[M+2>>1]=N;M=b,N=hc(e,16),u[M+4>>1]=N;M=b,N=hc(e,6),t[M+6|0]=N;M=b,N=hc(e,8),t[M+7|0]=N;i=hc(e,4)+1|0;t[b+8|0]=i;h=b+9|0;f=0;while(1){if((i&255)>>>0>f>>>0){M=f+h|0,N=hc(e,8),t[M|0]=N;f=f+1|0;i=w[b+8|0];continue}break}Vb(e,4);break c}g=v[e+260>>2]+B(m,1596)|0;b=hc(e,5);t[g|0]=b;f=0;i=-1;while(1)if((b&255)>>>0<=f>>>0){i=i+1|0;b=0;while(1){if((b|0)!=(i|0)){h=b+g|0;M=h,N=hc(e,3)+1|0,t[M+33|0]=N;j=hc(e,2);t[h+49|0]=j;f=0;m:{if(!(j&255)){break m}j=hc(e,8);t[h+65|0]=j;if(v[e+120>>2]>(j&255)){break m}Vb(e,20);break c}n:{while(1){if(1<<w[h+49|0]<=(f|0)){break n}j=hc(e,8)-1|0;u[((g+(b<<4)|0)+(f<<1)|0)+82>>1]=j;f=f+1|0;if(v[e+120>>2]>j<<16>>16){continue}break}Vb(e,20);break c}b=b+1|0;continue}break}b=2;M=g,N=hc(e,2)+1|0,t[M+1588|0]=N;f=hc(e,4);v[g+1592>>2]=2;h=0;u[g+338>>1]=0;t[g+1589|0]=f;u[g+340>>1]=1<<f;f=g+1592|0;n=g+338|0;p=g+1589|0;j=0;while(1){if(w[g|0]>j>>>0){o=g+w[(g+j|0)+1|0]|0;i=0;while(1){if(w[o+33|0]>i>>>0){b=hc(e,w[p|0]);u[(g+(v[f>>2]<<1)|0)+338>>1]=b;b=v[f>>2]+1|0;v[f>>2]=b;i=i+1|0;continue}break}j=j+1|0;continue}break}while(1){if((b|0)>(h|0)){b=x[(g+(h<<1)|0)+338>>1];i=(l+16|0)+(h<<2)|0;u[i+2>>1]=h;u[i>>1]=b;h=h+1|0;b=v[f>>2];continue}break}PG(l+16|0,b,1070);i=0;b=v[f>>2];h=b-1|0;j=(h|0)>0?h:0;h=0;o:{while(1){if((h|0)==(j|0)){break o}p=l+16|0;o=x[p+(h<<2)>>1];h=h+1|0;if((o|0)!=x[p+(h<<2)>>1]){continue}break}Vb(e,20);break c}while(1){if((b|0)>(i|0)){t[(g+i|0)+838|0]=w[((l+16|0)+(i<<2)|0)+2|0];i=i+1|0;b=v[f>>2];continue}break}i=2;while(1){if((b|0)>(i|0)){v[l+12>>2]=0;v[l+8>>2]=0;b=0;F=(i|0)>0?i:0;j=n+(i<<1)|0;o=65536;p=-1;while(1){if((b|0)!=(F|0)){q=n+(b<<1)|0;h=x[q>>1];if(!((p|0)>=(h|0)|x[j>>1]<=h>>>0)){v[l+12>>2]=b;h=x[q>>1];p=h}if(!((h|0)>=(o|0)|x[j>>1]>=h>>>0)){v[l+8>>2]=b;o=x[q>>1]}b=b+1|0;continue}break}b=g+(i<<1)|0;t[b+1088|0]=v[l+12>>2];t[b+1089|0]=v[l+8>>2];i=i+1|0;b=v[f>>2];continue}break}k=(b|0)>(k|0)?b:k;m=m+1|0;continue l}else{b=hc(e,4);t[(f+g|0)+1|0]=b;b=b&255;i=(b|0)>(i|0)?b:i;f=f+1|0;b=w[g|0];continue}}}Vb(e,3);break c}b=hc(e,6)+1|0;v[e+264>>2]=b;b=Yd(e,B(b,24));v[e+396>>2]=b;if(!b){Vb(e,3);break c}j=0;Jb(b,0,B(v[e+264>>2],24));p:{q:{r:{s:{while(1){if(v[e+264>>2]>(j|0)){b=v[e+396>>2];h=hc(e,16);u[((j<<1)+e|0)+268>>1]=h;if((h&65535)>>>0>=3){Vb(e,20);break c}g=b+B(j,24)|0;M=g,N=hc(e,24),v[M>>2]=N;b=hc(e,24);v[g+4>>2]=b;if(b>>>0<y[g>>2]){Vb(e,20);break c}M=g,N=hc(e,24)+1|0,v[M+8>>2]=N;M=g,N=hc(e,6)+1|0,t[M+12|0]=N;b=hc(e,8);t[g+13|0]=b;if(v[e+120>>2]<=(b&255)){break r}f=0;while(1){b=w[g+12|0];if(b>>>0>f>>>0){h=(l+16|0)+f|0;i=hc(e,3);if(hc(e,1)){b=hc(e,5)}else{b=0}t[h|0]=i+(b<<3);f=f+1|0;continue}break}b=Yd(e,b<<4);v[g+20>>2]=b;if(!b){break q}h=0;while(1){if(w[g+12|0]>h>>>0){b=w[(l+16|0)+h|0];f=0;while(1){if((f|0)!=8){t:{if(b>>>f&1){i=hc(e,8);n=f<<1;m=h<<4;u[n+(m+v[g+20>>2]|0)>>1]=i;if(v[e+120>>2]>u[n+(m+v[g+20>>2]|0)>>1]){break t}Vb(e,20);break c}u[(v[g+20>>2]+(h<<4)|0)+(f<<1)>>1]=65535}f=f+1|0;continue}break}h=h+1|0;continue}break}h=Yd(e,v[(v[e+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);v[g+16>>2]=h;if(!h){Vb(e,3);break c}b=0;Jb(h,0,v[(v[e+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);while(1){h=v[e+124>>2]+B(w[g+13|0],2096)|0;if(v[h+4>>2]>(b|0)){f=v[h>>2];i=Yd(e,f);h=b<<2;v[h+v[g+16>>2]>>2]=i;i=b;if(!v[h+v[g+16>>2]>>2]){break s}while(1){if((f|0)>0){f=f-1|0;t[f+v[h+v[g+16>>2]>>2]|0]=(i|0)%w[g+12|0];i=(i|0)/w[g+12|0]|0;continue}break}b=b+1|0;continue}break}j=j+1|0;continue}break}b=hc(e,6)+1|0;v[e+400>>2]=b;b=Yd(e,B(b,40));v[e+404>>2]=b;if(!b){Vb(e,3);break c}Jb(b,0,B(v[e+400>>2],40));j=0;while(1){if(v[e+400>>2]>(j|0)){b=v[e+404>>2];if(hc(e,16)){Vb(e,20);break c}g=b+B(j,40)|0;b=Yd(e,B(v[e+4>>2],3));v[g+4>>2]=b;if(!b){Vb(e,3);break c}if(hc(e,1)){b=hc(e,4)+1|0}else{b=1}t[g+8|0]=b;u:{if(hc(e,1)){b=hc(e,8)+1|0;u[g>>1]=b;f=0;h=v[e+4>>2];if((h|0)<(b&65535)){Vb(e,20);break c}while(1){if((b&65535)>>>0<=f>>>0){break u}h=hc(e,Bl(h-1|0));b=B(f,3);t[b+v[g+4>>2]|0]=h;h=hc(e,Bl(v[e+4>>2]-1|0));t[(b+v[g+4>>2]|0)+1|0]=h;h=v[e+4>>2];b=b+v[g+4>>2]|0;i=w[b|0];if((h|0)<=(i|0)){Vb(e,20);break c}b=w[b+1|0];if((b|0)>=(h|0)){Vb(e,20);break c}if((b|0)!=(i|0)){f=f+1|0;b=x[g>>1];continue}break}Vb(e,20);break c}u[g>>1]=0}if(hc(e,2)){Vb(e,20);break c}h=0;b=0;f=0;v:{if(w[g+8|0]>=2){while(1){if(v[e+4>>2]<=(b|0)){break v}f=hc(e,4);i=B(b,3);t[(i+v[g+4>>2]|0)+2|0]=f;b=b+1|0;if(w[(i+v[g+4>>2]|0)+2|0]<w[g+8|0]){continue}break}Vb(e,20);break c}while(1){if(v[e+4>>2]<=(f|0)){break v}t[(v[g+4>>2]+B(f,3)|0)+2|0]=0;f=f+1|0;continue}}w:{while(1){if(w[g+8|0]<=h>>>0){break w}hc(e,8);b=g+h|0;M=b,N=hc(e,8),t[M+9|0]=N;f=hc(e,8);t[b+24|0]=f;if(v[e+128>>2]<=w[b+9|0]){Vb(e,20);break c}h=h+1|0;if(v[e+264>>2]>(f&255)){continue}break}Vb(e,20);break c}j=j+1|0;continue}break}f=hc(e,6)+1|0;v[e+408>>2]=f;i=0;x:{while(1){if((f|0)<=(i|0)){break x}b=B(i,6)+e|0;M=b,N=hc(e,1),t[M+412|0]=N;M=b,N=hc(e,16),u[M+414>>1]=N;M=b,N=hc(e,16),u[M+416>>1]=N;h=hc(e,8);t[b+413|0]=h;if(x[b+414>>1]){Vb(e,20);break c}if(x[b+416>>1]){Vb(e,20);break c}if(v[e+400>>2]>(h&255)){i=i+1|0;f=v[e+408>>2];continue}break}Vb(e,20);break c}VG(e);v[e+992>>2]=0;h=k<<1;f=0;while(1){if(v[e+4>>2]>(f|0)){b=(f<<2)+e|0;M=b,N=Yd(e,v[e+116>>2]<<2),v[M+800>>2]=N;M=b,N=Yd(e,v[e+116>>2]<<1&2147483646),v[M+928>>2]=N;g=Yd(e,h);v[b+996>>2]=g;i=v[b+800>>2];if(g?!i|!v[b+928>>2]:1){Vb(e,3);break c}Jb(i,0,v[e+116>>2]<<2);f=f+1|0;continue}break}f=0;if(!OG(e,0,v[e+112>>2])){break a}if(!OG(e,1,v[e+116>>2])){break a}v[e+104>>2]=v[e+112>>2];g=v[e+116>>2];v[e+108>>2]=g;b=v[e+264>>2];j=(b|0)>0?b:0;b=(g|0)/2|0;h=0;while(1){if((f|0)!=(j|0)){i=v[e+396>>2]+B(f,24)|0;k=v[i+4>>2];p=b>>>0>k>>>0?k:b;k=v[i>>2];i=(p-(b>>>0>k>>>0?k:b)>>>0)/y[i+8>>2]|0;h=(h|0)<(i|0)?i:h;f=f+1|0;continue}break}b=g<<1&2147483646;h=B(v[e+4>>2],(h<<2)+4|0);b=b>>>0>h>>>0?b:h;v[e+12>>2]=b;y:{if(!v[e+80>>2]){break y}h=v[e+92>>2];if((h|0)!=v[e+84>>2]){break p}if(h>>>0>=(b+v[e+88>>2]|0)+1512>>>0){break y}Vb(e,3);break c}if(v[e+1380>>2]==-1){v[e+52>>2]=w[e+48|0]?0:v[e+32>>2]-v[e+36>>2]|0;f=1;break a}v[e+52>>2]=0;f=1;break a}Vb(e,3);break c}Vb(e,20);break c}Vb(e,3);break c}ca(7262,13164,4196,8800);L()}z:{if(f&255){i=Ym(e,b);break z}i=Yd(e,b);v[g+8>>2]=i}if(!i){Vb(e,3);break c}j=0;A:{if(!k){f=0;while(1){b=v[m>>2];if((f|0)>=(b|0)){break A}B:{C:{if(w[g+23|0]){if(!hc(e,1)){break C}}b=hc(e,5)+1|0;t[f+i|0]=b;if((b&255)!=32){j=j+1|0;break B}Vb(e,20);break c}t[f+i|0]=255}f=f+1|0;continue}}h=hc(e,5);f=0;while(1){b=v[m>>2];if((f|0)>=(b|0)){break A}k=hc(e,Bl(b-f|0));h=h+1|0;if((h|0)>=32){Vb(e,20);break c}b=f+k|0;if((b|0)>v[m>>2]){Vb(e,20);break c}else{Jb(f+i|0,h,k);f=b;continue}}}D:{E:{F:{if(w[g+23|0]){if(b>>2>(j|0)){break F}if(v[e+16>>2]<(b|0)){v[e+16>>2]=b;b=v[m>>2]}b=Yd(e,b);v[g+8>>2]=b;if(!b){Vb(e,3);break c}gc(b,i,v[m>>2]);Ri(e,i,v[m>>2]);i=v[g+8>>2];t[g+23|0]=0;b=v[m>>2]}h=0;j=(b|0)>0?b:0;f=0;while(1){if((f|0)!=(j|0)){h=((w[f+i|0]-11&255)>>>0<244)+h|0;f=f+1|0;continue}break}v[g+2092>>2]=h;b=Yd(e,b<<2);v[g+32>>2]=b;if(b){k=g+2092|0;f=0;break E}Vb(e,3);break c}v[g+2092>>2]=j;k=g+2092|0;G:{if(!j){f=0;h=0;break G}b=Yd(e,j);v[g+8>>2]=b;if(!b){Vb(e,3);break c}b=Ym(e,v[k>>2]<<2);v[g+32>>2]=b;if(!b){Vb(e,3);break c}f=Ym(e,v[k>>2]<<2);if(!f){break D}b=v[m>>2];h=v[k>>2]}b=(h<<3)+b|0;if(b>>>0<=y[e+16>>2]){break E}v[e+16>>2]=b}n=v[m>>2];b=0;h=ab-128|0;ab=h;o=Jb(h,0,128);h=(n|0)>0?n:0;while(1){H:{I:{if((b|0)!=(h|0)){if(w[b+i|0]==255){break I}h=b}if((h|0)==(n|0)){b=1;if(!v[g+2092>>2]){break H}ca(15677,13164,1103,7506);L()}b=h+i|0;j=w[b|0];if(j>>>0<32){MG(g,0,h,0,j,f);q=1;j=w[b|0]+1|0;b=1;J:{while(1){if((b|0)==(j|0)){K:while(1){L:{b=1;h=h+1|0;if((n|0)<=(h|0)){break H}E=h+i|0;j=w[E|0];if((j|0)==255){continue}b=j;if(b>>>0>=32){break L}while(1){if((b|0)<=0){b=0;break H}G=o+(b<<2)|0;F=v[G>>2];if(!F){b=b-1|0;continue}break}v[G>>2]=0;MG(g,zl(F),h,q,j,f);q=q+1|0;j=w[E|0];if((j|0)==(b|0)){continue}while(1){if((b|0)>=(j|0)){continue K}E=o+(j<<2)|0;if(v[E>>2]){break J}v[E>>2]=F+(1<<32-j);j=j-1|0;continue}}break}}else{v[o+(b<<2)>>2]=1<<32-b;b=b+1|0;continue}break}ca(15142,13164,1118,7506);L()}ca(15721,13164,1133,7506);L()}ca(15149,13164,1104,7506);L()}b=b+1|0;continue}break}ab=o+128|0;if(!b){if(w[g+23|0]){Ri(e,f,0)}Vb(e,20);break c}b=v[k>>2];if(b){b=Yd(e,(b<<2)+4|0);v[g+2084>>2]=b;if(!b){Vb(e,3);break c}b=Yd(e,(v[k>>2]<<2)+4|0);v[g+2088>>2]=b;if(!b){Vb(e,3);break c}v[g+2088>>2]=b+4;v[b>>2]=-1;b=0;j=0;M:{N:{O:{if(w[g+23|0]){while(1){j=v[g+2092>>2];if((j|0)<=(b|0)){break O}h=b<<2;M=h+v[g+2084>>2]|0,N=zl(v[h+v[g+32>>2]>>2]),v[M>>2]=N;b=b+1|0;continue}}while(1){if(v[g+4>>2]>(b|0)){if(LG(w[g+23|0],w[b+i|0])){M=v[g+2084>>2]+(j<<2)|0,N=zl(v[v[g+32>>2]+(b<<2)>>2]),v[M>>2]=N;j=j+1|0}b=b+1|0;continue}break}if(v[g+2092>>2]!=(j|0)){break N}}PG(v[g+2084>>2],j,1071);v[v[g+2084>>2]+(v[g+2092>>2]<<2)>>2]=-1;h=0;b=v[g+(w[g+23|0]?2092:4)>>2];F=(b|0)>0?b:0;P:{while(1){if((h|0)!=(F|0)){b=h;j=w[g+23|0];b=j?v[(b<<2)+f>>2]:b;E=w[b+i|0];Q:{if(!LG(j,E)){break Q}G=h<<2;n=zl(v[G+v[g+32>>2]>>2]);b=v[g+2092>>2];j=0;while(1){if((b|0)>=2){o=b>>>1|0;J=o+j|0;q=n>>>0<y[v[g+2084>>2]+(J<<2)>>2];b=q?o:b-o|0;j=q?j:J;continue}break}b=j<<2;if((n|0)!=v[b+v[g+2084>>2]>>2]){break P}if(w[g+23|0]){v[b+v[g+2088>>2]>>2]=v[f+G>>2];t[v[g+8>>2]+j|0]=E;break Q}v[b+v[g+2088>>2]>>2]=h}h=h+1|0;continue}break}break M}ca(12205,13164,1230,9943);L()}ca(7447,13164,1200,9943);L()}}if(w[g+23|0]){Ri(e,f,v[k>>2]<<2);Ri(e,v[g+32>>2],v[k>>2]<<2);Ri(e,i,v[m>>2]);v[g+32>>2]=0}b=0;f=0;while(1){if((b|0)!=1024){u[(g+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=v[g+(w[g+23|0]?2092:4)>>2];b=(b|0)<32767?b:32767;h=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){R:{if(w[v[g+8>>2]+f|0]>10){break R}S:{if(w[g+23|0]){b=zl(v[v[g+2084>>2]+(f<<2)>>2]);break S}b=v[v[g+32>>2]+(f<<2)>>2]}while(1){if(b>>>0>1023){break R}u[(g+(b<<1)|0)+36>>1]=f;b=(1<<w[v[g+8>>2]+f|0])+b|0;continue}}f=f+1|0;continue}break}b=hc(e,4);t[g+21|0]=b;b=b&255;if(b>>>0>=3){Vb(e,20);break c}if(b){M=g,O=NG(hc(e,32)),z[M+12>>2]=O;M=g,O=NG(hc(e,32)),z[M+16>>2]=O;M=g,N=hc(e,4)+1|0,t[M+20|0]=N;M=g,N=hc(e,1),t[M+22|0]=N;f=v[g>>2];h=v[m>>2];T:{if(w[g+21|0]==1){A=H(dx(+C(C(So(+C(h|0)))/C(f|0))));U:{if(D(A)<2147483648){b=~~A;break U}b=-2147483648}A=+(f|0);K=H(Gj(+C(C(b|0)+C(1)),A));V:{if(D(K)<2147483648){f=~~K;break V}f=-2147483648}b=((f|0)<=(h|0))+b|0;s=C(b|0);if(Gj(+C(s+C(1)),A)<=+(h|0)){f=-1}else{A=H(Gj(+s,A));W:{if(D(A)<2147483648){f=~~A;break W}f=-2147483648}f=(f|0)>(h|0)?-1:b}if((f|0)>=0){break T}Vb(e,20);break c}f=B(f,h)}v[g+24>>2]=f;if(!f){Vb(e,20);break c}n=Ym(e,f<<1);if(!n){break h}f=0;while(1){i=v[g+24>>2];if((i|0)>(f|0)){b=hc(e,w[g+20|0]);if((b|0)==-1){Ri(e,n,v[g+24>>2]<<1);Vb(e,20);break c}else{u[n+(f<<1)>>1]=b;f=f+1|0;continue}}break}X:{Y:{if(w[g+21|0]==1){o=w[g+23|0];Z:{if(o){f=v[k>>2];if(f){break Z}break X}f=v[m>>2]}b=Yd(e,B(v[g>>2],f)<<2);v[g+28>>2]=b;if(!b){Ri(e,n,v[g+24>>2]<<1);Vb(e,3);break c}h=0;b=v[(o?k:m)>>2];m=(b|0)>0?b:0;q=g+2088|0;s=C(0);while(1){if((h|0)==(m|0)){break Y}j=o?v[v[q>>2]+(h<<2)>>2]:h;i=v[g>>2];f=0;b=1;while(1){if((f|0)<(i|0)){I=C(s+C(C(C(x[n+(((j>>>0)/(b>>>0)>>>0)%y[g+24>>2]<<1)>>1])*z[g+16>>2])+z[g+12>>2]));z[v[g+28>>2]+(B(h,i)+f<<2)>>2]=I;s=w[g+22|0]?I:s;f=f+1|0;i=v[g>>2];if((f|0)>=(i|0)){continue}k=v[g+24>>2];oia(k,0,b,0);if(db){Ri(e,n,k<<1);Vb(e,20);break c}else{b=B(b,k);continue}}break}h=h+1|0;continue}}b=Yd(e,i<<2);v[g+28>>2]=b;if(!b){break g}f=0;s=C(0);while(1){i=v[g+24>>2];if((i|0)<=(f|0)){break X}I=C(s+C(C(C(x[n+(f<<1)>>1])*z[g+16>>2])+z[g+12>>2]));z[v[g+28>>2]+(f<<2)>>2]=I;s=w[g+22|0]?I:s;f=f+1|0;continue}}t[g+21|0]=2;i=v[g+24>>2]}Ri(e,n,i<<1)}p=p+1|0;continue}break}Vb(e,3);break c}Vb(e,3);break c}Ri(e,n,v[g+24>>2]<<1);Vb(e,3);break c}Vb(e,20);break c}Vb(e,3);break c}t[b+v[v[e+28>>2]+(h<<2)>>2]|0]=0;h=h+1|0;continue}}Vb(e,3);break c}Vb(e,20)}f=0}ab=l+1024|0;_:{$:{if(!f){v[d>>2]=v[r+104>>2]?1:v[r+108>>2];break $}b=Yd(r+8|0,1512);if(b){M=c,N=v[gc(b,r+8|0,1512)+32>>2]-a|0,v[M>>2]=N;v[d>>2]=0;break _}}YG(r+8|0);b=0}ab=r+1520|0;return b}function HF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0;s=ab-48|0;ab=s;a:{if(c>>>0<=2){c=c<<2;F=v[c+75532>>2];H=v[c+75520>>2];while(1){c=v[b+4>>2];b:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=cd(b)}if(uk(c)){continue}break}n=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}n=(c|0)==45?-1:1;c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=cd(b)}e:{f:{while(1){if(t[g+4913|0]==(c|32)){g:{if(g>>>0>6){break g}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=cd(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){v[b+4>>2]=v[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}l=ab-16|0;ab=l;i=(p(C(C(n|0)*C(N))),j(2));b=i&2147483647;h:{if(b-8388608>>>0<=2130706431){n=b<<25;c=(b>>>7|0)+1065353216|0;break h}n=i<<25;c=i>>>7|2147418112;if(b>>>0>=2139095040){break h}n=0;c=0;if(!b){break h}c=b;b=E(b);zf(l,c,0,0,0,b+81|0);h=v[l>>2];k=v[l+4>>2];n=v[l+8>>2];c=v[l+12>>2]^65536|16265-b<<16}v[s>>2]=h;v[s+4>>2]=k;v[s+8>>2]=n;v[s+12>>2]=i&-2147483648|c;ab=l+16|0;D=v[s+8>>2];z=v[s+12>>2];h=v[s>>2];k=v[s+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(t[g+9939|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=cd(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=v[b+4>>2];o:{if((g|0)!=v[b+104>>2]){v[b+4>>2]=g+1;f=w[g|0];break o}f=cd(b)}if((f&-33)==88){c=0;f=ab-432|0;ab=f;p:{q:{g=b;b=v[b+4>>2];if(v[g+104>>2]!=(b|0)){v[g+4>>2]=b+1;c=w[b|0];break q}b=0;break p}b=1}while(1){r:{s:{t:{u:{v:{w:{x:{y:{if(!b){c=cd(g);break y}if((c|0)!=48){z=1073676288;if((c|0)==46){break w}break v}b=v[g+4>>2];if((b|0)==v[g+104>>2]){break x}o=1;v[g+4>>2]=b+1;c=w[b|0]}b=1;continue}o=1;break s}b=v[g+4>>2];z:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break z}c=cd(g)}if((c|0)==48){break u}G=1}break t}while(1){b=h;h=b-1|0;k=k-!b|0;G=1;b=v[g+4>>2];A:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break A}c=cd(g)}if((c|0)==48){continue}break}o=1}while(1){L=c|32;B:{C:{M=c-48|0;if(M>>>0<10){break C}if(!((c|0)==46|L-97>>>0<6)){b=c;break r}b=46;if((c|0)!=46){break C}if(G){break r}G=1;h=l;k=i;break B}b=(c|0)>57?L-87|0:M;D:{if((i|0)<=0&l>>>0<=7|(i|0)<0){q=b+(q<<4)|0;break D}if(!i&l>>>0<=28){Fg(f+48|0,b);wd(f+32|0,m,A,D,z,0,0,0,1073414144);m=v[f+32>>2];A=v[f+36>>2];D=v[f+40>>2];z=v[f+44>>2];wd(f+16|0,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2],m,A,D,z);og(f,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2],r,e,u,x);u=v[f+8>>2];x=v[f+12>>2];r=v[f>>2];e=v[f+4>>2];break D}if(!b|I){break D}wd(f+80|0,m,A,D,z,0,0,0,1073610752);og(f- -64|0,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2],r,e,u,x);u=v[f+72>>2];x=v[f+76>>2];I=1;r=v[f+64>>2];e=v[f+68>>2]}b=l+1|0;i=b?i:i+1|0;l=b;o=1}b=v[g+4>>2];if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0]}else{c=cd(g)}continue}}b=0;continue}break}E:{if(!o){b=v[g+116>>2];F:{G:{if((b|0)>0|(b|0)>=0){b=v[g+4>>2];v[g+4>>2]=b-1;if(!d){break G}v[g+4>>2]=b-2;if(!G){break F}v[g+4>>2]=b-3;break F}if(d){break F}}Th(g,0,0)}Ni(f+96|0,+(n|0)*0);r=v[f+96>>2];e=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2];break E}if((i|0)<=0&l>>>0<=7|(i|0)<0){D=l;z=i;while(1){q=q<<4;m=z;c=D+1|0;m=c?m:m+1|0;D=c;z=m;if((c|0)!=8|m){continue}break}}H:{I:{J:{if((b&-33)==80){D=GF(g,d);b=db;z=b;if(D|(b|0)!=-2147483648){break H}if(d){b=v[g+116>>2];if((b|0)>0|(b|0)>=0){break J}break I}r=0;e=0;Th(g,0,0);c=0;b=0;break E}D=0;z=0;if(v[g+116>>2]<0){break H}}v[g+4>>2]=v[g+4>>2]-1}D=0;z=0}if(!q){Ni(f+112|0,+(n|0)*0);r=v[f+112>>2];e=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break E}b=G?h:l;i=(G?k:i)<<2|b>>>30;b=D+(b<<2)|0;d=i+z|0;d=b>>>0<D>>>0?d+1|0:d;l=b-32|0;i=d-(b>>>0<32)|0;b=i;if(l>>>0>0-F>>>0&(b|0)>=0|(b|0)>0){v[114934]=68;Fg(f+160|0,n);wd(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);wd(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);r=v[f+128>>2];e=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break E}b=F-226|0;c=b>>31;if((i|0)>=(c|0)&b>>>0<=l>>>0|(c|0)<(i|0)){if((q|0)>=0){while(1){og(f+416|0,r,e,u,x,0,0,0,-1073807360);c=wA(r,e,u,x,1073610752);b=(c|0)<0;og(f+400|0,r,e,u,x,b?r:v[f+416>>2],b?e:v[f+420>>2],b?u:v[f+424>>2],b?x:v[f+428>>2]);b=l;l=b-1|0;i=i-!b|0;u=v[f+408>>2];x=v[f+412>>2];r=v[f+400>>2];e=v[f+404>>2];q=q<<1|(c|0)>=0;if((q|0)>=0){continue}break}}d=i-((F>>31)+(l>>>0<F>>>0)|0)|0;b=(l-F|0)+32|0;d=b>>>0<32?d+1|0:d;c=b>>>0<H>>>0&(d|0)<=0|(d|0)<0?(b|0)>0?b:0:H;K:{if((c|0)>=113){Fg(f+384|0,n);h=v[f+392>>2];k=v[f+396>>2];m=v[f+384>>2];A=v[f+388>>2];i=0;b=0;break K}Ni(f+352|0,xj(1,144-c|0));Fg(f+336|0,n);m=v[f+336>>2];A=v[f+340>>2];h=v[f+344>>2];k=v[f+348>>2];JF(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],m,A,h,k);J=v[f+376>>2];K=v[f+380>>2];i=v[f+372>>2];b=v[f+368>>2]}c=!(q&1)&(($l(r,e,u,x,0,0,0,0)|0)!=0&(c|0)<32);Pm(f+320|0,c+q|0);wd(f+304|0,m,A,h,k,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);d=b;og(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,i,J,K);b=c;wd(f+288|0,m,A,h,k,b?0:r,b?0:e,b?0:u,b?0:x);og(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);Ax(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],d,i,J,K);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];h=v[f+252>>2];if(!$l(b,c,d,h,0,0,0,0)){v[114934]=68}IF(f+224|0,b,c,d,h,l);r=v[f+224>>2];e=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break E}v[114934]=68;Fg(f+208|0,n);wd(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);wd(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);r=v[f+176>>2];e=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2]}v[s+16>>2]=r;v[s+20>>2]=e;v[s+24>>2]=b;v[s+28>>2]=c;ab=f+432|0;D=v[s+24>>2];z=v[s+28>>2];h=v[s+16>>2];k=v[s+20>>2];break a}if(v[b+116>>2]<0){break n}v[b+4>>2]=v[b+4>>2]-1}f=b;r=n;n=0;g=0;e=ab-8976|0;ab=e;G=F+H|0;L=0-G|0;L:{M:{while(1){if((c|0)!=48){N:{if((c|0)!=46){break L}b=v[f+4>>2];if((b|0)==v[f+104>>2]){break N}v[f+4>>2]=b+1;c=w[b|0];break M}}else{b=v[f+4>>2];if((b|0)!=v[f+104>>2]){n=1;v[f+4>>2]=b+1;c=w[b|0]}else{n=1;c=cd(f)}continue}break}c=cd(f)}o=1;if((c|0)!=48){break L}while(1){b=h;h=b-1|0;k=k-!b|0;b=v[f+4>>2];O:{if((b|0)!=v[f+104>>2]){v[f+4>>2]=b+1;c=w[b|0];break O}c=cd(f)}if((c|0)==48){continue}break}n=1}v[e+784>>2]=0;P:{Q:{b=(c|0)==46;m=c-48|0;R:{S:{T:{U:{if(!(!b&m>>>0>9)){while(1){V:{if(b&1){if(!o){h=l;k=i;o=1;break V}b=!n;break U}b=l+1|0;i=b?i:i+1|0;l=b;if((g|0)<=2044){I=(c|0)==48?I:l;b=(e+784|0)+(g<<2)|0;if(q){m=(B(v[b>>2],10)+c|0)-48|0}v[b>>2]=m;n=1;c=q+1|0;b=(c|0)==9;q=b?0:c;g=b+g|0;break V}if((c|0)==48){break V}v[e+8960>>2]=v[e+8960>>2]|1;I=18396}b=v[f+4>>2];W:{if((b|0)!=v[f+104>>2]){v[f+4>>2]=b+1;c=w[b|0];break W}c=cd(f)}b=(c|0)==46;m=c-48|0;if(b|m>>>0<10){continue}break}}h=o?h:l;k=o?k:i;if(!(!n|(c&-33)!=69)){m=GF(f,d);b=db;A=b;X:{if(m|(b|0)!=-2147483648){break X}if(!d){break R}m=0;A=0;if(v[f+116>>2]<0){break X}v[f+4>>2]=v[f+4>>2]-1}if(!n){break S}k=k+A|0;b=h+m|0;k=b>>>0<m>>>0?k+1|0:k;h=b;break Q}b=!n;if((c|0)<0){break T}}if(v[f+116>>2]<0){break T}v[f+4>>2]=v[f+4>>2]-1}if(!b){break Q}}v[114934]=28}l=0;i=0;Th(f,0,0);h=0;k=0;break P}b=v[e+784>>2];if(!b){Ni(e,+(r|0)*0);h=v[e+8>>2];k=v[e+12>>2];l=v[e>>2];i=v[e+4>>2];break P}if(!((h|0)!=(l|0)|(i|0)!=(k|0)|(l>>>0>9&(i|0)>=0|(i|0)>0)|(b>>>H|0?(H|0)<=30:0))){Fg(e+48|0,r);Pm(e+32|0,b);wd(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);h=v[e+24>>2];k=v[e+28>>2];l=v[e+16>>2];i=v[e+20>>2];break P}if(h>>>0>(F|0)/-2>>>0&(k|0)>=0|(k|0)>0){v[114934]=68;Fg(e+96|0,r);wd(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);wd(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);h=v[e+72>>2];k=v[e+76>>2];l=v[e+64>>2];i=v[e+68>>2];break P}b=F-226|0;c=h>>>0<b>>>0;b=b>>31;if(c&(k|0)<=(b|0)|(b|0)>(k|0)){v[114934]=68;Fg(e+144|0,r);wd(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);wd(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);h=v[e+120>>2];k=v[e+124>>2];l=v[e+112>>2];i=v[e+116>>2];break P}if(q){if((q|0)<=8){b=(e+784|0)+(g<<2)|0;f=v[b>>2];while(1){f=B(f,10);q=q+1|0;if((q|0)!=9){continue}break}v[b>>2]=f}g=g+1|0}Y:{o=h;if((I|0)>(h|0)|(I|0)>8|(h|0)>17){break Y}if((o|0)==9){Fg(e+192|0,r);Pm(e+176|0,v[e+784>>2]);wd(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);h=v[e+168>>2];k=v[e+172>>2];l=v[e+160>>2];i=v[e+164>>2];break P}if((o|0)<=8){Fg(e+272|0,r);Pm(e+256|0,v[e+784>>2]);wd(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);Fg(e+224|0,v[(0-o<<2)+75520>>2]);YO(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);h=v[e+216>>2];k=v[e+220>>2];l=v[e+208>>2];i=v[e+212>>2];break P}b=(B(o,-3)+H|0)+27|0;c=v[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break Y}Fg(e+352|0,r);Pm(e+336|0,c);wd(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);Fg(e+304|0,v[(o<<2)+75448>>2]);wd(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);h=v[e+296>>2];k=v[e+300>>2];l=v[e+288>>2];i=v[e+292>>2];break P}while(1){c=g;g=c-1|0;if(!v[(e+784|0)+(g<<2)>>2]){continue}break}b=(o|0)%9|0;Z:{if(!b){q=0;b=0;break Z}d=(o|0)>=0?b:b+9|0;q=0;_:{if(!c){b=0;c=0;break _}h=v[(0-d<<2)+75520>>2];k=1e9/(h|0)|0;m=0;f=0;b=0;while(1){i=m;l=(e+784|0)+(f<<2)|0;n=v[l>>2];m=(n>>>0)/(h>>>0)|0;i=i+m|0;v[l>>2]=i;i=!i&(b|0)==(f|0);b=i?b+1&2047:b;o=i?o-9|0:o;m=B(k,n-B(h,m)|0);f=f+1|0;if((f|0)!=(c|0)){continue}break}if(!m){break _}v[(e+784|0)+(c<<2)>>2]=m;c=c+1|0}o=(o-d|0)+9|0}while(1){l=(e+784|0)+(b<<2)|0;g=(o|0)<36;while(1){$:{if(g){break $}if((o|0)==36){if(y[l>>2]<=10384592){break $}o=36}aa:{ba:while(1){d=c+1&2047;i=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(o|0)>45?9:1;ca:{while(1){n=b;f=0;da:{while(1){ea:{b=f+n&2047;if((b|0)==(c|0)){break ea}b=v[(e+784|0)+(b<<2)>>2];k=v[(f<<2)+75472>>2];if(b>>>0<k>>>0){break ea}if(b>>>0>k>>>0){break da}f=f+1|0;if((f|0)!=4){continue}}break}if((o|0)!=36){break da}h=0;k=0;f=0;l=0;i=0;while(1){b=f+n&2047;if((b|0)==(c|0)){c=c+1&2047;v[(e+(c<<2)|0)+780>>2]=0}Pm(e+768|0,v[(e+784|0)+(b<<2)>>2]);wd(e+752|0,h,k,l,i,0,0,1342177280,1075633366);og(e+736|0,v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2],v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2]);l=v[e+744>>2];i=v[e+748>>2];h=v[e+736>>2];k=v[e+740>>2];f=f+1|0;if((f|0)!=4){continue}break}Fg(e+720|0,r);wd(e+704|0,h,k,l,i,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);l=v[e+712>>2];i=v[e+716>>2];h=0;k=0;m=v[e+704>>2];A=v[e+708>>2];f=q+113|0;d=f-F|0;g=(d|0)<(H|0);b=g?(d|0)>0?d:0:H;if((b|0)<=112){break ca}break aa}q=h+q|0;b=c;if((n|0)==(b|0)){continue}break}l=1e9>>>h|0;m=-1<<h^-1;f=0;b=n;while(1){k=f;g=(e+784|0)+(n<<2)|0;f=v[g>>2];k=k+(f>>>h|0)|0;v[g>>2]=k;k=!k&(b|0)==(n|0);b=k?b+1&2047:b;o=k?o-9|0:o;f=B(l,f&m);n=n+1&2047;if((n|0)!=(c|0)){continue}break}if(!f){continue}if((b|0)!=(d|0)){v[(e+784|0)+(c<<2)>>2]=f;c=d;continue ba}v[i>>2]=v[i>>2]|1;b=d;continue}break}break}Ni(e+656|0,xj(1,225-b|0));JF(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],m,A,l,i);D=v[e+696>>2];z=v[e+700>>2];J=v[e+688>>2];K=v[e+692>>2];Ni(e+640|0,xj(1,113-b|0));yO(e+672|0,m,A,l,i,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);h=v[e+672>>2];k=v[e+676>>2];u=v[e+680>>2];x=v[e+684>>2];Ax(e+624|0,m,A,l,i,h,k,u,x);og(e+608|0,J,K,D,z,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);l=v[e+616>>2];i=v[e+620>>2];m=v[e+608>>2];A=v[e+612>>2]}o=n+4&2047;fa:{if((o|0)==(c|0)){break fa}o=v[(e+784|0)+(o<<2)>>2];ga:{if(o>>>0<=499999999){if(!o&(n+5&2047)==(c|0)){break ga}Ni(e+496|0,+(r|0)*.25);og(e+480|0,h,k,u,x,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);u=v[e+488>>2];x=v[e+492>>2];h=v[e+480>>2];k=v[e+484>>2];break ga}if((o|0)!=5e8){Ni(e+592|0,+(r|0)*.75);og(e+576|0,h,k,u,x,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);u=v[e+584>>2];x=v[e+588>>2];h=v[e+576>>2];k=v[e+580>>2];break ga}O=+(r|0);if((n+5&2047)==(c|0)){Ni(e+528|0,O*.5);og(e+512|0,h,k,u,x,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);u=v[e+520>>2];x=v[e+524>>2];h=v[e+512>>2];k=v[e+516>>2];break ga}Ni(e+560|0,O*.75);og(e+544|0,h,k,u,x,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);u=v[e+552>>2];x=v[e+556>>2];h=v[e+544>>2];k=v[e+548>>2]}if((b|0)>111){break fa}yO(e+464|0,h,k,u,x,0,0,0,1073676288);if($l(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break fa}og(e+448|0,h,k,u,x,0,0,0,1073676288);u=v[e+456>>2];x=v[e+460>>2];h=v[e+448>>2];k=v[e+452>>2]}og(e+432|0,m,A,l,i,h,k,u,x);Ax(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],J,K,D,z);l=v[e+424>>2];i=v[e+428>>2];m=v[e+416>>2];A=v[e+420>>2];ha:{if((-2-G|0)>=(f&2147483647)){break ha}v[e+408>>2]=l;v[e+412>>2]=i&2147483647;v[e+400>>2]=m;v[e+404>>2]=A;wd(e+384|0,m,A,l,i,0,0,0,1073610752);z=v[e+400>>2];D=v[e+404>>2];o=v[e+408>>2];f=v[e+412>>2];c=wA(z,D,o,f,1081081856);n=(c|0)<0;l=n?l:v[e+392>>2];i=n?i:v[e+396>>2];m=n?m:v[e+384>>2];A=n?A:v[e+388>>2];q=((c|0)>=0)+q|0;if((q+110|0)<=(L|0)){if((((wA(z,D,o,f,1081081856)|0)<0?g:g&(b|0)!=(d|0))|0)!=1){break ha}if(!$l(h,k,u,x,0,0,0,0)){break ha}}v[114934]=68}IF(e+368|0,m,A,l,i,q);h=v[e+376>>2];k=v[e+380>>2];l=v[e+368>>2];i=v[e+372>>2];break P}n=c+2047|0;m=0;while(1){h=m;i=n&2047;n=(e+784|0)+(i<<2)|0;d=v[n>>2];m=d>>>3|0;k=d<<29;h=h+k|0;d=m;d=h>>>0<k>>>0?d+1|0:d;k=d;if(!k&h>>>0<1000000001){m=0}else{m=ria(h,k,1e9,0);d=oia(m,db,-1e9,-1)+h|0;h=d}v[n>>2]=h;c=(i|0)!=(c-1&2047)?c:(b|0)==(i|0)?c:h?c:i;n=i-1|0;if((b|0)!=(i|0)){continue}break}q=q-29|0;if(!m){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;h=d+((c+2046&2047)<<2)|0;c=c-1&2047;v[h>>2]=v[h>>2]|v[d+(c<<2)>>2]}o=o+9|0;v[(e+784|0)+(b<<2)>>2]=m;continue}}v[s+40>>2]=h;v[s+44>>2]=k;v[s+32>>2]=l;v[s+36>>2]=i;ab=e+8976|0;D=v[s+40>>2];z=v[s+44>>2];h=v[s+32>>2];k=v[s+36>>2];break a;case 3:break j;default:break m}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}break i}ia:{c=v[b+4>>2];ja:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ja}c=cd(b)}if((c|0)==40){g=1;break ia}z=2147450880;if(v[b+116>>2]<0){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];ka:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ka}c=cd(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}z=2147450880;if((c|0)==41){break a}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}la:{if(d){if(g){break la}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(g){continue}break}break a}v[114934]=28;Th(b,0,0)}z=0}v[a>>2]=h;v[a+4>>2]=k;v[a+8>>2]=D;v[a+12>>2]=z;ab=s+48|0}function aga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0;e=ab-416|0;ab=e;qc(b);d=e+408|0;f=hu(b,d);if(!f){IR(d)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!f){break k}if(!JR(e+408|0)){break k}if(!c){q=1;break k}D=_d(e+384|0,b);v[22452]=0;R(452,e+368|0,D|0);b=v[22452];v[22452]=0;l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if((b|0)!=1){v[22452]=0;U(453,e+344|0,e+368|0,20041);b=v[22452];v[22452]=0;if((b|0)==1){break v}v[22452]=0;b=T(169,e+344|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break m}if(!b){break l}v[22452]=0;b=Q(454,e+344|0,e+248|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break m}if(!b){break l}v[22452]=0;R(240,a|0,16384);b=v[22452];v[22452]=0;if((b|0)==1){break m}v[a+480208>>2]=8;v[22452]=0;b=Y(258,a+1074312|0,9,1)|0;d=v[22452];v[22452]=0;if((d|0)==1){break m}v[22452]=0;b=Y(258,b|0,114,1)|0;d=v[22452];v[22452]=0;if((d|0)==1){break m}v[22452]=0;b=Q(259,b|0,21)|0;d=v[22452];v[22452]=0;if((d|0)==1){break m}v[22452]=0;Q(259,b|0,30)|0;b=v[22452];v[22452]=0;if((b|0)==1){break m}v[22452]=0;b=Q(1,e+208|0,8267)|0;d=v[22452];v[22452]=0;if((d|0)==1){break s}tb(a+1298344|0,b);pb(b);v[22452]=0;b=Q(1,e+208|0,10683)|0;d=v[22452];v[22452]=0;if((d|0)==1){break r}tb(a+1298356|0,b);pb(b);v[22452]=0;b=Q(1,e+96|0,17445)|0;d=v[22452];v[22452]=0;if((d|0)==1){break q}d=w[e+412|0];switch(d-16|0){case 1:break p;case 0:break u;default:break t}}d=P()|0;O()|0;break a}d=P()|0;O()|0;break b}v[22452]=0;Q(1,e+232|0,15004)|0;d=v[22452];v[22452]=0;if((d|0)!=1){break n}break e}if(!d){break o}v[22452]=0;Q(1,e+232|0,21598)|0;d=v[22452];v[22452]=0;if((d|0)==1){break e}break n}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}v[22452]=0;Q(1,e+232|0,15023)|0;d=v[22452];v[22452]=0;if((d|0)!=1){break n}break e}v[22452]=0;Q(1,e+232|0,13237)|0;d=v[22452];v[22452]=0;if((d|0)==1){break e}}v[22452]=0;U(2,e+208|0,b|0,e+232|0);d=v[22452];v[22452]=0;if((d|0)==1){break f}d=e+208|0;tb(a+1298368|0,d);pb(d);pb(e+232|0);pb(b);v[a+1298404>>2]=5;Qe(e+96|0,3,e+248|0);v[22452]=0;W(213,d|0,v[e+96>>2],v[e+100>>2],w[e+104|0]);b=v[22452];v[22452]=0;if((b|0)==1){break g}b=e+208|0;tb(a+1298308|0,b);pb(b);lj(e+232|0,3,e+280|0);v[22452]=0;W(213,e+96|0,v[e+232>>2],v[e+236>>2],w[e+240|0]);b=v[22452];v[22452]=0;if((b|0)==1){break h}v[22452]=0;U(11,e+208|0,5,e+96|0);b=v[22452];v[22452]=0;if((b|0)==1){break i}b=e+208|0;tb(a+1298320|0,b);pb(b);pb(e+96|0);v[a+480200>>2]=w[e+304|0]+1;K=a,M=Ld(w[e+305|0],1,255),v[K+480196>>2]=M;K=a,M=B(Ld(w[e+306|0],4,255),1e4),v[K+480204>>2]=M;b=a+484360|0;d=Kb(b);f=w[e+300|0]|w[e+301|0]<<8;v[22452]=0;ea(337,d|0,e+344|0,f|0,65535,65535)|0;d=v[22452];v[22452]=0;if((d|0)==1){break m}Re(Kb(b),w[e+302|0]|w[e+303|0]<<8);u[a+480188>>1]=0;b=0;while(1){if((b|0)==32){v[22452]=0;U(453,e+208|0,e+368|0,17741);b=v[22452];v[22452]=0;if((b|0)!=1){d=e+344|0;f=e+208|0;b=Mc(d,f);qb(f);v[22452]=0;d=T(151,d|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break m}v[22452]=0;W(326,a+1298332|0,b|0,d|0,0);d=v[22452];v[22452]=0;if((d|0)==1){break m}v[22452]=0;U(453,e+208|0,e+368|0,21321);d=v[22452];v[22452]=0;if((d|0)!=1){d=e+208|0;b=Mc(b,d);qb(d);v[22452]=0;d=T(169,e+344|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break m}w:{x:{if(d){v[22452]=0;U(453,e+208|0,e+368|0,16723);d=v[22452];v[22452]=0;if((d|0)==1){break w}v[22452]=0;q=T(197,b|0)|0;d=v[22452];v[22452]=0;y:{if((d|0)!=1){n=c&2;l=a+480190|0;while(1){if(q>>>0<=(j&255)>>>0){break y}v[22452]=0;f=T(197,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break x}if(!f){break y}v[22452]=0;d=Q(147,e+344|0,56)|0;k=v[22452];v[22452]=0;if((k|0)==1){break x}if(!d){break y}if(f>>>0>x[l>>1]){u[l>>1]=f}v[22452]=0;d=B(f,104)+a|0;k=d+484380|0;R(271,k|0,0);h=v[22452];v[22452]=0;if((h|0)==1){break x}WA(k);v[22452]=0;U(307,b|0,((f<<5)+a|0)+946304|0,32);f=v[22452];v[22452]=0;if((f|0)==1){break x}v[22452]=0;R(310,b|0,d+484423|0);f=v[22452];v[22452]=0;if((f|0)==1){break x}z:{if(w[e+412|0]<=15){v[22452]=0;h=T(185,b|0)|0;f=v[22452];v[22452]=0;if((f|0)!=1){break z}break x}v[22452]=0;h=T(148,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break x}}v[d+484404>>2]=h<<1;v[22452]=0;f=T(148,b|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break x}v[k>>2]=f;v[22452]=0;h=T(148,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break x}f=d+484384|0;v[f>>2]=h;v[22452]=0;h=T(148,b|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break x}g=d+484388|0;v[g>>2]=h;if(h){i=d+484414|0;u[i>>1]=x[i>>1]|2;v[g>>2]=h+v[f>>2]}v[22452]=0;h=T(197,b|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break x}if(w[e+412|0]<=15){u[d+484410>>1]=h}v[22452]=0;h=T(197,b|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break x}o=d+484414|0;d=x[o>>1];i=8;if(h&1){d=d|1;u[o>>1]=d;v[k>>2]=v[k>>2]>>>1;v[f>>2]=v[f>>2]>>>1;v[g>>2]=v[g>>2]>>>1;i=16}u[o>>1]=d&65531|h<<1&4;d=Gc(e+96|0,i,1,0,((h&12)!=0)<<3);A:{if(!n){break A}v[22452]=0;Y(210,d|0,k|0,e+208|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){break A}break x}j=j+1|0;continue}}break x}qb(e+208|0)}v[22452]=0;U(453,e+208|0,e+368|0,18761);d=v[22452];v[22452]=0;B:{if((d|0)!=1){d=b;b=e+208|0;k=Mc(d,b);qb(b);v[22452]=0;b=T(169,e+344|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break m}if(!b){break B}h=Pb(e+96|0);g=Pb(e+232|0);i=Pb(e+192|0);v[22452]=0;U(453,e+168|0,e+368|0,17750);b=v[22452];v[22452]=0;C:{if((b|0)==1){break C}d=v[e+180>>2];b=e- -64|0;v[b>>2]=v[e+176>>2];v[b+4>>2]=d;v[e+72>>2]=v[e+184>>2];v[22452]=0;b=v[e+172>>2];v[e+56>>2]=v[e+168>>2];v[e+60>>2]=b;R(455,e+56|0,h|0);b=v[22452];v[22452]=0;if((b|0)==1){break C}v[22452]=0;U(453,e+144|0,e+368|0,17744);b=v[22452];v[22452]=0;if((b|0)==1){break C}b=v[e+156>>2];v[e+40>>2]=v[e+152>>2];v[e+44>>2]=b;v[e+48>>2]=v[e+160>>2];v[22452]=0;b=v[e+148>>2];v[e+32>>2]=v[e+144>>2];v[e+36>>2]=b;R(455,e+32|0,g|0);b=v[22452];v[22452]=0;if((b|0)==1){break C}v[22452]=0;U(453,e+120|0,e+368|0,17734);b=v[22452];v[22452]=0;if((b|0)==1){break C}b=v[e+132>>2];v[e+16>>2]=v[e+128>>2];v[e+20>>2]=b;v[e+24>>2]=v[e+136>>2];v[22452]=0;b=v[e+124>>2];v[e+8>>2]=v[e+120>>2];v[e+12>>2]=b;R(455,e+8|0,i|0);b=v[22452];v[22452]=0;if((b|0)==1){break C}v[22452]=0;y=T(197,k|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break C}b=e+208|0;z=b|4;A=b|2;p=b|6;s=b|5;r=b|3;l=b|1;C=a+480190|0;o=0;while(1){if(y>>>0<=(o&255)>>>0){Rn(i);Rn(g);Rn(h);break B}v[22452]=0;R(254,e+80|0,k|0);b=v[22452];v[22452]=0;D:{if((b|0)!=1){n=Zc(e+80|0);E:{F:{if(!w[e+80|0]){break F}b=w[n|0];v[22452]=0;b=Q(147,e+344|0,B(b,14)+32|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break C}if(!b){break F}b=w[e+80|0];v[22452]=0;f=Y(245,a|0,b|0,0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break C}if(f){break E}}b=w[n|0];v[22452]=0;Q(179,e+344|0,B(b,14)+32|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break D}break C}v[22452]=0;U(307,k|0,f+492|0,32);b=v[22452];v[22452]=0;if((b|0)==1){break C}E=f+88|0;F=f+68|0;G=f+48|0;J=f+236|0;b=0;q=0;while(1){if(w[n|0]<=(q&255)>>>0){break D}v[22452]=0;R(456,k|0,e+208|0);d=v[22452];v[22452]=0;if((d|0)==1){break C}d=w[e+208|0];G:{if(!d|d>>>0>x[C>>1]){break G}if(w[l|0]>=129){t[l|0]=128}while(1){H=w[l|0];d=b&255;if(H>>>0<d>>>0){b=v[h+4>>2];d=v[h>>2];j=w[r|0];v[22452]=0;W(457,G|0,j|0,d|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break C}b=v[g+4>>2];d=v[g>>2];j=w[s|0];v[22452]=0;W(457,F|0,j|0,d|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break C}b=v[i+4>>2];d=v[i>>2];j=w[e+221|0];v[22452]=0;W(457,E|0,j|0,d|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break C}v[f>>2]=(w[p|0]|w[p+1|0]<<8)+1>>>1;b=w[e+208|0];H:{if(w[r|0]&64){u[(B(b,104)+a|0)+484410>>1]=w[A|0];break H}d=(B(b,104)+a|0)+484414|0;u[d>>1]=x[d>>1]|32768}u[e+118>>1]=w[z|0]<<1;u[e+116>>1]=254;j=B(b,104)+a|0;K=j+484408|0,M=x[Lc(e+118|0,e+116|0)>>1],u[K>>1]=M;t[j+484418|0]=w[(w[e+219|0]&3)+26660|0];d=j+484419|0;m=w[e+218|0];t[d|0]=m;I=w[e+217|0]+3>>>2|0;t[j+484420|0]=I;t[j+484421|0]=w[e+216|0];b=H+1|0;if(m){m=pm(Fc(((I<<8|m>>>1)>>>0)/(m>>>0)|0,0))}else{m=255}t[d|0]=m;if(!(w[s|0]&64)){break G}d=j+484414|0;u[d>>1]=x[d>>1]|32}else{K=Yb(J,d),M=w[e+208|0],u[K>>1]=M;b=b+1|0;continue}break}}q=q+1|0;continue}}break C}o=o+1|0;continue}}d=P()|0;O()|0;Rn(i);Rn(g);Rn(h);break c}d=P()|0;O()|0;break c}q=1;n=Pb(e+232|0);I:{if(!(c&1)){break I}v[22452]=0;U(453,e+208|0,e+368|0,21076);b=v[22452];v[22452]=0;J:{K:{L:{M:{N:{O:{if((b|0)!=1){c=Mc(k,e+208|0);v[22452]=0;b=T(169,e+344|0)|0;d=v[22452];v[22452]=0;P:{Q:{R:{if((d|0)!=1){qb(e+208|0);if(!b){break P}v[22452]=0;b=T(185,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break R}v[22452]=0;d=b+1|0;R(458,n|0,d|0);b=v[22452];v[22452]=0;if((b|0)==1){break R}b=1;while(1){if((b|0)==(d|0)){break P}v[22452]=0;f=T(185,c|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break Q}v[22452]=0;U(181,e+96|0,e+344|0,f|0);f=v[22452];v[22452]=0;if((f|0)==1){break Q}f=e+208|0;k=e+96|0;h=bc(f,k);Mc(tg(v[n>>2],b),h);b=b+1|0;qb(f);qb(k);continue}}d=P()|0;O()|0;qb(e+208|0);break J}d=P()|0;O()|0;break J}d=P()|0;O()|0;break J}v[22452]=0;U(453,e+208|0,e+368|0,16720);b=v[22452];v[22452]=0;if((b|0)==1){break L}m=Mc(c,e+208|0);v[22452]=0;b=T(169,e+344|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break M}qb(e+208|0);if(!b){break O}v[22452]=0;y=T(197,m|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break K}i=0;S:{T:{U:while(1){V:{if(y>>>0<=(i&65535)>>>0){v[22452]=0;Q(146,e+344|0,1)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break V}break K}j=32;W:{if(w[e+412|0]<16){break W}v[22452]=0;R(459,m|0,e+208|0);b=v[22452];v[22452]=0;if((b|0)==1){break S}j=w[e+208|0];if(j>>>0<=x[a+480188>>1]|j>>>0>32){break W}u[a+480188>>1]=j;j=w[e+208|0]}b=0;while(1){c=b&65535;if(c>>>0>=j>>>0){i=i+1|0;continue U}v[22452]=0;d=T(185,m|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break T}if(!(!d|c>>>0>31|c>>>0<x[a+480188>>1])){u[a+480188>>1]=b+1}b=b+1|0;continue}}break}v[22452]=0;p=a+484344|0;R(216,p|0,y|0);b=v[22452];v[22452]=0;if((b|0)==1){break K}b=e+208|0;E=b|2;F=b|1;c=0;while(1){if((c|0)==(y|0)){break O}s=Bb(e+96|0);X:{if(w[e+412|0]<16){o=32;b=64;break X}v[22452]=0;R(459,m|0,e+208|0);b=v[22452];v[22452]=0;if((b|0)==1){break N}o=w[e+208|0];b=w[F|0];_e(e+80|0,E,16,3);v[22452]=0;W(213,e+192|0,v[e+80>>2],v[e+84>>2],w[e+88|0]);d=v[22452];v[22452]=0;if((d|0)==1){break N}d=e+192|0;tb(s,d);pb(d);b=b+1|0}v[22452]=0;k=b;b=Y(217,p|0,c&65535,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break N}Y:{if(!b){v[22452]=0;Q(179,e+344|0,o<<1)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break Y}break N}b=Rb(p,c);v[22452]=0;R(275,b|0,s|0);b=v[22452];v[22452]=0;if((b|0)==1){break N}G=k-1|0;z=0;while(1){r=z&65535;if(r>>>0>=o>>>0){break Y}v[22452]=0;b=T(185,m|0)|0;d=v[22452];v[22452]=0;Z:{if((d|0)!=1){if(!b){break Z}d=v[n>>2];if(Ef(d,v[n+4>>2])>>>0<=b>>>0|r>>>0>=x[a+480188>>1]){break Z}l=tg(d,b);qc(l);f=0;_:while(1){d=f;if(k>>>0<=d>>>0){break Z}v[22452]=0;b=Q(147,l|0,1)|0;f=v[22452];v[22452]=0;$:{aa:{ba:{ca:{da:{if((f|0)!=1){if(!b){break Z}b=Qc(Rb(p,c),d,r);v[22452]=0;f=T(197,l|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break N}h=f>>>2|0;switch((f&3)-1|0){case 2:break aa;case 1:break ba;case 0:break ca;default:break da}}break N}f=(d+h|0)+1|0;continue}f=0;if(!d){continue}g=Qc(Rb(p,c),d-1|0,r);while(1){f=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;f=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=f;t[b+5|0]=f>>>8;f=d+1|0;if((d|0)==(G|0)){continue _}b=B(x[a+480188>>1],6)+b|0;i=h&255;d=f;h=h-1|0;if(i){continue}break}continue}if(d>>>0<=h>>>0){break $}f=Qc(Rb(p,c),h,r);h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=h;t[b+1|0]=h>>>8;t[b+2|0]=h>>>16;t[b+3|0]=h>>>24;f=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=f;t[b+5|0]=f>>>8;break $}if(h&1){v[22452]=0;f=T(197,l|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break N}t[b|0]=f>>>0>120?-1:f}if(h&2){v[22452]=0;f=T(197,l|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break N}t[b+1|0]=f}j=0;f=0;ea:{if(h&4){v[22452]=0;f=T(197,l|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break ea}}i=0;if(h&8){v[22452]=0;g=T(197,l|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break ea}j=g&15;i=g>>>4|0}A=0;C=0;if(h&16){v[22452]=0;C=T(197,l|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break ea}}if(h&32){v[22452]=0;A=T(197,l|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break ea}}g=ab-16|0;ab=g;t[g+14|0]=i;t[g+15|0]=j;t[g+13|0]=C;t[g+12|0]=A;if((i-1&255)>>>0<=5){t[g+14|0]=i+15}GR(g+15|0,g+13|0);GR(g+14|0,g+12|0);fa:{ga:{i=w[g+15|0];ha:{if((i|0)==10){h=w[g+12|0];j=w[g+13|0]&15;t[g+13|0]=j?-1:h;i=w[g+14|0];i=(i|0)==10?0:i;t[g+14|0]=i;h=h|j<<8;break ha}if(w[g+14|0]!=10){break ga}h=w[g+12|0]&15;t[g+12|0]=h?-1:0;h=h<<8}if(h-256>>>0>4294967038){break ga}if(ti(i)>>>0>=ti(10)>>>0){break ga}t[b+5|0]=h;t[b+2|0]=15;t[b+3|0]=10;t[b+4|0]=h>>>8;break fa}if(f){t[b+2|0]=1;t[b+4|0]=f+2>>>2}qu(g+15|0,g+13|0,g+14|0,g+12|0);h=w[g+15|0];ia:{if(!h){break ia}i=w[g+14|0];if(!i){t[g+14|0]=h;t[g+12|0]=w[g+13|0];t[g+15|0]=0;break ia}if(!((h|0)==20|(h|0)!=(i|0))){t[g+15|0]=0;break ia}if(!f){Yn(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);t[b+2|0]=w[g+15|0];t[b+4|0]=w[g+13|0];break ia}if(ti(h)>>>0<=ti(i)>>>0){break ia}Tg(g+15|0,g+14|0);Tg(g+13|0,g+12|0)}t[b+3|0]=w[g+14|0];t[b+5|0]=w[g+12|0]}ab=g+16|0;break $}break N}f=d+1|0;continue}}break N}z=z+1|0;continue}}pb(s);c=c+1|0;continue}}d=P()|0;O()|0;break J}d=P()|0;O()|0;break J}d=P()|0;O()|0;break J}v[22452]=0;U(453,e+208|0,e+368|0,20048);b=v[22452];v[22452]=0;ja:{ka:{if((b|0)!=1){b=Mc(m,e+208|0);v[22452]=0;c=T(169,e+344|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break ka}qb(e+208|0);if(!c){break I}a=a+484344|0;while(1){if(!lf(a)){break I}v[22452]=0;c=Q(147,e+344|0,16)|0;d=v[22452];v[22452]=0;if((d|0)==1){break ja}if(!c){break I}v[22452]=0;R(460,b|0,e+208|0);c=v[22452];v[22452]=0;if((c|0)!=1){c=Rb(a,0);v[22452]=0;R(461,c|0,e+208|0);c=v[22452];v[22452]=0;if((c|0)!=1){continue}}break}d=P()|0;O()|0;break J}d=P()|0;O()|0;break J}d=P()|0;O()|0;qb(e+208|0);break J}d=P()|0;O()|0;break J}d=P()|0;O()|0;pb(s);break J}d=P()|0;O()|0;qb(e+208|0);break J}d=P()|0;O()|0;break J}d=P()|0;O()|0}Yc(n);break c}Yc(n);break l}d=P()|0;O()|0;qb(e+208|0);break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=(b<<5)+a|0;f=d+480280|0;Le(f);k=b+e|0;h=w[k+307|0]<<1&254;u[d+480284>>1]=(h|0)==254?256:h;la:{if(t[k+307|0]<0){v[f>>2]=v[f>>2]|1024;break la}u[a+480188>>1]=b+1}v[22452]=0;R(462,e+344|0,d+480289|0);d=v[22452];v[22452]=0;if((d|0)==1){break j}b=b+1|0;continue}}d=P()|0;O()|0;break c}qb(e+344|0);Rd(e+368|0);qb(D)}ab=e+416|0;return q|0}d=P()|0;O()|0;break c}d=P()|0;O()|0;pb(e+96|0);break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;pb(e+232|0);break d}d=P()|0;O()|0}pb(b)}qb(e+344|0)}Rd(e+368|0)}qb(D);S(d|0);L()}function Zda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;d=ab-336|0;ab=d;qc(b);a:{if(!Wn(b,d+320|0)){break a}if(!gQ(d+320|0)){break a}q=_d(d+296|0,b);p=Ye(d+280|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if(!c){v[22452]=0;R(605,d|0,q|0);b=v[22452];v[22452]=0;if((b|0)==1){break y}break A}v[22452]=0;R(606,d|0,q|0);b=v[22452];v[22452]=0;if((b|0)==1){break z}}ot(p,d);Rd(d);v[22452]=0;U(607,d|0,p|0,1413891155);b=v[22452];v[22452]=0;B:{C:{if((b|0)!=1){v[22452]=0;e=Q(608,d|0,14102)|0;b=v[22452];v[22452]=0;if((b|0)==1){break C}qb(d);if(!c){break b}if(!(e^1)){break B}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;qb(d);break c}v[22452]=0;R(240,a|0,4194304);b=v[22452];v[22452]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[22452]=0;U(607,d+256|0,p|0,1280592212);b=v[22452];v[22452]=0;if((b|0)==1){break e}v[22452]=0;b=T(151,d+256|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break g}v[22452]=0;U(403,d+256|0,a+1298308|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break g}m=a+484360|0;uc(Kb(m));l=Pb(d+240|0);t[d+239|0]=0;v[22452]=0;U(609,d+224|0,p|0,1196314451);b=v[22452];v[22452]=0;if((b|0)==1){break i}y=d,z=wb(v[d+224>>2]),v[y+216>>2]=z;j=d+44|0;h=wb(v[d+228>>2]);D:{E:{while(1){b=v[d+216>>2];if(!Tb(b,h)){break E}e=_d(d+192|0,b);v[22452]=0;f=Q(610,e|0,d+176|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break D}b=1;if(!(!f|w[d+185|0]!=1)){y=a,z=Ld(w[d+186|0],x[a+480188>>1],127),u[y+480188>>1]=z;v[22452]=0;i=T(611,d|0)|0;b=v[22452];v[22452]=0;F:{G:{H:{I:{if((b|0)!=1){_e(d+160|0,d+176|0,9,1);v[22452]=0;W(213,d+120|0,v[d+160>>2],v[d+164>>2],w[d+168|0]);b=v[22452];v[22452]=0;if((b|0)==1){break I}b=d+152|0;Zb(b,j,10);f=b;b=d+120|0;pj(f,b);pb(b);b=Kb(m);if(jc(v[b>>2],v[b+4>>2])){break G}v[22452]=0;b=T(266,m|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break H}if((b|0)!=255){break G}b=2;break F}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=Kb(m);v[22452]=0;U(5,d+120|0,5,j|0);f=v[22452];v[22452]=0;if((f|0)==1){break n}v[22452]=0;R(267,b|0,d+120|0);b=v[22452];v[22452]=0;if((b|0)==1){break o}pb(d+120|0);v[22452]=0;R(606,d+160|0,e|0);b=v[22452];v[22452]=0;if((b|0)==1){break p}y=d,z=wb(v[d+160>>2]),v[y+144>>2]=z;k=wb(v[d+164>>2]);J:{K:{while(1){e=v[d+144>>2];if(!Tb(e,k)){b=0;if(x[d+36>>1]==65535|x[d+38>>1]==65535){break J}b=Kb(m);v[22452]=0;Z(612,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){v[22452]=0;R(613,l|0,i|0);e=v[22452];v[22452]=0;b=0;if((e|0)!=1){break J}}b=P()|0;O()|0;break m}gm(d+120|0,e);b=d+152|0;qi(b,e);e=1;L:{f=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);M:{if((f|0)!=1212960847){b=0;if((f|0)!=1312903248){break M}while(1){if(x[a+480188>>1]<=b>>>0){break M}v[22452]=0;f=Q(147,d+120|0,2)|0;g=v[22452];v[22452]=0;if((g|0)!=1){if(!f){break M}v[22452]=0;R(254,d+96|0,d+120|0);f=v[22452];v[22452]=0;N:{O:{P:{Q:{if((f|0)!=1){switch(w[d+96|0]){case 4:break O;case 2:break P;case 0:break Q;default:break N}}break q}f=Zc(d+96|0);y=Cb(v[d>>2],b),z=w[f|0]^128,t[y|0]=z;f=d+104|0;rb(f,v[d+24>>2],b);mg(f,0);break N}y=Cb(v[d>>2],b),z=128,t[y|0]=z;f=d+104|0;rb(f,v[d+24>>2],b);mg(f,1);break N}y=Cb(v[d>>2],b),z=128,t[y|0]=z;f=d+104|0;rb(f,v[d+24>>2],b);mg(f,0)}b=b+1|0;continue}break}break q}if(Wl(d+152|0)>>>0<9){break M}b=0;v[22452]=0;Q(179,d+120|0,2)|0;e=v[22452];v[22452]=0;f=65535;if((e|0)==1){break L}while(1){R:{v[22452]=0;e=Q(147,d+120|0,1)|0;g=v[22452];v[22452]=0;S:{T:{U:{V:{W:{X:{Y:{Z:{if((g|0)!=1){if(!e){break R}v[22452]=0;g=T(197,d+120|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break q}e=0;switch(g|0){case 0:break R;case 14:break T;case 13:break U;case 12:break V;case 8:break W;case 7:break X;case 4:break Y;case 1:break Z;default:break M}}break q}if(x[d+36>>1]==65535){y=d,z=el(Kb(m)),u[y+36>>1]=z}e=el(Kb(m));v[22452]=0;u[d+38>>1]=e;e=Q(614,d+120|0,d+239|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break q}_:{$:{switch(e-254|0){case 1:e=65535;break _;case 0:break $;default:break _}}e=65534}g=Kb(m);v[22452]=0;R(484,g|0,e|0);e=v[22452];v[22452]=0;if((e|0)==1){break q}f=(f&65535)==65535?b:f;break S}v[22452]=0;e=T(185,d+120|0)|0;g=v[22452];v[22452]=0;aa:{ba:{if((g|0)!=1){if(e>>>0>=(f&65535)>>>0){break ba}e=x[d+40>>1];break aa}break q}e=e-f|0;u[d+40>>1]=e}Re(Kb(m),e&65535);break S}v[22452]=0;e=T(197,d+120|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break q}t[d+43|0]=e;break S}v[22452]=0;e=T(197,d+120|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break q}t[d+42|0]=e;break S}v[22452]=0;g=Q(576,d+120|0,d+104|0)|0;n=v[22452];v[22452]=0;if((n|0)!=1){if(w[d+104|0]|!g|(w[d+106|0]|w[d+105|0]!=255)){break M}if(w[d+107|0]|w[d+108|0]!=1){break M}if(!w[d+109|0]){break S}break M}break q}v[22452]=0;R(496,d+112|0,d+120|0);e=v[22452];v[22452]=0;ca:{da:{ea:{fa:{if((e|0)!=1){n=Zc(d+112|0);e=v[d>>2];o=Ic(e,v[d+4>>2]);g=w[d+112|0];if(o>>>0<=g>>>0){break S}switch(w[Me(d+112|0)|0]){case 4:break da;case 2:break ea;case 0:break fa;default:break ca}}break q}y=Cb(e,g),z=w[n|0]^128,t[y|0]=z;e=d+104|0;rb(e,v[d+24>>2],w[d+112|0]);mg(e,0);break ca}y=Cb(e,g),z=128,t[y|0]=z;e=d+104|0;rb(e,v[d+24>>2],w[d+112|0]);mg(e,1);break ca}y=Cb(e,g),z=128,t[y|0]=z;e=d+104|0;rb(e,v[d+24>>2],w[d+112|0]);mg(e,0)}ga:{if(r){break ga}r=0;e=v[l+4>>2];if(!Ep(v[l>>2],e)){break S}g=e-56|0;e=w[d+112|0];if(w[Cb(v[g>>2],e)|0]!=w[Cb(v[d>>2],e)|0]){break ga}rb(d+104|0,v[g+24>>2],e);e=sb(v[v[d+104>>2]>>2],v[d+108>>2]);rb(d+96|0,v[d+24>>2],w[d+112|0]);if((sb(v[v[d+96>>2]>>2],v[d+100>>2])|0)==(e|0)){break S}}r=1;break S}v[22452]=0;R(254,d+104|0,d+120|0);e=v[22452];v[22452]=0;if((e|0)==1){break q}e=v[d+12>>2];n=Ic(e,v[d+16>>2]);g=w[d+104|0];if(n>>>0<=g>>>0){break S}n=Zc(d+104|0);y=Cb(e,g),z=(w[n|0]>>>2|0)+1|0,t[y|0]=z}b=b+1|0;continue}break}e=1}qb(d+120|0);if(!e){break K}em(d+144|0);continue}break}break q}b=1}Rd(d+160|0)}nt(i)}qb(d+192|0);if(!b){jh(d+216|0);continue}break}e=0;if((b|0)!=2){break v}}e=0;si(m,0);b=v[l>>2];if(jc(b,v[l+4>>2])){break v}if(!(c&2)){break w}v[22452]=0;U(609,d+192|0,p|0,1347244868);b=v[22452];v[22452]=0;if((b|0)!=1){y=d,z=wb(v[d+192>>2]),v[y+176>>2]=z;e=a+480190|0;f=d+13|0;i=d+17|0;g=wb(v[d+196>>2]);j=w[d+239|0];while(1){b=v[d+176>>2];if(!Tb(b,g)){Yc(d+192|0);b=v[l>>2];break w}ha:{ia:{ja:{if(!j){v[22452]=0;h=Q(615,b|0,d|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break ha}if(!h){break ia}h=w[d+52|0]|w[d+53|0]<<8;k=h+1|0;u[d+152>>1]=k;if(h>>>0>3998){break ja}y=a,z=x[Ne(e,d+152|0)>>1],u[y+480190>>1]=z;v[22452]=0;R(616,d|0,(B(k&65535,104)+a|0)+484380|0);h=v[22452];v[22452]=0;if((h|0)==1){break ha}fQ(d+160|0,f);v[22452]=0;W(213,d+120|0,v[d+160>>2],v[d+164>>2],w[d+168|0]);h=v[22452];v[22452]=0;if((h|0)==1){break x}h=d+120|0;sc(((x[d+152>>1]<<5)+a|0)+946304|0,h);pb(h);break ja}v[22452]=0;h=Q(617,b|0,d|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break x}if(!h){break ia}h=w[d+56|0]|w[d+57|0]<<8;k=h+1|0;u[d+152>>1]=k;if(h>>>0>3998){break ja}y=a,z=x[Ne(e,d+152|0)>>1],u[y+480190>>1]=z;v[22452]=0;R(618,d|0,(B(k&65535,104)+a|0)+484380|0);h=v[22452];v[22452]=0;if((h|0)==1){break x}fQ(d+160|0,i);v[22452]=0;W(213,d+120|0,v[d+160>>2],v[d+164>>2],w[d+168|0]);h=v[22452];v[22452]=0;if((h|0)==1){break x}h=d+120|0;sc(((x[d+152>>1]<<5)+a|0)+946304|0,h);pb(h)}if((x[d+152>>1]-1&65535)>>>0>3998){break ia}h=Gc(d,8,1,0,2);v[22452]=0;Y(210,h|0,(B(x[d+152>>1],104)+a|0)+484380|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break ia}break x}jh(d+176|0);continue}break}break x}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;Yc(d+192|0);break j}b=Az(b,0);v[a+480196>>2]=w[b+43|0];v[a+480204>>2]=B(w[b+42|0],1e4);Re(Kb(m),x[b+40>>1]);b=0;while(1){if(x[a+480188>>1]>b>>>0){e=(b<<5)+a|0;f=e+480280|0;Le(f);i=Az(v[l>>2],0);y=e+480286|0,z=w[Cb(v[i+12>>2],b)|0],u[y>>1]=z;y=e+480284|0,z=w[Cb(v[i>>2],b)|0],u[y>>1]=z;rb(d,v[i+24>>2],b);y=f,z=v[f>>2]&-257|(sb(v[v[d>>2]>>2],v[d+4>>2])?256:0),v[y>>2]=z;b=b+1|0;continue}break}ka:{if(w[d+239|0]){v[22452]=0;Q(1,d|0,17075)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break ka}break r}v[22452]=0;Q(1,d|0,16948)|0;b=v[22452];v[22452]=0;if((b|0)==1){break r}}tb(a+1298344|0,d);pb(d);v[22452]=0;b=Q(1,d|0,10098)|0;f=v[22452];v[22452]=0;e=1;if((f|0)!=1){tb(a+1298356|0,b);pb(b);v[a+1298404>>2]=5;if(!(c&1)|!x[a+480188>>1]){break v}v[22452]=0;U(609,d+120|0,p|0,1146045008);b=v[22452];v[22452]=0;if((b|0)==1){break s}b=v[d+124>>2];c=v[d+120>>2];v[22452]=0;g=a+484344|0;R(216,g|0,Ef(c,b)&65535);b=v[22452];v[22452]=0;if((b|0)==1){break u}y=d,z=wb(v[d+120>>2]),v[y+160>>2]=z;s=wb(v[d+124>>2]);while(1){i=v[d+160>>2];if(!Tb(i,s)){la:{ma:{b=v[l>>2];e=v[l+4>>2];if(Ep(b,e)>>>0<2){break ma}c=0;while(1){if(Ep(b,e)>>>0<=c>>>0){break ma}i=jj(m,c&255);h=v[i>>2];f=Az(b,c);j=x[f+36>>1];if(he(g,x[Yb(h,j)>>1])){v[22452]=0;e=Q(357,i|0,j|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break la}na:{if(!r){break na}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break na}rb(d,v[f+24>>2],b);j=sb(v[v[d>>2]>>2],v[d+4>>2]);i=Rb(g,e);oa:{if(j){je(i,mh(Xn(Ae(ve(d,20,145),0),b&65535)));break oa}je(i,mh(Xn(Ae(ve(d,9,w[Cb(v[f>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}je(Rb(g,e),mh(Ae(ve(d,16,w[f+43|0]),0)));je(Rb(g,e),mh(Ae(ve(d,17,w[f+42|0]),0)));e=v[l+4>>2];b=v[l>>2]}c=c+1|0;continue}}Yc(d+120|0);e=1;break v}b=P()|0;O()|0;break t}v[22452]=0;b=T(151,i|0)|0;c=v[22452];v[22452]=0;pa:{qa:{ra:{sa:{ta:{ua:{va:{if((c|0)==1){break va}v[22452]=0;c=T(148,i|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break va}if((b|0)!=(c|0)){break pa}v[22452]=0;b=Q(619,i|0,8)|0;c=v[22452];v[22452]=0;if((c|0)==1){break va}if(!b){break pa}v[22452]=0;k=Q(614,i|0,d+239|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break qa}v[22452]=0;n=T(185,i|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break ra}v[22452]=0;b=Y(217,g|0,k|0,n|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break ra}if(!b){break pa}h=0;while(1){if((h|0)==(n|0)){break pa}c=Of(Rb(g,k),h);v[22452]=0;b=T(185,i|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break ua}wa:{if(b>>>0>=3){v[22452]=0;U(181,d+192|0,i|0,b-2|0);b=v[22452];v[22452]=0;if((b|0)==1){break sa}b=d+192|0;j=bc(d,b);qb(b);while(1){v[22452]=0;b=Q(147,d|0,3)|0;e=v[22452];v[22452]=0;if((e|0)==1){break wa}if(b){v[22452]=0;R(254,d+192|0,j|0);b=v[22452];v[22452]=0;xa:{ya:{za:{Aa:{if((b|0)!=1){b=d+192|0;f=b;u[d+176>>1]=x[a+480188>>1]-1;y=d,z=w[Zc(b)|0],u[y+152>>1]=z;e=x[Lc(d+176|0,d+152|0)>>1];b=t[b|0];if((b|0)>=0){break xa}v[22452]=0;b=T(197,j|0)|0;o=v[22452];v[22452]=0;if((o|0)==1){break ta}if(w[d+239|0]){break za}if((b|0)!=255){break Aa}b=254;break ya}break ta}if(b>>>0>128){break ya}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break ya}b=b>>>0<85?b+36|0:b}t[c+B(e,6)|0]=b;b=w[f|0]}if(b&64){v[22452]=0;b=T(197,j|0)|0;o=v[22452];v[22452]=0;if((o|0)==1){break ta}t[(c+B(e,6)|0)+1|0]=b+1;b=w[f|0]}if(b&32){v[22452]=0;b=T(197,j|0)|0;o=v[22452];v[22452]=0;if((o|0)==1){break ta}t[d+176|0]=b;b=c+B(e,6)|0;t[b+2|0]=1;t[d+152|0]=127;y=b,z=w[Qb(d+176|0,d+152|0)|0]+1>>>1|0,t[y+4|0]=z;b=w[f|0]}if(!(b&16)){continue}v[22452]=0;R(254,d+176|0,j|0);b=v[22452];v[22452]=0;Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{if((b|0)!=1){b=c+B(e,6)|0;o=d+176|0;f=w[Zc(o)|0];t[b+5|0]=f;switch(w[o|0]-1|0){case 72:break Ca;case 71:break Da;case 70:break Ea;case 61:break Fa;case 60:break Ga;case 53:break Ha;case 52:break Ia;case 51:break Ja;case 50:break Ka;case 43:break La;case 42:break Ma;case 41:break Na;case 40:break Oa;case 31:break Pa;case 30:break Qa;case 23:break Ra;case 22:break Sa;case 21:break Ta;case 20:break Ua;case 18:break Va;case 17:break Wa;case 15:break Xa;case 16:break Ya;case 14:break Za;case 13:break _a;case 12:break $a;case 11:break ab;case 10:break bb;case 3:break cb;case 2:break db;case 1:break eb;case 0:break fb;default:break Ba}}break ta}t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f<<4|15;continue}t[b+5|0]=f<<3|15;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f<<4;continue}t[b+5|0]=f<<3&240;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f|240;continue}t[b+5|0]=f>>>1|240;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f&15;continue}if(f>>>0<=1){t[b+5|0]=f|240;continue}t[b+5|0]=f>>>1&15;continue}t[(c+B(e,6)|0)+3|0]=2;y=b,z=mt(f,w[d+239|0])|240,t[y+5|0]=z;continue}t[(c+B(e,6)|0)+3|0]=2;y=b,z=mt(f,w[d+239|0]),t[y+5|0]=z;continue}t[(c+B(e,6)|0)+3|0]=3;y=b,z=mt(f,w[d+239|0])|240,t[y+5|0]=z;continue}t[(c+B(e,6)|0)+3|0]=3;y=b,z=mt(f,w[d+239|0]),t[y+5|0]=z;continue}t[(c+B(e,6)|0)+3|0]=4;if(w[d+239|0]){continue}t[b+5|0]=(f&252)>>>2;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&1|16;continue}t[(c+B(e,6)|0)+3|0]=6;t[b+5|0]=f&240;continue}t[(c+B(e,6)|0)+3|0]=6;t[b+5|0]=(f&240)>>>4;continue}t[(c+B(e,6)|0)+3|0]=20;continue}t[(c+B(e,6)|0)+3|0]=5;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|48;continue}t[(c+B(e,6)|0)+3|0]=7;t[b+5|0]=f|240;continue}t[(c+B(e,6)|0)+3|0]=7;continue}t[(c+B(e,6)|0)+3|0]=8;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|64;continue}t[(c+B(e,6)|0)+3|0]=10;v[22452]=0;e=T(197,j|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break ta}t[b+5|0]=e;v[22452]=0;Q(179,d|0,1)|0;b=v[22452];v[22452]=0;if((b|0)!=1){continue}break ta}t[(c+B(e,6)|0)+3|0]=15;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|192;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|208;continue}t[(c+B(e,6)|0)+3|0]=12;t[b+5|0]=(f&254)>>>1;v[22452]=0;Q(179,d|0,1)|0;b=v[22452];v[22452]=0;if((b|0)!=1){continue}break ta}t[(c+B(e,6)|0)+3|0]=14;t[b+5|0]=0;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|176;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|224;continue}t[(c+B(e,6)|0)+3|0]=16;continue}t[(c+B(e,6)|0)+3|0]=17;continue}t[(c+B(e,6)|0)+3|0]=1;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|32;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|128;continue}t[(c+B(e,6)|0)+3|0]=0;continue}break}qb(d)}h=h+1|0;continue}break}break ta}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;qb(d);break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}jh(d+160|0);continue}}b=P()|0;O()|0;break j}Yc(d+224|0);dQ(l);qb(d+256|0);break b}b=P()|0;O()|0}Yc(d+120|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;qb(d+120|0);break m}b=P()|0;O()|0;break l}b=P()|0;O()|0;pb(d+120|0);break l}b=P()|0;O()|0;break l}Rd(d+160|0)}nt(i)}qb(d+192|0)}Yc(d+224|0);break h}b=P()|0;O()|0}dQ(l);break f}b=P()|0;O()|0}qb(d+256|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0}Rd(p);qb(q);S(b|0);L()}Rd(p);qb(q)}ab=d+336|0;return e|0}function $T(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=ab-416|0;ab=d;qc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!Mh(b,d+408|0)){break F}if(!tB(d+408|0)){break F}if(!c){p=1;break F}q=_d(d+384|0,b);v[22452]=0;R(255,d+368|0,q|0);b=v[22452];v[22452]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((b|0)!=1){v[22452]=0;U(256,d+224|0,d+368|0,1229866575);b=v[22452];v[22452]=0;if((b|0)==1){break da}v[22452]=0;p=Q(257,d+224|0,d+352|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break fa}qb(d+224|0);if(!p){break G}v[22452]=0;R(240,a|0,524288);b=v[22452];v[22452]=0;ga:{if((b|0)==1){break ga}wg(a);v[a+480208>>2]=12;b=d+360|0;I=a+480188|0,J=Ld(Ab(w[b|0]|w[b+1|0]<<8),1,127),u[I>>1]=J;b=d+352|0;I=d,J=Ab(w[b|0]|w[b+1|0]<<8),u[I+224>>1]=J;u[d+328>>1]=255;I=a+480192|0,J=x[Lc(d+224|0,d+328|0)>>1],u[I>>1]=J;b=b|2;I=d,J=Ab(w[b|0]|w[b+1|0]<<8),u[I+224>>1]=J;u[d+328>>1]=3999;I=a+480190|0,J=x[Lc(d+224|0,d+328|0)>>1],u[I>>1]=J;v[22452]=0;b=Y(258,a+1074312|0,6,1)|0;e=v[22452];v[22452]=0;if((e|0)==1){break ga}v[22452]=0;b=Q(259,b|0,21)|0;e=v[22452];v[22452]=0;if((e|0)==1){break ga}v[22452]=0;Q(259,b|0,13)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break ea}}b=P()|0;O()|0;break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;qb(d+224|0);break b}v[22452]=0;b=Q(1,d+224|0,9253)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}tb(a+1298344|0,b);pb(b);v[22452]=0;b=Q(1,d+224|0,10278)|0;e=v[22452];v[22452]=0;if((e|0)==1){break d}tb(a+1298356|0,b);pb(b);v[22452]=0;R(260,d+328|0,4297);b=v[22452];v[22452]=0;if((b|0)==1){break e}v[22452]=0;R(261,d+304|0,d+408|4);b=v[22452];v[22452]=0;if((b|0)==1){break g}v[22452]=0;R(261,d+280|0,d+408|5);b=v[22452];v[22452]=0;if((b|0)==1){break i}v[22452]=0;W(102,d+224|0,d+328|0,d+304|0,d+280|0);b=v[22452];v[22452]=0;if((b|0)==1){break j}b=d+224|0;tb(a+1298368|0,b);pb(b);pb(d+280|0);pb(d+304|0);b=d+328|0;yb(b);v[a+1298404>>2]=2;v[22452]=0;U(256,b|0,d+368|0,1312902469);b=v[22452];v[22452]=0;if((b|0)==1){break k}v[22452]=0;b=T(151,d+328|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break m}v[22452]=0;e=a+1298308|0;U(262,d+328|0,e|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break m}v[22452]=0;U(256,d+304|0,d+368|0,1397706311);b=v[22452];v[22452]=0;if((b|0)==1){break n}b=a+484360|0;uc(Kb(b));g=d+352|4;g=Ab(w[g|0]|w[g+1|0]<<8);ha:{ia:{while(1){if(g>>>0<=(f&65535)>>>0){break ha}v[22452]=0;h=Q(147,d+304|0,46)|0;j=v[22452];v[22452]=0;ja:{if((j|0)!=1){if(!h){break ha}v[22452]=0;R(263,d+304|0,d+224|0);h=v[22452];v[22452]=0;if((h|0)!=1){if(!pd(e)){break ja}v[22452]=0;Q(264,e|0,d+224|0)|0;h=v[22452];v[22452]=0;if((h|0)!=1){break ja}}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}v[22452]=0;h=T(265,d+304|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break ca}j=Kb(b);if(!jc(v[j>>2],v[j+4>>2])){v[22452]=0;j=T(266,b|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break ca}if((j|0)==255){break ha}}j=Kb(b);v[22452]=0;U(5,d+280|0,2,d+224|0);k=v[22452];v[22452]=0;if((k|0)!=1){v[22452]=0;R(267,j|0,d+280|0);j=v[22452];v[22452]=0;if((j|0)==1){break ia}pb(d+280|0);j=Kb(b);v[22452]=0;U(268,j|0,d+304|0,h|0);h=v[22452];v[22452]=0;if((h|0)==1){break ca}f=f+1|0;continue}break}b=P()|0;O()|0;break o}b=P()|0;O()|0;pb(d+280|0);break o}si(b,0);v[22452]=0;U(256,d+280|0,d+368|0,1229869908);b=v[22452];v[22452]=0;if((b|0)==1){break ba}v[22452]=0;b=T(269,d+280|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break p}ka:{if(!b){break ka}h=d+262|0;j=d+272|0;b=d+266|0;k=d+258|0;n=d+256|0;m=d+270|0;e=d+254|0;o=a+480192|0;f=1;la:{while(1){g=f&65535;if(g>>>0>x[o>>1]){v[22452]=0;U(256,d+200|0,d+368|0,1447382614);b=v[22452];v[22452]=0;if((b|0)!=1){break la}break p}v[22452]=0;R(270,d+280|0,d+224|0);i=v[22452];v[22452]=0;if((i|0)==1){break p}i=w[e|0]|w[e+1|0]<<8;v[22452]=0;g=Y(245,a|0,g|0,Ab(i)|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break p}ma:{na:{if(!g){break na}if(Ab(w[e|0]|w[e+1|0]<<8)>>>0>3999){break na}cu(d+112|0,2,d+224|0);v[22452]=0;W(213,d+136|0,v[d+112>>2],v[d+116>>2],w[d+120|0]);i=v[22452];v[22452]=0;if((i|0)==1){break ma}i=d+136|0;sc(g+492|0,i);pb(i);cu(d+112|0,2,d+224|0);v[22452]=0;W(213,i|0,v[d+112>>2],v[d+116>>2],w[d+120|0]);i=v[22452];v[22452]=0;if((i|0)==1){break p}i=d+136|0;sc(((Ab(w[e|0]|w[e+1|0]<<8)<<5)+a|0)+946304|0,i);pb(i);v[g>>2]=0;I=g,J=Ab(w[m|0]|w[m+1|0]<<8)+128&65535,v[I+8>>2]=J;mc(g+8|0,256);t[g+15|0]=w[g+15|0]|1;g=w[e|0]|w[e+1|0]<<8;v[22452]=0;g=B(Ab(g),104)+a|0;R(271,g+484380|0,0);i=v[22452];v[22452]=0;if((i|0)==1){break p}I=d,J=Ab(w[n|0]|w[n+1|0]<<8),u[I+136>>1]=J;u[d+112>>1]=64;I=g+484410|0,J=x[Lc(d+136|0,d+112|0)>>1]<<2,u[I>>1]=J;I=g+484404|0,J=Wb(w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24)),v[I>>2]=J;if(!Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break na}if(!(Ab(w[j|0]|w[j+1|0]<<8)&3)){break na}i=Wb(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24));v[g+484384>>2]=i;I=g+484388|0,J=Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+i|0,v[I>>2]=J;g=g+484414|0;i=x[g>>1];u[g>>1]=i|2;if(!(Ab(w[j|0]|w[j+1|0]<<8)&2)){break na}u[g>>1]=i|6}f=f+1|0;continue}break}break p}b=v[d+212>>2];v[d+32>>2]=v[d+208>>2];v[d+36>>2]=b;v[d+40>>2]=v[d+216>>2];v[22452]=0;b=v[d+204>>2];v[d+24>>2]=v[d+200>>2];v[d+28>>2]=b;W(272,d+24|0,0,a|0,0);b=v[22452];v[22452]=0;if((b|0)==1){break p}v[22452]=0;U(256,d+176|0,d+368|0,1346719318);b=v[22452];v[22452]=0;if((b|0)==1){break p}b=v[d+188>>2];v[d+8>>2]=v[d+184>>2];v[d+12>>2]=b;v[d+16>>2]=v[d+192>>2];v[22452]=0;b=v[d+180>>2];v[d>>2]=v[d+176>>2];v[d+4>>2]=b;W(272,d|0,1,a|0,w[d+412|0]>2|0);b=v[22452];v[22452]=0;if((b|0)==1){break p}e=x[a+480192>>1];b=1;while(1){f=b&65535;if(f>>>0>e>>>0){break ka}f=v[((f<<2)+a|0)+900380>>2];if(!(!f|t[f+60|0]&1)){v[f>>2]=32767}b=b+1|0;continue}}qb(d+280|0);v[22452]=0;U(256,d+224|0,d+368|0,1346458708);b=v[22452];v[22452]=0;if((b|0)==1){break q}v[22452]=0;b=T(169,d+224|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break s}if(!(!(c&1)|b^1)){v[22452]=0;U(256,d+280|0,d+368|0,1347305805);b=v[22452];v[22452]=0;if((b|0)==1){break t}v[22452]=0;Q(179,d+280|0,1)|0;b=v[22452];v[22452]=0;if((b|0)==1){break v}o=d+352|6;b=w[o|0]|w[o+1|0]<<8;v[22452]=0;j=a+484344|0;R(216,j|0,Ab(b)|0);b=v[22452];v[22452]=0;if((b|0)==1){break v}b=d+112|0;y=b|5;z=b|3;A=b|4;C=b|2;D=b|1;g=Pb(d+160|0);E=a+480188|0;f=0;while(1){if(Ab(w[o|0]|w[o+1|0]<<8)>>>0<=f>>>0){_c(g);qb(d+280|0);if(!(c&4)){break $}e=0;if(!F){break aa}f=x[a+480188>>1];b=0;e=1;while(1){if((b|0)==(f|0)){break aa}g=(b<<5)+a|0;t[g+480288|0]=1;g=g+480280|0;v[g>>2]=v[g>>2]|67108864;b=b+1|0;continue}}v[22452]=0;h=T(265,d+224|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break x}v[22452]=0;b=T(273,d+224|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break y}v[22452]=0;U(181,d+112|0,d+224|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break z}e=d+112|0;b=bc(d+136|0,e);qb(e);v[22452]=0;e=Y(217,j|0,f&65535,h|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break B}oa:{if(e){n=Bb(d+96|0);v[22452]=0;R(274,d+280|0,n|0);e=v[22452];v[22452]=0;if((e|0)==1){break oa}e=Rb(j,f);v[22452]=0;R(275,e|0,n|0);e=v[22452];v[22452]=0;if((e|0)==1){break oa}m=0;e=Of(Rb(j,f),0);uc(g);G=(h>>>0>1?h:1)-1|0;pa:while(1){v[22452]=0;h=Q(147,d+136|0,1)|0;k=v[22452];v[22452]=0;if((k|0)==1){break C}qa:{if(!h){break qa}v[22452]=0;k=T(197,b|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break C}if(!k){I=d,J=wb(v[g>>2]),v[I+88>>2]=J;h=wb(v[g+4>>2]);while(1){e=v[d+88>>2];if(Tb(e,h)){je(Rb(j,f),Ae(ve(d+112|0,w[e|0],w[e+1|0]),m));Ke(d+88|0);continue}else{uc(g);if((m|0)==(G|0)){break qa}m=m+1|0;e=Of(Rb(j,f),m);continue pa}}}kh(d+112|0);r=x[E>>1];v[22452]=0;h=T(197,b|0)|0;i=v[22452];v[22452]=0;ra:{sa:{if((i|0)!=1){s=k-1|0;ta:{if(!(h&1)){break ta}v[22452]=0;i=T(197,b|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break C}l=k>>>0>r>>>0?d+112|0:B(s,6)+e|0;if((i|0)!=31){if((i-1&255)>>>0>252){break ta}i=(B(i>>>4|0,12)+(i&15)|0)+13|0}else{i=255}t[l|0]=i}if(!(h&2)){break ra}v[22452]=0;i=T(197,b|0)|0;l=v[22452];v[22452]=0;if((l|0)!=1){break sa}}break C}t[(k>>>0>r>>>0?D:(B(s,6)+e|0)+1|0)|0]=i}if(!(h&60)){continue}t[d+87|0]=0;t[d+86|0]=0;t[d+85|0]=0;t[d+84|0]=0;if(h&4){v[22452]=0;i=T(197,b|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break C}t[d+86|0]=i}if(h&8){v[22452]=0;i=T(197,b|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break C}t[d+84|0]=i}if(h&16){v[22452]=0;i=T(197,b|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break C}t[d+87|0]=i}if(h&32){v[22452]=0;h=T(197,b|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break C}t[d+85|0]=h}rB(d+87|0,d+85|0);rB(d+86|0,d+84|0);h=w[d+86|0];if(!(w[d+87|0]==13|h?(h|0)!=13:0)){Tg(d+87|0,d+86|0);Tg(d+85|0,d+84|0)}Yn(d+88|0,d+87|0,d+85|0,d+86|0,d+84|0);if(pB(w[d+88|0],w[d+89|0])){$b(d+80|0,wb(v[g>>2]));v[22452]=0;U(276,g|0,v[d+80>>2],d+88|0);h=v[22452];v[22452]=0;if((h|0)==1){break C}}h=B(s,6)+e|0;k=k>>>0>r>>>0;t[(k?C:h+2|0)|0]=w[d+87|0];t[(k?A:h+4|0)|0]=w[d+85|0];i=w[d+86|0];t[(k?z:h+3|0)|0]=i;t[(k?y:h+5|0)|0]=w[d+84|0];if((i|0)==43){F=1;continue}if((i|0)!=31){continue}H=1;continue}break}pb(n)}f=f+1|0;qb(d+136|0);continue}break}break C}e=0;if(c&4){break aa}break H}b=P()|0;O()|0;break b}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}v[d+136>>2]=-1778364416;v[d+140>>2]=-16756736;v[22452]=0;U(256,d+280|0,d+368|0,1146310725);b=v[22452];v[22452]=0;if((b|0)==1){break E}v[22452]=0;b=T(269,d+280|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break D}if(b){v[22452]=0;h=T(265,d+280|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break D}j=a+480188|0;b=0;f=e;while(1){ua:{if((b|0)==(h|0)){v[22452]=0;R(277,d+280|0,d+136|0);b=v[22452];v[22452]=0;if((b|0)!=1){break ua}break D}v[22452]=0;g=T(197,d+280|0)|0;k=v[22452];v[22452]=0;va:{wa:{if((k|0)!=1){if(x[j>>1]<=b>>>0){break va}if(!e){break wa}k=((b<<5)+a|0)+480280|0;v[k>>2]=v[k>>2]&-67108865|((g|0)!=0)<<26;break va}break D}if(g){break va}f=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}break}e=f&1}qb(d+280|0);if(!e){break $}v[22452]=0;Z(278,a+906300|0);b=v[22452];v[22452]=0;if((b|0)==1){break _}b=a+906316|0;v[b>>2]=810369604;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[d+280>>2]=0;f=a+906348|0;b=d+280|0;mB(a+906332|0,f,b);v[22452]=0;b=Q(55,b|0,9527)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Z}bu(f,b);pb(b);v[22452]=0;b=Q(55,d+280|0,9491)|0;f=v[22452];v[22452]=0;if((f|0)==1){break Y}gq(a+906380|0,b);pb(b);v[22452]=0;b=a+906304|0;R(279,b|0,8);f=v[22452];v[22452]=0;if((f|0)==1){break _}lB(d+280|0,w[d+137|0],w[d+139|0],w[d+141|0],w[d+143|0]);f=v[d+284>>2];b=v[b>>2];e=v[d+280>>2];t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=f;t[b+5|0]=f>>>8;t[b+6|0]=f>>>16;t[b+7|0]=f>>>24}if(!H){break H}f=a+902204|0;b=0;while(1){if((b|0)==32){break H}v[d+160>>2]=B(b,127)>>>5;v[22452]=0;R(280,d+136|0,4054);e=v[22452];v[22452]=0;if((e|0)==1){break X}v[22452]=0;R(281,d+112|0,d+160|0);e=v[22452];v[22452]=0;if((e|0)==1){break W}v[22452]=0;U(282,d+280|0,d+136|0,d+112|0);e=v[22452];v[22452]=0;if((e|0)==1){break V}e=d+280|0;qe(d+72|0,e);Ie(ie(f,b),v[d+72>>2],v[d+76>>2]);pb(e);pb(d+112|0);e=d+136|0;yb(e);v[22452]=0;R(280,e|0,4036);e=v[22452];v[22452]=0;if((e|0)==1){break T}v[22452]=0;R(281,d+112|0,d+160|0);e=v[22452];v[22452]=0;if((e|0)==1){break S}v[22452]=0;U(282,d+280|0,d+136|0,d+112|0);e=v[22452];v[22452]=0;if((e|0)==1){break R}e=d+280|0;qe(d- -64|0,e);Ie(ie(f,b+32|0),v[d+64>>2],v[d+68>>2]);pb(e);pb(d+112|0);e=d+136|0;yb(e);v[22452]=0;R(280,e|0,4027);e=v[22452];v[22452]=0;if((e|0)==1){break P}v[22452]=0;R(281,d+112|0,d+160|0);e=v[22452];v[22452]=0;if((e|0)==1){break O}v[22452]=0;U(282,d+280|0,d+136|0,d+112|0);e=v[22452];v[22452]=0;if((e|0)==1){break N}e=d+280|0;qe(d+56|0,e);Ie(ie(f,b- -64|0),v[d+56>>2],v[d+60>>2]);pb(e);pb(d+112|0);e=d+136|0;yb(e);v[22452]=0;R(280,e|0,4e3);e=v[22452];v[22452]=0;if((e|0)==1){break L}v[22452]=0;R(281,d+112|0,d+160|0);e=v[22452];v[22452]=0;if((e|0)==1){break K}v[22452]=0;U(282,d+280|0,d+136|0,d+112|0);e=v[22452];v[22452]=0;if((e|0)==1){break J}e=d+280|0;qe(d+48|0,e);Ie(ie(f,b+96|0),v[d+48>>2],v[d+52>>2]);b=b+1|0;pb(e);pb(d+112|0);yb(d+136|0);continue}}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break U}b=P()|0;O()|0;pb(d+112|0)}yb(d+136|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break Q}b=P()|0;O()|0;pb(d+112|0)}yb(d+136|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break M}b=P()|0;O()|0;pb(d+112|0)}yb(d+136|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break I}b=P()|0;O()|0;pb(d+112|0)}yb(d+136|0);break r}v[22452]=0;U(256,d+280|0,d+368|0,1397575756);b=v[22452];v[22452]=0;xa:{if((b|0)!=1){v[22452]=0;b=T(169,d+280|0)|0;f=v[22452];v[22452]=0;if((f|0)!=1){ya:{if(!(c&2)|b^1){break xa}c=a+480190|0;f=1;while(1){e=f&65535;if(e>>>0>x[c>>1]){break xa}v[22452]=0;b=T(273,d+280|0)|0;g=v[22452];v[22452]=0;za:{if((g|0)!=1){v[22452]=0;g=T(273,d+280|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break ya}if(!(b&7)){break za}e=(B(e,104)+a|0)+484380|0;v[e>>2]=g;b=Gc(d+136|0,b&4?32:b&2?16:8,1,1,0);v[22452]=0;Y(210,b|0,e|0,d+280|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break za}break ya}break ya}f=f+1|0;continue}}}b=P()|0;O()|0;qb(d+280|0);break r}b=P()|0;O()|0;break r}qb(d+280|0);qb(d+224|0);qb(d+304|0);qb(d+328|0)}Rd(d+368|0);qb(q)}ab=d+416|0;return p|0}b=P()|0;O()|0;break r}b=P()|0;O()|0;qb(d+280|0);break r}b=P()|0;O()|0;pb(n);break A}b=P()|0;O()|0}qb(d+136|0);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0}_c(g);break u}b=P()|0;O()|0}qb(d+280|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0}qb(d+224|0);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;qb(d+280|0)}qb(d+304|0);break l}b=P()|0;O()|0;break l}b=P()|0;O()|0}qb(d+328|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;pb(d+280|0);break h}b=P()|0;O()|0}pb(d+304|0);break f}b=P()|0;O()|0}yb(d+328|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}Rd(d+368|0)}qb(q);S(b|0);L()}function Dha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=ab-240|0;ab=d;qc(b);e=ab-16|0;ab=e;h=d+216|0;Ot(e+8|0,h);g=v[e+12>>2];_b(e,b,v[e+8>>2],g);i=v[e+4>>2];if((i|0)==(g|0)){Ob(b,v[e+12>>2])}ab=e+16|0;e=(g|0)==(i|0);if(!e){PS(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!QS(d+216|0)){break n}if(!c){f=1;break n}vd(a,1024);wg(a);v[a+480208>>2]=v[a+480208>>2]|12;Cf(a+1074312|0,21);e=Ab(w[d+232|0]|w[d+233|0]<<8);if(e){v[a+480204>>2]=B(e,1e4)}e=Ab(w[d+230|0]|w[d+231|0]<<8);if(e){v[a+480196>>2]=e}if(!w[d+226|0]){lh(a,1)}e=d+216|4;du(b,a+1298308|0,Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-14|0);b=_d(d+112|0,b);v[22452]=0;R(335,d+200|0,b|0);e=v[22452];v[22452]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((e|0)!=1){qb(b);v[22452]=0;U(336,d+112|0,d+200|0,1395544366);b=v[22452];v[22452]=0;if((b|0)==1){break s}v[22452]=0;b=T(269,d+112|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break y}if(!b){break r}v[22452]=0;b=T(265,d+112|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break y}v[22452]=0;e=T(265,d+112|0)|0;f=v[22452];v[22452]=0;A:{if((f|0)==1){break A}v[22452]=0;Q(179,d+112|0,4)|0;f=v[22452];v[22452]=0;if((f|0)==1){break A}f=a+484360|0;g=Kb(f);v[22452]=0;ea(337,g|0,d+112|0,b|0,65535,65535)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break z}}break y}a=P()|0;O()|0;qb(b);break a}Re(Kb(f),e);b=d+112|0;qb(b);v[22452]=0;U(336,b|0,d+200|0,1346458708);b=v[22452];v[22452]=0;if((b|0)==1){break x}v[22452]=0;e=T(269,d+112|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break w}f=0;b=0;if(!e){break t}v[22452]=0;e=T(265,d+112|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break w}u[a+480188>>1]=e;if((e-33&65535)>>>0<65504){break t}v[22452]=0;b=T(265,d+112|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break w}v[22452]=0;R(216,a+484344|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break w}b=0;v[22452]=0;m=T(273,d+112|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break w}switch(m-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}a=P()|0;O()|0;qb(d+112|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;qb(d+112|0);break b}if(m){break t}}b=1}qb(d+112|0);if(!b){break o}v[22452]=0;U(336,d+176|0,d+200|0,1398157625);b=v[22452];v[22452]=0;if((b|0)==1){break d}v[22452]=0;b=T(269,d+176|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}if(!b){break q}v[22452]=0;Q(179,d+176|0,2)|0;b=v[22452];v[22452]=0;if((b|0)==1){break c}v[22452]=0;b=T(273,d+176|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}G=a,H=xe((+(b>>>0)*2.3283064365386963e-10+ +(y[a+480204>>2]/1e4>>>0))*1e4),v[G+480204>>2]=H;b=0;v[22452]=0;Q(338,d+176|0,d+112|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}f=a+480188|0;while(1){if((b|0)!=32&x[f>>1]>b>>>0){e=(d+112|0)+(b<<1)|0;G=d,H=Ab(w[e|0]|w[e+1|0]<<8),v[G+48>>2]=H;v[d+32>>2]=180;e=v[jd(d+48|0,d+32|0)>>2]-90|0;g=e>>31;G=((b<<5)+a|0)+480284|0,H=vc(pia(e<<7|45,g<<7|e>>>25,90,0),db)+128|0,u[G>>1]=H;b=b+1|0;continue}else{B:{v[22452]=0;Q(179,d+176|0,16)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break B}break c}}break}v[22452]=0;b=Q(147,d+176|0,2)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}C:{if(b){v[22452]=0;b=T(265,d+176|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break C}u[d+48>>1]=b;u[d+32>>1]=256;G=a,H=x[Lc(d+48|0,d+32|0)>>1],v[G+480200>>2]=H}v[22452]=0;Q(179,d+176|0,128)|0;b=v[22452];v[22452]=0;if((b|0)==1){break c}v[22452]=0;b=Q(338,d+176|0,d+48|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){if(!b){break q}b=0;e=a+480188|0;while(1)if((b|0)!=32&x[e>>1]>b>>>0){f=(d+48|0)+(b<<1)|0;G=d,H=Ab(w[f|0]|w[f+1|0]<<8),v[G+32>>2]=H;v[d+16>>2]=128;G=((b<<5)+a|0)+480286|0,H=v[jd(d+32|0,d+16|0)>>2]/2&255,u[G>>1]=H;b=b+1|0;continue}else{v[a+480228>>2]=v[a+480228>>2]<<1;break q}}break c}break c}a=P()|0;O()|0;break b}qb(d+112|0);break p}qb(d+176|0);v[22452]=0;U(336,d+112|0,d+200|0,1413830740);b=v[22452];v[22452]=0;D:{E:{if((b|0)!=1){v[22452]=0;b=T(269,d+112|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break e}if(!b){break D}v[22452]=0;R(339,d+112|0,d+48|0);b=v[22452];v[22452]=0;if((b|0)==1){break e}if((Ab(w[d+58|0]|w[d+59|0]<<8)|0)!=65535){break E}v[22452]=0;Q(179,d+112|0,1)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break E}break e}a=P()|0;O()|0;break b}v[22452]=0;b=T(193,d+112|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break e}v[22452]=0;W(326,a+1298332|0,d+112|0,b|0,2);b=v[22452];v[22452]=0;if((b|0)==1){break e}}qb(d+112|0);v[22452]=0;U(336,d+48|0,d+200|0,1229869908);b=v[22452];v[22452]=0;if((b|0)==1){break h}v[22452]=0;b=T(269,d+48|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break l}if(b){F:{v[22452]=0;b=T(265,d+48|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break i}G:{H:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break H}v[22452]=0;e=Q(147,d+48|0,B(f,(b>>>14&2)+50|0)|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break g}if(!e){break H}u[a+480190>>1]=f;g=a+480190|0;h=d+130|0;i=(b|0)>=0;b=1;I:{J:{K:{L:{while(1){if(f>>>0<(b&65535)>>>0){v[22452]=0;b=T(265,d+48|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){break I}break g}M:{if(i){p=b}else{v[22452]=0;e=T(265,d+48|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break M}p=e+1|0}u[d+16>>1]=p;v[22452]=0;R(340,d+48|0,d+112|0);e=v[22452];v[22452]=0;if((e|0)==1){break L}e=x[d+16>>1];if((e-4e3&65535)>>>0>=61537){G=a,H=x[Ne(g,d+16|0)>>1],u[G+480190>>1]=H;j=w[d+234|0]|w[d+235|0]<<8|(w[d+236|0]<<16|w[d+237|0]<<24);v[22452]=0;W(341,d+112|0,(B(e,104)+a|0)+484380|0,Wb(j)|0,m|0);e=v[22452];v[22452]=0;if((e|0)==1){break K}gl(d+32|0,2,h);v[22452]=0;W(213,d+176|0,v[d+32>>2],v[d+36>>2],w[d+40|0]);e=v[22452];v[22452]=0;if((e|0)==1){break J}e=d+176|0;sc(((x[d+16>>1]<<5)+a|0)+946304|0,e);pb(e)}b=b+1|0;continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}if((b|0)!=4){break G}u[d+112>>1]=x[a+480190>>1];u[d+176>>1]=255;i=a+480192|0;b=d+176|0;G=i,H=x[Lc(d+112|0,b)>>1],u[G>>1]=H;v[22452]=0;U(336,b|0,d+200|0,1229278806);b=v[22452];v[22452]=0;if((b|0)==1){break j}b=d+32|0;g=b|4;j=b|3;h=b|5;q=b|7;N:{O:while(1){v[22452]=0;b=Q(147,d+48|0,15)|0;e=v[22452];v[22452]=0;if((e|0)==1){break N}if(b){v[22452]=0;R(342,d+48|0,d+32|0);b=v[22452];v[22452]=0;if((b|0)==1){break k}b=Ab(w[d+32|0]|w[d+33|0]<<8);if(b>>>0>=x[i>>1]){continue}b=B(b,104)+a|0;t[b+484524|0]=w[d+40|0];e=w[q|0];t[b+484523|0]=255;t[b+484525|0]=e;b=w[d+32|0]|w[d+33|0]<<8;v[22452]=0;b=Ab(b)+1&65535;e=Y(245,a|0,b|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break k}if(!e){continue}G=d,H=Ab(w[h|0]|w[h+1|0]<<8),u[G+112>>1]=H;u[d+16>>1]=4095;G=e,H=x[Lc(d+112|0,d+16|0)>>1],v[G>>2]=H;b=w[j|0];if((b|0)==255){continue}v[22452]=0;b=Q(146,d+176|0,B(b,34)+2|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break k}if(!b){continue}v[22452]=0;R(343,d+176|0,d+112|0);b=v[22452];v[22452]=0;if((b|0)==1){break k}t[e+60|0]=w[e+60|0]|1;b=w[d+112|0]|w[d+113|0]<<8;v[d+20>>2]=16;v[d+24>>2]=240;G=d,H=Ab(b),v[G+16>>2]=H;b=au(d+16|0);v[22452]=0;f=e+48|0;R(285,f|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break k}b=0;while(1)if(Td(f)>>>0<=b>>>0){if(w[g|0]!=255){t[e+60|0]=w[e+60|0]|4;b=w[g|0];t[e+63|0]=b;t[e- -64|0]=b}if(jc(v[f>>2],v[e+52>>2])){continue O}t[e+60|0]=w[e+60|0]|2;b=Td(f)-1|0;t[e+61|0]=b;t[e+62|0]=b;continue O}else{t[d+16|0]=64;o=(d+112|0)+(b<<1)|0;t[d+8|0]=w[o+2|0];r=Qb(d+16|0,d+8|0);l=Fb(v[f>>2],b);t[l+2|0]=w[r|0];u[l>>1]=w[o+3|0];b=b+1|0;continue}}break}qb(d+176|0);break F}break k}qb(d+48|0);break p}}}qb(d+48|0);v[22452]=0;U(344,d+176|0,d+200|0,1145131092);b=v[22452];v[22452]=0;if((b|0)==1){break m}G=d,H=wb(v[d+176>>2]),v[G+8>>2]=H;i=a+484344|0;C=c&1;q=d+48|4;D=wb(v[d+180>>2]);o=(m|0)!=841887798;r=a+480188|0;E=(m|0)!=841887796;while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{g=v[d+8>>2];if(!Tb(g,D)){Yc(d+176|0);v[22452]=0;U(336,d+112|0,d+200|0,1346458702);b=v[22452];v[22452]=0;if((b|0)!=1){break ba}a=P()|0;O()|0;break b}v[22452]=0;Q(179,g|0,4)|0;b=v[22452];v[22452]=0;if((b|0)!=1){v[22452]=0;f=T(265,g|0)|0;b=v[22452];v[22452]=0;ca:{if((b|0)!=1){v[22452]=0;j=T(265,g|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break R}j=o?j:(j>>>0)/y[a+480196>>2]|0;if(!C|f>>>0>255){break P}v[22452]=0;b=Y(217,i|0,f|0,j|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break R}if(b){break ca}break P}a=P()|0;O()|0;break Q}if(!o){h=0;v[22452]=0;Q(179,g|0,4)|0;b=v[22452];v[22452]=0;if((b|0)==1){break R}while(1){A=h&65535;if(A>>>0>=x[r>>1]){break P}v[22452]=0;b=T(265,g|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break aa}v[22452]=0;U(181,d+48|0,g|0,b+(b&1)&65535);b=v[22452];v[22452]=0;if((b|0)==1){break S}b=d+48|0;l=bc(d+112|0,b);qb(b);v[d+48>>2]=0;v[d+52>>2]=0;n=0;da:{while(1){v[22452]=0;b=Q(147,d+112|0,6)|0;e=v[22452];v[22452]=0;if((e|0)==1){break da}e=v[d+48>>2];if(b&e>>>0<j>>>0){b=Qc(Rb(i,f),e,A);v[22452]=0;R(345,d+16|0,l|0);e=v[22452];v[22452]=0;ea:{fa:{if((e|0)!=1){e=d+16|0;k=Zc(e);F=Me(e);p=vi(e);s=ac(e);z=t[e|0];if((z-1&255)>>>0>95){break fa}t[b|0]=z+13;if(!v[d+52>>2]){break ea}t[b+3|0]=19;v[d+32>>2]=15;G=b,H=w[jd(q,d+32|0)|0]|208,t[G+5|0]=H;break ea}break T}if((z|0)>=0){break ea}if(v[d+52>>2]){t[b+3|0]=19;v[d+32>>2]=15;G=b,H=w[jd(q,d+32|0)|0]|192,t[G+5|0]=H;break ea}t[b|0]=254}if(w[k|0]){t[b+2|0]=1;t[d+32|0]=64;G=b,H=w[Qb(k,d+32|0)|0],t[G+4|0]=H}k=w[F|0];if(k){t[b+1|0]=k}k=w[p|0];if(k|w[s|0]){t[b+3|0]=k;t[b+5|0]=w[s|0];Mf(b)}k=d+32|0;b=w[e+5|0];if(b&128){v[22452]=0;e=T(197,l|0)|0;s=v[22452];v[22452]=0;if((s|0)==1){break T}b=e|b<<8&32512}n=b+n|0;aB(k,n,v[a+480196>>2]);b=v[d+36>>2];v[d+48>>2]=v[d+32>>2];v[d+52>>2]=b;continue}break}h=h+1|0;qb(d+112|0);continue}break}break T}h=0;b=Qc(Rb(i,f),0,0);ga:while(1){f=0;if((h|0)==(j|0)){break P}while(1){if(x[r>>1]<=(f&65535)>>>0){h=h+1|0;continue ga}v[22452]=0;R(346,d+112|0,g|0);e=v[22452];v[22452]=0;if((e|0)==1){break $}ha:{if(!E){v[d+48>>2]=v[d+112>>2];e=d+48|0;l=Zc(e);n=Me(e);k=vi(e);e=t[e|0];if((e|0)>0){t[b|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+12}e=w[l|0];if(e>>>0>=4){t[b+2|0]=1;t[b+4|0]=(e>>>2|0)-1;e=w[l|0]}t[b+1|0]=e<<4&48|w[n|0]>>>4;t[b+3|0]=w[n|0]&15;t[b+5|0]=w[k|0];break ha}e=v[d+112>>2];v[d+4>>2]=e;v[d>>2]=e;Nt(d,b);G=b,H=w[b+1|0]|w[Cb(d+112|0,0)|0]&48,t[G+1|0]=H}Mf(b);e=w[b+3|0];ia:{if(e>>>0>11){break ia}e=1<<e;ja:{if(!(e&2240)){if(!(e&12)){break ia}if(!w[b+5|0]){break ja}break ia}e=w[b+5|0];l=e&240;if(l){t[b+5|0]=l;break ia}if(e){break ia}}t[b+3|0]=0}b=b+6|0;f=f+1|0;continue}}}a=P()|0;O()|0;break Q}v[22452]=0;b=T(269,d+112|0)|0;e=v[22452];v[22452]=0;ka:{la:{ma:{na:{oa:{if((e|0)!=1){if(b){e=Bb(d+48|0);b=0;pa:{while(1){qa:{v[22452]=0;f=Q(147,d+112|0,1)|0;g=v[22452];v[22452]=0;if((g|0)==1){break qa}if(!f){break pa}if(lf(i)>>>0<=b>>>0){break pa}v[22452]=0;U(347,d+112|0,e|0,32);f=v[22452];v[22452]=0;if((f|0)==1){break qa}f=Rb(i,b);v[22452]=0;R(275,f|0,e|0);f=v[22452];v[22452]=0;if((f|0)==1){break qa}b=b+1|0;continue}break}a=P()|0;O()|0;pb(e);break oa}pb(e)}b=d+112|0;qb(b);v[22452]=0;U(336,b|0,d+200|0,1414679374);b=v[22452];v[22452]=0;if((b|0)==1){break na}v[22452]=0;b=T(269,d+112|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break V}if(!b){break ka}e=Bb(d+48|0);f=a+480188|0;b=0;while(1){v[22452]=0;g=Q(147,d+112|0,1)|0;h=v[22452];v[22452]=0;if((h|0)==1){break ma}if(!g|x[f>>1]<=b>>>0){break la}v[22452]=0;U(347,d+112|0,e|0,32);g=v[22452];v[22452]=0;if((g|0)==1){break ma}jm(((b<<5)+a|0)+480289|0,e);b=b+1|0;continue}}a=P()|0;O()|0}qb(d+112|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;pb(e);break U}pb(e)}b=d+112|0;qb(b);v[22452]=0;U(344,b|0,d+200|0,1145129300);b=v[22452];v[22452]=0;if((b|0)==1){break W}G=d,H=wb(v[d+112>>2]),v[G+48>>2]=H;e=c&2;f=wb(v[d+116>>2]);g=a+480190|0;ra:{sa:{ta:{ua:{va:{wa:{while(1){b=v[d+48>>2];if(!Tb(b,f)){Yc(d+112|0);b=Bb(d+48|0);if((m|0)!=841887798){break va}v[22452]=0;c=Q(1,d+112|0,9461)|0;e=v[22452];v[22452]=0;if((e|0)==1){break wa}tb(b,c);pb(c);break ua}v[22452]=0;c=T(265,b|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break X}xa:{if(!(!e|c>>>0>=x[g>>1])){c=B(c,104)+a|0;h=x[c+484518>>1];h=Gc(d+176|0,h&1?16:8,h&64?2:1,1,0);v[22452]=0;Y(210,h|0,c+484484|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break xa}}jh(d+48|0);continue}break}break X}a=P()|0;O()|0;break Y}v[22452]=0;U(336,d+112|0,d+200|0,1447383635);c=v[22452];v[22452]=0;ya:{za:{Aa:{Ba:{Ca:{if((c|0)!=1){v[22452]=0;c=T(269,d+112|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break ta}if(!c){break za}v[22452]=0;c=T(273,d+112|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break Ca}v[22452]=0;R(260,d+32|0,4253);e=v[22452];v[22452]=0;if((e|0)==1){break Ba}v[d+16>>2]=c>>>4;v[22452]=0;v[d+8>>2]=c&15;W(348,d+176|0,d+32|0,d+16|0,d+8|0);c=v[22452];v[22452]=0;if((c|0)==1){break Aa}c=d+176|0;tb(b,c);pb(c);yb(d+32|0);break ya}a=P()|0;O()|0;break Y}a=P()|0;O()|0;break Z}a=P()|0;O()|0;break Z}a=P()|0;O()|0;yb(d+32|0);break Z}v[22452]=0;c=Q(1,d+176|0,8496)|0;e=v[22452];v[22452]=0;if((e|0)==1){break _}tb(b,c);pb(c)}qb(d+112|0)}v[22452]=0;c=Q(1,d+112|0,8496)|0;e=v[22452];v[22452]=0;if((e|0)==1){break sa}tb(a+1298344|0,c);pb(c);v[22452]=0;c=Q(1,d+112|0,10094)|0;e=v[22452];v[22452]=0;if((e|0)==1){break ra}tb(a+1298356|0,c);pb(c);tb(a+1298368|0,b);v[a+1298404>>2]=2;pb(b);f=1;break o}a=P()|0;O()|0;break Z}a=P()|0;O()|0;break Y}a=P()|0;O()|0;break Y}a=P()|0;O()|0;break Q}a=P()|0;O()|0;break Q}a=P()|0;O()|0}qb(d+112|0)}pb(b);break b}a=P()|0;O()|0;Yc(d+112|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}qb(d+112|0);break b}a=P()|0;O()|0;qb(d+112|0);break Q}a=P()|0;O()|0;break Q}a=P()|0;O()|0}Yc(d+176|0);break b}jh(d+8|0);continue}}f=0}Rd(d+200|0)}ab=d+240|0;return f|0}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;qb(d+176|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break b}a=P()|0;O()|0}qb(d+48|0);break b}a=P()|0;O()|0;qb(d+112|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;qb(d+176|0)}Rd(d+200|0)}S(a|0);L()}function uda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,W=0,X=0;e=ab-400|0;ab=e;qc(b);g=ab-16|0;ab=g;f=e+192|0;vP(g+8|0,f);o=b;b=v[g+12>>2];_b(g,o,v[g+8>>2],b);p=v[g+4>>2];if((p|0)==(b|0)){Ob(o,v[g+12>>2])}ab=g+16|0;b=(b|0)==(p|0);if(!b){uP(f)}a:{if(!b){break a}if(!wP(e+192|0)){break a}if(!c){d=1;break a}vd(a,134217728);b=e+136|0;af(b,3936);v[22452]=0;d=b;b=e+192|4;U(642,e+8|0,d|0,b|0);d=v[22452];v[22452]=0;b:{c:{d:{e:{f:{g:{if((d|0)!=1){d=e+8|0;tb(a+1298344|0,d);pb(d);yb(e+136|0);d=Mb(d,8945);tb(a+1298356|0,d);pb(d);v[a+480188>>2]=4;v[a+1298404>>2]=2;W=a,X=Ab(w[e+328|0]|w[e+329|0]<<8),v[W+480196>>2]=X;d=w[e+332|0]|w[e+333|0]<<8;v[a+480260>>2]=56;v[a+480264>>2]=13696;W=a,X=tP(Ab(d)),v[W+480204>>2]=X;cq(Kb(a+484360|0),e+200|0,w[e+192|6]);s=a+480190|0;j=a+480188|0;q=Pb(e+176|0);A=Pb(e+160|0);h:{i:{j:{k:{while(1){if(Ab(w[e+392|0]|w[e+393|0]<<8)>>>0<=(m&65535)>>>0){break k}v[22452]=0;d=T(265,o|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break g}u[e+112>>1]=d;if((d-4e3&65535)>>>0<=61536){break c}d=Ab(w[e+394|0]|w[e+395|0]<<8);if((Ab(w[b|0]|w[b+1|0]<<8)|0)==2){v[22452]=0;d=T(273,o|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break h}d=d-2|0}v[22452]=0;U(181,e+136|0,o|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break i}g=e+136|0;d=bc(e+8|0,g);qb(g);C=x[Ne(s,e+112|0)>>1];u[a+480190>>1]=C;v[22452]=0;p=B(x[e+112>>1],104)+a|0;f=p+484380|0;R(271,f|0,1);g=v[22452];v[22452]=0;l:{m:{n:{if((g|0)==1){break n}if(Ab(w[b|0]|w[b+1|0]<<8)>>>0>1){break m}v[22452]=0;R(643,d|0,p+484423|0);g=v[22452];v[22452]=0;if((g|0)==1){break n}v[22452]=0;Q(179,e+8|0,1)|0;g=v[22452];v[22452]=0;if((g|0)==1){break n}v[22452]=0;U(320,d|0,((x[e+112>>1]<<5)+a|0)+946304|0,30);g=v[22452];v[22452]=0;if((g|0)!=1){break l}}d=P()|0;O()|0;break f}g=Bb(e+136|0);v[22452]=0;U(347,d|0,g|0,257);k=v[22452];v[22452]=0;o:{p:{if((k|0)==1){break p}ke(p+484423|0,g);v[22452]=0;Q(179,e+8|0,1)|0;k=v[22452];v[22452]=0;if((k|0)==1){break p}v[22452]=0;U(347,d|0,g|0,31);k=v[22452];v[22452]=0;if((k|0)==1){break p}sc(((x[e+112>>1]<<5)+a|0)+946304|0,g);if(!(t[e+16|0]&1)){break o}v[22452]=0;Q(179,e+8|0,1)|0;k=v[22452];v[22452]=0;if((k|0)!=1){break o}}d=P()|0;O()|0;pb(g);break f}pb(g)}v[22452]=0;R(644,d|0,e+136|0);d=v[22452];v[22452]=0;q:{if((d|0)==1){break q}i=ab-16|0;ab=i;k=e+136|0;d=Wb(w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24));v[f>>2]=d;t[i+15|0]=w[k+4|0];t[i+14|0]=64;W=f,X=w[Qb(i+15|0,i+14|0)|0]<<2,u[W+30>>1]=X;g=k+6|0;h=Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));v[f+4>>2]=h;l=Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));g=k+10|0;g=l+Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))|0;v[f+8>>2]=g;if(d>>>0<=h>>>0){h=d-1|0;v[f+4>>2]=h}if(d>>>0<g>>>0){v[f+8>>2]=d;g=d}r:{if(g>>>0<h>>>0){v[f+4>>2]=0;v[f+8>>2]=0;break r}if(g>>>0<=h>>>0){break r}u[f+34>>1]=x[f+34>>1]|2;W=Fb(f+68|0,0),X=h,v[W>>2]=X}ab=i+16|0;d=Ab(w[b|0]|w[b+1|0]<<8);if((d|0)==2){t[p+484417|0]=w[e+154|0]<<3;d=Ab(w[b|0]|w[b+1|0]<<8)}s:{if(!d){break s}v[22452]=0;R(205,A|0,C|0);d=v[22452];v[22452]=0;if((d|0)==1){break q}v[22452]=0;R(645,q|0,C|0);d=v[22452];v[22452]=0;if((d|0)==1){break q}f=ld(v[q>>2],x[e+112>>1]-1|0);uc(f);v[22452]=0;g=T(265,o|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break j}v[22452]=0;d=Q(147,o|0,g<<3)|0;k=v[22452];v[22452]=0;if((k|0)==1){break j}if(d){v[22452]=0;R(646,f|0,g|0);d=v[22452];v[22452]=0;if((d|0)==1){break j}d=0;v[e+128>>2]=0;if(!(!(w[p+484414|0]&2)|g)){d=v[p+484384>>2];v[e+120>>2]=d;g=v[p+484388>>2];v[22452]=0;v[e+124>>2]=g-d;R(647,f|0,e+120|0);d=v[22452];v[22452]=0;if((d|0)!=1){break s}d=P()|0;O()|0;break f}while(1){if(g>>>0<=(d&65535)>>>0){break s}v[22452]=0;p=T(273,o|0)|0;k=v[22452];v[22452]=0;t:{if((k|0)==1){break t}v[22452]=0;v[e+120>>2]=p;p=T(273,o|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break t}v[22452]=0;v[e+124>>2]=p;R(647,f|0,e+120|0);p=v[22452];v[22452]=0;if((p|0)==1){break t}d=d+1|0;continue}break}d=P()|0;O()|0;break f}qb(e+8|0);break c}m=m+1|0;qb(e+8|0);continue}break}d=P()|0;O()|0;break f}E=128;p=b;u:{if(Ab(w[b|0]|w[b+1|0]<<8)){break u}v[22452]=0;E=T(265,o|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break u}d=P()|0;O()|0;break e}D=w[e+192|7];u[e+118>>1]=4;v:{w:{if(Ab(w[p|0]|w[p+1|0]<<8)){d=v[o+8>>2];f=0;while(1){x:{if((f&65535)>>>0>=E>>>0){break x}v[22452]=0;b=T(265,o|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break w}if((b|0)==65535){break x}v[22452]=0;D=T(265,o|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break w}v[22452]=0;b=T(265,o|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break w}u[e+118>>1]=b;if(b>>>0>127){break c}W=j,X=x[Ne(j,e+118|0)>>1],u[W>>1]=X;v[22452]=0;Q(179,o|0,B(b,D)<<2)|0;b=v[22452];v[22452]=0;if((b|0)==1){break w}f=f+1|0;continue}break}v[22452]=0;Q(146,o|0,d|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break v}}b=x[j>>1];v[22452]=0;F=Q(648,e+136|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){K=a+484344|0;V=c&1;G=Ab(w[e+330|0]|w[e+331|0]<<8);g=0;b=0;while(1){y:{z:{A:{B:{if((g&65535)>>>0>=E>>>0){break B}C:{if(!Ab(w[p|0]|w[p+1|0]<<8)){d=x[e+118>>1];f=g;break C}v[22452]=0;f=T(265,o|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break y}if((f|0)==65535){break B}v[22452]=0;D=T(265,o|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break y}v[22452]=0;d=T(265,o|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break y}u[e+118>>1]=d}v[22452]=0;k=d&65535;H=D&65535;d=H<<2;k=Q(147,o|0,B(k,d)|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break y}if(!k){break B}if(!V){break A}v[22452]=0;M=f&65535;f=Y(217,K|0,M|0,H|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break y}if(!f){break A}z=0;D:while(1){if((z|0)==(H|0)){break z}f=0;j=Of(Rb(K,M),z);I=0;k=0;E:{F:{G:{switch((G&3)-1|0){case 0:k=!(z&3);break F;case 1:k=!(z&1);break F;case 2:break G;default:break E}}k=(z&3)!=3}}while(1){if(x[e+118>>1]<=f>>>0){z=z+1|0;continue D}d=v[F>>2];v[22452]=0;R(346,e+120|0,o|0);i=v[22452];v[22452]=0;if((i|0)==1){break y}i=B(f,9)+d|0;d=e+120|0;h=Zc(d);r=Me(d);m=j+B(f,6)|0;t[m+1|0]=w[d|0];l=w[h|0];t[m|0]=l;h=w[vi(d)|0];t[m+5|0]=h;n=m+5|0;if(l){t[m|0]=l+25;t[i+8|0]=0;t[i|0]=0;t[i+1|0]=0;t[i+2|0]=0;t[i+3|0]=0;t[i+4|0]=0;t[i+5|0]=0;t[i+6|0]=0;t[i+7|0]=0;h=w[n|0]}l=h&255;r=w[r|0];H:{if(r>>>0>=240){d=l|(r&15)<<8;if(d){W=n,X=Nn(+(tP(d)>>>0)/1e4),t[W|0]=X;t[m+3|0]=17;break H}t[m+3|0]=0;break H}J=l>>>4|0;N=l<<4;d=J|N;I:{switch(r|0){case 0:d=j+B(f,6)|0;if(h&255){t[d+3|0]=1;break H}t[d+3|0]=0;break H;case 1:t[(j+B(f,6)|0)+3|0]=2;break H;case 2:t[(j+B(f,6)|0)+3|0]=3;break H;case 3:t[e+8|0]=15;W=i,X=w[Qb(n,e+8|0)|0]|16,t[W|0]=X;t[i+7|0]=0;t[i+1|0]=0;t[i+2|0]=0;t[(j+B(f,6)|0)+3|0]=0;break H;case 4:t[e+8|0]=15;W=i,X=w[Qb(n,e+8|0)|0]|32,t[W|0]=X;t[i+7|0]=0;t[i+1|0]=0;t[i+2|0]=0;t[(j+B(f,6)|0)+3|0]=0;break H;case 5:t[i+7|0]=0;t[i+2|0]=0;t[i+1|0]=h;t[i|0]=0;t[(j+B(f,6)|0)+3|0]=0;break H;case 6:t[i+7|0]=0;t[i+2|0]=h;t[i|0]=0;t[i+1|0]=0;t[(j+B(f,6)|0)+3|0]=0;break H;case 7:t[(j+B(f,6)|0)+3|0]=23;b=0;break H;case 8:t[(j+B(f,6)|0)+3|0]=0;b=d;break H;case 9:t[(j+B(f,6)|0)+3|0]=19;t[e+8|0]=15;W=n,X=w[Qb(n,e+8|0)|0]|16,t[W|0]=X;break H;case 10:t[(j+B(f,6)|0)+3|0]=19;t[e+8|0]=15;W=n,X=w[Qb(n,e+8|0)|0]|32,t[W|0]=X;break H;case 11:t[i+3|0]=d;t[(j+B(f,6)|0)+3|0]=0;break H;case 12:d=j+B(f,6)|0;t[d+4|0]=h;t[d+2|0]=1;t[i+3|0]=0;t[d+3|0]=0;break H;case 13:r=j+B(f,6)|0;J:{K:{if(l&240){t[(j+B(f,6)|0)+2|0]=4;d=(h&240)>>>4|0;break K}if(!(l&15)){break J}t[(j+B(f,6)|0)+2|0]=3;d=h&15}t[r+4|0]=d}t[i+3|0]=0;t[(j+B(f,6)|0)+3|0]=0;break H;case 14:t[(j+B(f,6)|0)+3|0]=19;t[n|0]=!(h&255);break H;case 15:t[(j+B(f,6)|0)+3|0]=16;t[n|0]=(h&240)>>>4;G=h&15;break H;case 16:t[i+5|0]=0;t[i+4|0]=h;t[(j+B(f,6)|0)+3|0]=0;break H;case 17:t[i+6|0]=l&15?h:0;t[(j+B(f,6)|0)+3|0]=0;break H;case 18:t[(j+B(f,6)|0)+3|0]=14;break H;case 19:t[i+8|0]=0;t[i+7|0]=h;t[i+2|0]=0;t[i|0]=0;t[i+1|0]=0;t[(j+B(f,6)|0)+3|0]=0;break H;case 20:t[(j+B(f,6)|0)+3|0]=12;break H;case 22:d=w[m+1|0];L:{if(!d){break L}l=v[q>>2];if(ad(l,v[q+4>>2])>>>0<d>>>0){break L}d=ld(l,d-1|0);h=h-1|0;t[n|0]=h;v[22452]=0;T(649,e+8|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break y}v[e+112>>2]=9;W=e,X=ad(v[d>>2],v[d+4>>2]),v[W+4>>2]=X;if(y[zb(e+112|0,e+4|0)>>2]<=(h&255)>>>0){break L}d=j+B(f,6)|0;t[d+2|0]=15;t[d+4|0]=w[n|0]}t[(j+B(f,6)|0)+3|0]=0;break H;case 23:d=w[m+1|0];M:{if(!d){break M}l=v[q>>2];if(ad(l,v[q+4>>2])>>>0<d>>>0){break M}h=h-1|0;t[n|0]=h;d=ld(l,d-1|0);l=v[d>>2];r=ad(l,v[d+4>>2]);d=h&255;if(r>>>0<=d>>>0){break M}d=ld(l,d);h=x[d+8>>1];N:{if(h){break N}h=0;if(!Dh(a)){break N}h=x[s>>1]+1|0;u[s>>1]=h;u[d+8>>1]=h}t[m+1|0]=h}t[(j+B(f,6)|0)+3|0]=0;break H;case 24:d=w[m+1|0];O:{if(!d){break O}l=v[q>>2];if(ad(l,v[q+4>>2])>>>0<d>>>0){break O}d=ld(l,d-1|0);h=h-1|0;t[n|0]=h;v[22452]=0;T(649,e+8|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break y}v[e+112>>2]=9;W=e,X=ad(v[d>>2],v[d+4>>2]),v[W+4>>2]=X;if(y[zb(e+112|0,e+4|0)>>2]>(h&255)>>>0){d=j+B(f,6)|0;t[d+2|0]=15;t[d+4|0]=w[n|0]}d=Yb(v[A>>2],w[m+1|0]-1|0);h=x[d>>1];P:{if(h){break P}h=0;if(!Dh(a)){break P}h=x[s>>1]+1|0;u[s>>1]=h;u[d>>1]=h}t[m+1|0]=h}t[(j+B(f,6)|0)+3|0]=0;break H;case 25:d=w[m+1|0];Q:{if(!d){break Q}l=v[q>>2];if(ad(l,v[q+4>>2])>>>0<d>>>0){break Q}h=h-1|0;t[n|0]=h;d=ld(l,d-1|0);l=v[d>>2];r=ad(l,v[d+4>>2]);d=h&255;if(r>>>0<=d>>>0){break Q}d=ld(l,d);h=x[d+10>>1];R:{if(h){break R}h=0;if(!Dh(a)){break R}h=x[s>>1]+1|0;u[s>>1]=h;u[d+10>>1]=h}t[m+1|0]=h}t[(j+B(f,6)|0)+3|0]=0;break H;case 29:t[(j+B(f,6)|0)+3|0]=11;t[n|0]=d;if(l&15){t[n|0]=N|15;break H}if((h&255)>>>0<16){break H}t[n|0]=J|240;break H;case 32:if(l&240){t[i+3|0]=J;t[(j+B(f,6)|0)+3|0]=0;break H}t[(j+B(f,6)|0)+3|0]=19;t[n|0]=h&15|192;break H;case 33:t[(j+B(f,6)|0)+3|0]=19;t[e+8|0]=15;W=n,X=w[Qb(n,e+8|0)|0]|208,t[W|0]=X;break H;case 34:t[(j+B(f,6)|0)+3|0]=19;t[e+8|0]=15;W=n,X=w[Qb(n,e+8|0)|0]|144,t[W|0]=X;break H;case 73:t[(j+B(f,6)|0)+3|0]=10;break H;case 78:if((h&112|128)==224){t[(j+B(f,6)|0)+3|0]=19;break H}t[(j+B(f,6)|0)+3|0]=0;break H;case 79:d=j+B(f,6)|0;if((h&255)>>>0<=31){t[d+3|0]=16;G=0;break H}t[d+3|0]=17;break H;default:break I}}t[(j+B(f,6)|0)+3|0]=0}l=0;h=w[i+3|0];if(!(w[m+2|0]|!h)){S:{if(h>>>0>=16){t[m+2|0]=5;h=h>>>4|0;break S}t[m+2|0]=6}t[m+4|0]=h;l=1}T:{if(w[m+3|0]){break T}d=w[i+1|0];U:{if(d){t[m+3|0]=2;break U}d=w[i+2|0];if(d){t[m+3|0]=3;break U}d=w[i|0];if(d){t[m+3|0]=19;break U}d=w[i+7|0];if(d){t[m+3|0]=4;t[i+8|0]=d;break U}d=w[i+4|0];if(d){t[m+3|0]=5;t[i+5|0]=d;break U}d=w[i+3|0];if(!(!d|l)){t[m+3|0]=11;t[n|0]=d;if(d&15){d=d|-16;break U}if(!(d&240)){break T}d=d|15;break U}d=w[i+6|0];if(d){t[m+3|0]=8;break U}if(k){t[m+3|0]=20;k=0;d=97;break U}k=0;if(I){break T}d=b&255;if(!d){break T}t[m+3|0]=24;t[n|0]=b;if(b&15){d=b|-16}else{if(!(d&240)){I=1;break T}d=b|15}I=1}t[n|0]=d}f=f+1|0;continue}}}v[a+480228>>2]=256/x[a+480188>>1];lh(a,1);if(Ab(w[p|0]|w[p+1|0]<<8)){V:{while(1){v[22452]=0;b=Q(147,o|0,2)|0;d=v[22452];v[22452]=0;if((d|0)==1){break y}if(!b){break V}v[22452]=0;b=T(265,o|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break y}if((b|0)==65535){break V}v[22452]=0;Q(179,o|0,2)|0;b=v[22452];v[22452]=0;if((b|0)==1){break y}v[22452]=0;b=T(273,o|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){v[22452]=0;Q(179,o|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){continue}}break}break y}v[22452]=0;Q(179,o|0,34)|0;b=v[22452];v[22452]=0;if((b|0)==1){break y}}W:{if(!(c&2)){break W}l=1;while(1){b=l&65535;if(b>>>0>C>>>0){break W}X:{d=(B(b,104)+a|0)+484380|0;if(!v[d>>2]){break X}c=Gc(e+8|0,8,1,0,0);v[22452]=0;Y(210,c|0,d|0,o|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break y}c=v[q>>2];if(ad(c,v[q+4>>2])>>>0<b>>>0){break X}i=b-1|0;p=ld(c,i);c=0;g=0;h=ab-112|0;ab=h;Y:{if(!Fd(d)){break Y}if(ad(v[p>>2],v[p+4>>2])>>>0<2){break Y}f=Ln(h+8|0,d);v[f+20>>2]=0;v[f>>2]=0;m=v[p>>2];b=ad(m,v[p+4>>2]);k=v[d>>2];Z:{while(1){if((b|0)==(c|0)){break Z}_:{j=ld(m,c);n=v[j>>2];if(n>>>0>=k>>>0){break _}j=v[j+4>>2];if(j>>>0>k-n>>>0|268435456-j>>>0<g>>>0){break _}g=g+j|0;v[f>>2]=g;c=c+1|0;continue}break}b=c}if(!sg(f)){break Y}j=f+68|0;g=0;c=0;while(1){if((b|0)==(c|0)){Xl(d);b=Ln(d,f);v[b+4>>2]=0;v[b+8>>2]=v[d>>2];u[b+34>>1]=x[b+34>>1]|2;break Y}m=v[f+20>>2]+g|0;n=v[d+20>>2];k=ld(v[p>>2],c);gc(m,n+v[k>>2]|0,v[k+4>>2]);v[k>>2]=g;if(c-10>>>0>=4294967287){W=Fb(j,c-1|0),X=g,v[W>>2]=X}c=c+1|0;g=v[k+4>>2]+g|0;continue}}ab=h+112|0;b=x[Yb(v[A>>2],i)>>1];if(b){wz(d,(B(b,104)+a|0)+484380|0,0,v[d>>2],0)}b=ld(v[q>>2],i);W=e,X=wb(v[b>>2]),v[W+8>>2]=X;c=wb(v[b+4>>2]);while(1){b=v[e+8>>2];if(!Tb(b,c)){break X}g=x[b+8>>1];if(g){wz(d,(B(g,104)+a|0)+484380|0,v[b>>2],v[b+4>>2],1)}g=x[b+10>>1];if(g){wz(d,(B(g,104)+a|0)+484380|0,v[b>>2],v[b+4>>2],0)}Sn(e+8|0);continue}}l=l+1|0;continue}}Cp(F);d=1;break b}v[22452]=0;Q(179,o|0,B(d,x[e+118>>1])|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){break z}break y}g=g+1|0;continue}break}d=P()|0;O()|0;Cp(F);break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;yb(e+136|0);break d}d=P()|0;O()|0;break e}qb(e+8|0)}_c(A);pP(q)}S(d|0);L()}d=0}_c(A);pP(q)}ab=e+400|0;return d|0}function Fda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=ab-272|0;ab=e;qc(b);a:{b:{c:{if(!pt(b,e+176|0)){break c}if(!QP(e+176|0)){break c}if(!Hb(b,Fc(PP(e+176|0),db))){break c}if(!c){h=1;break c}vd(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;l=Bb(e+160|0);d:{e:{f=w[e+216|0]|w[e+217|0]<<8;if((f|0)==20479){k=w[e+230|0]|w[e+231|0]<<8;break e}k=f-16464|0;f:{g:{h:{i:{j:{switch(f>>>12|0){case 0:if((f|0)!=520){break f}v[22452]=0;f=Q(1,e+32|0,12283)|0;g=v[22452];v[22452]=0;if((g|0)!=1){tb(l,f);pb(f);break f}d=P()|0;O()|0;break a;case 1:k:{if((f|0)!=4896){break k}if(!(w[e+208|0]&15|(w[e+238|0]|w[e+239|0]<<8)|(w[e+228|0]|(w[e+214|0]|w[e+215|0]<<8)&65455))){l:{if(t[e+227|0]<0){v[a+1074308>>2]=18219008;v[22452]=0;d=Q(1,e+32|0,14741)|0;f=v[22452];v[22452]=0;if((f|0)!=1){break l}d=P()|0;O()|0;break a}v[a+1074308>>2]=16777216;v[22452]=0;d=Q(1,e+32|0,13333)|0;f=v[22452];v[22452]=0;if((f|0)==1){break i}}tb(l,d);pb(d);v[22452]=0;d=1;Y(258,a+1074312|0,81,1)|0;f=v[22452];v[22452]=0;h=1;if((f|0)!=1){break d}break b}if(w[e+228|0]|(w[e+238|0]|w[e+239|0]<<8)|(w[e+229|0]|(w[e+214|0]|w[e+215|0]<<8))){break k}v[22452]=0;f=Q(1,e+32|0,9447)|0;g=v[22452];v[22452]=0;if((g|0)!=1){tb(l,f);pb(f);break f}d=P()|0;O()|0;break a}v[22452]=0;d=Q(1,e+32|0,8481)|0;f=v[22452];v[22452]=0;g=1;if((f|0)!=1){tb(l,d);pb(d);break g}d=P()|0;O()|0;break a;case 2:v[22452]=0;d=Q(1,e+32|0,6734)|0;f=v[22452];v[22452]=0;h=1;if((f|0)!=1){tb(l,d);pb(d);break g}d=P()|0;O()|0;break a;case 3:m:{n:{o:{p:{if(f>>>0<=12820){v[22452]=0;d=Q(1,e+32|0,8528)|0;g=v[22452];v[22452]=0;if((g|0)!=1){tb(l,d);pb(d);break p}d=P()|0;O()|0;break a}v[22452]=0;R(389,e+144|0,3976);d=v[22452];v[22452]=0;if((d|0)==1){break o}d=w[e+216|0]|w[e+217|0]<<8;v[22452]=0;v[e+128>>2]=d-12820;U(390,e+32|0,e+144|0,e+128|0);d=v[22452];v[22452]=0;if((d|0)==1){break n}d=e+32|0;tb(l,d);pb(d);yb(e+144|0)}d=w[e+216|0]|w[e+217|0]<<8;if(d>>>0<12807){break h}g=w[e+232|0]|w[e+233|0]<<8|(w[e+234|0]<<16|w[e+235|0]<<24);if(g){break m}break h}d=P()|0;O()|0;break a}d=P()|0;O()|0;yb(e+144|0);break a}d=EC(d,g);g=bq(e+32|0);v[g+44>>2]=d;v[22452]=0;R(392,a+1298408|0,g|0);d=v[22452];v[22452]=0;if((d|0)!=1){break h}d=P()|0;O()|0;break a;case 4:if((f|0)!=16640){break e}v[22452]=0;f=Q(1,e+32|0,8327)|0;g=v[22452];v[22452]=0;h=1;if((g|0)!=1){tb(l,f);pb(f);v[22452]=0;Y(258,a+1074312|0,81,1)|0;f=v[22452];v[22452]=0;g=0;if((f|0)==1){break b}break d}d=P()|0;O()|0;break a;case 5:f=f&4095;d=f<<16;if(f>>>0>=297){d=d|(w[e+230|0]|w[e+231|0]<<8)}v[a+1074308>>2]=d;v[22452]=0;f=Q(1,e+144|0,17558)|0;d=v[22452];v[22452]=0;q:{r:{s:{if((d|0)!=1){d=v[a+1074308>>2];v[22452]=0;R(131,e+128|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break s}d=0;v[22452]=0;U(2,e+32|0,f|0,e+128|0);g=v[22452];v[22452]=0;if((g|0)==1){break r}g=e+32|0;tb(l,g);pb(g);pb(e+128|0);pb(f);break f}d=P()|0;O()|0;break a}d=P()|0;O()|0;break q}d=P()|0;O()|0;pb(e+128|0)}pb(f);break a;case 6:v[22452]=0;f=Q(1,e+32|0,8327)|0;g=v[22452];v[22452]=0;if((g|0)!=1){tb(l,f);pb(f);v[22452]=0;Y(258,a+1074312|0,81,1)|0;f=v[22452];v[22452]=0;g=0;if((f|0)==1){break b}break d}d=P()|0;O()|0;break a;case 7:v[22452]=0;f=Q(1,e+32|0,8339)|0;g=v[22452];v[22452]=0;if((g|0)!=1){tb(l,f);pb(f);break f}d=P()|0;O()|0;break a;default:break j}}if((f|0)!=51712){break f}v[22452]=0;f=Q(1,e+32|0,9246)|0;g=v[22452];v[22452]=0;if((g|0)!=1){tb(l,f);pb(f);break f}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}v[22452]=0;d=Y(258,a+1074312|0,7,1)|0;g=v[22452];v[22452]=0;if((g|0)==1){break b}v[22452]=0;d=Y(258,d|0,23,1)|0;g=v[22452];v[22452]=0;if((g|0)==1){break b}v[22452]=0;d=Y(258,d|0,38,1)|0;g=v[22452];v[22452]=0;if((g|0)==1){break b}v[22452]=0;Y(258,d|0,107,1)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}h=1;v[a+480260>>2]=1;g=0;if(f>>>0<=12820){break g}d=0;break d}v[22452]=0;Z(634,e+144|0);d=v[22452];v[22452]=0;t:{u:{v:{if((d|0)!=1){d=w[e+216|0]|w[e+217|0]<<8;v[e+16>>2]=d>>>8&15;v[22452]=0;v[e>>2]=d&255;R(391,e+128|0,e|0);d=v[22452];v[22452]=0;if((d|0)==1){break v}d=0;v[22452]=0;ga(635,e+32|0,e+144|0,l|0,e+16|0,e+128|0);f=v[22452];v[22452]=0;if((f|0)==1){break u}f=e+32|0;tb(l,f);pb(f);pb(e+128|0);yb(e+144|0);break d}d=P()|0;O()|0;break a}d=P()|0;O()|0;break t}d=P()|0;O()|0;pb(e+128|0)}yb(e+144|0);break a}g=0;break d}d=w[e+230|0]|w[e+231|0]<<8;v[22452]=0;U(394,e+32|0,f|0,d|0);d=v[22452];v[22452]=0;w:{x:{if((d|0)!=1){d=e+32|0;tb(l,d);pb(d);v[a+480260>>2]=1;if((k|0)<4201){break x}v[22452]=0;Y(258,a+1074312|0,7,1)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}break w}d=P()|0;O()|0;break a}if((k|0)>=2386){break w}h=1;d=0;j=1;break d}d=0;v[22452]=0;h=1;Y(258,a+1074312|0,38,1)|0;f=v[22452];v[22452]=0;j=1;if((f|0)==1){break b}}v[22452]=0;f=Q(1,e+32|0,15008)|0;i=v[22452];v[22452]=0;y:{z:{A:{B:{C:{D:{E:{F:{if((i|0)!=1){tb(a+1298344|0,f);pb(f);v[22452]=0;f=Q(1,e+32|0,10435)|0;i=v[22452];v[22452]=0;if((i|0)==1){break F}tb(a+1298356|0,f);pb(f);p=tb(a+1298368|0,l);v[a+1298404>>2]=v[a+1074308>>2]?8:5;if(h){v[22452]=0;f=Q(259,a+1074312|0,77)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}v[22452]=0;f=Q(259,f|0,78)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}v[22452]=0;f=Q(259,f|0,79)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}v[22452]=0;f=Q(259,f|0,80)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}v[22452]=0;f=Q(259,f|0,82)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}v[22452]=0;f=Q(259,f|0,96)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}v[22452]=0;Q(259,f|0,113)|0;f=v[22452];v[22452]=0;if((f|0)==1){break b}}f=w[e+216|0]|w[e+217|0]<<8;i=f&61440;if(i>>>0>=4097){d=(i|0)!=12288|f>>>0>12819|d}v[22452]=0;f=a+901404|0;Z(636,f|0);i=v[22452];v[22452]=0;if((i|0)==1){break b}if(!d){Pp(f)}dl(e+144|0,1,e+176|0);v[22452]=0;W(213,e+32|0,v[e+144>>2],v[e+148>>2],w[e+152|0]);d=v[22452];v[22452]=0;if((d|0)==1){break C}d=e+32|0;tb(a+1298308|0,d);pb(d);d=w[e+214|0]|w[e+215|0]<<8;if(d&16){v[a+480208>>2]=v[a+480208>>2]|65536;d=w[e+214|0]|w[e+215|0]<<8}if(d&1){v[a+480208>>2]=v[a+480208>>2]|131072}if(!(w[e+214|0]&64?0:(w[e+216|0]|w[e+217|0]<<8)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}d=w[e+225|0];v[a+480196>>2]=d;G:{H:{if(d){if((d|0)!=255){break H}f=0;if(!g){break G}}v[a+480196>>2]=6}f=g}i=f;v[a+480204>>2]=B(w[e+226|0],1e4);if(w[e+226|0]<=32){v[a+480204>>2]=i?125e4:32e4}t[e+32|0]=w[e+224|0];t[e+144|0]=64;d=w[Qb(e+32|0,e+144|0)|0];v[a+480200>>2]=d<<2;if(!((w[e+216|0]|w[e+217|0]<<8)>>>0>4895|d)){v[a+480200>>2]=256}if((w[e+218|0]|w[e+219|0]<<8)!=1){break E}h=e+227|0;d=w[h|0];if(d>>>0>7){break E}v[e+32>>2]=(d<<4)+16;v[e+144>>2]=127;f=v[jd(e+32|0,e+144|0)>>2];break D}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}h=e+227|0;d=w[h|0];f=32;if((d|16)==18){break D}d=d&127;f=48;if(!d){break D}v[e+32>>2]=d;v[e+144>>2]=16;f=v[Ee(e+32|0,e+144|0)>>2]}v[a+480228>>2]=f;d=0;g=1;I:{if(t[h|0]<0){break I}g=1;if(v[a+1074308>>2]){break I}H=a,I=Fc(ria(f<<3|5,f>>>29|0,11,0),db),v[H+480228>>2]=I;g=0}q=a+480188|0;u[q>>1]=4;v[a+480232>>2]=j?(k|0)<3299?64:36:36;h=Ap(e+120|0);while(1){if((d|0)==32){d=a+480188|0;if(!x[d>>1]){u[d>>1]=1}d=Kb(a+484360|0);f=w[e+208|0]|w[e+209|0]<<8;v[22452]=0;ea(337,d|0,b|0,f|0,255,254)|0;d=v[22452];v[22452]=0;if((d|0)!=1){q=Pb(e+144|0);d=w[e+210|0]|w[e+211|0]<<8;v[22452]=0;Y(208,b|0,q|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){r=Pb(e+128|0);d=w[e+212|0]|w[e+213|0]<<8;v[22452]=0;Y(208,b|0,r|0,d|0)|0;d=v[22452];v[22452]=0;J:{if((d|0)!=1){if(w[e+229|0]!=252){break B}d=0;v[22452]=0;R(637,b|0,e+32|0);f=v[22452];v[22452]=0;if((f|0)==1){break J}while(1){if((d|0)==32){break B}g=(e+32|0)+d|0;f=w[g|0];K:{if(!(f&32)){break K}j=((d<<5)+a|0)+480284|0;if(i){vk(e+16|0,h,d);if(sb(v[v[e+16>>2]>>2],v[e+20>>2])){break K}f=w[g|0]}u[j>>1]=(((f&15)<<8|8)>>>0)/15}d=d+1|0;continue}}break A}break A}d=P()|0;O()|0;break z}d=P()|0;O()|0;break a}f=(d<<5)+a|0;k=f+480280|0;Le(k);r=e+d|0;j=w[r+240|0];m=j&127;L:{if((j|0)!=255){u[q>>1]=d+1;if(g){u[f+480284>>1]=j&8?204:51}if(t[r+240|0]>=0){break L}}v[k>>2]=1024}if((m-16&255)>>>0<=13){u[f+480284>>1]=128;f=e+32|0;vk(f,h,d);Zl(f)}d=d+1|0;continue}}d=P()|0;O()|0;break a}u[e+32>>1]=w[e+210|0]|w[e+211|0]<<8;u[e+16>>1]=3999;h=x[Lc(e+32|0,e+16|0)>>1];u[a+480190>>1]=h;f=c&2;k=e+80|0;d=0;j=0;g=0;M:{N:{O:{while(1){if((h&65535)>>>0<=d>>>0){if(!i){break N}if(!(!j|g&65535)&(w[e+216|0]|w[e+217|0]<<8)!=4864){break O}v[22452]=0;d=g&65535;f=Y(258,a+1074312|0,79,d>>>0>1|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break A}v[22452]=0;d=d>>>0<2;f=Y(258,f|0,107,d|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break A}v[22452]=0;Y(258,f|0,38,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break A}v[22452]=0;d=g&65535;Q(124,p|0,(d>>>0>1?17119:17126)|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break A}if(d>>>0<2){break N}v[a+480228>>2]=48;break N}h=Yb(v[q>>2],d);h=w[h|0]|w[h+1|0]<<8;v[22452]=0;h=Q(146,b|0,h<<4)|0;m=v[22452];v[22452]=0;if((m|0)==1){break M}P:{Q:{if(!h){break Q}v[22452]=0;h=Q(638,b|0,e+32|0)|0;m=v[22452];v[22452]=0;if((m|0)==1){break M}if(!h){break Q}v[22452]=0;h=d+1|0;m=(B(h,104)+a|0)+484380|0;U(639,e+32|0,m|0,i|0);o=v[22452];v[22452]=0;if((o|0)==1){break M}dl(e,1,k);v[22452]=0;W(213,e+16|0,v[e>>2],v[e+4>>2],w[e+8|0]);o=v[22452];v[22452]=0;if((o|0)==1){break P}n=((h<<5)+a|0)+946304|0;h=e+16|0;sc(n,h);pb(h);if(w[e+32|0]>1){break Q}h=NP(e+32|0);R:{if(!f|!(w[e+48|0]|w[e+49|0]<<8|(w[e+50|0]<<16|w[e+51|0]<<24))){break R}v[22452]=0;h=Q(146,b|0,h|0)|0;o=v[22452];v[22452]=0;if((o|0)==1){break A}if(!h){break R}h=e+16|0;MP(h,e+32|0,(w[e+218|0]|w[e+219|0]<<8)==1);v[22452]=0;Y(210,h|0,m|0,b|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break A}j=1}g=w[e+72|0]|w[e+73|0]<<8|g}d=d+1|0;h=x[a+480190>>1];continue}break}break A}v[22452]=0;d=Q(1,e+32|0,9711)|0;f=v[22452];v[22452]=0;if((f|0)==1){break A}tb(p,d);pb(d)}h=1;if(!(c&1)){break y}c=w[e+216|0]|w[e+217|0]<<8;u[e+32>>1]=w[e+212|0]|w[e+213|0]<<8;u[e+16>>1]=255;o=x[Lc(e+32|0,e+16|0)>>1];v[22452]=0;j=a+484344|0;R(216,j|0,o|0);d=v[22452];v[22452]=0;if((d|0)==1){break M}s=c>>>0<4896;c=e+32|0;A=c|5;C=c|3;y=c|4;D=c|2;E=c|1;F=a+480188|0;g=0;p=0;m=0;while(1){if((g|0)==(o|0)){if(!s){break y}a=x[a+480188>>1];if((a|0)>(m+p|0)|(a|0)<=(p-m|0)){break y}d=lf(j)-1&65535;c=0;S:{if(lf(j)>>>0<=d>>>0){break S}while(1){b=c&65535;if(b>>>0>d>>>0){break S}a=Nf(v[j>>2],b);if(Gh(a)){a=vg(a);f=ug(Nf(v[j>>2],b));b=ab-16|0;ab=b;v[b+8>>2]=a;while(1){if(Tb(a,f)){if(w[a+3|0]==31){t[a+3|0]=20;t[a+5|0]=w[a+5|0]|128}ui(b+8|0);a=v[b+8>>2];continue}break}ab=b+16|0}c=c+1|0;continue}}break y}v[22452]=0;c=Y(217,j|0,g&65535,64)|0;d=v[22452];v[22452]=0;if((d|0)==1){break M}T:{if(!c){break T}c=Yb(v[r>>2],g);c=w[c|0]|w[c+1|0]<<8;if(!c){break T}v[22452]=0;c=Q(146,b|0,c<<4)|0;d=v[22452];v[22452]=0;if((d|0)==1){break M}if(!c){break T}v[22452]=0;Q(179,b|0,2)|0;c=v[22452];v[22452]=0;if((c|0)==1){break M}d=0;z=Of(Rb(j,g),0);while(1){if(d>>>0>63){break T}f=d;v[22452]=0;k=T(197,b|0)|0;c=v[22452];v[22452]=0;U:{if((c|0)!=1){if(k){break U}d=64;if(f>>>0>62){continue}d=f+1|0;z=Of(Rb(j,g),d);continue}break A}G=Fh(e+32|0);c=k&31;d=c>>>0<x[F>>1];i=B(c,6)+z|0;if(k&32){v[22452]=0;R(254,e+16|0,b|0);c=v[22452];v[22452]=0;V:{W:{X:{if((c|0)!=1){n=Zc(e+16|0);c=w[e+16|0];if(c>>>0>239){break X}c=LP((B(c>>>4|0,12)+(c&15)|0)+13|0);break W}break A}Y:{switch(c-254|0){case 0:break W;case 1:break Y;default:break V}}c=0}t[(d?i:e+32|0)|0]=c}t[(d?i+1|0:E)|0]=w[n|0]}Z:{if(!(k&64)){break Z}v[22452]=0;n=T(197,b|0)|0;c=v[22452];v[22452]=0;_:{if((c|0)!=1){c=d?i+2|0:D;n=n<<24>>24;t[e+16|0]=n;if((n|0)>-64){break _}t[c|0]=2;t[(d?i+4|0:y)|0]=w[e+16|0]^128;break Z}break A}t[c|0]=1;t[e|0]=64;H=d?i+4|0:y,I=w[Qb(e+16|0,e)|0],t[H|0]=I}$:{if(!(k&128)){break $}v[22452]=0;R(254,e+16|0,b|0);c=v[22452];v[22452]=0;aa:{ba:{if((c|0)!=1){k=d?i+3|0:C;n=e+16|0;t[k|0]=w[n|0];c=d?i+5|0:A;H=c,I=w[Zc(n)|0],t[H|0]=I;CA(d?i:G,0);d=w[k|0];if((d|0)==10){break aa}if((d|0)==31){break ba}if((d|0)!=20){break $}d=w[c|0];if((d&240)!=160|(w[e+216|0]|w[e+217|0]<<8)>>>0>4895){break $}t[c|0]=d&15^136;break $}break A}c=w[c|0];if(c>>>0>15){s=0;break $}if(c>>>0<=7){m=m+1|0;break $}p=((c|0)!=8)+p|0;break $}if(w[c|0]|(w[e+216|0]|w[e+217|0]<<8)>>>0>4865){break $}t[k|0]=37}d=f;continue}}g=g+1|0;continue}}}d=P()|0;O()|0;_c(r)}_c(q);break a}_c(r);_c(q);pb(l)}ab=e+272|0;return h|0}d=P()|0;O()|0}pb(l);S(d|0);L()}function Aca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=ab-512|0;ab=d;qc(b);a:{if(!DA(b,d+432|0)){break a}if(!IO(d+432|0)){break a}if(!Hb(b,Fc(HO(d+432|0),db))){break a}b:{if(!c){break b}vd(a,4);wg(a);t[a+1074368|0]=4;j=Bb(d+416|0);c:{d:{e:{f:{k=d+470|0;g:{if(!(Ib(k,17741,20)|(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24))!=276)){if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break g}e=FA(d+449|0,0,20)?1154:34;break e}if(!Ib(k,17720,20)){e=1;break e}lj(d+16|0,3,k);v[22452]=0;W(213,d+56|0,v[d+16>>2],v[d+20>>2],w[d+24|0]);h=v[22452];v[22452]=0;h:{i:{if((h|0)!=1){v[22452]=0;U(11,d+128|0,5,d+56|0);h=v[22452];v[22452]=0;if((h|0)==1){break i}h=d+128|0;tb(j,h);pb(h);pb(d+56|0);if(Ib(k,17558,8)){break h}e=1048;break e}f=P()|0;O()|0;break c}f=P()|0;O()|0;pb(d+56|0);break c}if(!Ib(k,17458,12)){e=16;if(!Ib(d+482|0,17762,8)){break e}t[a+1074368|0]=5;break e}if(Ib(k,11631,20)){break f}}e=48;break e}if(!Ib(k,27088,15)){v[22452]=0;h=Q(259,a+1074312|0,54)|0;e=v[22452];v[22452]=0;D=1;if((e|0)==1){break d}v[22452]=0;Q(259,h|0,51)|0;h=v[22452];v[22452]=0;e=16;if((h|0)==1){break d}break e}j:{if(Ib(k,27104,14)){if(Ib(k,27119,14)){break j}}v[22452]=0;h=Q(259,a+1074312|0,57)|0;e=v[22452];v[22452]=0;if((e|0)==1){break d}v[22452]=0;Q(259,h|0,51)|0;h=v[22452];v[22452]=0;e=16;if((h|0)!=1){break e}break d}e=Ib(k,17546,11)?16:256}z=d+449|0;lj(d+56|0,3,z);v[22452]=0;W(213,d+128|0,v[d+56>>2],v[d+60>>2],w[d+64|0]);h=v[22452];v[22452]=0;k:{l:{m:{n:{o:{p:{q:{if((h|0)!=1){h=d+128|0;tb(a+1298308|0,h);pb(h);v[a+480260>>2]=1;v[a+480264>>2]=31999;q=a+484360|0;Re(Kb(q),w[d+498|0]|w[d+499|0]<<8);u[a+480188>>1]=w[d+500|0]|w[d+501|0]<<8;u[d+128>>1]=w[d+504|0]|w[d+505|0]<<8;u[d+56>>1]=255;G=a+480192|0,H=x[Lc(h,d+56|0)>>1],u[G>>1]=H;h=w[d+508|0]|w[d+509|0]<<8;if(h){v[a+480196>>2]=h}h=w[d+510|0]|w[d+511|0]<<8;if(h){h=B(h,1e4);h=h>>>0<1e7?h:1e7;v[a+480204>>2]=h>>>0>32e4?h:32e4}v[a+480208>>2]=0;h=(w[d+506|0]|w[d+507|0]<<8)<<4&16;v[a+480208>>2]=h;f=w[d+506|0]|w[d+507|0]<<8;v[a+480208>>2]=h|f<<3&32768;h=Kb(q);m=w[d+496|0]|w[d+497|0]<<8;v[22452]=0;ea(337,h|0,b|0,m|0,65535,65535)|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}f=f>>>12&1?(e|0)==34?146:e:e;if(!(f&1024|(w[d+496|0]|w[d+497|0]<<8))){h=Kb(q);v[22452]=0;U(703,h|0,1,0);h=v[22452];v[22452]=0;if((h|0)==1){break d}}h=w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24);v[22452]=0;Q(146,b|0,h+60|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if((w[d+490|0]|w[d+491|0]<<8)>>>0>=260){v[22452]=0;U(704,b|0,d+432|0,a|0);h=v[22452];v[22452]=0;if((h|0)==1){break d}}t[d+415|0]=0;A=c&2;E=d+74|0;n=d+161|0;m=Pb(d+400|0);F=a+480192|0;o=1;h=-1;while(1){e=o&65535;if(e>>>0>x[F>>1]){if(!(!(f&2)|r&255)){f=FA(z,0,20)?f|16:f}if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){break o}if(c&3){v[22452]=0;U(704,b|0,d+432|0,a|0);c=v[22452];v[22452]=0;if((c|0)==1){break n}}if(!A){break o}n=a+480190|0;e=1;while(1){c=e&65535;if(c>>>0>x[n>>1]){break o}g=v[m>>2];v[22452]=0;Y(210,Fb(g,c-1|0)|0,(B(c,104)+a|0)+484380|0,b|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){e=e+1|0;continue}break}f=P()|0;O()|0;break k}v[22452]=0;g=T(148,b|0)|0;l=v[22452];v[22452]=0;r:{s:{if((l|0)!=1){gg(b,4);v[22452]=0;U(705,b|0,d+128|0,(g?g:263)|0);g=v[22452];v[22452]=0;if((g|0)==1){break p}t:{if((f|0)==1){g=w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24);if((g|0)!=263){f=16;if((g|0)!=245){break t}v[a+1074308>>2]=16777381;v[22452]=0;f=Q(1,d+56|0,13333)|0;g=v[22452];v[22452]=0;if((g|0)!=1){tb(j,f);pb(f);f=17;break t}f=P()|0;O()|0;break k}v[a+1074308>>2]=16777395;v[22452]=0;f=Q(1,d+56|0,13248)|0;g=v[22452];v[22452]=0;if((g|0)!=1){tb(j,f);pb(f);f=17;break t}f=P()|0;O()|0;break k}if(w[d+155|0]|w[d+156|0]<<8){break t}g=w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24);if(!(!(f&2)|(w[d+157|0]|w[d+158|0]<<8|(w[d+159|0]<<16|w[d+160|0]<<24))|(g|0)!=263)){f=f|16;break t}if(!(!(f&256)|(g|0)==29)){f=f&-257;break t}if(!(f&160)){break t}f=(g|0)==33?f:0}v[22452]=0;g=Y(245,a|0,e|0,0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break p}if(!g){break r}g=((e<<2)+a|0)+900380|0;e=v[g>>2];v[22452]=0;R(706,d+128|0,e|0);e=v[22452];v[22452]=0;if((e|0)==1){break p}e=w[d+154|0];u:{if((h|0)==-1){h=e;break u}if(!(f&32)|(e|0)==(h|0)){break u}f=f&-161|128}e=w[d+155|0]|w[d+156|0]<<8;if(!e){break r}l=w[d+369|0];i=w[d+370|0];p=w[d+371|0]|w[d+372|0]<<8;s=w[d+375|0];v[22452]=0;U(707,d+112|0,a|0,e|0);e=v[22452];v[22452]=0;if((e|0)==1){break q}f=s|(p|(i|l))?f&-4:f;g=v[g>>2]+236|0;e=12;l=v[d+112>>2];i=wc(l,v[d+116>>2]);v:{while(1){w:{if((e|0)==108){if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){uc(m)}g=w[d+155|0]|w[d+156|0]<<8;e=0;v[22452]=0;l=Q(708,d+96|0,g|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){break w}f=P()|0;O()|0;break v}p=Yb(g,e);if(i>>>0>x[p>>1]){G=p,H=x[Yb(l,x[Yb(g,e)>>1])>>1],u[G>>1]=H}e=e+1|0;continue}break}x:{y:{z:{A:{while(1){g=w[d+155|0]|w[d+156|0]<<8;if(g>>>0<=e>>>0){e=0;if((w[d+490|0]|w[d+491|0]<<8)>>>0<=259){break s}B:{while(1){if(e>>>0>=g>>>0){break s}i=w[Fb(v[m>>2],e)+3|0];g=v[Fb(v[d+96>>2],e)>>2];v[22452]=0;U(181,d+16|0,b|0,((i|0)==10?(g+1>>>1|0)+16|0:g)|0);g=v[22452];v[22452]=0;if((g|0)!=1){g=d+16|0;i=bc(d+56|0,g);qb(g);g=v[d+112>>2];if(!(!A|wc(g,v[d+116>>2])>>>0<=e>>>0)){p=x[Yb(g,e)>>1];g=Fb(v[m>>2],e);g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);v[22452]=0;v[d+12>>2]=g;v[d+8>>2]=g;g=da(709,(B(p,104)+a|0)+484380|0,d+8|0,i|0,d+415|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break B}C=g^1|C}e=e+1|0;qb(d+56|0);g=w[d+155|0]|w[d+156|0]<<8;continue}break}f=P()|0;O()|0;break x}f=P()|0;O()|0;qb(d+56|0);break x}v[22452]=0;R(710,b|0,d+56|0);g=v[22452];v[22452]=0;if((g|0)==1){break y}g=d+16|0;i=d+56|0;C:{if(!(w[i+17|0]!=173|w[i+14|0]&48)){Gc(g,8,1,0,10);break C}i=w[i+14|0];Gc(g,i&16?16:8,i&32?3:1,0,2)}v[22452]=0;R(711,m|0,g|0);g=v[22452];v[22452]=0;if((g|0)!=1){G=Fb(v[d+96>>2],e),H=w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24),v[G>>2]=H;p=w[d+73|0];g=v[d+112>>2];if(wc(g,v[d+116>>2])>>>0>e>>>0){i=x[Yb(g,e)>>1];v[22452]=0;g=(B(i,104)+a|0)+484380|0;R(712,d+56|0,g|0);s=v[22452];v[22452]=0;if((s|0)==1){break A}t[g+38|0]=w[n+202|0];t[g+39|0]=w[n+203|0];t[g+40|0]=w[n+204|0];t[g+41|0]=w[n+205|0];gl(d+40|0,3,E);v[22452]=0;W(213,d+16|0,v[d+40>>2],v[d+44>>2],w[d+48|0]);g=v[22452];v[22452]=0;if((g|0)==1){break z}g=d+16|0;sc(((i<<5)+a|0)+946304|0,g);pb(g);f=(w[d+70|0]&3)==3?(f&2)>>>1|0?f|4:f:f}r=p|r;e=e+1|0;continue}break}f=P()|0;O()|0;break x}f=P()|0;O()|0;break x}f=P()|0;O()|0;break x}f=P()|0;O()|0}ec(l)}_c(d+112|0);break k}f=P()|0;O()|0;break k}ec(l);_c(d+112|0)}o=o+1|0;continue}}f=P()|0;O()|0;break c}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}D:{if(!(C&1)){break D}v[22452]=0;c=Q(1,d+128|0,16573)|0;e=v[22452];v[22452]=0;E:{if((e|0)!=1){e=v[a+1298464>>2];v[22452]=0;U(364,e|0,2,c|0);e=v[22452];v[22452]=0;if((e|0)==1){break E}pb(c);break D}f=P()|0;O()|0;break k}f=P()|0;O()|0;pb(c);break k}v[22452]=0;c=Q(359,b|0,5519)|0;e=v[22452];v[22452]=0;if((e|0)==1){break n}if(c){v[22452]=0;c=T(148,b|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break n}v[22452]=0;W(326,a+1298332|0,b|0,c|0,0);c=v[22452];v[22452]=0;if((c|0)==1){break n}f=f|16}v[22452]=0;n=Q(359,b|0,14064)|0;c=v[22452];v[22452]=0;if((c|0)==1){break l}if(n){v[22452]=0;c=T(148,b|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break l}v[22452]=0;e=a+901404|0;U(713,b|0,e|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break l}EA(e);f=f|16}v[22452]=0;c=Q(359,b|0,13830)|0;e=v[22452];v[22452]=0;if((e|0)==1){break l}if(!c){break m}v[22452]=0;c=T(148,b|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){u[d+128>>1]=c>>>5;c=a+484344|0;G=d,H=lf(c),u[G+56>>1]=H;g=x[Lc(d+128|0,d+56|0)>>1];e=0;while(1){if((e|0)==(g|0)){f=f|16;break m}v[22452]=0;R(530,b|0,d+128|0);o=v[22452];v[22452]=0;F:{if((o|0)==1){break F}o=Rb(c,e);v[22452]=0;Q(531,o|0,d+128|0)|0;o=v[22452];v[22452]=0;if((o|0)==1){break F}e=e+1|0;continue}break}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[22452]=0;c=Q(359,b|0,13835)|0;e=v[22452];v[22452]=0;if((e|0)==1){break l}G:{if(!c){break G}v[22452]=0;c=T(148,b|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){u[d+128>>1]=(c>>>0)/20;u[d+56>>1]=x[a+480188>>1];c=x[Lc(d+128|0,d+56|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break G}v[22452]=0;U(370,b|0,((e<<5)+a|0)+480289|0,20);g=v[22452];v[22452]=0;if((g|0)!=1){e=e+1|0;continue}break}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[22452]=0;c=Q(147,b|0,8)|0;e=v[22452];v[22452]=0;if((e|0)==1){break l}H:{I:{J:{K:{if(c){c=v[b+8>>2];v[22452]=0;Q(371,a|0,b|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break K}f=(c|0)==v[b+8>>2]?f:f|16}L:{if(!(f&16)){break L}if(f&4){v[a+1074308>>2]=17367040;v[22452]=0;c=Q(1,d+128|0,14671)|0;e=v[22452];v[22452]=0;if((e|0)!=1){tb(j,c);pb(c);break L}f=P()|0;O()|0;break k}if(!(f&2)){break L}v[a+1074308>>2]=18219008;v[22452]=0;c=Q(1,d+128|0,14828)|0;e=v[22452];v[22452]=0;if((e|0)==1){break J}tb(j,c);pb(c)}M:{N:{O:{P:{Q:{R:{S:{if(!Ib(k,17558,8)){v[22452]=0;c=Q(714,d+128|0,d+478|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break S}v[22452]=0;U(11,d+56|0,1,c|0);e=v[22452];v[22452]=0;if((e|0)==1){break R}v[22452]=0;e=T(715,d+56|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break Q}v[a+1074308>>2]=e;pb(d+56|0);t[a+1074368|0]=y[a+1074308>>2]<19007257?4:5;pb(c);f=24}if(!(!v[a+1074308>>2]|f&8)){t[a+1074368|0]=0;It(a+1074312|0)}c=f&32;T:{if(!c){break T}t[a+1074368|0]=5;if(!n){Pp(a+901404|0)}if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break T}v[22452]=0;Y(258,a+1074312|0,4,1)|0;e=v[22452];v[22452]=0;if((e|0)==1){break l}}if(!pd(j)){break M}if(!(f&256)|r&255|h+1>>>0>1){break N}v[22452]=0;c=Q(1,d+128|0,8279)|0;h=v[22452];v[22452]=0;if((h|0)==1){break O}tb(j,c);pb(c);break M}f=P()|0;O()|0;break k}f=P()|0;O()|0;break P}f=P()|0;O()|0;pb(d+56|0)}pb(c);break k}f=P()|0;O()|0;break k}if(c){v[22452]=0;c=Q(1,d+128|0,12043)|0;h=v[22452];v[22452]=0;if((h|0)!=1){tb(j,c);pb(c);break M}f=P()|0;O()|0;break k}v[22452]=0;c=Q(1,d+128|0,9711)|0;h=v[22452];v[22452]=0;if((h|0)==1){break I}tb(j,c);pb(c)}t[d+40|0]=0;U:{if(x[a+480192>>1]){v[22452]=0;c=Q(380,a|0,b|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break U}t[d+40|0]=c}v[22452]=0;W(381,a|0,b|0,1,d+40|0);b=v[22452];v[22452]=0;if((b|0)==1){break U}e=v[a+1074308>>2];V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if(w[d+40|0]){if(e>>>0>18284543){break ha}v[a+1074308>>2]=18284544;break ha}if(e>>>0<18284544){break ga}}v[22452]=0;b=Q(1,d+56|0,17558)|0;c=v[22452];v[22452]=0;if((c|0)==1){break fa}c=v[a+1074308>>2];v[22452]=0;R(716,d+16|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break ea}v[22452]=0;U(2,d+128|0,b|0,d+16|0);c=v[22452];v[22452]=0;if((c|0)==1){break da}c=d+128|0;tb(j,c);pb(c);pb(d+16|0);pb(b);e=v[a+1074308>>2]}ia:{if(e-1>>>0>19005952){break ia}b=a+484344|0;if(!he(b,254)){c=Kb(q);v[22452]=0;R(717,c|0,254);c=v[22452];v[22452]=0;if((c|0)==1){break U}}if(he(b,255)){break ia}Mz(Kb(q),255,65535)}v[22452]=0;R(718,d+56|0,4063);b=v[22452];v[22452]=0;if((b|0)==1){break ba}b=w[d+490|0]|w[d+491|0]<<8;v[d+112>>2]=b>>>8;v[22452]=0;v[d+96>>2]=b&255;R(391,d+16|0,d+96|0);b=v[22452];v[22452]=0;if((b|0)==1){break aa}v[22452]=0;W(377,d+128|0,d+56|0,d+112|0,d+16|0);b=v[22452];v[22452]=0;if((b|0)==1){break $}c=d+128|0;b=tb(a+1298344|0,c);pb(c);pb(d+16|0);yb(d+56|0);tb(a+1298368|0,j);v[a+1298404>>2]=D?8:v[a+1074308>>2]?8:5;if(!w[d+415|0]){break W}tb(a+1298380|0,b);v[22452]=0;c=Q(1,d+128|0,15190)|0;h=v[22452];v[22452]=0;if((h|0)==1){break Z}tb(b,c);pb(c);v[22452]=0;b=Q(1,d+128|0,10062)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Y}tb(a+1298356|0,b);pb(b);v[22452]=0;b=Q(1,d+128|0,10063)|0;c=v[22452];v[22452]=0;if((c|0)==1){break X}tb(a+1298392|0,b);break V}f=P()|0;O()|0;break k}f=P()|0;O()|0;break ca}f=P()|0;O()|0;pb(d+16|0)}pb(b);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break _}f=P()|0;O()|0;pb(d+16|0)}yb(d+56|0);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[22452]=0;b=Q(1,d+128|0,10063)|0;c=v[22452];v[22452]=0;if((c|0)==1){break H}tb(a+1298356|0,b)}pb(b);ec(m);pb(j);break b}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0}ec(m);break c}f=P()|0;O()|0}pb(j);S(f|0);L()}e=1}ab=d+512|0;return e|0}function yd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=ab-16|0;ab=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){f=v[114937];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=f>>>c|0;if(b&3){d=c+((b^-1)&1)|0;b=d<<3;e=v[b+459796>>2];a=e+8|0;c=v[e+8>>2];b=b+459788|0;l:{if((c|0)==(b|0)){m=459748,n=sia(-2,d)&f,v[m>>2]=n;break l}v[c+12>>2]=b;v[b+8>>2]=c}b=d<<3;v[e+4>>2]=b|3;b=b+e|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[114939];if(k>>>0>=h>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=(c|a)+(b>>>a|0)|0;a=c<<3;g=v[a+459796>>2];b=v[g+8>>2];a=a+459788|0;m:{if((b|0)==(a|0)){f=sia(-2,c)&f;v[114937]=f;break m}v[b+12>>2]=a;v[a+8>>2]=b}a=g+8|0;v[g+4>>2]=h|3;d=g+h|0;b=c<<3;e=b-h|0;v[d+4>>2]=e|1;v[b+g>>2]=e;if(k){b=k>>>3|0;c=(b<<3)+459788|0;g=v[114942];b=1<<b;n:{if(!(b&f)){v[114937]=b|f;b=c;break n}b=v[c+8>>2]}v[c+8>>2]=g;v[b+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=b}v[114942]=d;v[114939]=e;break a}j=v[114938];if(!j){break k}b=(0-j&j)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+460052>>2];d=(v[b+4>>2]&-8)-h|0;c=b;while(1){o:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break o}}c=(v[a+4>>2]&-8)-h|0;e=c>>>0<d>>>0;d=e?c:d;b=e?a:b;c=a;continue}break}i=v[b+24>>2];e=v[b+12>>2];if((e|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=e;v[e+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;e=a;c=a+20|0;a=v[c>>2];if(a){continue}c=e+16|0;a=v[e+16>>2];if(a){continue}break}v[g>>2]=0;break b}h=-1;if(a>>>0>4294967231){break k}a=a+11|0;h=a&-8;j=v[114938];if(!j){break k}d=0-h|0;f=0;p:{if(h>>>0<256){break p}f=31;if(h>>>0>16777215){break p}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;f=(a<<1|h>>>a+21&1)+28|0}c=v[(f<<2)+460052>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=h<<((f|0)==31?0:25-(f>>>1|0)|0);while(1){t:{g=(v[c+4>>2]&-8)-h|0;if(g>>>0>=d>>>0){break t}e=c;d=g;if(d){break t}d=0;a=c;break r}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|e)){e=0;a=2<<f;a=(0-a|a)&j;if(!a){break k}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+460052>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-h|0;c=b>>>0<d>>>0;d=c?b:d;e=c?a:e;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!e|v[114939]-h>>>0<=d>>>0){break k}f=v[e+24>>2];b=v[e+12>>2];if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=e+20|0;a=v[c>>2];if(!a){a=v[e+16>>2];if(!a){break i}c=e+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[114939];if(c>>>0>=h>>>0){d=v[114942];b=c-h|0;u:{if(b>>>0>=16){v[114939]=b;a=d+h|0;v[114942]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=h|3;break u}v[114942]=0;v[114939]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}i=v[114940];if(i>>>0>h>>>0){b=i-h|0;v[114940]=b;c=v[114943];a=c+h|0;v[114943]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(v[115055]){c=v[115057]}else{v[115058]=-1;v[115059]=-1;v[115056]=4096;v[115057]=4096;v[115055]=l+12&-16^1431655768;v[115060]=0;v[115048]=0;c=4096}g=j+c|0;e=0-c|0;c=g&e;if(c>>>0<=h>>>0){break a}d=v[115047];if(d){b=v[115045];f=b+c|0;if(d>>>0<f>>>0|b>>>0>=f>>>0){break a}}if(w[460192]&4){break f}v:{w:{d=v[114943];if(d){a=460196;while(1){b=v[a>>2];if(b>>>0<=d>>>0&d>>>0<b+v[a+4>>2]>>>0){break w}a=v[a+8>>2];if(a){continue}break}}b=Go(0);if((b|0)==-1){break g}f=c;d=v[115056];a=d-1|0;if(a&b){f=(c-b|0)+(a+b&0-d)|0}if(f>>>0<=h>>>0|f>>>0>2147483646){break g}d=v[115047];if(d){a=v[115045];e=a+f|0;if(e>>>0>d>>>0|a>>>0>=e>>>0){break g}}a=Go(f);if((b|0)!=(a|0)){break v}break e}f=e&g-i;if(f>>>0>2147483646){break g}b=Go(f);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|h+48>>>0<=f>>>0)){b=v[115057];b=b+(j-f|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((Go(b)|0)!=-1){f=b+f|0;b=a;break e}Go(0-f|0);break g}b=a;if((a|0)!=-1){break e}break g}e=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[115048]=v[115048]|4}if(c>>>0>2147483646){break d}b=v[22371];c=c+3&-4;a=b+c|0;x:{y:{if(!c|a>>>0>b>>>0){if(nw()>>>0>=a>>>0){break y}if(ta(a|0)|0){break y}a=v[22371]}else{a=b}v[114934]=48;b=-1;break x}v[22371]=a}if(nw()>>>0<a>>>0){if(!(ta(a|0)|0)){break d}}v[22371]=a;if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}f=a-b|0;if(f>>>0<=h+40>>>0){break d}}a=v[115045]+f|0;v[115045]=a;if(a>>>0>y[115046]){v[115046]=a}z:{A:{B:{g=v[114943];if(g){a=460196;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break B}a=v[a+8>>2];if(a){continue}break}break A}a=v[114941];if(!(a>>>0<=b>>>0?a:0)){v[114941]=b}a=0;v[115050]=f;v[115049]=b;v[114945]=-1;v[114946]=v[115055];v[115052]=0;while(1){d=a<<3;c=d+459788|0;v[d+459796>>2]=c;v[d+459800>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[114940]=c;a=a+b|0;v[114943]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[114944]=v[115059];break z}if(w[a+12|0]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break A}v[a+4>>2]=c+f;a=g+8&7?-8-g&7:0;c=a+g|0;v[114943]=c;b=v[114940]+f|0;a=b-a|0;v[114940]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[114944]=v[115059];break z}if(y[114941]>b>>>0){v[114941]=b}d=b+f|0;c=460196;C:{while(1){if((d|0)!=v[c>>2]){a=460196;c=v[c+8>>2];if(c){continue}break C}break}a=460196;if(w[c+12|0]&8){break C}v[c>>2]=b;v[c+4>>2]=v[c+4>>2]+f;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=h|3;e=d+(d+8&7?-8-d&7:0)|0;i=h+j|0;c=e-i|0;D:{if((e|0)==(g|0)){v[114943]=i;a=v[114940]+c|0;v[114940]=a;v[i+4>>2]=a|1;break D}if(v[114942]==(e|0)){v[114942]=i;a=v[114939]+c|0;v[114939]=a;v[i+4>>2]=a|1;v[a+i>>2]=a;break D}a=v[e+4>>2];if((a&3)==1){f=a&-8;E:{if(a>>>0<=255){d=v[e+8>>2];a=a>>>3|0;b=v[e+12>>2];if((b|0)==(d|0)){m=459748,n=v[114937]&sia(-2,a),v[m>>2]=n;break E}v[d+12>>2]=b;v[b+8>>2]=d;break E}h=v[e+24>>2];b=v[e+12>>2];F:{if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break F}G:{a=e+20|0;d=v[a>>2];if(d){break G}a=e+16|0;d=v[a>>2];if(d){break G}b=0;break F}while(1){g=a;b=d;a=b+20|0;d=v[a>>2];if(d){continue}a=b+16|0;d=v[b+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break E}d=v[e+28>>2];a=(d<<2)+460052|0;H:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break H}m=459752,n=v[114938]&sia(-2,d),v[m>>2]=n;break E}v[h+(v[h+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break E}}v[b+24>>2]=h;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break E}v[b+20>>2]=a;v[a+24>>2]=b}e=e+f|0;c=c+f|0}v[e+4>>2]=v[e+4>>2]&-2;v[i+4>>2]=c|1;v[c+i>>2]=c;if(c>>>0<=255){a=c>>>3|0;b=(a<<3)+459788|0;c=v[114937];a=1<<a;I:{if(!(c&a)){v[114937]=a|c;a=b;break I}a=v[b+8>>2]}v[b+8>>2]=i;v[a+12>>2]=i;v[i+12>>2]=b;v[i+8>>2]=a;break D}a=31;if(c>>>0<=16777215){a=c>>>8|0;e=a+1048320>>>16&8;a=a<<e;d=a+520192>>>16&4;a=a<<d;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(e|d))|0;a=(a<<1|c>>>a+21&1)+28|0}v[i+28>>2]=a;v[i+16>>2]=0;v[i+20>>2]=0;e=(a<<2)+460052|0;J:{d=v[114938];b=1<<a;K:{if(!(d&b)){v[114938]=b|d;v[e>>2]=i;v[i+24>>2]=e;break K}a=c<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[e>>2];while(1){d=b;if((v[b+4>>2]&-8)==(c|0)){break J}b=a>>>29|0;a=a<<1;e=d+(b&4)|0;b=v[e+16>>2];if(b){continue}break}v[e+16>>2]=i;v[i+24>>2]=d}v[i+12>>2]=i;v[i+8>>2]=i;break D}a=v[d+8>>2];v[a+12>>2]=i;v[d+8>>2]=i;v[i+24>>2]=0;v[i+12>>2]=d;v[i+8>>2]=a}a=j+8|0;break a}while(1){L:{c=v[a>>2];if(c>>>0<=g>>>0){e=c+v[a+4>>2]|0;if(e>>>0>g>>>0){break L}}a=v[a+8>>2];continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[114940]=c;a=a+b|0;v[114943]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[114944]=v[115059];a=(e+(e-39&7?39-e&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[115052];v[c+16>>2]=v[115051];v[c+20>>2]=a;a=v[115050];v[c+8>>2]=v[115049];v[c+12>>2]=a;v[115051]=c+8;v[115050]=f;v[115049]=b;v[115052]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<e>>>0){continue}break}if((c|0)==(g|0)){break z}v[c+4>>2]=v[c+4>>2]&-2;e=c-g|0;v[g+4>>2]=e|1;v[c>>2]=e;if(e>>>0<=255){a=e>>>3|0;b=(a<<3)+459788|0;c=v[114937];a=1<<a;M:{if(!(c&a)){v[114937]=a|c;a=b;break M}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break z}a=31;v[g+16>>2]=0;v[g+20>>2]=0;if(e>>>0<=16777215){a=e>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|e>>>a+21&1)+28|0}v[g+28>>2]=a;d=(a<<2)+460052|0;N:{c=v[114938];b=1<<a;O:{if(!(c&b)){v[114938]=b|c;v[d>>2]=g;v[g+24>>2]=d;break O}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((e|0)==(v[b+4>>2]&-8)){break N}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=g;v[g+24>>2]=c}v[g+12>>2]=g;v[g+8>>2]=g;break z}a=v[c+8>>2];v[a+12>>2]=g;v[c+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=c;v[g+8>>2]=a}a=v[114940];if(a>>>0<=h>>>0){break d}b=a-h|0;v[114940]=b;c=v[114943];a=c+h|0;v[114943]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;v[114934]=48;break a}P:{if(!f){break P}c=v[e+28>>2];a=(c<<2)+460052|0;Q:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break Q}j=sia(-2,c)&j;v[114938]=j;break P}v[f+(v[f+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break P}}v[b+24>>2]=f;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break P}v[b+20>>2]=a;v[a+24>>2]=b}R:{if(d>>>0<=15){a=d+h|0;v[e+4>>2]=a|3;a=a+e|0;v[a+4>>2]=v[a+4>>2]|1;break R}v[e+4>>2]=h|3;f=e+h|0;v[f+4>>2]=d|1;v[d+f>>2]=d;if(d>>>0<=255){a=d>>>3|0;b=(a<<3)+459788|0;c=v[114937];a=1<<a;S:{if(!(c&a)){v[114937]=a|c;a=b;break S}a=v[b+8>>2]}v[b+8>>2]=f;v[a+12>>2]=f;v[f+12>>2]=b;v[f+8>>2]=a;break R}a=31;if(d>>>0<=16777215){a=d>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|d>>>a+21&1)+28|0}v[f+28>>2]=a;v[f+16>>2]=0;v[f+20>>2]=0;b=(a<<2)+460052|0;T:{c=1<<a;U:{if(!(c&j)){v[114938]=c|j;v[b>>2]=f;break U}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);h=v[b>>2];while(1){b=h;if((v[b+4>>2]&-8)==(d|0)){break T}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=v[c+16>>2];if(h){continue}break}v[c+16>>2]=f}v[f+24>>2]=b;v[f+12>>2]=f;v[f+8>>2]=f;break R}a=v[b+8>>2];v[a+12>>2]=f;v[b+8>>2]=f;v[f+24>>2]=0;v[f+12>>2]=b;v[f+8>>2]=a}a=e+8|0;break a}V:{if(!i){break V}c=v[b+28>>2];a=(c<<2)+460052|0;W:{if(v[a>>2]==(b|0)){v[a>>2]=e;if(e){break W}m=459752,n=sia(-2,c)&j,v[m>>2]=n;break V}v[i+(v[i+16>>2]==(b|0)?16:20)>>2]=e;if(!e){break V}}v[e+24>>2]=i;a=v[b+16>>2];if(a){v[e+16>>2]=a;v[a+24>>2]=e}a=v[b+20>>2];if(!a){break V}v[e+20>>2]=a;v[a+24>>2]=e}X:{if(d>>>0<=15){a=d+h|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break X}v[b+4>>2]=h|3;e=b+h|0;v[e+4>>2]=d|1;v[e+d>>2]=d;if(k){a=k>>>3|0;c=(a<<3)+459788|0;g=v[114942];a=1<<a;Y:{if(!(a&f)){v[114937]=a|f;a=c;break Y}a=v[c+8>>2]}v[c+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=a}v[114942]=e;v[114939]=d}a=b+8|0}ab=l+16|0;return a|0}function S4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=ab-32|0;ab=g;a:{b:{c:{d:{e:{if(ge(b,21598)){Bb(a);break e}if(ge(b,9854)){b=ab-96|0;ab=b;f=Bb(a);v[22452]=0;Z(125,b- -64|0);a=v[22452];v[22452]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[22452]=0;v[b+32>>2]=0;R(1025,b+48|0,b+32|0);a=v[22452];v[22452]=0;if((a|0)==1){break p}v[22452]=0;a=Q(776,f|0,b+48|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break o}pb(b+48|0);v[22452]=0;a=Q(913,a|0,16715)|0;c=v[22452];v[22452]=0;q:{if((c|0)==1){break q}v[22452]=0;v[b+32>>2]=6;R(1025,b+48|0,b+32|0);c=v[22452];v[22452]=0;if((c|0)==1){break n}v[22452]=0;a=Q(776,a|0,b+48|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break m}pb(b+48|0);v[22452]=0;a=Q(913,a|0,16715)|0;c=v[22452];v[22452]=0;if((c|0)==1){break q}v[22452]=0;v[b+32>>2]=1;R(1025,b+48|0,b+32|0);c=v[22452];v[22452]=0;if((c|0)==1){break l}v[22452]=0;a=Q(776,a|0,b+48|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break k}c=b+48|0;pb(c);v[22452]=0;c=Q(55,c|0,21598)|0;d=v[22452];v[22452]=0;if((d|0)==1){break j}d=ub(c);pb(c);if(!d){break i}v[22452]=0;Q(913,a|0,21598)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;pb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;pb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;pb(b+48|0);break h}a=P()|0;O()|0;break h}c=Pb(b+48|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=v[b+76>>2];if(d){v[22452]=0;v[b+12>>2]=d;R(1025,b+16|0,b+12|0);d=v[22452];v[22452]=0;if((d|0)==1){break D}v[22452]=0;U(939,b+32|0,8935,b+16|0);d=v[22452];v[22452]=0;if((d|0)==1){break C}v[22452]=0;R(174,c|0,b+32|0);d=v[22452];v[22452]=0;if((d|0)==1){break B}pb(b+32|0);pb(b+16|0)}if(!zd(w[b+80|0])){break x}v[22452]=0;d=Q(55,b+32|0,12744)|0;e=v[22452];v[22452]=0;if((e|0)==1){break z}v[22452]=0;R(174,c|0,d|0);e=v[22452];v[22452]=0;if((e|0)==1){break y}pb(d);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;pb(b+32|0)}pb(b+16|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;pb(d);break r}if(!zd(w[b+81|0])){break w}v[22452]=0;d=Q(55,b+32|0,12515)|0;e=v[22452];v[22452]=0;if((e|0)==1){break v}v[22452]=0;R(174,c|0,d|0);e=v[22452];v[22452]=0;if((e|0)==1){break u}pb(d)}if(zd(w[b+82|0])){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;pb(d);break r}v[22452]=0;d=Q(55,b+32|0,11040)|0;e=v[22452];v[22452]=0;E:{if((e|0)!=1){v[22452]=0;R(174,c|0,d|0);e=v[22452];v[22452]=0;if((e|0)==1){break E}pb(d);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;pb(d);break r}if(jc(v[c>>2],v[c+4>>2])){break f}v[22452]=0;a=Q(913,a|0,16745)|0;d=v[22452];v[22452]=0;if((d|0)!=1){v[22452]=0;d=Q(55,b+16|0,16715)|0;e=v[22452];v[22452]=0;F:{G:{H:{if((e|0)!=1){v[22452]=0;U(1026,b+32|0,c|0,d|0);e=v[22452];v[22452]=0;if((e|0)==1){break H}v[22452]=0;Q(776,a|0,b+32|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break G}pb(b+32|0);pb(d);break f}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;pb(b+32|0)}pb(d);break r}a=P()|0;O()|0}Uc(c)}pf(b- -64|0)}pb(f);break a}Uc(c);pf(b- -64|0);ab=b+96|0;break e}if(ge(b,8119)){v[g>>2]=0;Uo(a,g);break e}if(ge(b,8097)){v[g>>2]=6;Uo(a,g);break e}if(ge(b,10760)){v[g>>2]=1;Uo(a,g);break e}if(ge(b,10557)){Mb(a,21598);break e}if(ge(b,11377)){b=Mb(g,21598);c=ub(b);v[22452]=0;Q(55,a|0,(c?15750:15420)|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break d}pb(b);break e}if(ge(b,7330)){b=ab-48|0;ab=b;QD(b+16|0);v[22452]=0;Z(142,b|0);c=v[22452];v[22452]=0;I:{J:{K:{L:{if((c|0)!=1){v[22452]=0;U(143,b+32|0,b+16|0,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break L}v[22452]=0;R(986,a|0,b+32|0);a=v[22452];v[22452]=0;if((a|0)==1){break K}pb(b+32|0);pb(b);pb(b+16|0);ab=b+48|0;break e}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;pb(b+32|0)}pb(b)}pb(b+16|0);break a}if(ge(b,9870)){b=ab-16|0;ab=b;e=ab-16|0;ab=e;v[e+8>>2]=101;c=ab-112|0;ab=c;f=Pb(c+96|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{d=v[e+8>>2];if(d&1){v[22452]=0;R(131,c- -64|0,19923456);d=v[22452];v[22452]=0;if((d|0)==1){break $}v[22452]=0;R(115,f|0,c- -64|0);d=v[22452];v[22452]=0;if((d|0)==1){break _}pb(c- -64|0);d=v[e+8>>2]}if(!(d&4)){break Y}v[22452]=0;d=ha(132)|0;h=v[22452];v[22452]=0;if((h|0)==1){break X}if(!d){break Z}break Y}d=P()|0;O()|0;break N}d=P()|0;O()|0;pb(c- -64|0);break N}v[22452]=0;Z(133,c- -64|0);d=v[22452];v[22452]=0;aa:{if((d|0)!=1){v[22452]=0;R(115,f|0,c- -64|0);d=v[22452];v[22452]=0;if((d|0)==1){break aa}pb(c- -64|0);break Y}d=P()|0;O()|0;break N}d=P()|0;O()|0;pb(c- -64|0);break N}ba:{d=v[e+8>>2];if(!(d&32)){break ba}v[22452]=0;Z(125,c- -64|0);d=v[22452];v[22452]=0;ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((d|0)!=1){v[22452]=0;R(134,c+48|0,c- -64|0);d=v[22452];v[22452]=0;if((d|0)==1){break da}d=c+48|0;h=pd(d);pb(d);if(!h){v[22452]=0;Z(135,c+32|0);d=v[22452];v[22452]=0;if((d|0)==1){break ua}v[22452]=0;R(134,c+16|0,c- -64|0);d=v[22452];v[22452]=0;if((d|0)==1){break ta}v[22452]=0;U(136,c+48|0,c+32|0,c+16|0);d=v[22452];v[22452]=0;if((d|0)==1){break sa}v[22452]=0;R(115,f|0,c+48|0);d=v[22452];v[22452]=0;if((d|0)==1){break ra}pb(c+48|0);pb(c+16|0);yb(c+32|0)}d=so(c- -64|0);if(!pd(d)){v[22452]=0;Z(137,c+32|0);h=v[22452];v[22452]=0;if((h|0)==1){break oa}v[22452]=0;U(138,c+48|0,c+32|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break na}v[22452]=0;R(115,f|0,c+48|0);d=v[22452];v[22452]=0;if((d|0)==1){break ma}pb(c+48|0);yb(c+32|0)}v[22452]=0;R(139,c+48|0,c- -64|0);d=v[22452];v[22452]=0;if((d|0)==1){break ka}d=c+48|0;h=pd(d);pb(d);if(!h){v[22452]=0;Z(135,c+32|0);d=v[22452];v[22452]=0;if((d|0)==1){break ja}v[22452]=0;R(139,c+16|0,c- -64|0);d=v[22452];v[22452]=0;if((d|0)==1){break ia}v[22452]=0;U(136,c+48|0,c+32|0,c+16|0);d=v[22452];v[22452]=0;if((d|0)==1){break ha}v[22452]=0;R(115,f|0,c+48|0);d=v[22452];v[22452]=0;if((d|0)==1){break ga}pb(c+48|0);pb(c+16|0);yb(c+32|0)}pf(c- -64|0);d=v[e+8>>2];break ba}d=P()|0;O()|0;break N}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break pa}d=P()|0;O()|0;break qa}d=P()|0;O()|0;pb(c+48|0)}pb(c+16|0)}yb(c+32|0);break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break la}d=P()|0;O()|0;pb(c+48|0)}yb(c+32|0);break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break ea}d=P()|0;O()|0;break fa}d=P()|0;O()|0;pb(c+48|0)}pb(c+16|0)}yb(c+32|0);break ca}d=P()|0;O()|0}pf(c- -64|0);break N}va:{if(!(d&64)){break va}v[22452]=0;d=ha(132)|0;h=v[22452];v[22452]=0;if((h|0)==1){break X}if(d){break va}d=c- -64|0;Bb(d);v[22452]=0;R(115,f|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break O}pb(c- -64|0)}if(w[e+8|0]&128){v[22452]=0;Z(140,c- -64|0);d=v[22452];v[22452]=0;if((d|0)==1){break W}v[22452]=0;R(115,f|0,c- -64|0);d=v[22452];v[22452]=0;if((d|0)==1){break V}pb(c- -64|0)}v[22452]=0;h=Q(1,c- -64|0,21598)|0;d=v[22452];v[22452]=0;if((d|0)==1){break U}v[22452]=0;U(141,c|0,f|0,h|0);d=v[22452];v[22452]=0;if((d|0)==1){break T}v[22452]=0;Z(142,c+48|0);d=v[22452];v[22452]=0;if((d|0)==1){break S}v[22452]=0;U(143,b|0,c|0,c+48|0);d=v[22452];v[22452]=0;if((d|0)==1){break R}pb(c+48|0);pb(c);pb(h);Uc(f);ab=c+112|0;break M}d=P()|0;O()|0;break N}d=P()|0;O()|0;break N}d=P()|0;O()|0;pb(c- -64|0);break N}d=P()|0;O()|0;break N}d=P()|0;O()|0;break P}d=P()|0;O()|0;break Q}d=P()|0;O()|0;pb(c+48|0)}pb(c)}pb(h);break N}d=P()|0;O()|0;pb(c- -64|0)}Uc(f);S(d|0);L()}ab=e+16|0;v[22452]=0;R(986,a|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(b);ab=b+16|0;break e}break b}if(ge(b,10486)){b=ab-48|0;ab=b;Wq(b);v[22452]=0;R(134,b+32|0,b|0);c=v[22452];v[22452]=0;wa:{xa:{if((c|0)!=1){v[22452]=0;R(986,a|0,b+32|0);a=v[22452];v[22452]=0;if((a|0)==1){break xa}pb(b+32|0);pf(b);ab=b+48|0;break e}a=P()|0;O()|0;break wa}a=P()|0;O()|0;pb(b+32|0)}pf(b);break a}if(ge(b,11340)){b=ab-32|0;ab=b;Wq(b);v[22452]=0;R(986,a|0,so(b)|0);a=v[22452];v[22452]=0;if((a|0)!=1){pf(b);ab=b+32|0;break e}a=P()|0;O()|0;pf(b);break a}if(ge(b,9883)){b=ab-48|0;ab=b;Wq(b+16|0);c=v[b+28>>2];ya:{if(c){v[22452]=0;v[b+12>>2]=c;R(1025,a|0,b+12|0);a=v[22452];v[22452]=0;if((a|0)!=1){break ya}a=P()|0;O()|0;pf(b+16|0);break a}Bb(a)}pf(b+16|0);ab=b+48|0;break e}if(ge(b,12734)){Wq(g);b=w[g+16|0];v[22452]=0;Q(55,a|0,(zd(b)?15420:15750)|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){pf(g);break e}a=P()|0;O()|0;pf(g);break a}if(ge(b,9899)){Wq(g);b=w[g+17|0];v[22452]=0;Q(55,a|0,(zd(b)?15420:15750)|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){pf(g);break e}a=P()|0;O()|0;pf(g);break a}if(ge(b,12187)){Wq(g);b=w[g+18|0];v[22452]=0;Q(55,a|0,(zd(b)?15420:15750)|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){pf(g);break e}a=P()|0;O()|0;pf(g);break a}if(ge(b,12489)){b=ab-16|0;ab=b;c=ab-32|0;ab=c;d=Bb(b);v[22452]=0;Z(125,c|0);f=v[22452];v[22452]=0;za:{Aa:{Ba:{if((f|0)!=1){v[22452]=0;R(126,d|0,so(c)|0);f=v[22452];v[22452]=0;if((f|0)==1){break Ba}pf(c);ab=c+32|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;pf(c)}pb(d);break a}v[22452]=0;R(986,a|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(b);ab=b+16|0;break e}break b}if(ge(b,8240)){b=ab-16|0;ab=b;c=ab-48|0;ab=c;d=Bb(b);v[22452]=0;R(128,c+16|0,4096);f=v[22452];v[22452]=0;Ca:{Da:{Ea:{Fa:{Ga:{if((f|0)!=1){v[c+12>>2]=14;v[c+8>>2]=0;v[22452]=0;v[c+4>>2]=0;ga(129,c+32|0,c+16|0,c+12|0,c+8|0,c+4|0);f=v[22452];v[22452]=0;if((f|0)==1){break Ga}v[22452]=0;Q(89,d|0,c+32|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break Fa}pb(c+32|0);yb(c+16|0);ab=c+48|0;break Ca}a=P()|0;O()|0;break Da}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;pb(c+32|0)}yb(c+16|0)}pb(d);S(a|0);L()}v[22452]=0;R(986,a|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(b);ab=b+16|0;break e}break b}if(ge(b,6783)){b=ab-16|0;ab=b;Gm(b,0,19544);v[22452]=0;R(986,a|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(b);ab=b+16|0;break e}break b}if(ge(b,6416)){b=ab-48|0;ab=b;c=Mb(b+16|0,17605);v[22452]=0;R(1027,b|0,2);d=v[22452];v[22452]=0;Ha:{Ia:{Ja:{Ka:{if((d|0)!=1){v[22452]=0;U(2,b+32|0,c|0,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break Ka}v[22452]=0;R(986,a|0,b+32|0);a=v[22452];v[22452]=0;if((a|0)==1){break Ja}pb(b+32|0);pb(b);pb(c);ab=b+48|0;break e}a=P()|0;O()|0;break Ha}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;pb(b+32|0)}pb(b)}pb(c);break a}if(ge(b,11363)){b=ab-16|0;ab=b;Gm(b,0,17944);v[22452]=0;R(986,a|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(b);ab=b+16|0;break e}break b}if(ge(b,10493)){b=ab-16|0;ab=b;Sq(b,0);v[22452]=0;R(986,a|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(b);ab=b+16|0;break e}break b}if(ge(b,10468)){b=ab-16|0;ab=b;Sq(b,2);v[22452]=0;R(986,a|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(b);ab=b+16|0;break e}break b}if(ge(b,10453)){b=ab-16|0;ab=b;Sq(b,3);v[22452]=0;R(986,a|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(b);ab=b+16|0;break e}break b}Bb(a)}ab=g+32|0;break c}a=P()|0;O()|0;pb(b);break a}return}a=P()|0;O()|0;pb(b)}S(a|0);L()}function c9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;f=ab-48|0;ab=f;b=v[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){Cf(a+1074312|0,0)}h=a+1074312|0;rb(f+32|0,h,0);if(sb(v[v[f+32>>2]>>2],v[f+36>>2])){o=(v[a+480180>>2]&16777248)!=0}rb(f+32|0,h,0);if(sb(v[v[f+32>>2]>>2],v[f+36>>2])){C=v[a+480180>>2]==4}a:{i=a+1074308|0;b=v[i>>2];if(b>>>0>18874367){break a}c=a+480192|0;j=a+480180|0;d=1;while(1){b:{e=d&65535;if(e>>>0<=x[c>>1]){e=v[((e<<2)+a|0)+900380>>2];if(!e){break b}v[f+32>>2]=B(w[e+20|0],100)>>>6;v[f+16>>2]=100;E=e,F=v[zb(f+32|0,f+16|0)>>2],t[E+20|0]=F;c:{d:{e:{if(o){if(b>>>0>18350079){break b}k=t[e+26|0];t[e+26|0]=((k>>31|1)+k|0)/2;if(b>>>0<18285314){break e}break d}b=t[e+26|0];t[e+26|0]=((b>>31|1)+b|0)/2}GA(zi(e,2),v[j>>2]);b=v[a+1074308>>2];if(b>>>0<18284544){break c}if(b>>>0>18285135){break b}if(!w[e+34|0]){break c}if(!fj(w[e+31|0])){break c}Db(h,2,1);b=v[i>>2]}if(b>>>0>18285135){break b}}if(!(w[e+24|0]|(w[e+23|0]|(w[e+19|0]|w[e+20|0])))){break b}Db(h,1,1)}f:{if(!(v[a+480180>>2]&16777248)|y[i>>2]>18285313&o){break f}e=x[a+480190>>1];c=1;while(1){b=c&65535;if(b>>>0>e>>>0){break f}b=B(b,104)+a|0;d=b+484419|0;if(!(w[d|0]|!(w[b+484421|0]|w[b+484420|0]))){t[d|0]=255}c=c+1|0;continue}}e=a+901404|0;j=ez(e);while(1){if((e|0)!=(j|0)){b=e;k=zp(b);while(1){if((b|0)!=(k|0)){c=w[b|0];g:{h:{if((c-97&255)>>>0<=5){g=c-32|0;break h}if(!(c-88>>>0<2|c-120>>>0<2)){g=99;if((c|0)==75|(c|0)==107){break h}break g}g=122}t[b|0]=g}b=b+1|0;continue}break}e=e+32|0;continue}break}b=v[a+1074308>>2];break a}d=d+1|0;continue}}i:{j:{k:{if((b|0)==18874368|b>>>0>18874895){break k}if(!(v[a+480180>>2]&16777252)){break j}e=0;j=x[a+480192>>1];c=1;while(1){d=c&65535;if(d>>>0>j>>>0){if(!e){break k}Db(h,3,1);b=v[i>>2]}else{d=v[((d<<2)+a|0)+900380>>2];if(!(!d|!w[d+31|0])){t[d+33|0]=13;e=1}c=c+1|0;continue}break}}if((b|0)==19005440|b>>>0>19006225){break i}}if(!(v[a+480180>>2]&16777248)){break i}rb(f+32|0,h,0);if(!sb(v[v[f+32>>2]>>2],v[f+36>>2])){rb(f+16|0,h,1);if(!sb(v[v[f+16>>2]>>2],v[f+20>>2])){break i}}e=x[a+480192>>1];c=1;while(1){b=c&65535;if(b>>>0>e>>>0){break i}b=v[((b<<2)+a|0)+900380>>2];if(!(!b|!w[b+19|0]|!(t[b+80|0]&1))){t[b+19|0]=0}c=c+1|0;continue}}l:{m:{n:{o:{p:{if(y[i>>2]>19007232){break p}b=a+946300|0;c=a+906300|0;while(1){if((b|0)==(c|0)){break p}e=f+16|0;d=c+80|0;iL(e,d);v[22452]=0;W(229,f+32|0,0,8,e|0);e=v[22452];v[22452]=0;if((e|0)==1){break o}pb(f+16|0);e=f+32|0;gq(d,e);c=c+160|0;pb(e);continue}}q:{r:{s:{if(v[a+480180>>2]!=4){break s}e=v[i>>2];if(e>>>0<19007257){break q}if(e>>>0>19071235){break r}if(w[a+1074368|0]!=4){break s}Yx(a,5)}e=v[i>>2]}if(e>>>0>19202054){break n}b=19202048;if((e|0)==19202048){break m}}j=x[a+480192>>1];d=1;while(1){b=d&65535;if(b>>>0>j>>>0){break n}b=v[((b<<2)+a|0)+900380>>2];t:{if(!b|!w[b+20|0]|!w[b+31|0]){break t}c=b+236|0;k=$s(c);while(1){if((c|0)!=(k|0)){m=x[c>>1];c=c+2|0;if(!m){continue}break t}break}t[b+20|0]=0}d=d+1|0;continue}}a=P()|0;O()|0;pb(f+16|0);S(a|0);L()}b=e;if(b>>>0>19267583){break l}}d=x[a+480192>>1];j=b>>>0>18350079;c=1;while(1){e=c&65535;if(e>>>0>d>>>0){break l}e=v[((e<<2)+a|0)+900380>>2];u:{if(!e){break u}k=t[e+26|0];t[e+26|0]=((k>>31|1)+k|0)/2;if(j&o){break u}t[e+19|0]=w[e+19|0]+3>>>2}c=c+1|0;continue}}v:{if(b>>>0>19398673){break v}e=x[a+480192>>1];c=1;while(1){d=c&65535;if(d>>>0>e>>>0){break v}d=v[((d<<2)+a|0)+900380>>2];if(!d|w[d+65|0]==255){c=c+1|0;continue}else{Db(h,94,1);b=v[i>>2]}break}}w:{if(b>>>0>19399427){break w}e=x[a+480192>>1];c=1;while(1){d=c&65535;if(d>>>0>e>>>0){break w}d=v[((d<<2)+a|0)+900380>>2];if(!d|w[d+36|0]>1){c=c+1|0;continue}else{Db(h,101,1);b=v[i>>2]}break}}x:{if(b>>>0>19923027){break x}b=x[a+480190>>1];c=1;while(1){e=c&65535;if(e>>>0>b>>>0){break x}e=B(e,104)+a|0;if(!Fd(e+484380|0)|!(w[e+484414|0]&20)){c=c+1|0;continue}else{Db(h,116,1)}break}}b=ab-16|0;ab=b;u[f+12>>1]=0;v[f+8>>2]=a;rb(b+8|0,a+1074312|0,0);E=f,F=sb(v[v[b+8>>2]>>2],v[b+12>>2]),t[E+14|0]=F;ab=b+16|0;b=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=b;j=ab-16|0;ab=j;p=a+484344|0;c=lf(p);b=v[f+4>>2];e=v[f>>2];v[j>>2]=e;v[j+4>>2]=b;v[j+8>>2]=e;v[j+12>>2]=b;e=ab-32|0;ab=e;z=c-1&65535;y:{if(lf(p)>>>0>z>>>0){q=v[j>>2];r=v[j+4>>2];while(1){b=A&65535;if(b>>>0>z>>>0){v[f+32>>2]=q;v[f+36>>2]=r;break y}c=Nf(v[p>>2],b);if(Gh(c)){d=vg(c);D=ug(Nf(v[p>>2],b));v[e+24>>2]=q;v[e+28>>2]=r;v[e+8>>2]=q;v[e+12>>2]=r;k=ab-16|0;ab=k;v[k+8>>2]=d;while(1){if(Tb(d,D)){m=ab-16|0;ab=m;s=x[e+12>>1];b=s+1|0;u[e+12>>1]=b;l=v[e+8>>2];u[e+12>>1]=x[l+480188>>1]>(b&65535)>>>0?b:0;z:{if(Lg(w[d|0])){break z}c=v[l+1074308>>2];A:{l=v[l+480180>>2];B:{C:{if((l|0)==2){if(c>>>0>18415615){break C}if(w[d+3|0]!=23){break B}jf(d+5|0,64);break B}if(l&16777248){D:{E:{if(c>>>0>=18285314){if(w[e+14|0]){break E}b=0;g=0;if(c>>>0>18874367){break D}}F:{switch(w[d+3|0]-20|0){case 3:jf(d+5|0,128);break E;case 0:break F;default:break E}}b=w[d+5|0];if((b|0)!=208){if((b|0)!=192){break E}t[d|0]=254;t[d+3|0]=0;break E}t[d+3|0]=0}G:{H:{if(c>>>0>=18350080){if(w[e+14|0]){break H}b=0;g=0;if(c>>>0>18874367){break D}}g=w[d+3|0];n=g-6&255;b=0;if(n>>>0>23){break G}b=8388643>>>n&1;break G}b=0;g=0;if(c>>>0>18874367){break D}g=w[d+3|0];b=0}g=(g|0)==24|(g|0)==22}I:{if(!(g?1:b)){break I}g=w[d+5|0];b=g&15;if(!b|(b|0)==15){break I}g=g&240;if(!g|(g|0)==240){break I}t[d+5|0]=w[d+3|0]==24?g:b}J:{if((c|0)==19005440|c>>>0>19005699){break J}b=x[v[e+8>>2]+480192>>1];if(w[e+14|0]|(!b|b>>>0>=w[d+1|0])){break J}t[d+4|0]=0;t[d+2|0]=1}if(w[d+3|0]!=18|w[d+5|0]!=17){break C}if(c>>>0>19468801){break A}rb(m+8|0,v[e+8>>2]+1074312|0,22);if(!sb(v[v[m+8>>2]>>2],v[m+12>>2])|v[v[e+8>>2]+480208>>2]&4){break C}t[d+5|0]=0;break C}if((l|0)!=4){break C}K:{L:{M:{N:{O:{if(c>>>0<18285314){break O}b=w[e+14|0];if(!(!b&c>>>0<18874368|c>>>0>19137025|w[d+3|0]!=23|w[d+5|0]<65)){t[d+3|0]=0}if(c>>>0<18415616){break O}if(b|c>>>0>18874367){break N}}b=w[d+2|0];if(w[d+3|0]!=10|(b|0)!=11){break M}t[d+3|0]=0;b=11;break M}if(c>>>0>18874639){break L}b=w[d+2|0]}if((b|0)!=11|w[d+3|0]!=4){break K}b=w[d+4|0];if(!(w[e+14|0]?1:b)){break K}g=w[d+5|0];if(!g){break K}t[d+2|0]=0;E=d,F=Pt(g+(b<<4)|0),t[E+5|0]=F;break K}if(c>>>0>19007240){break A}}if(w[d+5|0]|w[d+3|0]!=16){break C}t[d+3|0]=0}if(c>>>0>18874367){break A}}b=w[d+3|0];n=w[d+5|0]&240;P:{Q:{if((b|0)!=28|(n|0)!=96){g=0}else{if(!w[e+14|0]|(l|0)!=4){break Q}g=c>>>0<18350080}if(!(g|(b|0)==20&(n|0)==96)){break P}}b=B(s,-6)+d|0;while(1){if(b>>>0<d>>>0){if(!((w[b+3|0]|8)!=28|(w[b+5|0]&240)!=96)){t[b+3|0]=0}b=b+6|0;continue}break}b=w[d+3|0]}if((b|0)!=20|(w[d+5|0]&240)!=224){break A}b=B(s,-6)+d|0;while(1){if(b>>>0>=d>>>0){break A}if(!(w[b+3|0]!=20|(w[b+5|0]&240)!=224)){t[b+3|0]=0}b=b+6|0;continue}}b=d+2|0;g=w[d+2|0];R:{if((g|0)==8){if((c|0)==19333120|c>>>0>19333174){break z}l=w[d+4|0];c=w[d+3|0];if(!(!l|(c|0)!=7)){t[d+3|0]=11;break z}S:{switch(c-5|0){default:if((c|0)!=26){break z}break;case 0:break S;case 1:break z;case 2:break R}}g=w[d+5|0];if(!(g&15)){t[d+3|0]=5;t[d+5|0]=g|l&15;break R}T:{switch(c-5|0){case 1:break z;case 0:case 2:break R;default:break T}}if((c|0)==26){break R}break z}U:{if(!((l|0)==16777216|(g|0)!=15)){if(w[d+3|0]){break U}t[d+3|0]=10;t[d+5|0]=w[d+4|0]<<3;break R}if((g|0)!=15){break z}}if(w[d+3|0]!=10|c>>>0>19922963){break z}b=w[d+5|0]?b:w[d+4|0]?d+3|0:b}t[b|0]=0}ab=m+16|0;ui(k+8|0);d=v[k+8>>2];continue}break}b=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=b;ab=k+16|0}A=A+1|0;continue}}b=v[j+4>>2];v[f+32>>2]=v[j>>2];v[f+36>>2]=b}ab=e+32|0;ab=j+16|0;V:{if(!(!o|y[i>>2]>19267583)){c=42032;while(1){if((c|0)==42376){break V}b=v[i>>2];e=v[c+4>>2];Db(h,v[c>>2],b>>>0>=e>>>0|(b|0)==(e&-65536));c=c+8|0;continue}}if(!C|y[i>>2]>19267583){break V}c=42384;while(1){if((c|0)==42624){break V}Db(h,v[c>>2],y[i>>2]>=y[c+4>>2]);c=c+8|0;continue}}W:{X:{b=v[a+480180>>2];if(b&16777248){c=42624;while(1){if((c|0)==42680){break X}b=v[i>>2];e=v[c+4>>2];d=e&-65536;if(!(b>>>0>=d>>>0&(b>>>0<=d>>>0|b>>>0>=e>>>0))){Cf(h,v[c>>2])}c=c+8|0;continue}}c=42752;d=42688;Y:{switch(b-2|0){case 2:while(1){if((d|0)==42752){break X}if(y[i>>2]<y[d+4>>2]){Cf(h,v[d>>2])}d=d+8|0;continue};case 0:break Y;default:break W}}while(1){if((c|0)==42840){break X}if(y[i>>2]<y[c+4>>2]){Cf(h,v[c>>2])}c=c+8|0;continue}}b=v[a+480180>>2]}Z:{if((b|0)==4){c=v[i>>2];if(c>>>0>18415615){break Z}Db(h,98,1)}c=v[i>>2]}d=8;if(c-19333159>>>0<=33){c=0;while(1){if((c|0)!=5){b=c+77|0;rb(f+32|0,h,b);Cf(Db(h,c+86|0,sb(v[v[f+32>>2]>>2],v[f+36>>2])),b);c=c+1|0;continue}break}c=v[i>>2]}_:{if(c>>>0>=18284544){if(c>>>0>18874627){break _}d=6;if((c|0)==18874368){break _}}Db(h,d,1)}b=v[a+1074308>>2];$:{if(w[a+480208|0]&16){if(b>>>0<=19136511){Cf(h,7);break $}if(!(v[a+480180>>2]&16777248)|b>>>0>19267583){break $}Db(h,7,1);break $}if((b|0)==19922944|b>>>0>19922997){break $}Cf(h,7)}rb(f+32|0,h,31);aa:{if(!sb(v[v[f+32>>2]>>2],v[f+36>>2])){break aa}b=v[i>>2];if(b>>>0<19071234|b>>>0>19398722){break aa}e=x[a+480192>>1];c=1;while(1){b=c&65535;if(b>>>0>e>>>0){break aa}ba:{b=v[((b<<2)+a|0)+900380>>2];if(!b){break ba}d=w[b+65|0];if(!(w[b+60|0]&4)|(d|0)==255|d>>>0<=w[b- -64|0]){break ba}Db(h,97,1);break aa}c=c+1|0;continue}}b=v[a+480180>>2];ca:{if(!(b&16777218)){break ca}e=x[a+480190>>1];c=1;while(1){d=c&65535;if(d>>>0>e>>>0){break ca}c=c+1|0;if(!(w[(B(d,104)+a|0)+484415|0]&2)){continue}break}da:{ea:{fa:{if(!(!x[a+480192>>1]|(b|0)!=16777216)){c=v[i>>2];if(c>>>0<19398688){break ea}if(c>>>0>19464277){break fa}Db(h,109,1)}c=v[i>>2]}if((c|0)==19922944|c>>>0>19922996){break da}}Cf(h,111)}if(v[a+480180>>2]==2){if(y[i>>2]>19464191){break ca}Db(h,108,1);break ca}Cf(h,108)}ga:{if(!(v[a+480180>>2]&16777252)|v[i>>2]-19333186>>>0>589827){break ga}b=a+946300|0;c=a+906300|0;while(1){if((b|0)==(c|0)){break ga}ha:{if((w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24))!=1146637647|(w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))!=-271958638){break ha}if((Ic(v[c+4>>2],v[c+8>>2])|0)!=32){break ha}a=Mb(f+32|0,16796);gq(c+80|0,a);pb(a)}c=c+160|0;continue}}ab=f+48|0}function kU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=ab-272|0;ab=e;qc(b);if(pq(b,17771)){p=Bb(e+256|0);v[22452]=0;f=Q(224,b|0,p|0)|0;g=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{if((g|0)!=1){if(!f){break a}v[22452]=0;f=Q(239,b|0,e+248|0)|0;g=v[22452];v[22452]=0;g:{if((g|0)==1){break g}if(!f){break a}if(!IB(e+248|0)){break a}f=Fc(HB(e+248|0),db);v[22452]=0;f=Q(147,b|0,f|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break g}if(!f){break a}if(!c){break b}v[22452]=0;R(240,a|0,4096);d=v[22452];v[22452]=0;if((d|0)==1){break g}v[22452]=0;R(241,a+1298308|0,p|0);d=v[22452];v[22452]=0;if((d|0)==1){break g}d=w[e+248|2];u[a+480188>>1]=32;u[a+480192>>1]=d;lh(a,1);v[22452]=0;d=Q(1,e+96|0,9447)|0;f=v[22452];v[22452]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((f|0)!=1){tb(a+1298344|0,d);pb(d);v[22452]=0;d=Q(1,e+96|0,7011)|0;f=v[22452];v[22452]=0;if((f|0)==1){break p}tb(a+1298356|0,d);pb(d);v[22452]=0;Z(242,e+48|0);d=v[22452];v[22452]=0;if((d|0)==1){break o}t[e+216|0]=w[e+248|1];d=w[e+248|0];v[22452]=0;t[e+8|0]=d;R(243,e+232|0,e+8|0);d=v[22452];v[22452]=0;if((d|0)==1){break n}v[22452]=0;W(244,e+96|0,e+48|0,e+216|0,e+232|0);d=v[22452];v[22452]=0;if((d|0)==1){break m}d=e+96|0;tb(a+1298368|0,d);pb(d);pb(e+232|0);yb(e+48|0);v[a+1298404>>2]=5;if(w[e+248|0]<2){break i}u[e+96>>1]=8192;v[22452]=0;d=T(185,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break k}u[e+48>>1]=d;s=a,y=B(x[Ne(e+96|0,e+48|0)>>1],1e4)>>>8|0,v[s+480204>>2]=y;v[22452]=0;t[e+96|0]=1;d=T(197,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break j}t[e+48|0]=d;s=a,y=w[$e(e+96|0,e+48|0)|0],v[s+480196>>2]=y;v[22452]=0;Q(179,b|0,3)|0;d=v[22452];v[22452]=0;if((d|0)!=1){v[22452]=0;d=T(185,b|0)|0;f=v[22452];v[22452]=0;if((f|0)!=1){break h}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break l}b=P()|0;O()|0;pb(e+232|0)}yb(e+48|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}t[e+96|0]=32;v[22452]=0;d=T(197,b|0)|0;f=v[22452];v[22452]=0;q:{if((f|0)!=1){t[e+48|0]=d;s=a,y=B(w[$e(e+96|0,e+48|0)|0],1e4),v[s+480204>>2]=y;v[22452]=0;t[e+96|0]=1;d=T(197,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break q}t[e+48|0]=d;s=a,y=w[$e(e+96|0,e+48|0)|0],v[s+480196>>2]=y;v[22452]=0;d=T(197,b|0)|0;f=v[22452];v[22452]=0;if((f|0)!=1){break h}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[a+480208>>2]=d>>>2&16|12;n=Pb(e+232|0);i=e+72|1;q=e+96|12;o=Pb(e+216|0);j=a+480190|0;h=1;while(1){r:{s:{d=h&65535;if(d>>>0>x[a+480192>>1]){break s}v[22452]=0;f=Y(245,a|0,d|0,0)|0;d=v[22452];v[22452]=0;t:{if((d|0)==1){break t}if(!f){break s}v[22452]=0;d=Q(234,b|0,f+492|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break t}if(!d){break s}v[22452]=0;m=T(197,b|0)|0;d=v[22452];v[22452]=0;u:{v:{w:{if((d|0)!=1){Jb(e+96|0,0,120);if(!m){break r}x:{if(w[e+248|0]){v[22452]=0;d=Q(246,b|0,e+96|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break w}if(!d){break r}if(w[e+248|0]){break x}}Zb(e+88|0,q,96);v[22452]=0;W(156,e+48|0,b|0,v[e+88>>2],v[e+92>>2]);d=v[22452];v[22452]=0;if((d|0)==1){break v}if(!v[e+52>>2]){break r}}g=f+236|0;d=0;break u}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}while(1){if((d|0)!=120){s=Yb(g,d),y=(w[(e+96|0)+d|0]+x[j>>1]|0)+1|0,u[s>>1]=y;d=d+1|0;continue}break}v[22452]=0;d=f+48|0;U(247,e+8|0,d|0,b|0);g=v[22452];v[22452]=0;if((g|0)==1){break e}v[22452]=0;g=f+68|0;U(247,e+32|0,g|0,b|0);l=v[22452];v[22452]=0;if((l|0)==1){break e}v[22452]=0;l=f+88|0;U(247,e+80|0,l|0,b|0);k=v[22452];v[22452]=0;if((k|0)==1){break e}v[22452]=0;R(248,b|0,e+72|0);k=v[22452];v[22452]=0;if((k|0)==1){break f}v[f>>2]=(w[i|0]|w[i+1|0]<<8)&4095;r=w[i|0]|w[i+1|0]<<8;k=e+72|0;ku(k,d,0);ku(k,g,1);ku(k,l,2);s=e,y=wb(v[d>>2]),v[s+48>>2]=y;k=r>>>12&3;r=wb(v[f+52>>2]);while(1){d=v[e+48>>2];if(Tb(d,r)){t[e+44|0]=64;t[e+70|0]=((w[d+2|0]<<6)- -64>>>0)/127;s=d,y=w[Qb(e+44|0,e+70|0)|0],t[s+2|0]=y;te(e+48|0);continue}else{s=e,y=wb(v[g>>2]),v[s+48>>2]=y;d=wb(v[f+72>>2])}break}while(1){g=v[e+48>>2];if(Tb(g,d)){t[e+44|0]=64;t[e+70|0]=((w[g+2|0]<<6)+128>>>0)/255;s=g,y=w[Qb(e+44|0,e+70|0)|0],t[s+2|0]=y;te(e+48|0);continue}break}s=e,y=wb(v[l>>2]),v[s+48>>2]=y;l=1<<k;k=wb(v[f+92>>2]);while(1){d=v[e+48>>2];if(Tb(d,k)){g=d;d=t[d+2|0];d=oia(d^-128,d>>31^-1,l,0);f=db;y:{if((f|0)>=-1&d>>>0>=4294967292|(f|0)>=0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break y}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}s=g,y=vc(d,f)^128,t[s+2|0]=y;te(e+48|0);continue}else{f=x[j>>1]+1|0;u[e+70>>1]=f;d=0;f=f&65535;g=4e3-f|0;g=g>>>0>4e3?0:g;z:{A:{B:{while(1){if((d|0)==(m|0)){break A}if((d|0)==(g|0)){v[22452]=0;Q(179,b|0,20)|0;d=v[22452];v[22452]=0;if((d|0)!=1){break A}b=P()|0;O()|0;break d}v[22452]=0;l=d+f|0;Q(234,b|0,((l<<5)+a|0)+946304|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break z}v[22452]=0;R(249,b|0,e+48|0);k=v[22452];v[22452]=0;C:{if((k|0)==1){break C}v[22452]=0;R(250,e+48|0,(B(l,104)+a|0)+484380|0);l=v[22452];v[22452]=0;if((l|0)==1){break C}l=w[e+72|0];k=w[e+67|0];v[22452]=0;u[e+44>>1]=l|d<<8&32512|((k&3)!=0)<<15;R(251,o|0,e+44|0);l=v[22452];v[22452]=0;if((l|0)==1){break B}d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[22452]=0;R(251,n|0,e+70|0);d=v[22452];v[22452]=0;if((d|0)!=1){v[e+48>>2]=3999;v[e+44>>2]=m+x[j>>1];s=j,y=v[jd(e+48|0,e+44|0)>>2],u[s>>1]=y;break r}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}}}b=P()|0;O()|0;break d}d=Bb(e+96|0);v[22452]=0;f=Q(224,b|0,d|0)|0;g=v[22452];v[22452]=0;D:{E:{F:{G:{H:{if((g|0)!=1){I:{if(f){v[22452]=0;U(11,e+48|0,7,d|0);f=v[22452];v[22452]=0;if((f|0)==1){break I}f=e+48|0;tb(a+1298320|0,f);pb(f)}pb(d);d=0;J:{while(1){if((d|0)==32){v[22452]=0;d=Q(252,b|0,e+32|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break G}if(!d){break F}d=w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24);if(d>>>0<12){break H}v[22452]=0;d=Q(147,b|0,d-11|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break G}if(d){break J}break H}f=(d<<5)+a|0;Le(f+480280|0);v[22452]=0;R(225,b|0,f+480289|0);f=v[22452];v[22452]=0;if((f|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}v[e+80>>2]=(w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24))-11;i=Pb(e+96|0);v[22452]=0;U(228,b|0,i|0,v[e+80>>2]);d=v[22452];v[22452]=0;K:{if((d|0)!=1){v[e+48>>2]=50529027;d=e+48|0;s=e,y=B(v[zb(e+80|0,d)>>2],85),v[s+72>>2]=y;g=Bb(d);d=e+32|4;v[e+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=v[zb(e+72|0,e+8|0)>>2];v[22452]=0;R(46,g|0,d|0);d=v[22452];v[22452]=0;L:{if((d|0)==1){break L}d=0;M:{while(1){f=v[e+80>>2];if(f>>>0<=d>>>0){break M}j=v[i>>2];h=w[Cb(j,d)|0];q=f;f=d+1|0;if(!((h|0)!=255|q-f>>>0<2)){f=t[Cb(j,f)|0];j=w[Cb(j,d+2|0)|0];s=e,y=Ff(g),v[s+8>>2]=y;Yg(e+24|0,e+8|0);v[22452]=0;W(231,g|0,v[e+24>>2],j|0,f|0);f=v[22452];v[22452]=0;if((f|0)!=1){d=d+3|0;continue}break L}v[22452]=0;R(47,g|0,h<<24>>24);j=v[22452];v[22452]=0;d=f;if((j|0)!=1){continue}break}break L}v[22452]=0;W(229,e+8|0,5,7,g|0);d=v[22452];v[22452]=0;if((d|0)!=1){N:{f=e+8|0;d=tb(g,f);pb(f);f=Eb(d);j=ub(d);v[22452]=0;ga(230,a+1298332|0,f|0,j|0,74,0);f=v[22452];v[22452]=0;if((f|0)==1){break N}pb(d);Xb(i);break H}}}b=P()|0;O()|0;pb(g);break K}b=P()|0;O()|0}Xb(i);break d}}b=P()|0;O()|0;pb(d);break d}d=Kb(a+484360|0);f=e+248|5;f=w[f|0]|w[f+1|0]<<8;v[22452]=0;ea(232,d|0,b|0,f|0,65535,65535)|0;d=v[22452];v[22452]=0;if((d|0)==1){break G}j=c&1;if(j){d=e+248|3;d=w[d|0]|w[d+1|0]<<8;v[22452]=0;R(216,a+484344|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break G}}f=a+484344|0;i=e+248|3;d=0;while(1){O:{if((w[i|0]|w[i+1|0]<<8)>>>0>d>>>0){v[22452]=0;g=Q(147,b|0,4)|0;h=v[22452];v[22452]=0;if((h|0)==1){break D}if(g){break O}}if(!(c&2)){break F}f=a+480190|0;d=0;while(1){c=x[f>>1];if(d>>>0>=c>>>0){d=0;g=a+480190|0;while(1){if(c>>>0<=d>>>0){break F}b=x[Yb(v[o>>2],d)>>1];f=b&255;P:{if(!f){break P}i=v[n>>2];f=f-1&65535;if(wc(i,v[n+4>>2])>>>0<=f>>>0){break P}b=x[Yb(i,f)>>1]+(b>>>8&127)&65535;if(b>>>0>c>>>0){break P}f=B(b,104);c=(f+a|0)+484380|0;if(!Fd(c)){break P}i=a+484380|0;b=i+B(d+1|0,104)|0;f=f+i|0;u[b+34>>1]=x[b+34>>1]&65534|u[f+34>>1]&1;v[b>>2]=v[c>>2];if(!sg(b)){break P}gc(v[b+20>>2],v[f+20>>2],mj(v[c>>2],x[f+34>>1]))}d=d+1|0;c=x[g>>1];continue}}c=x[Yb(v[o>>2],d)>>1];if(c&255){d=d+1|0;continue}d=d+1|0;g=B(d,104)+a|0;c=Gc(e+96|0,u[g+484414>>1]&1?16:8,1,0,c<<16>>16>=0?0:6);v[22452]=0;Y(210,c|0,g+484380|0,b|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){continue}break}b=P()|0;O()|0;break d}v[22452]=0;g=T(148,b|0)|0;h=v[22452];v[22452]=0;Q:{R:{S:{T:{if((h|0)!=1){v[22452]=0;U(181,e+48|0,b|0,g|0);g=v[22452];v[22452]=0;if((g|0)==1){break T}h=e+48|0;g=bc(e+96|0,h);qb(h);if(!j){break R}v[22452]=0;h=T(197,g|0)|0;m=v[22452];v[22452]=0;if((m|0)==1){break Q}v[22452]=0;Q(179,e+96|0,1)|0;m=v[22452];v[22452]=0;if((m|0)==1){break Q}v[22452]=0;h=Y(217,f|0,d&65535,h+1|0)|0;m=v[22452];v[22452]=0;if((m|0)==1){break Q}if(!h){break R}v[22452]=0;h=Q(226,g|0,e+48|0)|0;m=v[22452];v[22452]=0;if((m|0)==1){break E}if(!h){break S}h=Rb(f,d);v[22452]=0;R(227,h|0,e+48|0);h=v[22452];v[22452]=0;if((h|0)!=1){break S}break E}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}h=Rb(f,d);v[22452]=0;U(233,h|0,1,g|0);g=v[22452];v[22452]=0;if((g|0)==1){break E}}d=d+1|0;qb(e+96|0);continue}break}break E}b=P()|0;O()|0;break d}_c(o);_c(n);break b}b=P()|0;O()|0;qb(e+96|0);break d}b=P()|0;O()|0;break d}h=h+1|0;continue}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0}_c(o);_c(n)}pb(p);S(b|0);L()}d=1}pb(p)}ab=e+272|0;return d|0}function Oha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=ab-288|0;ab=e;qc(b);f=e+264|0;g=LB(b,f);if(!g){nu(f)}a:{b:{c:{d:{e:{if(!g){break e}if(!YS(e+264|0)){break e}if(!Hb(b,Fc(72,0))){break e}if(!c){d=1;break e}vd(a,1);v[a+480208>>2]=v[a+480208>>2]&-25231361|16842752;i=w[e+273|0];u[a+480190>>1]=63;u[a+480188>>1]=i;f:{g:{while(1){if((i&65535)>>>0<=d>>>0){h:{d=1;i:{while(1){j:{f=d&65535;if(f>>>0>x[a+480190>>1]){QB(b,a+1298308|0);f=e+184|0;d=ab-16|0;ab=d;k:{if(!Hb(b,8)){t[d|0]=0;Lh(f,8,d);break k}Am(d+8|0,f);fd(d,b,v[d+8>>2],v[d+12>>2])}ab=d+16|0;n=Pb(e+168|0);f=w[e+274|0]|w[e+275|0]<<8;if(!f){break i}g=w[e+273|0];d=0;v[22452]=0;f=Y(316,b|0,n|0,B(f,g)<<1)|0;g=v[22452];v[22452]=0;if((g|0)!=1){break j}a=P()|0;O()|0;break a}g=(B(f,104)+a|0)+484380|0;ed(g,1);j=f+(e+192|0)|0;f=ue(b);t[j|0]=f;if(f<<24>>24>=0){A=g,C=VS(b)<<1,v[A>>2]=C}d=d+1|0;continue}break}if(!f){break f}}d=v[n>>2];Ub(e+160|0,d,Ic(d,v[n+4>>2])>>>1|0);m=Pb(e+144|0);d=w[e+276|0]|w[e+277|0]<<8;v[22452]=0;R(317,m|0,d<<8);d=v[22452];v[22452]=0;if((d|0)==1){break h}d=0;l:{m:{n:{while(1){f=d&65535;d=w[e+276|0]|w[e+277|0]<<8;if(f>>>0>=d>>>0){break m}v[e+72>>2]=d-f;v[e+96>>2]=2e3;d=e+72|0;g=v[jd(d,e+96|0)>>2];d=Pb(d);v[22452]=0;g=Y(316,b|0,d|0,g<<8)|0;i=v[22452];v[22452]=0;if((i|0)==1){break l}if(!g){break n}$b(e+136|0,wb(v[m+4>>2]));g=wb(v[e+72>>2]);i=wb(v[e+76>>2]);v[22452]=0;W(318,m|0,v[e+136>>2],g|0,i|0);g=v[22452];v[22452]=0;if((g|0)!=1){Xb(d);d=f+2e3|0;continue}break}break c}Xb(d);d=0;break g}de(e+120|0,v[m>>2],v[m+4>>2]);Gg(e+128|0,v[e+120>>2],v[e+124>>2]);p=a+484360|0;d=Kb(p);f=w[e+274|0]|w[e+275|0]<<8;v[22452]=0;R(319,d|0,f|0);d=v[22452];v[22452]=0;if((d|0)==1){break d}q=a+484344|0;s=c&1;while(1){if((w[e+274|0]|w[e+275|0]<<8)>>>0<=h>>>0){g=c&2;i=1;o:{p:{q:{r:{s:{t:{u:{v:{while(1){c=i&65535;if(c>>>0<=x[a+480190>>1]){v[22452]=0;d=w[c+(e+192|0)|0];U(320,b|0,((c<<5)+a|0)+946304|0,d&63);f=v[22452];v[22452]=0;if((f|0)==1){break u}w:{if(d<<24>>24<0){break w}v[22452]=0;d=T(321,b|0)|0;f=v[22452];v[22452]=0;x:{y:{z:{A:{B:{C:{D:{E:{if((f|0)==1){break E}c=B(c,104)+a|0;f=c+484392|0;v[f>>2]=d<<1;v[22452]=0;d=T(321,b|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break D}d=d<<1;if(d>>>0>=3){v[c+484396>>2]=d+v[f>>2];d=c+484414|0;u[d>>1]=x[d>>1]|8}v[22452]=0;d=T(197,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break t}t[e+72|0]=d;t[e+96|0]=64;A=c+484410|0,C=w[Qb(e+72|0,e+96|0)|0]<<2,u[A>>1]=C;v[22452]=0;d=T(197,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break E}t[c+484417|0]=d<<4;c=c+484380|0;WA(c);if(!v[c>>2]){break w}v[22452]=0;f=T(197,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break p}d=0;switch(f|0){case 4:case 5:break z;case 2:case 3:break A;case 1:break B;case 0:break C;default:break g}}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}if(!g){break x}f=Pb(e+96|0);h=v[c>>2];v[22452]=0;h=Q(147,b|0,h|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break s}if(!h){break y}d=v[c>>2];v[22452]=0;U(322,b|0,f|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break s}A=e,C=wb(v[e+96>>2]),v[A+72>>2]=C;h=wb(v[e+100>>2]);while(1){d=v[e+72>>2];if(Tb(d,h)){j=d;d=w[d|0];t[j|0]=d<<7|(d^-1)<<24>>>25;Fe(e+72|0);continue}break}de(e- -64|0,v[e+96>>2],v[e+100>>2]);Vd(e+56|0);v[22452]=0;d=ea(323,e+72|0,v[e+64>>2],v[e+68>>2],v[e+56>>2],v[e+60>>2])|0;h=v[22452];v[22452]=0;F:{if((h|0)!=1){h=Gc(e+112|0,16,1,0,16);v[22452]=0;Y(210,h|0,c|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break F}qb(e+72|0);Xb(f);break w}a=P()|0;O()|0;break o}a=P()|0;O()|0;qb(e+72|0);break o}f=Pb(e+96|0);d=v[c>>2];v[22452]=0;U(324,e+72|0,b|0,d|0);d=v[22452];v[22452]=0;G:{H:{I:{if((d|0)!=1){d=e+72|0;h=bm(f,d);Xb(d);if(g){de(e+48|0,v[e+96>>2],v[e+100>>2]);Vd(e+40|0);v[22452]=0;d=ea(323,e+72|0,v[e+48>>2],v[e+52>>2],v[e+40>>2],v[e+44>>2])|0;k=v[22452];v[22452]=0;if((k|0)==1){break I}k=Gc(e+112|0,8,1,0,2);v[22452]=0;Y(210,k|0,c|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break H}qb(e+72|0)}Xb(h);break w}a=V(30480)|0;if((O()|0)!=(fa(30480)|0)){break G}_(a|0)|0;d=0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)!=1){break v}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;qb(e+72|0)}Xb(f);break b}if(g){d=Gc(e+72|0,(f|0)==2?8:16,1,0,0);v[22452]=0;Y(210,d|0,c|0,b|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break w}a=P()|0;O()|0;break b}c=v[c>>2];v[22452]=0;Q(179,b|0,B(c,f-1|0)|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break w}break p}h=Pb(e+96|0);d=v[c>>2];v[22452]=0;U(325,e+72|0,b|0,d|0);d=v[22452];v[22452]=0;J:{K:{L:{M:{N:{O:{if((d|0)!=1){d=e+72|0;k=bm(h,d);Xb(d);if(!g){break N}if((f|0)!=5){break O}A=e,C=wb(v[e+96>>2]),v[A+72>>2]=C;l=wb(v[e+100>>2]);while(1){d=v[e+72>>2];if(!Tb(d,l)){break O}j=d;d=w[d|0];t[j|0]=w[(d>>>7|0)+26369|0]^d;Fe(e+72|0);continue}}a=V(30480)|0;if((O()|0)!=(fa(30480)|0)){break J}_(a|0)|0;d=0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)!=1){break M}a=P()|0;O()|0;break J}de(e+32|0,v[e+96>>2],v[e+100>>2]);Vd(e+24|0);v[22452]=0;d=ea(323,e+72|0,v[e+32>>2],v[e+36>>2],v[e+24>>2],v[e+28>>2])|0;l=v[22452];v[22452]=0;if((l|0)==1){break L}f=(f|0)==5;f=Gc(e+112|0,f?16:8,1,0,f?16:1);v[22452]=0;Y(210,f|0,c|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break K}qb(e+72|0)}Xb(k);break w}Xb(h);break g}a=P()|0;O()|0;break J}a=P()|0;O()|0;qb(e+72|0)}Xb(h);break b}Xb(f);break g}c=v[c>>2];v[22452]=0;Q(179,b|0,c|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break p}}i=i+1|0;continue}break}P:{Q:{R:{S:{T:{U:{V:{d=w[e+278|0]|w[e+279|0]<<8|w[e+280|0]<<16;if(d){c=Pb(e+96|0);v[22452]=0;b=Y(316,b|0,c|0,d|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break r}if(!b){break T}de(e+16|0,v[c>>2],v[c+4>>2]);b=Vd(e+8|0);f=v[b+4>>2];b=v[b>>2];v[22452]=0;b=ea(323,e+72|0,v[e+16>>2],v[e+20>>2],b|0,f|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break V}v[22452]=0;W(326,a+1298332|0,b|0,d|0,1);d=v[22452];v[22452]=0;if((d|0)==1){break U}qb(b);Xb(c)}v[22452]=0;Z(327,e+96|0);b=v[22452];v[22452]=0;if((b|0)==1){break S}v[22452]=0;U(204,e+72|0,e+96|0,e+272|0);b=v[22452];v[22452]=0;if((b|0)==1){break R}b=e+72|0;tb(a+1298344|0,b);pb(b);yb(e+96|0);v[22452]=0;b=Q(1,b|0,10057)|0;c=v[22452];v[22452]=0;if((c|0)==1){break Q}tb(a+1298356|0,b);pb(b);v[22452]=0;b=Q(1,e+72|0,5062)|0;c=v[22452];v[22452]=0;if((c|0)==1){break P}tb(a+1298368|0,b);pb(b);v[a+1298404>>2]=2;d=1;break g}a=P()|0;O()|0;break q}a=P()|0;O()|0;qb(b);break q}Xb(c);d=0;break g}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(e+96|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}Xb(f);break g}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break o}a=P()|0;O()|0}Xb(c);break b}a=P()|0;O()|0;break b}Xb(f);break b}A=Yb(v[Kb(p)>>2],h),C=h,u[A>>1]=C;W:{X:{if(!s){break X}v[22452]=0;r=h&65535;d=Y(217,q|0,r|0,64)|0;f=v[22452];v[22452]=0;if((f|0)==1){break W}if(!d){break X}f=x[a+480188>>1];k=0;while(1){d=f&65535;if(d>>>0<=k>>>0){break X}d=Yb(v[e+160>>2],B(d,h)+k|0);d=w[d|0]|w[d+1|0]<<8;Y:{if(d>>>0>=(w[e+276|0]|w[e+277|0]<<8)>>>0){break Y}i=0;y=0-k|0;z=d<<8;d=Qc(Rb(q,h),0,k&65535);while(1){if((i|0)==64){break Y}Xp(e+72|0,v[e+128>>2],v[e+132>>2],(i<<2)+z|0,4);f=v[e+72>>2];g=Cb(f,0);o=w[g|0]&63;t[d|0]=o?o+48|0:0;l=Cb(f,1);t[d+1|0]=w[l|0]<<2&60|w[g|0]>>>6;g=w[l|0];j=Cb(f,2);l=w[Cb(f,3)|0];j=w[j|0];f=l<<4|j>>>4;u[e+118>>1]=f;g=j<<2&60|g>>>6;Z:{if(!(w[Cb(e+184|0,g>>>3|0)|0]>>>(g&7)&1)|!(f?1:g)){break Z}t[d+5|0]=f;t[d+3|0]=g;j=l>>>4|0;t[d+4|0]=j;_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{switch(g|0){case 0:case 1:case 2:case 32:case 33:case 34:t[d+3|0]=g&15;Mf(d);if(!w[d+4|0]){break Z}t[d+2|0]=g>>>0<32?3:4;break Z;case 9:t[d+3|0]=10;t[d+5|0]=f>>>1;if(f>>>0<512){break Z}t[d+2|0]=15;t[d+4|0]=l>>>5;break Z;case 10:case 42:if(f>>>0>254){break ia}t[d+3|0]=g&15;break;case 50:break $;case 48:break aa;case 43:break ba;case 47:break ca;case 17:case 18:case 26:case 27:break da;case 22:case 25:case 28:case 29:case 30:break ea;case 16:case 19:case 20:case 21:case 23:case 31:break fa;case 13:break ga;case 11:case 15:break ha;case 3:case 4:case 5:case 6:case 7:case 12:break ja;default:break _}}Mf(d);break Z}t[d+3|0]=19;t[d+5|0]=j|(g>>>0<32?16:32);if(l&15){t[d+2|0]=3;t[d+4|0]=(f&240)>>>4;break Z}t[d+2|0]=4;t[d+4|0]=f&15;break Z}t[d+3|0]=(g|0)==11?12:16;A=d,C=Pt(f),t[A+5|0]=C;break Z}t[d+3|0]=14;if((f&255)>>>0<64){break Z}t[d+5|0]=0;break Z}t[d+3|0]=19;t[d+5|0]=f&15|g<<4;break Z}t[d+3|0]=19;u[e+96>>1]=15;A=d,C=w[Lc(e+118|0,e+96|0)|0]|g<<4,t[A+5|0]=C;break Z}t[d+3|0]=19;if(f&255){t[d+5|0]=f&15|((g|0)==17?16:(g|0)==26?16:32);if(!(l&240)){break Z}t[d+2|0]=g>>>0>25?6:5;break Z}t[d+5|0]=j|(g>>>0>25?-80:-96);break Z}if(!f){break _}t[d+3|0]=17;v[e+96>>2]=8;v[e+112>>2]=f+4;A=d,C=pi(v[Ee(e+96|0,e+112|0)>>2]/8|0),t[A+5|0]=C;break Z}t[d+3|0]=14;l=B(y,6)+d|0;o=x[a+480188>>1];f=0;while(1){if((f|0)==(o|0)){break Z}g=l+B(f,6)|0;if(!w[g+3|0]){t[g+3|0]=12;A=g,C=Pt(r),t[A+5|0]=C}f=f+1|0;continue}}t[d+3|0]=9;g=f&7;if(g){t[d+5|0]=w[g+26361|0];break Z}g=f>>>4|0;if((g|0)==128){break _}t[d+5|0]=g;if(!(f&2048)){t[d+5|0]=g^128;break Z}t[d+5|0]=g^-1;break Z}t[d+5|0]=0;t[d+3|0]=0;if(!o){t[d|0]=255;break Z}t[d+3|0]=25;break Z}t[d+3|0]=0}i=i+1|0;f=x[a+480188>>1];d=B(f,6)+d|0;continue}}k=k+1|0;continue}}h=h+1|0;continue}break}a=P()|0;O()|0;break b}break c}}else{UA(a,d&65535);u[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;i=x[a+480188>>1];continue}break}a=P()|0;O()|0;break b}Xb(m)}Xb(n)}ab=e+288|0;return d|0}a=P()|0;O()|0;break b}a=P()|0;O()|0;Xb(d)}Xb(m)}Xb(n);S(a|0);L()}function EF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,D=0,E=0,F=0,G=0,H=C(0),I=0;f=ab-144|0;ab=f;d=Jb(f,0,144);v[d+76>>2]=-1;v[d+44>>2]=a;v[d+32>>2]=1092;v[d+84>>2]=a;y=c;h=ab-304|0;ab=h;a:{b:{c:{d:{if(v[d+4>>2]){break d}kw(d);if(v[d+4>>2]){break d}break c}c=w[b|0];if(!c){break a}e:{f:{g:{h:{i:{while(1){j:{a=c&255;k:{if(uk(a)){while(1){c=b;b=b+1|0;if(uk(w[c+1|0])){continue}break}Th(d,0,0);while(1){a=v[d+4>>2];l:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break l}a=cd(d)}if(uk(a)){continue}break}b=v[d+4>>2];a=v[d+116>>2];if((a|0)>0|(a|0)>=0){b=b-1|0;v[d+4>>2]=b}a=b-v[d+44>>2]|0;e=a>>31;g=a;a=o+v[d+124>>2]|0;b=n+v[d+120>>2]|0;a=b>>>0<n>>>0?a+1|0:a;f=b;b=g+b|0;g=a+e|0;n=b;o=b>>>0<f>>>0?g+1|0:g;break k}m:{n:{o:{if((a|0)==37){a=w[b+1|0];if((a|0)==42){break o}if((a|0)!=37){break n}}Th(d,0,0);p:{if(w[b|0]==37){while(1){a=v[d+4>>2];q:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;c=w[a|0];break q}c=cd(d)}if(uk(c)){continue}break}b=b+1|0;break p}a=v[d+4>>2];if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;c=w[a|0];break p}c=cd(d)}if(w[b|0]!=(c|0)){a=v[d+116>>2];if((a|0)>0|(a|0)>=0){v[d+4>>2]=v[d+4>>2]-1}if((c|0)>=0){break a}e=0;if(D){break a}break c}a=v[d+4>>2]-v[d+44>>2]|0;e=a>>31;f=a;a=o+v[d+124>>2]|0;c=n+v[d+120>>2]|0;a=c>>>0<n>>>0?a+1|0:a;g=c;c=f+c|0;f=a+e|0;n=c;o=c>>>0<g>>>0?f+1|0:f;c=b;break k}k=0;b=b+2|0;break m}if(!(!Dj(a)|w[b+2|0]!=36)){c=ab-16|0;v[c+12>>2]=y;a=a-48|0;a=(a>>>0>1?(a<<2)-4|0:0)+y|0;v[c+8>>2]=a+4;k=v[a>>2];b=b+3|0;break m}k=v[y>>2];y=y+4|0;b=b+1|0}f=0;while(1){i=w[b|0];if(Dj(i)){b=b+1|0;f=(B(f,10)+i|0)-48|0;continue}break}s=0;if((i|0)==109){m=0;s=(k|0)!=0;i=w[b+1|0];r=0;b=b+1|0}c=b+1|0;a=3;e=s;r:{s:{switch((i&255)-65|0){case 39:a=w[b+1|0]==104;c=a?b+2|0:c;a=a?-2:-1;break r;case 43:a=w[b+1|0]==108;c=a?b+2|0:c;a=a?3:1;break r;case 51:case 57:a=1;break r;case 11:a=2;break r;case 41:break r;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break s;default:break e}}a=0;c=b}e=a;a=w[c|0];b=(a&47)==3;x=b?1:e;p=b?a|32:a;t:{if((p|0)==91){break t}u:{if((p|0)!=110){if((p|0)!=99){break u}f=(f|0)>1?f:1;break t}FF(k,x,n,o);break k}Th(d,0,0);while(1){a=v[d+4>>2];v:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break v}a=cd(d)}if(uk(a)){continue}break}b=v[d+4>>2];a=v[d+116>>2];if((a|0)>0|(a|0)>=0){b=b-1|0;v[d+4>>2]=b}a=b-v[d+44>>2]|0;e=a>>31;j=a;a=o+v[d+124>>2]|0;b=n+v[d+120>>2]|0;a=b>>>0<n>>>0?a+1|0:a;g=b;b=j+b|0;o=a+e|0;o=b>>>0<g>>>0?o+1|0:o;n=b}j=f;l=f>>31;Th(d,f,l);a=v[d+4>>2];w:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;break w}if((cd(d)|0)<0){break f}}a=v[d+116>>2];if((a|0)>0|(a|0)>=0){v[d+4>>2]=v[d+4>>2]-1}b=16;x:{y:{z:{A:{B:{switch(p-88|0){default:a=p-65|0;if(a>>>0>6|!(1<<a&113)){break x}case 9:case 13:case 14:case 15:HF(h+8|0,d,x,0);a=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]!=(0-a|0)|v[d+124>>2]!=(0-((a>>31)+((a|0)!=0)|0)|0)){break z}break g;case 3:case 11:case 27:if((p&239)==99){Jb(h+32|0,-1,257);t[h+32|0]=0;if((p|0)!=115){break y}t[h+65|0]=0;t[h+46|0]=0;u[h+42>>1]=0;u[h+44>>1]=0;break y}a=w[c+1|0];e=(a|0)==94;Jb(h+32|0,e,257);t[h+32|0]=0;b=e?c+2|0:c+1|0;C:{D:{E:{c=w[(e?2:1)+c|0];if((c|0)!=45){if((c|0)==93){break E}a=(a|0)!=94;break C}a=(a|0)!=94;t[h+78|0]=a;break D}a=(a|0)!=94;t[h+126|0]=a}b=b+1|0}c=b;while(1){i=w[c|0];F:{if((i|0)!=45){if(!i){break f}if((i|0)!=93){break F}break y}i=45;e=w[c+1|0];if(!e|(e|0)==93){break F}g=c+1|0;b=w[c-1|0];G:{if(e>>>0<=b>>>0){i=e;break G}while(1){b=b+1|0;t[b+(h+32|0)|0]=a;i=w[g|0];if(i>>>0>b>>>0){continue}break}}c=g}t[(h+i|0)+33|0]=a;c=c+1|0;continue};case 23:b=8;break A;case 12:case 29:b=10;break A;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break x;case 0:case 24:case 32:break A;case 17:break B}}b=0}j=0;g=0;e=0;f=0;i=0;E=ab-16|0;ab=E;H:{if((b|0)==1){v[114934]=28;break H}while(1){a=v[d+4>>2];I:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break I}a=cd(d)}if(uk(a)){continue}break}J:{K:{switch(a-43|0){case 0:case 2:break K;default:break J}}i=(a|0)==45?-1:0;a=v[d+4>>2];if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break J}a=cd(d)}L:{M:{N:{O:{if(!(b&-17|(a|0)!=48)){a=v[d+4>>2];P:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break P}a=cd(d)}if((a&-33)==88){b=16;a=v[d+4>>2];Q:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break Q}a=cd(d)}if(w[a+75201|0]<16){break N}a=v[d+116>>2];if((a|0)>0|(a|0)>=0){v[d+4>>2]=v[d+4>>2]-1}Th(d,0,0);break H}if(b){break O}b=8;break N}b=b?b:10;if(b>>>0>w[a+75201|0]){break O}a=v[d+116>>2];if((a|0)>0|(a|0)>=0){v[d+4>>2]=v[d+4>>2]-1}Th(d,0,0);v[114934]=28;break H}if((b|0)!=10){break N}e=a-48|0;if(e>>>0<=9){b=0;while(1){b=B(b,10)+e|0;f=b>>>0<429496729;a=v[d+4>>2];R:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break R}a=cd(d)}e=a-48|0;if(f&e>>>0<=9){continue}break}j=b}S:{if(e>>>0>9){break S}l=oia(j,0,10,0);f=db;b=e;while(1){a=v[d+4>>2];T:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break T}a=cd(d)}e=a-48|0;q=e>>>0>9;j=b+l|0;g=j>>>0<b>>>0?f+1|0:f;if((g|0)==429496729&j>>>0>=2576980378|g>>>0>429496729|q){break S}l=oia(j,g,10,0);f=db;b=e;if((f|0)==-1&l>>>0<=(b^-1)>>>0|(f|0)!=-1){continue}break}b=10;break M}b=10;if(e>>>0<=9){break M}break L}if(b-1&b){f=w[a+75201|0];if(f>>>0<b>>>0){while(1){e=B(b,e)+f|0;j=e>>>0<119304647;a=v[d+4>>2];U:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break U}a=cd(d)}f=w[a+75201|0];if(j&f>>>0<b>>>0){continue}break}j=e}if(b>>>0<=f>>>0){break M}while(1){l=oia(j,g,b,0);e=db;f=f&255;if((e|0)==-1&(f^-1)>>>0<l>>>0){break M}a=e;g=f+l|0;a=g>>>0<f>>>0?a+1|0:a;j=g;g=a;a=v[d+4>>2];V:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break V}a=cd(d)}f=w[a+75201|0];if(b>>>0<=f>>>0){break M}hf(E,b,0,0,0,j,g,0,0);if(!(v[E+8>>2]|v[E+12>>2])){continue}break}break M}l=t[(B(b,23)>>>5&7)+75457|0];e=w[a+75201|0];if(e>>>0<b>>>0){while(1){f=f<<l|e;j=f>>>0<134217728;a=v[d+4>>2];W:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break W}a=cd(d)}e=w[a+75201|0];if(j&e>>>0<b>>>0){continue}break}j=f}if(b>>>0<=e>>>0){break M}f=l;q=f&31;if((f&63)>>>0>=32){f=0;q=-1>>>q|0}else{f=-1>>>q|0;q=f|(1<<q)-1<<32-q}if(!f&j>>>0>q>>>0){break M}while(1){F=e&255;e=l&31;if((l&63)>>>0>=32){a=j<<e;e=0}else{a=(1<<e)-1&j>>>32-e|g<<e;e=j<<e}j=F|e;g=a;a=v[d+4>>2];X:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break X}a=cd(d)}e=w[a+75201|0];if(b>>>0<=e>>>0){break M}if((f|0)==(g|0)&j>>>0<=q>>>0|f>>>0>g>>>0){continue}break}}if(w[a+75201|0]>=b>>>0){break L}while(1){a=v[d+4>>2];Y:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break Y}a=cd(d)}if(w[a+75201|0]<b>>>0){continue}break}v[114934]=68;j=-1;g=-1;i=0}a=v[d+116>>2];if((a|0)>0|(a|0)>=0){v[d+4>>2]=v[d+4>>2]-1}a=i^j;j=a-i|0;b=i>>31;g=(b^g)-((a>>>0<i>>>0)+b|0)|0}ab=E+16|0;a=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]==(0-a|0)&v[d+124>>2]==(0-((a>>31)+((a|0)!=0)|0)|0)){break g}if(!(!k|(p|0)!=112)){v[k>>2]=j;break x}FF(k,x,j,g);break x}if(!k){break x}a=v[h+16>>2];b=v[h+20>>2];e=v[h+8>>2];f=v[h+12>>2];Z:{switch(x|0){case 0:G=k,H=bF(e,f,a,b),z[G>>2]=H;break x;case 1:G=k,I=Ew(e,f,a,b),A[G>>3]=I;break x;case 2:break Z;default:break x}}v[k>>2]=e;v[k+4>>2]=f;v[k+8>>2]=a;v[k+12>>2]=b;break x}g=(p|0)==99;f=g?f+1|0:31;x=(x|0)!=1;_:{if(!x){a=k;if(s){a=yd(f<<2);if(!a){break h}}v[h+296>>2]=0;v[h+300>>2]=0;b=0;while(1){e=v[d+4>>2];$:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break $}e=cd(d)}if(w[(e+h|0)+33|0]){t[h+27|0]=e;e=lr(h+28|0,h+27|0,1,h+296|0);if((e|0)==-2){continue}m=0;if((e|0)==-1){break i}if(a){v[(b<<2)+a>>2]=v[h+28>>2];b=b+1|0}if(!((b|0)==(f|0)&s)){continue}e=1;r=a;b=f;f=b<<1|1;a=Ar(a,f<<2);if(a){continue}break e}break}m=0;if(h+296|0?v[h+296>>2]:0){break i}break _}if(s){b=0;i=yd(f);if(!i){break h}while(1){m=i;while(1){a=v[d+4>>2];aa:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break aa}a=cd(d)}if(!w[(a+h|0)+33|0]){a=0;break _}t[b+m|0]=a;b=b+1|0;if((f|0)!=(b|0)){continue}break}e=1;r=0;b=f;a=b<<1|1;f=a;i=Ar(m,a);if(i){continue}break}break e}b=0;if(k){while(1){a=v[d+4>>2];ba:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break ba}a=cd(d)}if(w[(a+h|0)+33|0]){t[b+k|0]=a;b=b+1|0;continue}else{a=0;m=k;break _}}}while(1){a=v[d+4>>2];ca:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break ca}a=cd(d)}if(w[(a+h|0)+33|0]){continue}break}m=0;a=0}i=v[d+4>>2];e=v[d+116>>2];if((e|0)>0|(e|0)>=0){i=i-1|0;v[d+4>>2]=i}f=i-v[d+44>>2]|0;r=f;e=f+v[d+120>>2]|0;f=v[d+124>>2]+(f>>31)|0;f=e>>>0<r>>>0?f+1|0:f;if(!(f|e)|((e|0)!=(j|0)|(f|0)!=(l|0))&(p|0)==99){break j}da:{if(!s){break da}if(!x){v[k>>2]=a;break da}v[k>>2]=m}ea:{if(g){break ea}if(a){v[(b<<2)+a>>2]=0}if(!m){m=0;break ea}t[b+m|0]=0}r=a}a=v[d+4>>2]-v[d+44>>2]|0;e=a>>31;g=a;a=o+v[d+124>>2]|0;b=n+v[d+120>>2]|0;a=b>>>0<n>>>0?a+1|0:a;f=b;b=g+b|0;a=a+e|0;n=b;o=b>>>0<f>>>0?a+1|0:a;D=((k|0)!=0)+D|0}b=c+1|0;c=w[c+1|0];if(c){continue}break a}break}r=a;break g}r=a;break f}e=1;m=0;r=0;break e}e=s;break b}e=s}if(D){break b}}D=-1}if(!e){break a}xb(m);xb(r)}ab=h+304|0;ab=d+144|0;return D}function l3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=ab-32|0;ab=g;d=Mb(g+16|0,11574);h=Jg(c,d);pb(d);a:{b:{c:{d:{e:{if(h){Hk(a,v[b+24>>2]+1298356|0);break e}d=Mb(g+16|0,10912);h=Jg(c,d);pb(d);if(h){Hk(a,v[b+24>>2]+1298344|0);break e}d=Mb(g+16|0,11404);h=Jg(c,d);pb(d);if(h){Hk(a,v[b+24>>2]+1298392|0);break e}d=Mb(g+16|0,10904);h=Jg(c,d);pb(d);if(h){Hk(a,v[b+24>>2]+1298380|0);break e}d=Mb(g+16|0,8230);h=Jg(c,d);pb(d);if(h){c=g+16|0;d=v[v[b+24>>2]+480184>>2];b=32784;f:{while(1){if((b|0)!=32832){if((d|0)==v[b>>2]){Gm(c,0,v[b+8>>2]);break f}else{b=b+12|0;continue}}break}Bb(c)}v[22452]=0;R(986,a|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break d}pb(g+16|0);break e}d=Mb(g+16|0,10889);h=Jg(c,d);pb(d);if(h){f=v[v[b+24>>2]+480184>>2];c=ab-48|0;ab=c;b=32784;e=Rg(c+32|0);j=g+16|0;d=Bb(j);while(1){if((b|0)!=32832){if((f|0)==v[b>>2]){h=v[b+4>>2];v[22452]=0;h=Q(1,c+16|0,h|0)|0;i=v[22452];v[22452]=0;g:{h:{i:{j:{k:{l:{if((i|0)!=1){v[22452]=0;U(821,c|0,e|0,h|0);i=v[22452];v[22452]=0;if((i|0)==1){break j}if(!w[c+4|0]){break g}if(!pd(d)){v[22452]=0;i=Q(1,c|0,17716)|0;k=v[22452];v[22452]=0;if((k|0)==1){break l}v[22452]=0;Q(89,d|0,i|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break k}pb(i)}v[22452]=0;Q(89,d|0,h|0)|0;i=v[22452];v[22452]=0;if((i|0)!=1){break g}b=P()|0;O()|0;break i}b=P()|0;O()|0;break h}b=P()|0;O()|0;break i}b=P()|0;O()|0;pb(i);break i}b=P()|0;O()|0}pb(h)}pb(d);NK(e);S(b|0);L()}pb(h)}b=b+12|0;continue}break}NK(e);ab=c+48|0;v[22452]=0;R(986,a|0,j|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(g+16|0);break e}c=P()|0;O()|0;pb(g+16|0);break a}d=Mb(g+16|0,8296);h=Jg(c,d);pb(d);if(h){Hk(a,v[b+24>>2]+1298368|0);break e}d=Mb(g+16|0,5581);h=Jg(c,d);pb(d);if(h){Hk(a,v[b+24>>2]+1298320|0);break e}d=Mb(g+16|0,11978);h=Jg(c,d);pb(d);if(h){c=g+16|0;Rf(c,v[b+24>>2]+1298308|0);v[22452]=0;U(980,a|0,b|0,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(g+16|0);break e}c=P()|0;O()|0;pb(g+16|0);break a}d=Mb(g+16|0,11347);h=Jg(c,d);pb(d);if(h){m:{b=b+24|0;c=Hw(v[b>>2]);if(!jc(v[c>>2],v[c+4>>2])){if(FC(v[JH(v[Hw(v[b>>2])+4>>2])+12>>2])){break m}}Bb(a);break e}o=g+16|0;b=JH(v[Hw(v[b>>2])+4>>2]);j=ab-144|0;ab=j;gc(j+96|0,b,44);e=v[b+44>>2];if(e){gc(j+44|0,b,44);h=ab-16|0;ab=h;b=Pw(v[j+64>>2]+1900|0,v[j+60>>2]+1|0,v[j+56>>2])-Pw(1970,1,1)|0;b=oia(b,b>>31,86400,0);c=B(v[j+52>>2],3600);b=b+c|0;d=db+(c>>31)|0;d=b>>>0<c>>>0?d+1|0:d;c=B(v[j+48>>2],60);i=c;b=c+b|0;c=(c>>31)+d|0;c=b>>>0<i>>>0?c+1|0:c;d=v[j+44>>2];i=d;b=d+b|0;d=(d>>31)+c|0;c=bn(h+8|0,b,b>>>0<i>>>0?d+1|0:d);b=v[c>>2];i=v[c+4>>2];ab=h+16|0;h=j+88|0;d=2147483647;m=be(+(e>>>0)/18.2);c=-1;n:{if(m>=0x8000000000000000){break n}d=-2147483648;c=0;if(m<=-0x8000000000000000){break n}if(D(m)<0x8000000000000000){d=D(m)>=1?~~(m>0?F(H(m*2.3283064365386963e-10),4294967295):I((m-+(~~m>>>0>>>0))*2.3283064365386963e-10))>>>0:0;c=~~m>>>0;break n}c=0}d=d+i|0;c=b+c|0;d=c>>>0<b>>>0?d+1|0:d;b=bn(h,c,d);i=v[b+4>>2];h=v[b>>2];k=ab-16|0;ab=k;v[k+12>>2]=0;v[k+8>>2]=0;v[k+4>>2]=0;b=Pw(1970,1,1)+pia(h,i,86400,0)|0;f=b>>31;d=oia(b,f,1e4,0)+14780|0;c=db;e=d;c=d>>>0<14780?c+1|0:c;l=pia(d,c,-14609700,-1)+b|0;d=f+db|0;d=b>>>0>l>>>0?d+1|0:d;n=pia(e,c,365242500,0);l=n+l|0;d=db+d|0;d=l>>>0<n>>>0?d+1|0:d;n=pia(e,c,-146097e4,-1);l=n+l|0;d=db+d|0;d=l>>>0<n>>>0?d+1|0:d;c=pia(e,c,3652425,0);e=db;n=e;p=l;l=oia(c,e,-365,-1);e=p+l|0;d=db+d|0;d=e>>>0<l>>>0?d+1|0:d;if(!((d|0)>0|(d|0)>=0)){d=n-!c|0;c=c-1|0;e=oia(c,d,-365,-1)+b|0;d=f+db|0;d=b>>>0>e>>>0?d+1|0:d;b=e;e=(c|0)/-4|0;b=b+e|0;d=(e>>31)+d|0;d=b>>>0<e>>>0?d+1|0:d;e=b;b=(c|0)/100|0;f=b;e=e+b|0;b=(b>>31)+d|0;b=e>>>0<f>>>0?b+1|0:b;d=(c|0)/-400|0;f=d;e=d+e|0;d=(d>>31)+b|0;d=e>>>0<f>>>0?d+1|0:d}f=c;b=oia(e,d,100,0)+52|0;c=db;b=pia(b,b>>>0<52?c+1|0:c,3060,0);c=b+2|0;d=(c|0)/12|0;v[k+12>>2]=f+d;v[k+8>>2]=(c+B(d,-12)|0)+1;b=oia(b,db,306,0)+5|0;d=db;b=pia(b,b>>>0<5?d+1|0:d,-10,-1)+e|0;v[k+4>>2]=b+1;v[j+136>>2]=0;v[j+128>>2]=0;v[j+132>>2]=0;v[j+120>>2]=0;v[j+124>>2]=0;v[j+116>>2]=v[k+12>>2]-1900;v[j+112>>2]=v[k+8>>2]-1;b=v[k+4>>2];q=j,r=qia(pia(h,i,3600,0),db,24),v[q+104>>2]=r;v[j+108>>2]=b;b=pia(h,i,60,0);c=db;q=j,r=qia(b,c,60),v[q+100>>2]=r;b=oia(b,c,-60,-1)+h|0;v[j+96>>2]=b;ab=k+16|0}c=gc(j,j+96|0,44);b=ab-112|0;ab=b;h=Bb(b+96|0);v[22452]=0;d=Q(1,b+80|0,13449)|0;e=v[22452];v[22452]=0;o:{p:{q:{r:{s:{if((e|0)!=1){e=v[c+20>>2];if(!e){break p}v[22452]=0;v[b+48>>2]=e+1900;R(88,b- -64|0,b+48|0);e=v[22452];v[22452]=0;if((e|0)!=1){v[22452]=0;i=Q(89,h|0,b- -64|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break s}pb(b- -64|0);f=v[c+16>>2];if(f>>>0>11){break p}v[22452]=0;e=Q(1,b+48|0,16743)|0;j=v[22452];v[22452]=0;t:{u:{v:{w:{x:{y:{if((j|0)!=1){v[22452]=0;v[b+16>>2]=f+1;R(90,b+32|0,b+16|0);f=v[22452];v[22452]=0;if((f|0)==1){break y}v[22452]=0;U(2,b- -64|0,e|0,b+32|0);f=v[22452];v[22452]=0;if((f|0)==1){break x}v[22452]=0;i=Q(89,i|0,b- -64|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break w}pb(b- -64|0);pb(b+32|0);pb(e);if(v[c+12>>2]-32>>>0>=4294967265){break t}break p}a=P()|0;O()|0;break r}a=P()|0;O()|0;break u}a=P()|0;O()|0;break v}a=P()|0;O()|0;pb(b- -64|0)}pb(b+32|0)}pb(e);break r}v[22452]=0;e=Q(1,b+48|0,16743)|0;f=v[22452];v[22452]=0;z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{if((f|0)!=1){v[22452]=0;R(90,b+32|0,c+12|0);f=v[22452];v[22452]=0;if((f|0)==1){break Y}v[22452]=0;U(2,b- -64|0,e|0,b+32|0);f=v[22452];v[22452]=0;if((f|0)==1){break X}v[22452]=0;i=Q(89,i|0,b- -64|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break W}pb(b- -64|0);pb(b+32|0);pb(e);j=v[c>>2];e=v[c+8>>2];f=v[c+4>>2];if(!(j|(e|f))|e>>>0>23|f>>>0>59){break p}v[22452]=0;e=Q(1,b- -64|0,13616)|0;f=v[22452];v[22452]=0;if((f|0)==1){break T}v[22452]=0;i=Q(89,i|0,e|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break S}pb(e);if(v[c+32>>2]>0){v[22452]=0;e=Q(1,b- -64|0,15533)|0;f=v[22452];v[22452]=0;if((f|0)==1){break R}tb(d,e);pb(e)}v[22452]=0;R(90,b+32|0,c+8|0);e=v[22452];v[22452]=0;if((e|0)==1){break Q}v[22452]=0;e=Q(1,b+16|0,14621)|0;f=v[22452];v[22452]=0;if((f|0)==1){break P}v[22452]=0;U(2,b+48|0,b+32|0,e|0);f=v[22452];v[22452]=0;if((f|0)==1){break O}v[22452]=0;R(90,b|0,c+4|0);f=v[22452];v[22452]=0;if((f|0)==1){break N}v[22452]=0;U(2,b- -64|0,b+48|0,b|0);f=v[22452];v[22452]=0;if((f|0)==1){break M}v[22452]=0;i=Q(89,i|0,b- -64|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break L}pb(b- -64|0);pb(b);pb(b+48|0);pb(e);pb(b+32|0);if(j>>>0<62){break G}v[22452]=0;U(91,o|0,i|0,d|0);e=v[22452];v[22452]=0;if((e|0)==1){break F}break o}a=P()|0;O()|0;break r}a=P()|0;O()|0;break U}a=P()|0;O()|0;break V}a=P()|0;O()|0;pb(b- -64|0)}pb(b+32|0)}pb(e);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;pb(e);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break H}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;break K}a=P()|0;O()|0;pb(b- -64|0)}pb(b)}pb(b+48|0)}pb(e)}pb(b+32|0);break r}v[22452]=0;e=Q(1,b+48|0,14621)|0;f=v[22452];v[22452]=0;if((f|0)==1){break E}v[22452]=0;R(90,b+32|0,c|0);f=v[22452];v[22452]=0;if((f|0)==1){break D}v[22452]=0;U(2,b- -64|0,e|0,b+32|0);f=v[22452];v[22452]=0;if((f|0)==1){break C}v[22452]=0;i=Q(89,i|0,b- -64|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break B}pb(b- -64|0);pb(b+32|0);pb(e);v[22452]=0;Q(89,i|0,d|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){break p}}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break z}a=P()|0;O()|0;break A}a=P()|0;O()|0;pb(b- -64|0)}pb(b+32|0)}pb(e);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break q}a=P()|0;O()|0;pb(b- -64|0)}pb(d)}pb(h);S(a|0);L()}Ac(o,h)}pb(d);pb(h);ab=b+112|0;ab=c+144|0;v[22452]=0;R(986,a|0,o|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(g+16|0);break e}c=P()|0;O()|0;pb(g+16|0);break a}d=Mb(g+16|0,12179);h=Jg(c,d);pb(d);if(h){c=g+16|0;d=b+24|0;zO(c,v[d>>2]+1298332|0);Z:{if(!pd(c)){break Z}d=v[v[d>>2]+480180>>2];_:{$:{if((d|0)==33554432){break $}c=1;if((d|0)==32){break _}if((d|0)==16384){break $}if((d|0)==16777216){break _}}c=2}aa:{switch(c-1|0){case 0:v[22452]=0;R(987,g|0,b|0);c=v[22452];v[22452]=0;if((c|0)!=1){tb(g+16|0,g);pb(g);break Z}break b;case 1:break aa;default:break Z}}v[22452]=0;R(988,g|0,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=tb(g+16|0,g);pb(g);if(!pd(c)){break Z}v[22452]=0;R(987,g|0,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break b}tb(c,g);pb(g)}v[22452]=0;U(980,a|0,b|0,g+16|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(g+16|0);break e}break b}d=Mb(g+16|0,5433);h=Jg(c,d);pb(d);if(h){c=g+16|0;zO(c,v[b+24>>2]+1298332|0);v[22452]=0;U(980,a|0,b|0,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(g+16|0);break e}c=P()|0;O()|0;pb(g+16|0);break a}e=c;c=Mb(g+16|0,7253);d=Jg(e,c);pb(c);if(d){a=Bb(a);q=g,r=wb(v[b+68>>2]),v[q+16>>2]=r;b=wb(v[b+72>>2]);c=1;while(1){d=v[g+16>>2];if(!Tb(d,b)){break e}if(!(c&1)){v[22452]=0;Q(913,a|0,21568)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}}v[22452]=0;Q(776,a|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}Sn(g+16|0);c=0;continue}}Mb(a,21598)}ab=g+32|0;return}c=P()|0;O()|0;pb(g+16|0);break a}c=P()|0;O()|0;pb(a);break a}c=P()|0;O()|0;pb(g+16|0)}S(c|0);L()}function TU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a:{n=oh(b,13804);if(!n){break a}o=a+480192|0;b:while(1){if(!Hb(b,6)){break a}c:{f=jg(b);d:{if((f|0)==(om(13623)|0)){break d}c=w[21574]|w[21575]<<8|(w[21576]<<16|w[21577]<<24);if(!(f&1616928864)|f&-2139062144){break d}if((c|0)!=(f|0)){break c}}gg(b,4);break a}l=1;c=xg(b);while(1){d=l&65535;if(d>>>0>x[o>>1]){continue b}d=v[((d<<2)+a|0)+900380>>2];if(d){e:{g=0;if((om(16699)|0)==(f|0)){Ob(b,c);break e}e=ab-48|0;ab=e;f:{if(!d){break f}g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{switch(f-1349079874|0){default:if((f|0)==1095062094){break v}if((f|0)==1095126087){break s}if((f|0)==1129524782){break B}if((f|0)==1145263150){break Y}if((f|0)==1145979182){break X}if((f|0)==1179463214){break z}if((f|0)==1851469358){break F}if((f|0)==1179931728){break n}$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{if((f|0)!=1196830254){if((f|0)==1229341486){break U}if((f|0)==1229345326){break T}if((f|0)==1264266798){break G}if((f|0)==1296182830){break S}if((f|0)==1296248366){break Q}if((f|0)==1297100334){break R}if((f|0)==1297110852){break q}if((f|0)==1298747438){break D}if((f|0)==1313692462){break H}if((f|0)==1313751342){break Z}if((f|0)==1345203758){break ja}if((f|0)==1346711086){break l}if((f|0)==1346720334){break w}if((f|0)==1346722606){break J}if((f|0)==1346784327){break t}if((f|0)==1347175726){break da}if((f|0)==1347179310){break ea}if((f|0)==1347437358){break O}if((f|0)==1347441454){break P}if((f|0)==1347443502){break M}if((f|0)==1347628590){break W}if((f|0)==1347633710){break ca}if((f|0)==1347634478){break ba}if((f|0)==1347703884){break o}if((f|0)==1347831112){break y}if((f|0)==1347833672){break x}if((f|0)==1349076270){break k}if((f|0)==1349076315){break I}if((f|0)==1349078085){break $}if((f|0)==1349078099){break aa}if((f|0)==1349079131){break L}if((f|0)==1378758190){break p}if((f|0)==1381183022){break A}if((f|0)==1447374382){break m}if((f|0)==1447383630){break u}if((f|0)==1447385902){break K}if((f|0)==1447447623){break r}if((f|0)==1447839022){break ha}if((f|0)==1447842606){break ia}if((f|0)==1448106798){break N}if((f|0)==1448226350){break C}if((f|0)==1448291886){break V}if((f|0)==1448297006){break ga}if((f|0)==1448297774){break fa}if((f|0)!=1682320942){if((f|0)==1718508334){break E}if((f|0)!=1179594286|c>>>0>4){break f}if(!Hb(b,c)){break f}p=d,q=Hu(b,c),v[p>>2]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+15|0]=q;break g}if(c>>>0>4){break f}if(!Hb(b,c)){break f}p=d,q=Hu(b,c),v[p+4>>2]=q;break g}if(c>>>0>4){break f}if(!Hb(b,c)){break f}p=d,q=Hu(b,c),v[p+8>>2]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+61|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+62|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+63|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d- -64|0,q=od(b,c),t[p|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+81|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+82|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+83|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+84|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+101|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+102|0]=q;break g;case 0:if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+103|0]=q;break g;case 3:break _;case 1:case 2:break f}}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+104|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+16|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+17|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+18|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+19|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+20|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+21|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+22|0]=q;break g}if(c>>>0>2){break f}if(!Hb(b,c)){break f}p=d,q=CC(b,c),u[p+28>>1]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+30|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+31|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=BC(b,c),t[p+26|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+27|0]=q;break g}Md(e,b,c);h=bc(e+24|0,e);qb(e);i=zi(d,0);while(1){if(Td(i)>>>0<=g>>>0){qb(h);break g}v[22452]=0;k=T(188,h|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break j}p=Fb(v[i>>2],g),q=k,u[p>>1]=q;g=g+1|0;continue}}Md(e,b,c);h=bc(e+24|0,e);qb(e);i=zi(d,1);while(1){if(Td(i)>>>0<=g>>>0){qb(h);break g}v[22452]=0;k=T(188,h|0)|0;j=v[22452];v[22452]=0;if((j|0)!=1){p=Fb(v[i>>2],g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Md(e,b,c);h=bc(e+24|0,e);qb(e);i=zi(d,2);while(1){if(Td(i)>>>0<=g>>>0){qb(h);break g}v[22452]=0;k=T(188,h|0)|0;j=v[22452];v[22452]=0;if((j|0)!=1){p=Fb(v[i>>2],g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Md(e,b,c);h=bc(e+24|0,e);qb(e);i=zi(d,0);while(1){if(Td(i)>>>0<=g>>>0){qb(h);break g}v[22452]=0;k=T(189,h|0)|0;j=v[22452];v[22452]=0;if((j|0)!=1){p=Fb(v[i>>2],g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Md(e,b,c);h=bc(e+24|0,e);qb(e);i=zi(d,1);while(1){if(Td(i)>>>0<=g>>>0){qb(h);break g}v[22452]=0;k=T(189,h|0)|0;j=v[22452];v[22452]=0;if((j|0)!=1){p=Fb(v[i>>2],g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Md(e,b,c);h=bc(e+24|0,e);qb(e);i=zi(d,2);while(1){if(Td(i)>>>0<=g>>>0){qb(h);break g}v[22452]=0;k=T(189,h|0)|0;j=v[22452];v[22452]=0;if((j|0)!=1){p=Fb(v[i>>2],g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>128){break f}i=d+108|0;Md(e,b,c);h=bc(e+24|0,e);qb(e);while(1){if((g|0)==128){qb(h);break g}v[22452]=0;k=T(189,h|0)|0;j=v[22452];v[22452]=0;if((j|0)!=1){p=Cb(i,g),q=k,t[p|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>256){break f}i=d+236|0;Md(e,b,c);h=bc(e+24|0,e);qb(e);while(1){if((g|0)==128){qb(h);break g}v[22452]=0;k=T(188,h|0)|0;j=v[22452];v[22452]=0;if((j|0)!=1){p=Yb(i,g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>32){break f}k=d+492|0;Md(e,b,c);h=bc(e+24|0,e);qb(e);i=Bb(e);while(1){if((c|0)==(g|0)){break h}v[22452]=0;j=T(190,h|0)|0;m=v[22452];v[22452]=0;ka:{if((m|0)==1){break ka}v[22452]=0;Q(191,i|0,j|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break ka}g=g+1|0;continue}break}g=P()|0;O()|0;pb(i);break i}if(c>>>0>32){break f}k=d+524|0;Md(e,b,c);h=bc(e+24|0,e);qb(e);i=Bb(e);la:{while(1){if((c|0)!=(g|0)){v[22452]=0;j=T(190,h|0)|0;m=v[22452];v[22452]=0;if((m|0)==1){break la}v[22452]=0;Q(191,i|0,j|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break la}g=g+1|0;continue}break}sc(k,i);pb(i);qb(h);break g}g=P()|0;O()|0;pb(i);break i}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+34|0]=q;break g}if(c>>>0>2){break f}if(!Hb(b,c)){break f}p=d,q=CC(b,c),u[p+12>>1]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+23|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+24|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+25|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+35|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+36|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+105|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+85|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+65|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+100|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+80|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=od(b,c),t[p+60|0]=q;break g}if(c>>>0>1){break f}if(!Hb(b,c)){break f}p=d,q=BC(b,c),t[p+33|0]=q;break g}g=1;h=co(b,c);if(!bo(h)){break f}t[d+14|0]=h;break f}p=d,q=B(Fu(b,c),1e4)+(y[d+40>>2]%1e4|0)|0,v[p+40>>2]=q;break g}g=Fu(b,c);h=v[d+40>>2];v[d+40>>2]=h-((h>>>0)%1e4|0)+(g>>>0)%1e4;break g}v[e+24>>2]=240;p=e,q=co(b,c),v[p>>2]=q;Wg(d+48|0,v[zb(e+24|0,e)>>2]);break g}v[e+24>>2]=240;p=e,q=co(b,c),v[p>>2]=q;Wg(d+68|0,v[zb(e+24|0,e)>>2]);break g}v[e+24>>2]=240;p=e,q=co(b,c),v[p>>2]=q;Wg(d+88|0,v[zb(e+24|0,e)>>2]);break g}g=P()|0;O()|0}qb(h);S(g|0);L()}sc(k,i);pb(i);qb(h)}g=1}ab=e+48|0;if(!g){Ob(b,c);break e}if((om(16704)|0)==(f|0)){e=w[d+15|0];t[d+15|0]=0;t[d+100|0]=w[d+100|0]&224|(e>>>5&4|e>>>6&1);t[d+60|0]=e>>>1&2|(e<<1&4|(w[d+60|0]&240|e&1));t[d+80|0]=w[d+80|0]&240|(e>>>4&2|(e>>>2&4|e>>>3&1))}}}l=l+1|0;continue}}}return n|0}function E8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=ab-768|0;ab=d;qc(b);a:{b:{c:{d:{e:{f:{if(!Mh(b,d+760|0)){break f}if(!GK(d+760|0)){break f}if(!eA(b,d+752|0)){break f}if(!FK(d+752|0)){break f}h=1313423693;j=w[d+752|0]|w[d+753|0]<<8|(w[d+754|0]<<16|w[d+755|0]<<24);if((j|0)!=1179012417){h=1414090313;if((j|0)!=538987841){break f}}m=_d(d+728|0,b);k=Ye(d+712|0);g:{h:{i:{j:{k:{l:{m:{if(!c){v[22452]=0;W(828,d+136|0,m|0,((j|0)==1179012417?1:2)|0,h|0);b=v[22452];v[22452]=0;if((b|0)!=1){break m}b=P()|0;O()|0;break a}v[22452]=0;U(829,d+136|0,m|0,((j|0)==1179012417?1:2)|0);b=v[22452];v[22452]=0;if((b|0)==1){break l}}b=d+136|0;ot(k,b);Rd(b);v[22452]=0;U(830,d+688|0,k|0,h|0);b=v[22452];v[22452]=0;if((b|0)!=1){v[22452]=0;b=T(169,d+688|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break k}e=0;if(!b){break g}v[22452]=0;b=Q(831,d+688|0,d+608|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break k}if(!b){break g}b=w[d+673|0];if(!b){break g}v[22452]=0;e=Q(147,d+688|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break k}if(!c|e^1){break g}v[22452]=0;R(240,a|0,8388608);b=v[22452];v[22452]=0;if((b|0)==1){break k}v[a+480208>>2]=12;v[a+480208>>2]=w[d+672|0]<<4&16^28;u[d+136>>1]=w[d+673|0];u[d+496>>1]=127;o=a,p=x[Lc(d+136|0,d+496|0)>>1],u[o+480188>>1]=p;v[a+480196>>2]=w[d+674|0];v[a+480204>>2]=B(w[d+675|0],1e4);v[a+480200>>2]=w[d+680|0]<<1;v[22452]=0;Q(127,a+1298344|0,((j|0)==1179012417?16914:16880)|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break k}v[22452]=0;b=Q(1,d+136|0,13233)|0;e=v[22452];v[22452]=0;if((e|0)==1){break i}tb(a+1298356|0,b);pb(b);v[a+1298404>>2]=5;Gz(d+496|0,2,d+608|0);v[22452]=0;W(213,d+136|0,v[d+496>>2],v[d+500>>2],w[d+504|0]);b=v[22452];v[22452]=0;if((b|0)==1){break j}l=(j|0)!=1179012417;b=d+136|0;tb(a+1298308|0,b);pb(b);i=(j|0)==1179012417;b=0;while(1){n:{o:{p:{if(x[a+480188>>1]<=b>>>0){e=wb(v[k>>2]);h=wb(v[k+4>>2]);b=ab-16|0;ab=b;v[b>>2]=1380209231;v[b+8>>2]=e;while(1){q:{r:{if(Tb(e,h)){if(!lT(b,e)){break r}e=v[b+8>>2]}ab=b+16|0;break q}em(b+8|0);e=v[b+8>>2];continue}break}if(Tb(e,wb(v[k+4>>2]))){break p}break h}h=(b<<5)+a|0;f=h+480280|0;Le(f);v[22452]=0;e=T(197,d+688|0)|0;g=v[22452];v[22452]=0;s:{t:{if((g|0)!=1){if(i){break s}if(e>>>0<129){break t}break o}b=P()|0;O()|0;break b}u[h+480284>>1]=e<<1;break n}if(e<<24>>24<0){break o}v[d+136>>2]=e<<2;v[d+496>>2]=256;o=h+480284|0,p=v[jd(d+136|0,d+496|0)>>2],u[o>>1]=p;break n}v[22452]=0;U(830,d+136|0,k|0,1380209231);b=v[22452];v[22452]=0;u:{if((b|0)!=1){v[22452]=0;b=T(197,d+136|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break u}e=Kb(a+484360|0);v[22452]=0;ea(337,e|0,d+136|0,b+1&255,255,254)|0;b=v[22452];v[22452]=0;if((b|0)==1){break u}qb(d+136|0);break h}b=P()|0;O()|0;break b}b=P()|0;O()|0;qb(d+136|0);break b}v[f>>2]=1024}b=b+1|0;continue}}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}v:{if(!(c&1)){break v}u[d+56>>1]=0;v[22452]=0;U(832,d+560|0,k|0,1414807888);b=v[22452];v[22452]=0;if((b|0)==1){break c}b=v[d+564>>2];h=v[d+560>>2];v[22452]=0;e=a+484344|0;R(216,e|0,Ef(h,b)&65535);b=v[22452];v[22452]=0;w:{if((b|0)!=1){o=d,p=wb(v[d+560>>2]),v[o+88>>2]=p;h=wb(v[d+564>>2]);x:{y:{z:{A:{B:{while(1){b=v[d+88>>2];if(!Tb(b,h)){b=0;break x}b=_d(d+136|0,b);v[22452]=0;i=T(197,b|0)|0;f=v[22452];v[22452]=0;if((f|0)!=1){v[22452]=0;u[d+480>>1]=i;b=T(148,b|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break B}v[22452]=0;U(181,d+496|0,d+136|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break A}b=bc(d+584|0,d+496|0);v[22452]=0;i=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=i;v[d+16>>2]=v[b+16>>2];i=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=i;W(833,d|0,x[d+480>>1],l|0,a|0);b=v[22452];v[22452]=0;if((b|0)==1){break z}qb(d+496|0);o=d,p=x[Ne(d+56|0,d+480|0)>>1],u[o+56>>1]=p;qb(d+136|0);jh(d+88|0);continue}break}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;qb(d+496|0)}qb(d+136|0);break w}while(1){h=b&65535;if(h>>>0>=x[d+56>>1]){Yc(d+560|0);break v}C:{if(!he(e,h)){v[22452]=0;Y(217,e|0,h|0,64)|0;h=v[22452];v[22452]=0;if((h|0)==1){break C}}b=b+1|0;continue}break}b=P()|0;O()|0;break w}b=P()|0;O()|0}Yc(d+560|0);break b}D:{if((j|0)==1179012417){v[22452]=0;U(832,d+88|0,k|0,1414745673);b=v[22452];v[22452]=0;if((b|0)==1){break d}o=d,p=wb(v[d+88>>2]),v[o+120>>2]=p;j=c&2;h=d+504|0;l=d+136|1;i=wb(v[d+92>>2]);while(1){b=v[d+120>>2];if(!Tb(b,i)){Yc(d+88|0);break D}c=_d(d+560|0,b);v[22452]=0;b=Q(834,c|0,d+136|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){E:{if(!b){break E}b=w[l|0];if((b|0)==255){break E}v[22452]=0;b=Y(245,a|0,b+1|0,0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break e}if(!b){break E}e=x[a+480190>>1];v[22452]=0;U(835,d+136|0,b|0,e|0);b=v[22452];v[22452]=0;if((b|0)==1){break e}b=0;while(1){if(w[d+166|0]<=b>>>0){break E}F:{if(!Dh(a)){break F}v[22452]=0;e=Q(836,c|0,d+496|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break e}if(!e){break F}e=x[a+480190>>1]+1|0;u[a+480190>>1]=e;if((w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24))!=1347240275){break F}dl(d+480|0,2,h);v[22452]=0;W(213,d+56|0,v[d+480>>2],v[d+484>>2],w[d+488|0]);f=v[22452];v[22452]=0;G:{if((f|0)!=1){e=e&65535;f=d+56|0;sc(((e<<5)+a|0)+946304|0,f);pb(f);v[22452]=0;f=B(e,104)+a|0;e=f+484380|0;U(837,d+496|0,d+136|0,e|0);g=v[22452];v[22452]=0;if((g|0)==1){break e}if(!j){break G}f=d+56|0;g=d+534|0;Gc(f,(w[g|0]|w[g+1|0]<<8)&4?16:8,1,0,0);v[22452]=0;Y(210,f|0,e|0,c|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){break F}break e}break e}f=x[f+484414>>1];e=v[e>>2];v[22452]=0;Q(179,d+560|0,mj(e,f)|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break e}}b=b+1|0;continue}}qb(d+560|0);jh(d+120|0);continue}break}break e}v[22452]=0;U(832,d+480|0,k|0,1179011410);b=v[22452];v[22452]=0;if((b|0)!=1){o=d,p=wb(v[d+480>>2]),v[o+472>>2]=p;j=c&2;h=d+496|4;b=d+80|4;l=d+136|5;i=wb(v[d+484>>2]);H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{while(1){c=v[d+472>>2];if(!Tb(c,i)){Yc(d+480|0);break D}c=_d(d+560|0,c);v[22452]=0;e=T(148,c|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break Q}R:{S:{if((e|0)!=538986817){break S}v[22452]=0;e=Q(838,c|0,d+464|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break P}if(!e|(w[d+464|0]|w[d+465|0]<<8|(w[d+466|0]<<16|w[d+467|0]<<24))!=1414745673){break S}v[22452]=0;e=Q(839,c|0,d+136|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break O}if(!e){break S}e=w[l|0];if((e|0)==255){break S}v[22452]=0;e=Y(245,a|0,e+1|0,0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break N}if(!e){break S}f=x[a+480190>>1];v[22452]=0;U(840,d+136|0,e|0,f|0);e=v[22452];v[22452]=0;if((e|0)==1){break N}v[22452]=0;U(829,d+496|0,c|0,2);c=v[22452];v[22452]=0;if((c|0)==1){break R}v[22452]=0;U(832,d+120|0,d+496|0,1179011410);c=v[22452];v[22452]=0;if((c|0)==1){break M}Rd(d+496|0);o=d,p=wb(v[d+120>>2]),v[o+112>>2]=p;f=wb(v[d+124>>2]);T:{U:{while(1){c=v[d+112>>2];if(!Tb(c,f)){break T}c=_d(d+88|0,c);v[22452]=0;e=T(148,c|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break L}V:{W:{if((e|0)!=538989377){break W}if(!Dh(a)){break W}e=w[d+460|0]|w[d+461|0]<<8;g=e-1|0;t[d+460|0]=g;t[d+461|0]=g>>>8;if(!e){qb(d+88|0);break T}g=x[a+480190>>1]+1|0;u[a+480190>>1]=g;v[22452]=0;c=Q(838,c|0,d+80|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break K}if(!c|(w[d+80|0]|w[d+81|0]<<8|(w[d+82|0]<<16|w[d+83|0]<<24))!=1347240275){break U}c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[22452]=0;U(181,d+496|0,d+88|0,c|0);c=v[22452];v[22452]=0;X:{if((c|0)!=1){c=d+496|0;e=bc(d+56|0,c);qb(c);v[22452]=0;c=Q(841,e|0,c|0)|0;n=v[22452];v[22452]=0;if((n|0)==1){break V}if(c){break X}qb(d+56|0);qb(d+88|0);break T}b=P()|0;O()|0;break I}Qe(d+24|0,2,h);v[22452]=0;W(213,d+40|0,v[d+24>>2],v[d+28>>2],w[d+32|0]);c=v[22452];v[22452]=0;if((c|0)==1){break J}c=g&65535;g=d+40|0;sc(((c<<5)+a|0)+946304|0,g);pb(g);v[22452]=0;c=(B(c,104)+a|0)+484380|0;U(842,d+496|0,d+136|0,c|0);g=v[22452];v[22452]=0;if((g|0)==1){break V}Y:{if(!j){break Y}g=w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24);v[22452]=0;Q(146,d+56|0,g+4|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break V}g=d+40|0;n=d+536|0;Gc(g,(w[n|0]|w[n+1|0]<<8)&4?16:8,1,0,0);v[22452]=0;Y(210,g|0,c|0,e|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break Y}break J}qb(d+56|0)}qb(d+88|0);jh(d+112|0);continue}break}break J}qb(d+88|0)}Yc(d+120|0)}qb(d+560|0);jh(d+472|0);continue}break}b=P()|0;O()|0;break H}b=P()|0;O()|0;break H}b=P()|0;O()|0;break H}b=P()|0;O()|0;break H}b=P()|0;O()|0;break H}b=P()|0;O()|0;Rd(d+496|0);break H}b=P()|0;O()|0;break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;qb(d+56|0)}qb(d+88|0);Yc(d+120|0)}qb(d+560|0);Yc(d+480|0);break b}b=P()|0;O()|0;break b}e=1}qb(d+688|0);Rd(k);qb(m)}ab=d+768|0;return e|0}b=P()|0;O()|0;qb(d+560|0);Yc(d+88|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}qb(d+688|0)}Rd(k);qb(m);S(b|0);L()}function bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;k=ab-208|0;ab=k;if(!ft(a)){e=k+48|0;gc(e,a,128);_e(k+176|0,e,128,2);e=k+192|0;tc(e,v[k+176>>2],v[k+180>>2],w[k+184|0]);sc(b+492|0,e);pb(e)}u[c+34>>1]=x[c+34>>1]&65489;p=k+192|0;f=ab-32|0;ab=f;a:{b:{switch(w[a+128|0]-4|0){default:v[f+28>>2]=0;Hn(p,0,f+28|0);break a;case 0:case 4:break b}}t[f+28|0]=w[a+129|0];t[f+24|0]=100;e=f+24|0;h=w[Qb(f+28|0,e)|0];t[f+24|0]=w[a+130|0];t[f+20|0]=100;e=w[Qb(e,f+20|0)|0];v[f+28>>2]=e;c:{if(w[a+140|0]&16){g=Ab(w[a+150|0]|w[a+151|0]<<8);j=Ab(w[a+152|0]|w[a+153|0]<<8);n=v[c>>2];s=+(n>>>0)/6553600;h=Up(s*+((g|h<<16)>>>0));v[f+24>>2]=n-h;y=f,z=Up(s*+((j|e<<16)>>>0)),v[y+20>>2]=z;y=f,z=v[zb(f+24|0,f+20|0)>>2],v[y+28>>2]=z;break c}if(!Fd(c)){break c}g=v[c>>2];j=g>>>7|0;h=B(j,(h<<7>>>0)/100|0);v[f+24>>2]=g-h;v[f+20>>2]=B(j,(e<<7>>>0)/100|0);e=v[zb(f+24|0,f+20|0)>>2];j=x[c+34>>1];d:{if(j&1){Ub(f+8|0,v[c+20>>2],B(qd(j),g));g=v[f+8>>2];n=qd(x[c+34>>1]);j=g+(B(n,e+h|0)<<1)|0;o=u[g+(B(h,n)<<1)>>1];n=0-n<<1;while(1){e:{f:{if(e){m=u[j>>1]-o|0;g=m>>31;if((g^g+m)>>>0>=1536){break f}}else{e=0}break e}e=e-1|0;j=j+n|0;continue}break}break d}Ub(f,v[c+20>>2],B(qd(j),g));g=v[f>>2];n=qd(x[c+34>>1]);o=0-n|0;j=g+B(n,e+h|0)|0;n=t[g+B(h,n)|0];while(1){g:{h:{if(e){m=t[j|0]-n|0;g=m>>31;if((g^g+m)>>>0>=6){break h}}else{e=0}break g}e=e-1|0;j=j+o|0;continue}break}}v[f+28>>2]=e}Hn(p,h,f+28|0)}ab=f+32|0;n=ac(p);if(!(!v[n>>2]|w[a+128|0]!=4)){u[c+34>>1]=x[c+34>>1]|2;v[c+4>>2]=v[p>>2];v[c+8>>2]=v[n>>2]+v[p>>2]}e=w[a+134|0];if((e-1&255)>>>0<=198){t[k+48|0]=e;t[k+176|0]=100;e=(w[Qb(k+48|0,k+176|0)|0]<<7>>>0)/100|0}else{e=128}t[k+47|0]=e;t[k+48|0]=64;e=k+47|0;f=k+48|0;y=c,z=w[$e(e,f)|0]>>>1|0,u[y+32>>1]=z;t[k+48|0]=64;y=b,z=w[Qb(e,f)|0],v[y+4>>2]=z;v[c+24>>2]=40460;Tp(c,+t[a+139|0]/12+ +(0-w[a+143|0]|0)+ +t[a+138|0]/1536);t[b+34|0]=w[a+142|0]&2?2:1;if(w[a+142|0]&2){rm(b,127,1);qm(b,0,1)}i:{if(!Fd(c)){break i}b=w[a+140|0];if(b&1){j:{if(!Fd(c)){break j}b=v[c>>2];if(b>>>0<2){break j}k:{l:{switch(hk(x[c+34>>1])-1|0){case 3:f=v[c+20>>2];e=0;g=b>>>1|0;while(1){if((e|0)!=(g|0)){cc(f+(e<<2)|0,f+(b+(e^-1)<<2)|0);e=e+1|0;continue}break};break k;case 1:f=v[c+20>>2];e=0;g=b>>>1|0;while(1){if((e|0)!=(g|0)){Ox(f+(e<<1)|0,f+(b+(e^-1)<<1)|0);e=e+1|0;continue}break};break k;case 0:break l;default:break j}}f=v[c+20>>2];e=0;g=b>>>1|0;while(1){if((e|0)!=(g|0)){Tg(e+f|0,f+(b+(e^-1)|0)|0);e=e+1|0;continue}break}}ii(c,d)}b=w[a+140|0]}if(b&4){m:{if(!Fd(c)){break m}e=x[c+34>>1];b=B(v[c>>2],qd(e));n:{o:{switch(xm(e)-1|0){case 1:f=v[c+20>>2];e=0;while(1){if((b|0)!=(e|0)){g=f+(e<<1)|0;u[g>>1]=x[g>>1]^-1;e=e+1|0;continue}break};break n;case 0:break o;default:break m}}f=v[c+20>>2];e=0;while(1){if((b|0)!=(e|0)){g=e+f|0;t[g|0]=w[g|0]^-1;e=e+1|0;continue}break}}ii(c,d)}}i=w[a+170|0]!=2|w[a+171|0]>100?i:w[a+172|0]<101;b=x[c+34>>1];if(!(!(w[a+141|0]?1:i|w[a+160|0]!=0)|b&1)){e=et(v[c>>2],qd(b)<<1&254);if(!e){break i}b=e;f=v[c>>2];g=x[c+34>>1];h=B(qd(g),f);j=v[c+20>>2];f=mj(f,g);g=ab-16|0;ab=g;v[g+12>>2]=h;mc(g+12|0,f);f=v[g+12>>2];while(1){if(f){u[b>>1]=t[j|0]<<8;j=j+1|0;b=b+2|0;f=f-1|0;continue}break}ab=g+16|0;u[c+34>>1]=x[c+34>>1]|1;bP(c,e,v[c>>2],d)}p:{if(t[a+141|0]>=0){break p}Ub(k+48|0,v[c+20>>2],B(v[c>>2],qd(x[c+34>>1])));f=v[k+52>>2];e=v[k+48>>2];q:while(1){if((0-t[a+141|0]|0)<=(l|0)){break p}h=u[e>>1];g=Yb(e,f);b=e;while(1)if((b|0)==(g|0)){l=l+1|0;continue q}else{h=Wc(u[b>>1]-Wc(h,1)|0,1);u[b>>1]=h;b=b+2|0;continue}}}r:{if(!i){break r}Ub(k+48|0,v[c+20>>2],B(v[c>>2],qd(x[c+34>>1])));i=v[k+52>>2];b=(i|0)/2|0;g=b>>31;m=b;b=w[a+172|0];h=w[a+171|0];e=h;f=0-(b>>>0<e>>>0)|0;b=b-e|0;e=f<<24|b>>>8;j=b<<24;f=m+j|0;b=e+g|0;b=vc(pia(f,f>>>0<j>>>0?b+1|0:b,i,i>>31),db);f=b;j=b>>31;b=h<<24;h=b;e=b>>31;b=v[k+48>>2];l=Yb(b,i);while(1){if((b|0)==(l|0)){break r}i=u[b>>1];i=oia(h,e,i,i>>31)+838860800|0;g=db;y=b,z=vc(pia(i,i>>>0<838860800?g+1|0:g,1677721600,0),db),u[y>>1]=z;b=b+2|0;e=e+j|0;i=f+h|0;e=i>>>0<f>>>0?e+1|0:e;h=i;continue}}s:{if(!w[a+160|0]){break s}Ub(k+176|0,v[c+20>>2],B(v[c>>2],qd(x[c+34>>1])));b=w[a+162|0];i=w[a+163|0];t:{if(w[a+161|0]<=1){f=0;e=v[k+180>>2];g=0;break t}f=v[k+180>>2];e=(f|0)/2|0;j=e>>31;h=e;e=w[a+164|0];g=0-(b>>>0>e>>>0)|0;e=e-b|0;l=e<<23;h=h+l|0;e=(g<<23|e>>>9)+j|0;f=vc(pia(h,h>>>0<l>>>0?e+1|0:e,f,f>>31),db);e=v[k+180>>2];g=(e|0)/2|0;j=g>>31;m=g;g=w[a+165|0];l=0-(i>>>0>g>>>0)|0;h=g-i|0;g=l<<23|h>>>9;l=h<<23;h=m+l|0;g=g+j|0;g=vc(pia(h,h>>>0<l>>>0?g+1|0:g,e,e>>31),db)}h=b<<23;i=i<<23;j=(k+48|0)+((w[a+160|0]&2)<<2)|0;l=0;b=v[k+176>>2];o=Yb(b,e);e=0;while(1){if((b|0)==(o|0)){break s}m=(u[b>>1]>>1)-e|0;v[k+56>>2]=m;q=m;m=(h|0)/8388608|0;l=Wc(B(q,m),8)+l|0;v[k+52>>2]=l;e=Wc(B(l,m),6)+e|0;e=Wc(Wc(B(e,(i|0)/8388608|0),6)+e|0,2);v[k+48>>2]=e;y=b,z=Jc(v[j>>2]),u[y>>1]=z;b=b+2|0;i=g+i|0;h=f+h|0;continue}}u:{if(t[a+141|0]<=0){break u}Ub(k+48|0,v[c+20>>2],B(v[c>>2],qd(x[c+34>>1])));l=0;f=v[k+52>>2];e=v[k+48>>2];v:while(1){if(t[a+141|0]<=(l|0)){break u}h=u[e>>1];i=Yb(e,f);b=e;while(1)if((b|0)==(i|0)){l=l+1|0;continue v}else{h=((u[b>>1]<<1)+h|0)/3|0;u[b>>1]=h;b=b+2|0;continue}}}b=x[c+34>>1];w:{if(b&1){Ub(k+32|0,v[c+20>>2],B(v[c>>2],qd(b)));j=ab-16|0;ab=j;b=v[k+32>>2];l=Yb(b,v[k+36>>2]);o=ab-16|0;ab=o;v[o+12>>2]=b;m=j+8|0;f=Hn(m,b,o+12|0);x:{if((b|0)==(l|0)){break x}e=b+2|0;if((l|0)==(e|0)){break x}y=(ij(x[e>>1],x[v[f>>2]>>1])?0:4)+f|0,z=e,v[y>>2]=z;g=f+4|0;while(1){h=e;i=e+2|0;if((l|0)!=(i|0)){e=h+4|0;if((l|0)==(e|0)){v[o+12>>2]=l;e=x[h+2>>1];if(!ij(e,x[v[f>>2]>>1])){f=g;if(ij(e,x[v[f>>2]>>1])){break x}}v[f>>2]=i;break x}r=x[v[f>>2]>>1];q=x[e>>1];h=x[h+2>>1];y:{if(ij(q,h)){if(ij(q,r)){v[f>>2]=e}if(ij(h,x[v[g>>2]>>1])){continue}break y}if(ij(h,r)){v[f>>2]=i}i=e;if(ij(q,x[v[g>>2]>>1])){continue}}v[g>>2]=i;continue}break}v[o+12>>2]=h}ab=o+16|0;v[j+4>>2]=0-u[v[m>>2]>>1];y=j,z=u[v[ac(m)>>2]>>1],v[y>>2]=z;z:{e=v[Ee(j+4|0,j)>>2];if((e|0)>32766|!e){break z}while(1){if((b|0)==(l|0)){break z}u[b>>1]=(B(u[b>>1],32767)|0)/(e|0);b=b+2|0;continue}}break w}Ub(k+24|0,v[c+20>>2],B(v[c>>2],qd(b)));j=ab-16|0;ab=j;b=v[k+24>>2];l=Cb(b,v[k+28>>2]);o=ab-16|0;ab=o;v[o+12>>2]=b;m=j+8|0;f=Hn(m,b,o+12|0);A:{if((b|0)==(l|0)){break A}e=b+1|0;if((l|0)==(e|0)){break A}y=(Vk(w[e|0],w[v[f>>2]])?0:4)+f|0,z=e,v[y>>2]=z;g=f+4|0;while(1){h=e;i=e+1|0;if((l|0)!=(i|0)){e=h+2|0;if((l|0)==(e|0)){v[o+12>>2]=l;e=w[h+1|0];if(!Vk(e,w[v[f>>2]])){f=g;if(Vk(e,w[v[f>>2]])){break A}}v[f>>2]=i;break A}r=w[v[f>>2]];q=w[e|0];h=w[h+1|0];B:{if(Vk(q,h)){if(Vk(q,r)){v[f>>2]=e}if(Vk(h,w[v[g>>2]])){continue}break B}if(Vk(h,r)){v[f>>2]=i}i=e;if(Vk(q,w[v[g>>2]])){continue}}v[g>>2]=i;continue}break}v[o+12>>2]=h}ab=o+16|0;v[j+4>>2]=0-t[v[m>>2]];y=j,z=t[v[ac(m)>>2]],v[y>>2]=z;C:{e=v[Ee(j+4|0,j)>>2];if((e|0)>126|!e){break C}while(1){if((b|0)==(l|0)){break C}t[b|0]=(B(t[b|0],127)|0)/(e|0);b=b+1|0;continue}}}ab=j+16|0;D:{if((w[a+134|0]-101&255)>>>0>98){break D}e=x[c+34>>1];b=B(v[c>>2],qd(e));if(e&1){e=v[c+20>>2];v[k+16>>2]=e;v[k+20>>2]=(e+(b<<1)|0)-e>>1;b=(3276800-(w[a+134|0]<<14)|0)/100|0;g=0-b|0;f=32768-b|0;e=v[k+16>>2];h=Yb(e,v[k+20>>2]);while(1){if((e|0)!=(h|0)){i=u[e>>1];E:{if((i|0)>(b|0)){m=f+((B(b,i-b|0)|0)/(f|0)|0)|0;break E}m=((B(b,b+i|0)|0)/(f|0)|0)-f|0;if((g|0)>(i|0)){break E}m=(B(f,i)|0)/(b|0)|0}y=e,z=Jc(m),u[y>>1]=z;e=e+2|0;continue}break}break D}e=v[c+20>>2];i=Zm(k+8|0,e,b+e|0);e=v[i>>2];b=(3276800-(w[a+134|0]<<14)|0)/100|0;g=0-b|0;f=32768-b|0;h=Cb(e,v[i+4>>2]);while(1){if((e|0)!=(h|0)){i=t[e|0]<<8;F:{if((i|0)>(b|0)){m=f+((B(b,i-b|0)|0)/(f|0)|0)|0;break F}m=((B(b,b+i|0)|0)/(f|0)|0)-f|0;if((g|0)>(i|0)){break F}m=(B(f,i)|0)/(b|0)|0}y=e,z=aR((m|0)/256|0),t[y|0]=z;e=e+1|0;continue}break}}aP(c);if(w[a+128|0]!=8){break i}b=w[a+131|0];if(!b){break i}e=v[n>>2];if(!e){break i}y=Fb(c+68|0,0),z=v[p>>2]+B(e,b+1|0)|0,v[y>>2]=z;v[c+12>>2]=v[p>>2];v[c+16>>2]=v[n>>2]+v[p>>2];i=v[n>>2];f=w[a+131|0];if(i>>>0>268435456/(f>>>0)>>>0){break i}e=v[c>>2];b=B(f,i);if(e>>>0>268435456-b>>>0){break i}g=v[p>>2];e=b+e|0;b=hk(x[c+34>>1]);h=et(e,b);if(!h){break i}i=g+B(i,f+1|0)|0;v[c>>2]=e;g=v[c+20>>2];f=gc(h,g,B(b,v[n>>2]+v[p>>2]|0));h=0;while(1){if(w[a+131|0]<=h>>>0){gc(f+B(b,i)|0,g+B(b,v[n>>2]+v[p>>2]|0)|0,B(b,e-i|0));bP(c,f,e,d)}else{l=v[p>>2];h=h+1|0;j=v[n>>2];gc(f+B(b,l+B(h,j)|0)|0,g+B(b,l)|0,B(b,j));continue}break}}ab=k+208|0}function _ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;e=ab+-64|0;ab=e;qc(a);a:{b:{if(b>>>0<=2){b=e+56|0;C=b,D=ue(a),t[C|0]=D;Ob(a,2);f=b|2;g=xg(a);t[f|0]=g;t[f+1|0]=g>>>8;b=b|4;f=jg(a);t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;break b}$p(a,e+56|0);if(b>>>0>5){break a}}t[e+56|1]=0}c:{n=d+484344|0;b=e+56|2;s=Ld(w[b|0]|w[b+1|0]<<8,1,1024);m=cB(n,s,0);if((m|0)==65535){break c}g=Of(Rb(n,m),0);f=x[d+480188>>1];u[e>>1]=f-1;u[e+40>>1]=w[e+56|0];y=x[Lc(e,e+40|0)>>1];h=y+1|0;b=h&65535;f=b>>>0<f>>>0?f:b;while(1)if((b|0)==(f|0)){t[c+13|0]=w[e+56|1]>>>4;b=w[c+12|0];t[e|0]=0;b=(b|0)!=0;p=Vt(e+40|0,h,e);z=d+480188|0;d:while(1){if((l|0)==(s|0)){Xb(p);break c}e:{d=Cb(v[p>>2],0);f=w[d|0];f:{g:{if(!f){v[22452]=0;d=T(197,a|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break e}d=d<<24>>24;if((d|0)<0){v[22452]=0;f=T(197,a|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break e}C=Cb(v[p>>2],0),D=f,t[C|0]=D}t[e|0]=0;h:{i:{d=d&63;if(!d){break i}v[22452]=0;j=T(197,a|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break h}t[e|0]=j;j:{k:{switch(d-1|0){case 0:t[c+12|0]=0;t[e+36|0]=1;C=c,D=w[$e(e+36|0,e)|0],t[C+14|0]=D;t[c+15|0]=0;break j;case 1:if(!j){break i}t[c+15|0]=j;t[c+12|0]=1;b=w[c+13|0];if(!b){break j}t[c+14|0]=B(B(b,j),15);break j;case 2:t[c+13|0]=j>>>4;if(j>>>0>=16){b=w[c+12|0];j=0;v[e+36>>2]=0;v[e+32>>2]=0;o=0;if(!b){break f}break g}j=0;t[c+12|0]=0;v[e+36>>2]=0;v[e+32>>2]=0;o=0;if(!(b&1)){break f}break g;case 3:o=0;v[e+36>>2]=0;v[e+32>>2]=0;if(b&1){break g}break f;case 5:if(!j){break i}d=(w[c+12|0]?15:14)+c|0;b=w[d|0];t[d|0]=b>>>0<256-j>>>0?b+j|0:-1;break j;case 6:break k;default:break i}}if(!j){break i}d=(w[c+12|0]?15:14)+c|0;b=w[d|0];t[d|0]=b>>>0>j+1>>>0?b-j|0:1}j=0;v[e+36>>2]=0;v[e+32>>2]=0;break g}j=0;v[e+36>>2]=0;v[e+32>>2]=0;o=0;if(!(b&1)){break f}break g}break e}t[d|0]=f-1;j=0;v[e+36>>2]=0;v[e+32>>2]=0;o=0;if(!(b&1)){break f}}b=w[c+13|0];d=w[c+12|0];if(d){o=0;if(!b){break f}}l:{if(d){v[e>>2]=1;v[e+28>>2]=B(b,w[c+15|0])<<1;d=v[Ee(e,e+28|0)>>2];break l}d=B(w[c+14|0],30)+30|0}b=255;f=0;while(1){m:{if(!b){b=0;break m}g=B(b,d);f=(g|0)/48|0;if(g-1536>>>0<10752){break m}b=b-1|0;continue}break}v[e+36>>2]=b;v[e+32>>2]=f;ce(e+32|0,32,255);o=1;v[e>>2]=1;C=c,D=v[Ee(e,e+36|0)>>2],t[C+16|0]=D}q=l-1|0;r=1;b=Qc(Rb(n,m),l,1);while(1){h=r&65535;if(h>>>0>y>>>0){if(o){je(Rb(n,m),mh(Xn(Ae(ve(e,17,w[e+32|0]),l),0)));je(Rb(n,m),mh(Ae(ve(e,16,w[e+36|0]),l)))}if(j&240){je(Rb(n,m),sT(Ae(ve(e,20,j>>>4|224),l)))}b=j&15;if(b){je(Rb(n,m),sT(Ae(ve(e,20,Ld((B(b,w[c+16|0])>>>0)/15&255,1,15)|96),l)))}l=l+1|0;b=0;continue d}n:{o:{p:{q:{d=Cb(v[p>>2],h);f=w[d|0];if(!f){v[22452]=0;k=T(197,a|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break e}if(k&128){v[22452]=0;d=T(197,a|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break e}C=Cb(v[p>>2],h),D=d,t[C|0]=D}A=1;if(k&64){v[22452]=0;d=T(197,a|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break e}t[b+1|0]=d;A=!d}if(!(k&32)){f=w[b|0];break q}v[22452]=0;f=T(197,a|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break e}t[b|0]=f;if((f-1&255)>>>0<=107){f=cm(f+24|0);t[b|0]=f;C=ud(v[c>>2],h),D=f,t[C+1|0]=D;break q}if((f+127&255)>>>0<=107){d=cm((f&127)+24|0);C=ud(v[c>>2],h),D=d,t[C|0]=D;t[b|0]=0;break p}if((f|0)!=255){break q}t[b|0]=254;break o}t[d|0]=f-1;break n}if(f&255){break o}}if(!w[b+1|0]){break o}d=w[ud(v[c>>2],h)+1|0];t[b+1|0]=0;t[b|0]=d}if(Kc(w[b|0])){C=ud(v[c>>2],h),D=0,t[C+5|0]=D}t[e+28|0]=0;t[e+27|0]=0;t[e+26|0]=0;t[e+25|0]=0;t[e+24|0]=0;t[e+23|0]=0;r:{if(k&16){t[b+2|0]=1;v[22452]=0;d=T(197,a|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break r}t[b+4|0]=d+2>>>2}d=0;f=0;s:{if(!(k&8)){break s}v[22452]=0;f=T(197,a|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break r}v[22452]=0;g=T(197,a|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break r}t[e+25|0]=g;t:{u:{switch(f-1|0){case 1:t[b|0]=255;break t;case 2:f=ud(v[c>>2],h);t[b|0]=w[f+1|0];t[f+5|0]=0;break t;case 3:f=Ut(g,w[c+16|0]);t[e+25|0]=f;v:{if(f){t[e+28|0]=20;t[e+25|0]=f|208;f=20;break v}t[e+28|0]=0;f=0}if(w[b|0]){break s}g=ud(v[c>>2],h);t[b|0]=w[g+1|0];t[g+5|0]=0;break s;case 4:t[e|0]=1;C=e,D=Ut(g,w[c+16|0]),t[C+22|0]=D;C=e,D=w[$e(e,e+22|0)|0],t[C+25|0]=D;t[e+28|0]=15;C=ud(v[c>>2],h),D=0,t[C+5|0]=D;f=20;break s;case 5:case 6:case 7:case 8:w:{if(!l){break w}if((f|0)==w[ud(v[c>>2],h)+4|0]){break w}if(!je(Rb(n,m),dm(Xn(Ae(ve(e,20,(f+122|160)&255),q),h)))){break w}C=ud(v[c>>2],h),D=f,t[C+4|0]=D}t[e+28|0]=10;f=ud(v[c>>2],h);if(!w[b|0]){t[b|0]=w[f+1|0]}t[f+5|0]=0;f=20;break s;case 9:f=20;t[e+28|0]=20;g=ud(v[c>>2],h);i=w[g+5|0];t[e+25|0]=i?-98:-97;t[g+5|0]=i^1;break s;case 0:break u;default:break t}}t[b|0]=254}f=0;t[e+28|0]=0}x:{if(!(k&4)){break x}v[22452]=0;g=T(197,a|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break r}v[22452]=0;t[e+27|0]=g;g=T(197,a|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break r}t[e+24|0]=g;y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{i=w[e+27|0];switch(i-1|0){case 11:break A;case 10:break B;case 7:case 8:case 9:break C;case 6:break D;case 5:break E;case 3:case 4:break F;case 2:break G;case 1:break H;case 0:break I;default:break z}}aB(e,g<<24>>24<<3,128);g=w[b|0];if(Kc(g)){C=b,D=cm(g+v[e>>2]|0),t[C|0]=D}t[e+27|0]=35;t[e+24|0]=w[e+4|0]^128;break x}d=Ut(g,w[c+16|0]);t[e+24|0]=d;if(d){t[e+27|0]=20;t[e+24|0]=d|208;d=1;break x}t[e+27|0]=0;d=1;break x}d=1;break y}d=1;g=rT(g,w[c+16|0],1);t[e+27|0]=(i|0)==4?2:3;t[e+24|0]=g;break x}if(!w[b|0]){C=b,D=w[ud(v[c>>2],h)|0],t[C|0]=D;g=w[e+24|0]}d=rT(g&255,w[c+16|0],0);t[e+27|0]=4;t[e+24|0]=d;d=1;break x}C=b,D=cm(g+25|0),t[C|0]=D;t[e+24|0]=255;t[e+27|0]=4;d=1;break x}J:{if(!l){break J}if((i|0)==w[ud(v[c>>2],h)+2|0]){break J}if(!je(Rb(n,m),dm(Xn(Ae(ve(e,20,(i-8|48)&255),q),h)))){break J}C=ud(v[c>>2],h),D=w[e+27|0],t[C+2|0]=D}t[e+27|0]=5;C=e,D=$A(w[e+24|0],w[c+16|0]),t[C+24|0]=D;d=1;break x}d=w[c+16|0];t[e+27|0]=18;C=e,D=qT(g,d),t[C+24|0]=D;d=1;break x}d=Ut(g,w[c+16|0]);t[e+24|0]=d;if(d){t[e+27|0]=20;t[e+24|0]=d|192;d=1;break x}t[e+27|0]=0;t[b|0]=254;d=1;break x}d=0}t[e+27|0]=d}g=0;K:{if(!(k&2)){break K}v[22452]=0;k=T(197,a|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break r}v[22452]=0;t[e+26|0]=k;k=T(197,a|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break r}t[e+23|0]=k;L:{M:{N:{O:{P:{Q:{R:{i=w[e+26|0];switch(i-1|0){case 9:break M;case 7:case 8:break N;case 6:break O;case 3:case 4:case 5:break P;case 2:break Q;case 0:case 1:break R;default:break L}}g=1;h=pT(k,w[c+16|0],(i|0)==1);t[e+26|0]=11;t[e+23|0]=h;break K}g=w[c+16|0];t[e+26|0]=18;C=e,D=qT(k,g),t[C+23|0]=D;g=1;break K}S:{if(!l){break S}if((i|0)==w[ud(v[c>>2],h)+3|0]){break S}if(!je(Rb(n,m),dm(Xn(Ae(ve(e,20,(i-4|64)&255),q),h)))){break S}C=ud(v[c>>2],h),D=w[e+26|0],t[C+3|0]=D}t[e+26|0]=8;C=e,D=$A(w[e+23|0],w[c+16|0]),t[C+23|0]=D;g=1;break K}t[e+26|0]=9;break K}g=pT(k,w[c+16|0],(i|0)==8);t[e+26|0]=29;t[e+23|0]=g;g=1;break K}t[e+26|0]=27;C=e,D=$A(k,w[c+16|0]),t[C+23|0]=D;g=1;break K}t[e+26|0]=0}if(d){oT(b,l,x[z>>1],w[e+27|0],e+24|0)}if(g){oT(b,l,x[z>>1],w[e+26|0],e+23|0)}T:{if(!A){break T}if(!Kc(w[b|0])){break T}d=w[e+27|0];if(!d){t[e+24|0]=255;t[e+27|0]=4;break T}if(w[e+26|0]|(d|0)==4){break T}t[e+23|0]=255;t[e+26|0]=4}U:{if(w[b+2|0]!=1){break U}V:{if(!w[e+27|0]){t[e+27|0]=13;t[e+24|0]=w[b+4|0];break V}if(w[e+26|0]){break U}t[e+26|0]=13;t[e+23|0]=w[b+4|0]}t[b+2|0]=0}Yn(e,e+27|0,e+24|0,e+26|0,e+23|0);W:{if(w[b+2|0]){break W}d=w[e+27|0];if(!d){break W}t[b+2|0]=d;t[b+4|0]=w[e+24|0]}X:{if(f){Yn(e,e+26|0,e+23|0,e+28|0,e+25|0);Y:{if(w[b+2|0]){break Y}d=w[e+26|0];if(!d){break Y}t[b+2|0]=d;t[b+4|0]=w[e+23|0]}f=e+25|0;d=w[e+28|0];break X}f=e+23|0;d=w[e+26|0];if(!d){break n}}t[b+3|0]=d;t[b+5|0]=w[f|0];break n}break e}b=b+6|0;r=r+1|0;continue}}break}a=P()|0;O()|0;Xb(p);S(a|0);L()}else{t[g+B(b,6)|0]=254;b=b+1|0;continue}}ab=e- -64|0;return m|0}function YO(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;k=ab-336|0;ab=k;n=h;o=i&65535;p=d;m=e&65535;r=(e^i)&-2147483648;u=i>>>16&32767;I=e>>>16&32767;a:{b:{if(u-32767>>>0>4294934529&I-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){z=d;r=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){z=h;r=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;r=2147450880;break a}r=r|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));z=b?0:z;r=b?2147450880:r;b=0;c=0;break a}if(!(f|h|(e|g))){r=r|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){i=b;d=!(m|p);h=d<<6;j=E(d?b:p)+32|0;b=E(d?c:m);b=h+((b|0)==32?j:b)|0;zf(k+320|0,i,c,p,m,b-15|0);l=16-b|0;p=v[k+328>>2];m=v[k+332>>2];c=v[k+324>>2];b=v[k+320>>2]}if(e>>>0>65535){break b}d=!(n|o);e=d<<6;h=E(d?f:n)+32|0;d=E(d?g:o);d=e+((d|0)==32?h:d)|0;zf(k+304|0,f,g,n,o,d-15|0);l=(d+l|0)-16|0;n=v[k+312>>2];o=v[k+316>>2];f=v[k+304>>2];g=v[k+308>>2]}e=o|65536;F=e;G=n;d=n;j=e<<15|d>>>17;e=d<<15|g>>>17;d=0-e|0;h=j;i=1963258675-(j+((e|0)!=0)|0)|0;hf(k+288|0,e,j,0,0,d,i,0,0);j=v[k+296>>2];hf(k+272|0,0-j|0,0-(v[k+300>>2]+((j|0)!=0)|0)|0,0,0,d,i,0,0);d=v[k+280>>2];i=d<<1|v[k+276>>2]>>>31;d=v[k+284>>2]<<1|d>>>31;hf(k+256|0,i,d,0,0,e,h,0,0);j=d;d=v[k+264>>2];hf(k+240|0,i,j,0,0,0-d|0,0-(v[k+268>>2]+((d|0)!=0)|0)|0,0,0);i=v[k+248>>2];j=i<<1|v[k+244>>2]>>>31;d=v[k+252>>2]<<1|i>>>31;hf(k+224|0,j,d,0,0,e,h,0,0);i=d;d=v[k+232>>2];hf(k+208|0,j,i,0,0,0-d|0,0-(v[k+236>>2]+((d|0)!=0)|0)|0,0,0);d=v[k+216>>2];i=d<<1|v[k+212>>2]>>>31;d=v[k+220>>2]<<1|d>>>31;hf(k+192|0,i,d,0,0,e,h,0,0);j=d;d=v[k+200>>2];hf(k+176|0,i,j,0,0,0-d|0,0-(v[k+204>>2]+((d|0)!=0)|0)|0,0,0);d=e;i=v[k+184>>2];e=i<<1|v[k+180>>2]>>>31;s=e-1|0;i=(v[k+188>>2]<<1|i>>>31)-!e|0;hf(k+160|0,d,h,0,0,s,i,0,0);d=f;j=g<<15|d>>>17;hf(k+144|0,d<<15,j,0,0,s,i,0,0);h=v[k+172>>2];o=v[k+160>>2];e=v[k+152>>2];d=o+e|0;n=v[k+164>>2];j=n+v[k+156>>2]|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=j;n=(n|0)==(d|0)&e>>>0<o>>>0|d>>>0<n>>>0;j=n+v[k+168>>2]|0;h=j>>>0<n>>>0?h+1|0:h;o=!d&e>>>0>1|(d|0)!=0;n=o+j|0;j=h;h=n;hf(k+112|0,s,i,0,0,0-h|0,0-(((h|0)!=0)+(h>>>0<o>>>0?j+1|0:j)|0)|0,0,0);hf(k+128|0,1-e|0,0-((e>>>0>1)+d|0)|0,0,0,s,i,0,0);N=(I-u|0)+l|0;e=v[k+116>>2];A=e;d=v[k+112>>2];j=e<<1|d>>>31;D=d<<1;q=j;d=j;h=v[k+140>>2];B=h;e=v[k+136>>2];j=h<<1|e>>>31;i=e<<1|v[k+132>>2]>>>31;h=i+D|0;d=d+j|0;d=h>>>0<i>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;w=d;J=d;l=0;d=m|65536;I=d;K=p;C=(d&2147483647)<<1|p>>>31;x=oia(w,l,C,0);d=db;t=d;j=b;d=c<<1|j>>>31;u=j<<1;s=d;n=d;j=0;o=j;i=h-13927|0;l=(e|0)==(w|0)&i>>>0<h>>>0|e>>>0>w>>>0;m=(e|0)==(q|0)&h>>>0<D>>>0|e>>>0<q>>>0;d=v[k+120>>2];h=v[k+124>>2]<<1|d>>>31;e=B>>>31|0;d=e+(d<<1|A>>>31)|0;j=h;j=d>>>0<e>>>0?j+1|0:j;e=d;d=m+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=l+d|0;l=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;H=l-!e|0;D=0;j=oia(n,o,H,D);e=j+x|0;h=db+t|0;h=e>>>0<j>>>0?h+1|0:h;l=(h|0)==(t|0)&e>>>0<x>>>0|h>>>0<t>>>0;j=0;x=l;q=d;d=p;O=c>>>31|0;t=O|d<<1;B=0;l=oia(q,j,t,B);d=l+e|0;j=db+h|0;j=d>>>0<l>>>0?j+1|0:j;p=d;m=j;e=(j|0)==(h|0)&d>>>0<e>>>0|h>>>0>j>>>0;d=x+e|0;l=0;l=d>>>0<e>>>0?1:l;e=oia(C,o,H,D);d=e+d|0;j=db+l|0;x=d;d=d>>>0<e>>>0?j+1|0:j;l=oia(C,o,q,B);h=db;w=oia(t,B,H,D);e=w+l|0;j=db+h|0;j=e>>>0<w>>>0?j+1|0:j;w=e;e=j;j=(h|0)==(j|0)&l>>>0>w>>>0|h>>>0>j>>>0;l=x+e|0;d=d+j|0;h=l;l=h>>>0<e>>>0?d+1|0:d;e=0;d=e+p|0;j=m+w|0;j=d>>>0<e>>>0?j+1|0:j;e=j;m=(j|0)==(m|0)&d>>>0<p>>>0|j>>>0<m>>>0;h=m+h|0;j=l;x=h;l=h>>>0<m>>>0?j+1|0:j;p=d;m=e;w=i;h=oia(i,0,t,B);e=db;i=oia(J,o,n,o);d=i+h|0;j=db+e|0;j=d>>>0<i>>>0?j+1|0:j;e=(e|0)==(j|0)&d>>>0<h>>>0|e>>>0>j>>>0;h=j;L=x;A=e;M=u&-2;i=oia(q,B,M,0);e=i+d|0;j=db+j|0;j=e>>>0<i>>>0?j+1|0:j;x=e;i=e;e=j;i=(j|0)==(h|0)&d>>>0>i>>>0|h>>>0>j>>>0;d=A+i|0;h=0;h=d>>>0<i>>>0?1:h;j=d;i=d+p|0;d=h+m|0;A=i;h=i;d=h>>>0<j>>>0?d+1|0:d;i=d;h=(d|0)==(m|0)&h>>>0<p>>>0|d>>>0<m>>>0;d=L+h|0;j=l;L=d;p=d>>>0<h>>>0?j+1|0:j;P=oia(C,o,w,z);C=db;h=oia(H,D,M,z);d=h+P|0;j=db+C|0;H=d;m=oia(J,o,t,B);l=d+m|0;h=d>>>0<h>>>0?j+1|0:j;d=h+db|0;d=l>>>0<m>>>0?d+1|0:d;t=l;m=oia(n,o,q,B);j=l+m|0;l=db+d|0;D=j;l=j>>>0<m>>>0?l+1|0:l;m=0;q=(d|0)==(l|0)&t>>>0>j>>>0|d>>>0>l>>>0;j=(d|0)==(h|0)&t>>>0<H>>>0|d>>>0<h>>>0;d=j+((h|0)==(C|0)&H>>>0<P>>>0|h>>>0<C>>>0)|0;h=0;d=q+d|0;q=l|0;h=q+A|0;j=(d|m)+i|0;j=h>>>0<q>>>0?j+1|0:j;q=h;d=h;m=j;h=(i|0)==(j|0)&d>>>0<A>>>0|i>>>0>j>>>0;d=h+L|0;j=p;C=d;i=d>>>0<h>>>0?j+1|0:j;t=oia(J,o,M,z);A=db;h=oia(n,o,w,z);d=h+t|0;j=db+A|0;j=d>>>0<h>>>0?j+1|0:j;p=0;h=(j|0)==(A|0)&d>>>0<t>>>0|j>>>0<A>>>0;n=j;d=j+x|0;j=(h|p)+e|0;h=d;j=d>>>0<n>>>0?j+1|0:j;n=(e|0)==(j|0)&d>>>0<x>>>0|e>>>0>j>>>0;e=0+d|0;d=j;l=D+d|0;l=e>>>0<p>>>0?l+1|0:l;e=(d|0)==(l|0)&e>>>0<h>>>0|d>>>0>l>>>0;d=n+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+q|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&d>>>0<q>>>0|j>>>0<m>>>0;h=j+C|0;l=h>>>0<j>>>0?i+1|0:i;i=l;c:{if((i|0)==131071|i>>>0<131071){j=K;l=I<<1|j>>>31;K=O|j<<1;I=l|B;hf(k+80|0,d,e,h,i,f,g,G,F);l=b<<17;b=0;c=v[k+88>>2];m=b-c|0;j=v[k+80>>2];o=v[k+84>>2];n=(j|o)!=0;p=m-n|0;m=(l-(v[k+92>>2]+(b>>>0<c>>>0)|0)|0)-(m>>>0<n>>>0)|0;n=0-j|0;o=0-(((j|0)!=0)+o|0)|0;b=N+16382|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;hf(k+96|0,d,e,h,i,f,g,G,F);m=0;n=v[k+104>>2];o=m-n|0;j=v[k+96>>2];s=v[k+100>>2];u=(j|s)!=0;p=o-u|0;m=((b<<16)-(v[k+108>>2]+(m>>>0<n>>>0)|0)|0)-(o>>>0<u>>>0)|0;n=0-j|0;o=0-(((j|0)!=0)+s|0)|0;u=b;s=c;b=N+16383|0}if((b|0)>=32767){r=r|2147418112;b=0;c=0;break a}d:{if((b|0)>0){c=p;j=m<<1|c>>>31;p=c<<1|o>>>31;m=j;u=h;s=i&65535|b<<16;b=n;j=o<<1|b>>>31;b=b<<1;break d}if((b|0)<=-113){b=0;c=0;break a}Yl(k- -64|0,d,e,h,i,1-b|0);zf(k+48|0,u,s,K,I,b+112|0);d=v[k+64>>2];e=v[k+68>>2];u=v[k+72>>2];s=v[k+76>>2];hf(k+32|0,f,g,G,F,d,e,u,s);c=v[k+40>>2];i=c<<1;c=v[k+44>>2]<<1|c>>>31;b=v[k+56>>2];h=v[k+36>>2];p=h>>>31|i;i=b-p|0;l=v[k+60>>2]-((b>>>0<p>>>0)+c|0)|0;c=v[k+32>>2];h=h<<1|c>>>31;c=c<<1;j=v[k+52>>2];b=v[k+48>>2];m=(h|0)==(j|0)&c>>>0>b>>>0|h>>>0>j>>>0;p=i-m|0;m=l-(i>>>0<m>>>0)|0;i=b;b=i-c|0;j=j-((c>>>0>i>>>0)+h|0)|0}hf(k+16|0,f,g,G,F,3,0,0,0);hf(k,f,g,G,F,5,0,0,0);i=d;n=d&1;c=b+n|0;d=0;h=j+d|0;h=b>>>0>c>>>0?h+1|0:h;l=c;b=l;g=(g|0)==(h|0)&b>>>0>f>>>0|g>>>0<h>>>0;c=(d|0)==(h|0)&b>>>0<n>>>0|d>>>0>h>>>0;b=c+p|0;j=m;j=b>>>0<c>>>0?j+1|0:j;f=b;c=j;d=(b|0)==(G|0)&(j|0)==(F|0)?g:(F|0)==(j|0)&b>>>0>G>>>0|j>>>0>F>>>0;b=i+d|0;j=e;j=b>>>0<d>>>0?j+1|0:j;d=b;b=j;g=(j|0)==(e|0)&d>>>0<i>>>0|e>>>0>j>>>0;e=g+u|0;j=s;j=e>>>0<g>>>0?j+1|0:j;g=e;e=d;n=g;d=v[k+20>>2];i=(d|0)==(h|0)&y[k+16>>2]<l>>>0|d>>>0<h>>>0;d=v[k+28>>2];g=v[k+24>>2];i=j>>>0<2147418112&((f|0)==(g|0)&(c|0)==(d|0)?i:(d|0)==(c|0)&g>>>0<f>>>0|c>>>0>d>>>0);g=e+i|0;d=b;d=g>>>0<i>>>0?d+1|0:d;e=(b|0)==(d|0)&e>>>0>g>>>0|b>>>0>d>>>0;b=n+e|0;j=b>>>0<e>>>0?j+1|0:j;e=j;i=b;b=v[k+4>>2];l=(b|0)==(h|0)&y[k>>2]<l>>>0|b>>>0<h>>>0;b=v[k+12>>2];h=v[k+8>>2];c=j>>>0<2147418112&((f|0)==(h|0)&(b|0)==(c|0)?l:(b|0)==(c|0)&h>>>0<f>>>0|b>>>0<c>>>0);b=c+g|0;j=b>>>0<c>>>0?d+1|0:d;c=j;g=(d|0)==(j|0)&b>>>0<g>>>0|d>>>0>j>>>0;f=i+g|0;d=e;z=f|z;r=r|(f>>>0<g>>>0?d+1|0:d)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=z;v[a+12>>2]=r;ab=k+336|0}function GH(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=ab-128|0;ab=h;a:{b:{if(g){ze(h+112|0,f,32);v[22452]=0;Y(489,h+96|0,f|0,32)|0;k=v[22452];v[22452]=0;if((k|0)!=1){break b}f=P()|0;O()|0;break a}Bb(h+112|0);Bb(h+96|0)}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if(Kr(c)){m=b+24|0;b=v[m>>2]+484344|0;if(he(b,c&65535)){break t}}v[22452]=0;U(1064,a|0,h+112|0,h+96|0);a=v[22452];v[22452]=0;if((a|0)!=1){break s}f=P()|0;O()|0;break c}b=Rb(b,c);if(!(v[b+12>>2]>(d|0)&(d|0)>=0)){v[22452]=0;U(1064,a|0,h+112|0,h+96|0);a=v[22452];v[22452]=0;if((a|0)!=1){break s}break d}if(!(x[v[m>>2]+480188>>1]>e>>>0&(e|0)>=0)){v[22452]=0;U(1064,a|0,h+112|0,h+96|0);a=v[22452];v[22452]=0;if((a|0)==1){break d}break s}c=Qc(b,d,e&65535);Pe(h+112|0);Pe(h+96|0);u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{b=w[c|0];if(!Kc(b)){if(!ap(b)){break I}}d=v[m>>2];e=w[c+1|0];v[22452]=0;W(1065,h- -64|0,d|0,b|0,e|0);b=v[22452];v[22452]=0;d=1;if((b|0)==1){break G}v[22452]=0;R(986,h+80|0,h- -64|0);b=v[22452];v[22452]=0;if((b|0)!=1){break H}f=P()|0;O()|0;break D}d=0;v[22452]=0;Q(55,h+80|0,16709)|0;b=v[22452];v[22452]=0;if((b|0)==1){break F}}v[22452]=0;k=Q(776,h+112|0,h+80|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break E}pb(h+80|0);if(d){pb(h- -64|0)}b=w[c|0];J:{if(Kc(b)){v[22452]=0;Q(55,h+80|0,9929)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}break J}if(ap(b)){v[22452]=0;Q(55,h+80|0,10239)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break J}break e}v[22452]=0;Q(55,h+80|0,16709)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}}v[22452]=0;d=Q(776,h+96|0,h+80|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break C}pb(h+80|0);if(f-6>>>0>4294967290){break v}v[22452]=0;b=Q(55,h+80|0,17769)|0;e=v[22452];v[22452]=0;if((e|0)==1){break B}v[22452]=0;e=Q(776,k|0,b|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break A}pb(b);v[22452]=0;b=Q(55,h+80|0,17769)|0;j=v[22452];v[22452]=0;if((j|0)==1){break z}v[22452]=0;j=Q(776,d|0,b|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break y}pb(b);b=c+1|0;K:{if(w[c+1|0]){v[22452]=0;R(507,h+80|0,b|0);i=v[22452];v[22452]=0;if((i|0)!=1){break K}break f}v[22452]=0;Q(55,h+80|0,16714)|0;i=v[22452];v[22452]=0;if((i|0)==1){break f}}v[22452]=0;i=Q(776,e|0,h+80|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break x}pb(h+80|0);L:{if(w[b|0]){v[22452]=0;Q(55,h+80|0,10729)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break L}break g}v[22452]=0;Q(55,h+80|0,16714)|0;b=v[22452];v[22452]=0;if((b|0)==1){break g}}v[22452]=0;j=Q(776,j|0,h+80|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break w}f=P()|0;O()|0;pb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;pb(h+80|0);if(!d){break c}}pb(h- -64|0);break c}f=P()|0;O()|0;pb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;pb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;pb(b);break c}f=P()|0;O()|0;pb(h+80|0);break c}pb(h+80|0);if(f-9>>>0>4294967287){break v}M:{N:{O:{P:{Q:{R:{S:{if(Lg(w[c|0])){v[22452]=0;e=Q(55,h+48|0,17769)|0;b=v[22452];v[22452]=0;if((b|0)==1){break R}b=w[c+4|0];l=w[c+2|0];v[22452]=0;n=h,o=Lj(l,b)&255,v[n+16>>2]=o;R(506,h+32|0,h+16|0);b=v[22452];v[22452]=0;if((b|0)==1){break Q}b=0;v[22452]=0;U(943,h+80|0,e|0,h+32|0);l=v[22452];v[22452]=0;e=1;if((l|0)!=1){break S}f=P()|0;O()|0;break i}b=w[c+2|0];if(b){b=BK(v[v[v[m>>2]+8>>2]+88>>2],b);v[22452]=0;b=Y(489,h+48|0,1,b|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break N}v[22452]=0;R(507,h+32|0,c+4|0);e=v[22452];v[22452]=0;if((e|0)==1){break P}e=0;v[22452]=0;U(943,h+80|0,b|0,h+32|0);l=v[22452];v[22452]=0;b=1;if((l|0)!=1){break S}f=P()|0;O()|0;break l}e=0;v[22452]=0;Q(55,h+80|0,16713)|0;l=v[22452];v[22452]=0;b=0;if((l|0)==1){break o}}v[22452]=0;i=Q(776,i|0,h+80|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break O}pb(h+80|0);if(b){pb(h+32|0);pb(h+48|0)}if(e){pb(h+32|0);pb(h+48|0)}T:{if(Lg(w[c|0])){v[22452]=0;Q(55,h+80|0,5449)|0;b=v[22452];v[22452]=0;if((b|0)==1){break m}break T}if(w[c+2|0]){v[22452]=0;Q(55,h+80|0,5445)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break T}break m}v[22452]=0;Q(55,h+80|0,16713)|0;b=v[22452];v[22452]=0;if((b|0)==1){break m}}v[22452]=0;e=Q(776,j|0,h+80|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break M}f=P()|0;O()|0;pb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break h}f=P()|0;e=0;O()|0;break k}f=P()|0;O()|0;pb(h+80|0);if(b){break l}break j}f=P()|0;O()|0;break c}pb(h+80|0);if(f-13>>>0>4294967283){break v}v[22452]=0;b=Q(55,h+80|0,17769)|0;j=v[22452];v[22452]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{if((j|0)!=1){v[22452]=0;j=Q(776,i|0,b|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break ba}pb(b);v[22452]=0;b=Q(55,h+80|0,17769)|0;i=v[22452];v[22452]=0;if((i|0)==1){break aa}v[22452]=0;i=Q(776,e|0,b|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break $}pb(b);b=w[c+3|0];ca:{if(Lg(w[c|0])){m=w[c+5|0];e=0;v[22452]=0;n=h,o=Lj(b,m)&4095,v[n+28>>2]=o;R(1066,h+80|0,h+28|0);b=v[22452];v[22452]=0;if((b|0)!=1){break ca}f=P()|0;O()|0;break c}if(b){b=AK(v[v[v[m>>2]+8>>2]+84>>2],b);v[22452]=0;b=Y(489,h+16|0,1,b|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break _}v[22452]=0;R(507,h|0,c+5|0);e=v[22452];v[22452]=0;if((e|0)==1){break Z}v[22452]=0;U(943,h+80|0,b|0,h|0);b=v[22452];v[22452]=0;e=1;if((b|0)!=1){break ca}f=P()|0;O()|0;break W}e=0;v[22452]=0;Q(55,h+80|0,16709)|0;b=v[22452];v[22452]=0;if((b|0)==1){break Y}}v[22452]=0;Q(776,j|0,h+80|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break X}pb(h+80|0);if(e){pb(h);pb(h+16|0)}da:{if(Lg(w[c|0])){v[22452]=0;Q(55,h+80|0,11072)|0;b=v[22452];v[22452]=0;if((b|0)==1){break n}break da}if(w[c+3|0]){v[22452]=0;Q(55,h+80|0,11072)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break da}break n}v[22452]=0;Q(55,h+80|0,16709)|0;b=v[22452];v[22452]=0;if((b|0)==1){break n}}v[22452]=0;Q(776,i|0,h+80|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break U}f=P()|0;O()|0;pb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;pb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;pb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break V}f=P()|0;O()|0;break c}f=P()|0;O()|0;pb(h+80|0);if(!e){break c}}pb(h)}pb(h+16|0);break c}pb(h+80|0);if(!f){break u}}ea:{fa:{ga:{ha:{ia:{if(ub(k)>>>0>f>>>0){v[22452]=0;W(121,h+80|0,k|0,0,f|0);b=v[22452];v[22452]=0;if((b|0)!=1){b=h+80|0;tb(k,b);pb(b);break ia}f=P()|0;O()|0;break c}if(!g){break ia}b=ub(k);v[22452]=0;b=Y(489,h+80|0,f-b|0,32)|0;c=v[22452];v[22452]=0;if((c|0)==1){break ha}v[22452]=0;Q(776,k|0,b|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break ga}pb(b)}if(ub(d)>>>0<=f>>>0){break ea}v[22452]=0;W(121,h+80|0,d|0,0,f|0);b=v[22452];v[22452]=0;if((b|0)==1){break fa}b=h+80|0;tb(d,b);pb(b);break u}f=P()|0;O()|0;break c}f=P()|0;O()|0;pb(b);break c}f=P()|0;O()|0;break c}if(!g){break u}b=ub(d);v[22452]=0;b=Y(489,h+80|0,f-b|0,32)|0;c=v[22452];v[22452]=0;if((c|0)==1){break r}v[22452]=0;Q(776,d|0,b|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break q}pb(b)}v[22452]=0;U(1064,a|0,k|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break p}}pb(h+96|0);pb(h+112|0);ab=h+128|0;return}f=P()|0;O()|0;break c}f=P()|0;O()|0;pb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}pb(h+32|0)}pb(h+48|0)}if(!e){break c}}pb(h+32|0)}pb(h+48|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}pb(h+96|0)}pb(h+112|0);S(f|0);L()}function RV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=ab-1456|0;ab=e;qc(b);ro(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!Rq(b,e+1432|0)){break n}if(!MD(e+1432|0)){break n}if(!c){i=1;break n}p=e+1450|0;c=p;if(!Qq(b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break n}C=e+1444|0;if(!Qq(b,(w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24))+((w[C|0]|w[C+1|0]<<8)<<2)|0)){break n}hv(a);H=e,I=gv(),v[H+56>>2]=I;d=e+56|0;fv(vj(v[a+4>>2])+32|0,d);Pq(d);n=v[vj(v[a+4>>2])+32>>2];c=e+1446|0;v[e+1428>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);H=e,I=jk(b),v[H+1168>>2]=I;v[e+1128>>2]=214748364;c=e+1168|0;i=e+1128|0;H=e,I=B(v[zb(c,i)>>2],20),v[H+56>>2]=I;Wm(n,v[zb(e+1428|0,d)>>2]);Jb(c,0,256);k=i|4;l=e+1144|0;D=e+1146|0;z=e+1142|0;m=e+1140|0;E=Pb(e+1152|0);o:{while(1){if((w[C|0]|w[C+1|0]<<8)>>>0>F>>>0){c=w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24);v[22452]=0;c=Q(146,b|0,c+(F<<2)|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break m}i=0;if(!c){break o}v[22452]=0;c=Q(147,b|0,4)|0;d=v[22452];v[22452]=0;if((d|0)==1){break m}if(!c){break o}v[22452]=0;c=T(148,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break l}v[22452]=0;d=Q(146,b|0,c|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break l}if(!d){break o}v[22452]=0;d=Q(149,b|0,e+1128|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break k}if(!d){break o}d=w[m|0]|w[m+1|0]<<8;v[22452]=0;d=Y(150,b|0,E|0,d|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break k}if(!d){break o}f=v[E>>2];d=w[m|0]|w[m+1|0]<<8;v[22452]=0;g=T(151,b|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break j}j=c+20|0;if(g>>>0<=j+(d<<3)>>>0){break o}c=d?f:0;f=w[m|0]|w[m+1|0]<<8;g=j+(f<<3)|0;d=0;j=w[z|0]|w[z+1|0]<<8;p:{if(!(j&1)){while(1){if(d>>>0>=f>>>0){break p}if(!c){break o}v[22452]=0;f=Y(152,c|0,n|0,v[e+1428>>2])|0;j=v[22452];v[22452]=0;if((j|0)==1){break i}if(!f){break o}v[22452]=0;f=Q(146,b|0,g|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break i}if(!f){break o}f=c+4|0;Zb(e+1120|0,Cb(v[n>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[22452]=0;W(153,e+56|0,b|0,v[e+1120>>2],v[e+1124>>2]);f=v[22452];v[22452]=0;if((f|0)==1){break h}if(v[e+60>>2]!=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))){break o}d=d+1|0;c=c+8|0;f=w[m|0]|w[m+1|0]<<8;continue}}q:{r:{s:{t:{u:{if(j&4){if(!c){break o}v[22452]=0;d=Y(152,c|0,n|0,v[e+1428>>2])|0;f=v[22452];v[22452]=0;if((f|0)==1){break g}if(!d){break o}u=Cb(v[n>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));o=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&-2;if(!o){break o}f=w[D|0]|w[D+1|0]<<8;d=w[l|0]|w[l+1|0]<<8;v[22452]=0;d=Q(146,b|0,d+g|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break f}if(!d){break o}d=w[l|0]|w[l+1|0]<<8;g=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);v[22452]=0;d=Q(147,b|0,g-d|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break f}if(!d){break o}d=w[l|0]|w[l+1|0]<<8;g=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);v[22452]=0;U(154,e+32|0,b|0,g-d|0);d=v[22452];v[22452]=0;if((d|0)==1){break b}d=e+32|0;q=Oq(e+56|0,d);qb(d);A=0;j=0;v:{w:{x:{while(1){g=0;y:{while(1){if((j&65535)>>>0>=(w[m|0]|w[m+1|0]<<8)>>>0){break x}v[22452]=0;d=Q(155,q|0,f+1|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break y}h=f&15;r=x[(h<<1)+25984>>1];z:{A:{if(r>>>0<=d>>>0){v[22452]=0;h=w[h+26032|0];s=Q(155,q|0,h|0)|0;G=v[22452];v[22452]=0;if((G|0)==1){break y}d=s+(d-r<<h)|0;if((d|0)!=(f|0)){f=d&15;break z}v[22452]=0;d=Q(155,q|0,4)|0;h=v[22452];v[22452]=0;if((h|0)==1){break y}if((d|0)==15){v[22452]=0;h=Q(155,q|0,1)|0;d=v[22452];v[22452]=0;if((d|0)==1){break y}d=65535;if(!h){break A}qb(e+56|0);break p}d=d+65520|0}if(d>>>0>65535){break z}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;s=g+u|0;h=w[z|0]|w[z+1|0]<<8;B:{if(h&2){A=d+A|0;d=A;break B}d=h&512?d:d^32768}r=d>>>8|0;h=h&1024;t[s+1|0]=h?d:r;t[s|0]=h?r:d;g=g+2|0}if(g>>>0<o>>>0){continue}break}j=j+1|0;if(j>>>0>=(w[m|0]|w[m+1|0]<<8)>>>0){break r}v[22452]=0;d=(j<<3)+c|0;g=Y(152,d|0,n|0,v[e+1428>>2])|0;o=v[22452];v[22452]=0;if((o|0)==1){break y}if(!g){break t}o=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))&-2;if(!o){break u}u=Cb(v[n>>2],w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));continue}break}i=V(30480)|0;if((O()|0)!=(fa(30480)|0)){break v}_(i|0)|0;v[22452]=0;X(17);c=v[22452];v[22452]=0;if((c|0)==1){break w}}qb(e+56|0);break p}i=P()|0;O()|0}qb(e+56|0);break a}if(!c){break o}v[22452]=0;d=Y(152,c|0,n|0,v[e+1428>>2])|0;f=v[22452];v[22452]=0;if((f|0)==1){break e}if(!d){break o}A=Cb(v[n>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));u=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[D|0]|w[D+1|0]<<8;if((w[l|0]|w[l+1|0]<<8)>>>0>256){break o}v[22452]=0;d=Q(146,b|0,g|0)|0;g=v[22452];v[22452]=0;C:{D:{if((g|0)!=1){if(!d){break o}Zb(e+24|0,e+1168|0,w[l|0]|w[l+1|0]<<8);v[22452]=0;W(156,e+56|0,b|0,v[e+24>>2],v[e+28>>2]);d=v[22452];v[22452]=0;if((d|0)==1){break D}if(y[e+60>>2]<(w[l|0]|w[l+1|0]<<8)>>>0){break o}d=w[l|0]|w[l+1|0]<<8;g=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);v[22452]=0;d=Q(147,b|0,g-d|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){break C}}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}if(!d){break o}d=w[l|0]|w[l+1|0]<<8;g=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);v[22452]=0;U(154,e+32|0,b|0,g-d|0);d=v[22452];v[22452]=0;if((d|0)==1){break c}d=e+32|0;q=Oq(e+56|0,d);qb(d);o=0;j=0;E:{F:{G:{while(1){g=0;H:{while(1){if((o&65535)>>>0>=(w[m|0]|w[m+1|0]<<8)>>>0){break G}v[22452]=0;d=Q(155,q|0,f+1|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break H}h=f&7;r=w[h+26016|0];I:{J:{if(r>>>0<=d>>>0){v[22452]=0;h=w[h+26024|0];s=Q(155,q|0,h|0)|0;G=v[22452];v[22452]=0;if((G|0)==1){break H}d=s+(d-r<<h)|0;if((d|0)!=(f|0)){f=d&7;break I}v[22452]=0;d=Q(155,q|0,3)|0;h=v[22452];v[22452]=0;if((h|0)==1){break H}if((d|0)==7){v[22452]=0;h=Q(155,q|0,1)|0;d=v[22452];v[22452]=0;if((d|0)==1){break H}d=255;if(!h){break J}qb(e+56|0);break p}d=d+248|0}if(d>>>0>255){break I}}d=w[(e+1168|0)+d|0];h=d+j|0;s=d;d=(w[z|0]|w[z+1|0]<<8)&2;t[g+A|0]=d?h:s;j=d?h:j;g=g+1|0}if(g>>>0<u>>>0){continue}break}o=o+1|0;if(o>>>0>=(w[m|0]|w[m+1|0]<<8)>>>0){break q}v[22452]=0;d=(o<<3)+c|0;g=Y(152,d|0,n|0,v[e+1428>>2])|0;u=v[22452];v[22452]=0;if((u|0)==1){break H}if(!g){break s}u=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);A=Cb(v[n>>2],w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));continue}break}i=V(30480)|0;if((O()|0)!=(fa(30480)|0)){break E}_(i|0)|0;v[22452]=0;X(17);c=v[22452];v[22452]=0;if((c|0)==1){break F}}qb(e+56|0);break p}i=P()|0;O()|0}qb(e+56|0);break a}qb(e+56|0);break o}qb(e+56|0);break o}qb(e+56|0);break o}qb(e+56|0);break p}qb(e+56|0)}F=F+1|0;continue}break}de(e+8|0,v[n>>2],v[n+4>>2]);Gg(e+16|0,v[e+8>>2],v[e+12>>2]);b=Vd(e);c=v[b+4>>2];b=v[b>>2];v[22452]=0;b=ea(157,e+56|0,v[e+16>>2],v[e+20>>2],b|0,c|0)|0;c=v[22452];v[22452]=0;i=1;if((c|0)==1){break d}Mc(vj(v[a+4>>2])+12|0,b);qb(b)}Ud(E)}ab=e+1456|0;return i|0}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0}Ud(E);S(i|0);L()}function Is(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=ab-32|0;ab=h;v[h+28>>2]=c;a:{if((c|0)<=0){break a}k=v[b+656>>2];if(!(!k|v[a+480180>>2]!=16777216)){m=v[k+44>>2]!=0}i=v[b+104>>2];b:{c:{d:{if(!k){j=c;break d}if((c|0)>128){break c}j=c-1|0;l=x[Yb(k+236|0,j)>>1];e:{if((l-1&65535)>>>0<=3998){i=(B(l,104)+a|0)+484380|0;break e}rb(h+16|0,a+1074312|0,43);if(!sb(v[v[h+16>>2]>>2],v[h+20>>2])){break e}if(!Kj(v[b+656>>2])){break a}}j=w[Cb(k+108|0,j)|0];v[h+28>>2]=j}if(j>>>0<121){break b}c=j}f:{if(!(v[a+480180>>2]&16777248?(c|0)!=255:0)){tn(a,b);if(d){break f}rb(h+16|0,a+1074312|0,100);if(!sb(v[v[h+16>>2]>>2],v[h+20>>2])|!(w[a+480208|0]&4)|!w[b+789|0]){break f}v[b+88>>2]=v[b+88>>2]&-6145;break f}if(!x[a+480192>>1]){break f}v[b+88>>2]=v[b+88>>2]|4096}g:{if((c|0)!=254){break g}c=v[b+88>>2];if(!(!(c&512)|v[a+480180>>2]!=2)){v[b+88>>2]=c|2048;break g}v[b+88>>2]=c|2101248;h:{if(v[a+480180>>2]&16777248){if(!x[a+480192>>1]){break h}rb(h+16|0,a+1074312|0,50);if(sb(v[v[h+16>>2]>>2],v[h+20>>2])){break h}}v[b+688>>2]=0}rb(h+16|0,a+1074312|0,50);if(sb(v[v[h+16>>2]>>2],v[h+20>>2])){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}rb(h+16|0,a+1074312|0,20);if(!sb(v[v[h+16>>2]>>2],v[h+20>>2])){break a}t[b+797|0]=0;t[b+802|0]=0;break a}i:{j:{k:{if(m){if(d){l=w[b+797|0];if(l){break k}}v[b+708>>2]=0}if(d){break j}if(!(!(v[a+480180>>2]&1048588)|!i)){u[b+770>>1]=t[i+36|0];u[b+772>>1]=t[i+37|0]}if(i){rb(h+16|0,a+1074312|0,24);l=0;o=1;if(!sb(v[v[h+16>>2]>>2],v[h+20>>2])){break i}v[b+704>>2]=v[i+24>>2];break i}i=0;l=0;break i}l=B((v[v[k+44>>2]+36>>2]<<16>>16)+1|0,(j<<16>>16)-l|0)-v[b+852>>2]|0;v[b+708>>2]=l;v[b+852>>2]=0-l}o=(i|0)!=0;l=1;if(gi(v[b+8>>2],v[b+12>>2])){break i}l=a+1074312|0;rb(h+16|0,l,54);if(sb(v[v[h+16>>2]>>2],v[h+20>>2])){v[b+700>>2]=0;break a}rb(h+16|0,l,39);l=(sb(v[v[h+16>>2]>>2],v[h+20>>2])^-1)&d}l:{if(_l(v[a+480180>>2])){v[h+28>>2]=u[b+770>>1]+j;ce(h+28|0,12,131);break l}xQ(h+28|0)}j=a+1074312|0;rb(h+16|0,j,34);m:{if(sb(v[v[h+16>>2]>>2],v[h+20>>2])){d=cm(c);break m}d=v[h+28>>2]}t[b+797|0]=d;t[b+851|0]=w[b+851|0]&183|64;if(!(v[a+480180>>2]&16777250?0:l)){t[b+803|0]=0}d=Kg(a,v[h+28>>2],u[b+772>>1],v[b+704>>2]);t[b+831|0]=0;rb(h+16|0,j,48);if(sb(v[v[h+16>>2]>>2],v[h+20>>2])){lM(a,b,k,i)}rb(h+16|0,j,115);if(!(!sb(v[v[h+16>>2]>>2],v[h+20>>2])|!k|!w[k+26|0])){if(!x[b+784>>1]){u[b+784>>1]=x[b+692>>1]+1}jM(b+692|0,c,k)}n:{if(e^1|l){break n}v[b+776>>2]=0;v[b+780>>2]=0;if(!k){break n}rb(h+16|0,j,29);if(sb(v[v[h+16>>2]>>2],v[h+20>>2])){t[b+798|0]=w[k+16|0]}if(!(w[k+60|0]&8)){$i(b+724|0)}if(!(w[k+80|0]&8)){$i(b+732|0)}if(!(w[k+100|0]&8)){$i(b+740|0)}if(w[k+20|0]){c=Gs(sn(a));n=w[k+20|0];rb(h+16|0,j,28);n=((B(c,n)<<16>>16)/64<<16)+65536>>16;o:{if(sb(v[v[h+16>>2]>>2],v[h+20>>2])){c=v[b+752>>2];break o}c=(v[b+688>>2]+1|0)/2|0}u[b+776>>1]=(B(c,n)|0)/199}p:{if(!w[k+19|0]){break p}q=b,r=(B(Gs(sn(a)),w[k+19|0])<<16>>16)/32|0,u[q+778>>1]=r;rb(h+16|0,j,28);if(sb(v[v[h+16>>2]>>2],v[h+20>>2])|x[b+784>>1]){break p}u[b+784>>1]=x[b+692>>1]+1}c=w[k+23|0];if(c){n=Gs(sn(a));p=w[b+837|0];t[b+796|0]=p+1;u[b+780>>1]=(B(p,(B(c,n+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=w[k+24|0];if(!c){break n}n=Gs(sn(a));p=w[b+838|0];t[b+795|0]=p+1;u[b+782>>1]=(B(p,(B(c,n+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!o){break a}c=0;q:{r:{if(!d){break r}if(!(v[b+700>>2]?l:0)){v[b+700>>2]=d}s:{t:{if(!m){if(!l){rb(h+16|0,j,69);if(sb(v[v[h+16>>2]>>2],v[h+20>>2])){break t}rb(h+8|0,j,46);if(sb(v[v[h+8>>2]>>2],v[h+12>>2])|v[a+480180>>2]==1){break t}}v[b+708>>2]=d;t[b+851|0]=w[b+851|0]&239}if(!l){break t}if(v[b+76>>2]|w[a+480180|0]&2){break s}}v[b+104>>2]=i;d=v[i>>2];v[b+84>>2]=d;v[b+76>>2]=d;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;u:{v:{if(!(v[a+480208>>2]&2097152)){rb(h+16|0,j,96);if(!sb(v[v[h+16>>2]>>2],v[h+20>>2])){break v}}if(w[b+789|0]){break v}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[zb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break u}v[b+660>>2]=0}m=x[i+34>>1];d=m&1023;o=d|v[b+88>>2]&-525056;v[b+88>>2]=o;w:{x:{if(m&8){v[b+80>>2]=v[i+12>>2];m=v[i+16>>2];v[b+88>>2]=(d&16?o|4:o&-524295)|2;v[b+84>>2]=m;if(y[b+76>>2]>m>>>0){break x}break w}if(!(d&2)){break w}v[b+80>>2]=v[i+4>>2];m=v[i+8>>2];v[b+84>>2]=m;if(y[b+76>>2]<=m>>>0){break w}}v[b+76>>2]=m}rb(h+16|0,j,83);if(!(!sb(v[v[h+16>>2]>>2],v[h+20>>2])|v[b+80>>2])){d=v[i>>2];v[b+84>>2]=d;v[b+76>>2]=d}d=v[b+88>>2];y:{if(!(d&128)){break y}i=v[b+76>>2];if(!i){break y}v[b+88>>2]=d|128;v[b+4>>2]=i-1}z:{if(w[b+822|0]>3){break z}rb(h+16|0,j,21);A:{B:{C:{if(!sb(v[v[h+16>>2]>>2],v[h+20>>2])){i=v[a+480180>>2];if(!(i&16777248)){break C}m=16;if(v[a+480208>>2]&4){break B}break A}i=v[a+480180>>2]}m=32;if((i|0)==16){break A}}if(i&67633152){break z}m=0}t[b+819|0]=m}rb(h+16|0,j,21);if(sb(v[v[h+16>>2]>>2],v[h+20>>2])|w[b+825|0]>3){break s}t[b+820|0]=0}i=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){d=v[b+80>>2];v[b>>2]=i;v[b+4>>2]=d}if(!l){break r}c=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break r}d=1;if(!(w[a+480208|0]&8)){break q}d=1;if(!w[b+789|0]){break q}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){Ml(b);rb(h+16|0,j,21);if(!sb(v[v[h+16>>2]>>2],v[h+20>>2])){t[b+818|0]=0;v[b+756>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}D:{if(!c){i=w[b+789|0];break D}i=w[b+789|0];if(!(w[a+480208|0]&8)){break D}d=1;if(!(i&255)){break q}}if(!(i&255?0:v[a+480180>>2]&1048580)){v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}d=c}rb(h+16|0,j,40);E:{F:{if(sb(v[v[h+16>>2]>>2],v[h+20>>2])){if(d){if(!(!(w[a+480208|0]&8)|!w[b+789|0])){v[b+88>>2]=v[b+88>>2]&-4196353;i=1;break E}v[b+88>>2]=v[b+88>>2]&-4194305;i=1;break E}c=v[b+88>>2]&-4196353;break F}c=v[b+88>>2]&-4196353;v[b+88>>2]=c;i=1;if(d){break E}}u[b+842>>1]=65535;v[b+88>>2]=c&-6326273|2097152;rb(h+16|0,j,23);G:{if(sb(v[v[h+16>>2]>>2],v[h+20>>2])){break G}rb(h+8|0,j,22);if(sb(v[v[h+8>>2]>>2],v[h+12>>2])){break G}rb(h+16|0,j,52);if(sb(v[v[h+16>>2]>>2],v[h+20>>2])){break G}rb(h+8|0,j,71);if(sb(v[v[h+8>>2]>>2],v[h+12>>2])){break G}t[b+839|0]=0;t[b+808|0]=0}if(e){t[b+818|0]=0;v[b+756>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;H:{I:{if(k){i=1;d=w[k+22|0];J:{if(!wq(d)){i=!(c>>>13|0);break J}q=b,r=xq(d),t[q+838|0]=r}c=w[k+21|0];if(wq(c)){q=b,r=xq(c),t[q+837|0]=r;break I}if(i){break I}c=(i|0)!=0;break H}v[b+776>>2]=0;v[b+780>>2]=0;c=!c;break H}c=1;d=w[k+25|0];if((d|0)==255){break H}t[b+845|0]=d}K:{if(w[b+837|0]>=127){rb(h+16|0,j,36);if(!sb(v[v[h+16>>2]>>2],v[h+20>>2])){break K}}if(!c){break K}if((mp(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break K}c=a+1298300|0;if(!td(c)|(g|0)==65535){break K}vp(v[c>>2],g,w[b+837|0]>>>1|0,1)}i=0;if(!(w[b+89|0]&2)){break E}c=a+1298300|0;if(!td(c)|(g|0)==65535){break E}rb(h+16|0,j,111);if(sb(v[v[h+16>>2]>>2],v[h+20>>2])){Nj(v[c>>2],g);break E}rb(h+16|0,j,110);if(!sb(v[v[h+16>>2]>>2],v[h+20>>2])){break E}Sy(v[c>>2],g,0,1,0)}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}L:{M:{if(w[a+24618|0]&16?c&1024:0){break M}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break M}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break L}}if(f){break L}v[b+700>>2]=0}if(i){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}ab=h+32|0}function Wca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;j=ab-288|0;ab=j;f=ab-128|0;ab=f;g=j+104|0;i=_d(g,c);v[22452]=0;m=T(165,g+20|0)|0;c=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((c|0)!=1){v[22452]=0;o=T(165,g+40|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break C}v[22452]=0;p=T(165,g+60|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break B}v[22452]=0;q=T(165,g+80|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break A}v[22452]=0;n=T(165,g+100|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break z}v[22452]=0;r=T(165,g+120|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break y}s=Ye(g+140|0);qc(g);v[g+172>>2]=1873739776;u[g+176>>1]=0;v[22452]=0;c=Q(745,i|0,f+112|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break x}if(!c){break m}c=f+112|0;h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if((h|0)!=1414744396&(h|0)!=1179011410){break m}c=f+120|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if((c|0)!=1163280727&(c|0)!=1702257015){break m}t[g+176|0]=(h|0)==1414744396;v[22452]=0;U(746,f+96|0,i|0,2);c=v[22452];v[22452]=0;if((c|0)==1){break w}h=v[f+96>>2];D:{if(fq(h,v[f+100>>2])>>>0<4){break D}c=f+40|0;qi(c,ps(h,1));if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1635017060){break D}c=f- -64|0;qi(c,ps(v[f+96>>2],1));if(!(Wl(c)&1)){break D}c=f+24|0;qi(c,ps(v[f+96>>2],2));if(Wl(c)){break D}c=f+88|0;qi(c,ps(v[f+96>>2],3));if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break D}v[22452]=0;Q(146,g|0,12)|0;c=v[22452];v[22452]=0;if((c|0)==1){break v}v[22452]=0;U(746,f+40|0,i|0,1);c=v[22452];v[22452]=0;if((c|0)==1){break u}c=f+40|0;ot(f+96|0,c);Rd(c)}v[22452]=0;U(747,f- -64|0,f+96|0,544501094);c=v[22452];v[22452]=0;if((c|0)==1){break t}v[22452]=0;i=g+156|0;c=Q(748,f- -64|0,i|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break k}if(!c){break n}c=w[i|0]|w[i+1|0]<<8;if((c|0)!=1){break r}v[22452]=0;c=T(193,f- -64|0)|0;h=v[22452];v[22452]=0;if((h|0)!=1){break s}break k}c=P()|0;O()|0;break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break f}c=P()|0;O()|0;break g}c=P()|0;O()|0;break h}c=P()|0;O()|0;break h}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}if((c|0)==4){break q}c=w[i|0]|w[i+1|0]<<8}if((c&65535)!=65534){break o}v[22452]=0;c=Q(749,f- -64|0,f+40|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break p}if(!c){break n}c=v[f+60>>2];v[f+16>>2]=v[f+56>>2];v[f+20>>2]=c;c=v[f+52>>2];v[f+8>>2]=v[f+48>>2];v[f+12>>2]=c;h=f+24|0;c=f+8|0;v[h>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[h+4>>1]=w[c+4|0]|w[c+5|0]<<8;u[h+6>>1]=w[c+6|0]|w[c+7|0]<<8;y=h,z=Sz(w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24),w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24)),v[y+8>>2]=z;v[h+12>>2]=db;u[g+172>>1]=v[h>>2];break o}v[22452]=0;c=T(188,f- -64|0)|0;h=v[22452];v[22452]=0;E:{if((h|0)!=1){v[22452]=0;h=T(188,f- -64|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break E}if((c|0)!=2|(h|0)!=1){break o}t[g+177|0]=1;break o}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}v[22452]=0;U(747,f+40|0,f+96|0,1635017060);c=v[22452];v[22452]=0;F:{G:{H:{I:{J:{K:{if((c|0)!=1){h=f+40|0;c=Mc(m,h);qb(h);v[22452]=0;h=T(169,c|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break k}if(!h){v[22452]=0;U(747,f+40|0,f+96|0,544039792);h=v[22452];v[22452]=0;if((h|0)==1){break K}h=f+40|0;Mc(c,h);qb(h)}v[22452]=0;U(747,f+40|0,f+96|0,1952670054);h=v[22452];v[22452]=0;if((h|0)==1){break J}v[22452]=0;h=T(148,f+40|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break I}v[g+152>>2]=h;qb(f+40|0);if(v[g+152>>2]?(w[i|0]|w[i+1|0]<<8)==17:0){break F}i=JK(g);if(!i){break F}h=np(g);if(h){if((h>>>0)/(Qj(g)>>>0)>>>0<i<<1>>>0){break H}}v[22452]=0;c=T(151,c|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break k}i=JK(g);break G}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;qb(f+40|0);break j}v[22452]=0;c=T(151,c|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break k}i=np(g)}v[g+152>>2]=(c>>>0)/(i>>>0)}v[22452]=0;c=Q(750,g|0,f+96|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break k}u[g+174>>1]=c;v[22452]=0;R(751,g|0,f+96|0);c=v[22452];v[22452]=0;if((c|0)==1){break k}v[22452]=0;U(747,f+40|0,f+96|0,1886221175);c=v[22452];v[22452]=0;if((c|0)==1){break l}c=f+40|0;Mc(n,c);qb(c)}qb(f- -64|0);Rd(f+96|0)}ab=f+128|0;break a}c=P()|0;O()|0;break j}c=P()|0;O()|0}qb(f- -64|0)}Rd(f+96|0)}Rd(s);qb(r)}qb(n)}qb(q)}qb(p)}qb(o)}qb(m)}qb(g);S(c|0);L()}v[22452]=0;c=T(684,g|0)|0;f=v[22452];v[22452]=0;L:{M:{if((f|0)!=1){N:{if(!c){break N}if((Qj(g)-3&65535)>>>0<65534){break N}O:{P:{c=En(g);Q:{if(!c){if((Pj(g)|0)==85){break Q}break N}if(c>>>0>31){break P}}if((Pj(g)|0)!=3){break O}break N}if(c>>>0>64){break N}}f=Pj(g);c=30240;while(1){R:{S:{if((c|0)!=30264){if((f|0)!=v[c>>2]){break S}}else{c=30264}break R}c=c+4|0;continue}break}if((c|0)==30264){break N}Ls(a,b);v[22452]=0;c=Q(55,j+80|0,21598)|0;f=v[22452];v[22452]=0;T:{U:{V:{W:{X:{Y:{Z:{if((f|0)!=1){i=sc(((b<<5)+a|0)+946304|0,c);pb(c);v[22452]=0;c=B(b,104)+a|0;f=c+484380|0;R(271,f|0,0);k=v[22452];v[22452]=0;if((k|0)==1){break Z}v[f>>2]=v[g+152>>2];k=c+484404|0;c=g+160|0;v[k>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=v[a+1298404>>2];v[22452]=0;W(685,g|0,f|0,c|0,i|0);c=v[22452];v[22452]=0;if((c|0)==1){break Z}_d(j+80|0,g+20|0);c=Gc(j+72|0,8,Qj(g)>>>0>1?2:1,0,0);i=Pj(g);if((i|0)==85){break W}if((i|0)!=17){break V}if(Qj(g)>>>0>2){break X}mc(f,268435456);d=B(b,104)+a|0;b=d+484414|0;c=x[b>>1]|1;u[b>>1]=c;y=b,z=c&65471|((Qj(g)|0)==2)<<6,u[y>>1]=z;if(sg(f)){break Y}k=0;break T}k=P()|0;O()|0;break L}k=P()|0;O()|0;break L}c=v[d+484400>>2];d=v[f>>2];b=_d(j+48|0,j+80|0);i=np(g);k=Qj(g);v[22452]=0;h=v[b+12>>2];v[j+8>>2]=v[b+8>>2];v[j+12>>2]=h;v[j+16>>2]=v[b+16>>2];h=v[b+4>>2];v[j>>2]=v[b>>2];v[j+4>>2]=h;ga(686,c|0,d|0,j|0,i|0,k|0);b=v[22452];v[22452]=0;if((b|0)==1){break M}ii(f,a);break U}if((i|0)!=85){break V}}v[22452]=0;b=ea(523,a|0,b|0,j+80|0,0,1)|0;c=v[22452];v[22452]=0;if((c|0)==1){break M}if(b){break U}k=0;break T}_:{if(hz(g)){break _}if(!zd(w[g+177|0])){break _}if((Pj(g)|0)!=1){break _}if((En(g)|0)!=32){break _}if((np(g)|0)!=Qj(g)<<2){break _}vh(c,32);nf(c,12);v[22452]=0;Y(210,c|0,f|0,j+80|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break U}break M}$:{if(hz(g)){break $}if((Pj(g)|0)!=1){break $}if((En(g)|0)!=24){break $}if((np(g)|0)!=Qj(g)<<2){break $}vh(c,32);nf(c,13);v[22452]=0;Y(210,c|0,f|0,j+80|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break M}break U}if((Pj(g)&65534)==6){vh(c,16);nf(c,(Pj(g)|0)==6?17:16);v[22452]=0;Y(210,c|0,f|0,j+80|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break M}break U}i=(En(g)-1>>>3|0)-1|0;k=i<<3;b=k&31;vh(c,(i>>>0<7?(k&63)>>>0>=32?4196360>>>b|0:((1<<b)-1&4196360)<<32-b|136321040>>>b:8)&255);if(En(g)>>>0<9){nf(c,1)}if((Pj(g)|0)==3){nf(c,3)}if(d){XM(c)}v[22452]=0;Y(210,c|0,f|0,j+80|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break M}}if(e){b=j+24|0;_d(b,g+100|0);Mc(e,b);qb(b)}Ws(f,v[a+480180>>2]);ii(f,a);k=1}qb(j+80|0)}KO(g);ab=j+288|0;return k|0}k=P()|0;O()|0;break L}k=P()|0;O()|0;qb(j+80|0)}KO(g);S(k|0);L()}function cia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=ab-272|0;ab=d;qc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(!vT(b,d+200|0)){break o}if(!wT(d+200|0)){break o}if(!c){f=1;break o}vd(a,131072);e=ab-16|0;ab=e;f=d+104|0;k=Mb(e,3913);Ac(f,k);pb(k);ab=e+16|0;v[22452]=0;U(298,d+152|0,f|0,d+200|4);e=v[22452];v[22452]=0;p:{if((e|0)!=1){e=d+152|0;tb(a+1298344|0,e);pb(e);f=d+104|0;yb(f);k=Mb(e,11052);tb(a+1298356|0,k);pb(k);v[a+1298404>>2]=5;cu(f,3,d+213|0);tc(e,v[d+104>>2],v[d+108>>2],w[d+112|0]);tb(a+1298308|0,e);pb(e);lj(d+80|0,3,d+243|0);tc(f,v[d+80>>2],v[d+84>>2],w[d+88|0]);v[22452]=0;U(11,e|0,5,f|0);e=v[22452];v[22452]=0;if((e|0)==1){break b}e=d+152|0;tb(a+1298320|0,e);pb(e);pb(d+104|0);e=bq(e);q=e,r=Ld(w[d+263|0],1,31),v[q+12>>2]=r;q=e,r=Ld(w[d+264|0],1,12)-1|0,v[q+16>>2]=r;v[e+20>>2]=w[d+265|0];f=a+1298408|0;uc(f);tT(f,e);h=d+112|0;j=d+48|4;k=Ye(d+136|0);q:{r:{s:{while(1){v[22452]=0;e=Q(147,b|0,8)|0;f=v[22452];v[22452]=0;t:{u:{v:{w:{x:{if((f|0)!=1){if(!e){break q}v[22452]=0;R(299,b|0,d+48|0);e=v[22452];v[22452]=0;if((e|0)==1){break x}f=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);y:{n=w[d+204|0];switch(n-3|0){case 1:break w;case 0:break y;default:break v}}e=2;if((w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))!=1431389523){break u}break t}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}e=4;if((w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))!=1431389523){break u}break t}e=0;if(n>>>0>7){break t}}f=(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))==1146113363?-1:f;e=0}n=v[d+52>>2];v[d+104>>2]=v[d+48>>2];v[d+108>>2]=n;v[22452]=0;U(181,d+80|0,b|0,f|0);f=v[22452];v[22452]=0;if((f|0)==1){break s}bc(h,d+80|0);v[22452]=0;R(300,k|0,d+104|0);f=v[22452];v[22452]=0;if((f|0)==1){break r}Tc(d+104|0);qb(d+80|0);v[22452]=0;Q(179,b|0,e|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){continue}break}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;Tc(d+104|0);qb(d+80|0);break c}v[22452]=0;n=T(165,d+104|0)|0;b=v[22452];v[22452]=0;z:{A:{B:{if((b|0)!=1){v[22452]=0;U(301,d+80|0,k|0,1431389523);b=v[22452];v[22452]=0;if((b|0)==1){break B}e=d+80|0;b=Mc(n,e);qb(e);u[d+78>>1]=0;u[d+76>>1]=65534;if(w[d+204|0]<3){break z}v[22452]=0;e=T(185,b|0)|0;f=v[22452];v[22452]=0;if((f|0)!=1){break A}break e}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}u[d+78>>1]=e;if(w[d+204|0]<4){break z}v[22452]=0;e=T(185,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break e}u[d+76>>1]=w[d+204|0]==4?e?e:-2:e}e=a+484360|0;f=Kb(e);v[22452]=0;j=T(193,b|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break e}v[22452]=0;ea(232,f|0,b|0,j>>>1|0,65535,65535)|0;f=v[22452];v[22452]=0;if((f|0)==1){break e}lg(d+78|0,Xt(Kb(e)));lg(d+76|0,Xt(Kb(e)));v[22452]=0;U(301,d+80|0,k|0,1414807888);f=v[22452];v[22452]=0;if((f|0)==1){break h}f=d+80|0;j=Mc(b,f);qb(f);v[22452]=0;f=T(169,b|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break e}if(!(c&1)|f^1){break p}v[22452]=0;R(302,j|0,d+72|0);f=v[22452];v[22452]=0;if((f|0)==1){break i}q=a+480188|0,r=Ld(w[d+72|2],1,32)+1|0,u[q>>1]=r;f=w[d+72|0]|w[d+73|0]<<8;v[22452]=0;f=Q(209,d+8|0,f|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break j}q=d,r=wb(v[f>>2]),v[q+32>>2]=r;m=wb(v[f+4>>2]);C:{D:{while(1){g=v[d+32>>2];if(!Tb(g,m)){h=x[a+480188>>1];v[22452]=0;h=Q(303,d+80|0,h|0)|0;m=v[22452];v[22452]=0;if((m|0)!=1){g=el(Kb(e));v[22452]=0;m=a+484344|0;R(216,m|0,g|0);g=v[22452];v[22452]=0;if((g|0)==1){break g}g=Kb(e);q=d,r=wb(v[g>>2]),v[q+48>>2]=r;i=wb(v[g+4>>2]);E:{while(1){F:{g=v[d+48>>2];if(!Tb(g,i)){g=Kb(e);v[22452]=0;i=g;g=x[d+76>>1];i=Q(304,i|0,g|0)|0;l=v[22452];v[22452]=0;if((l|0)!=1){break F}break g}l=v[f>>2];p=Ef(l,v[f+4>>2]);o=x[g>>1];if(p>>>0>o>>>0){v[22452]=0;l=da(305,tg(l,o)|0,w[d+204|0],h|0,a|0)|0;o=v[22452];v[22452]=0;if((o|0)==1){break E}u[g>>1]=l}Ke(d+48|0);continue}break}G:{if(!i){break G}i=x[d+78>>1];if(!i){if(Xt(Kb(e))>>>0<=g>>>0){break G}}e=x[Yb(v[Kb(e)>>2],g)>>1];je(Rb(m,e),dm(Ae(ve(d+48|0,12,i&255),v[Rb(m,e)+12>>2]-1|0)))}Eh(h);Yc(f);break p}break g}b=P()|0;O()|0;break f}v[22452]=0;h=w[d+204|0]<3?9:8;Q(179,b|0,h-4|0)|0;i=v[22452];v[22452]=0;if((i|0)!=1){v[22452]=0;i=T(148,j|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break D}gg(b,h);v[22452]=0;U(181,d+48|0,b|0,h+i|0);h=v[22452];v[22452]=0;if((h|0)==1){break C}i=g;h=d+80|0;g=d+48|0;Mc(i,bc(h,g));qb(h);qb(g);jh(d+32|0);continue}break}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;yb(d+104|0);break a}v[22452]=0;U(301,d+80|0,k|0,1196641603);e=v[22452];v[22452]=0;if((e|0)==1){break n}f=d+80|0;e=Mc(j,f);qb(f);v[22452]=0;f=T(169,b|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break e}if(f){v[22452]=0;Q(179,b|0,1)|0;f=v[22452];v[22452]=0;if((f|0)==1){break e}v[22452]=0;f=T(193,b|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break e}v[22452]=0;ga(306,a+1298332|0,e|0,f|0,40,0);f=v[22452];v[22452]=0;if((f|0)==1){break e}}v[22452]=0;U(301,d+80|0,k|0,1146113363);f=v[22452];v[22452]=0;if((f|0)==1){break m}v[22452]=0;U(301,d+48|0,k|0,1229999443);f=v[22452];v[22452]=0;H:{if((f|0)!=1){g=e;e=d+48|0;j=Mc(g,e);qb(e);v[22452]=0;e=T(197,j|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break l}h=a+480190|0;u[h>>1]=e;m=!(c&2);f=1;while(1){I:{c=f&65535;if(c>>>0>(e&65535)>>>0){wg(a);v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;v[22452]=0;f=1;Y(258,a+1074312|0,114,1)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break H}break l}e=30;J:{K:{L:{if(w[d+204|0]>=2){v[22452]=0;e=T(197,j|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break L}}v[22452]=0;U(307,j|0,((c<<5)+a|0)+946304|0,e|0);e=v[22452];v[22452]=0;if((e|0)==1){break L}v[22452]=0;R(308,j|0,d+32|0);e=v[22452];v[22452]=0;if((e|0)==1){break K}v[22452]=0;c=B(c,104)+a|0;g=c+484380|0;R(309,d+32|0,g|0);e=v[22452];v[22452]=0;if((e|0)==1){break K}e=w[d+204|0];if(e>>>0>=8){v[22452]=0;R(310,j|0,c+484423|0);e=v[22452];v[22452]=0;if((e|0)==1){break K}e=w[d+204|0]}v[22452]=0;Q(179,b|0,(e>>>0>1?6:2)|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break K}v[22452]=0;e=T(148,d+80|0)|0;i=v[22452];v[22452]=0;if((i|0)!=1){v[22452]=0;U(181,d+8|0,d+80|0,e|0);e=v[22452];v[22452]=0;if((e|0)!=1){break J}}b=P()|0;O()|0;break k}b=P()|0;O()|0;break k}b=P()|0;O()|0;break k}e=d+48|0;i=d+8|0;l=bc(e,i);qb(i);v[22452]=0;e=T(169,e|0)|0;i=v[22452];v[22452]=0;if((i|0)!=1){M:{if(m|e^1){break M}c=Gc(d+8|0,u[c+484414>>1]&1?16:8,1,0,(w[d+47|0]&12)==4?7:0);v[22452]=0;Y(210,c|0,g|0,l|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break M}break I}f=f+1|0;qb(d+48|0);e=x[h>>1];continue}}break}b=P()|0;O()|0;qb(d+48|0);break k}b=P()|0;O()|0;break k}qb(d+80|0);qb(b);Rd(k)}ab=d+272|0;return f|0}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0}qb(d+80|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;Eh(h)}Yc(f);break d}b=P()|0;O()|0}qb(n)}Rd(k);break a}b=P()|0;O()|0;pb(d+104|0)}S(b|0);L()}function oea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=ab-1328|0;ab=d;qc(b);e=ab-16|0;ab=e;rQ(e+8|0,d+216|0);m=v[e+12>>2];_b(e,b,v[e+8>>2],m);j=v[e+4>>2];if((j|0)==(m|0)){Ob(b,v[e+12>>2])}ab=e+16|0;a:{if((j|0)!=(m|0)){break a}if(!tQ(d+216|0)){break a}if(!Hb(b,Fc(sQ(d+216|0),db))){break a}if(!c){q=1;break a}qc(b);j=_d(d+216|0,b);v[22452]=0;R(585,d+200|0,j|0);b=v[22452];v[22452]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){qb(j);v[22452]=0;U(586,d+184|0,d+200|0,1196314451);b=v[22452];v[22452]=0;if((b|0)==1){break i}v[22452]=0;U(586,d+168|0,d+200|0,1280331091);b=v[22452];v[22452]=0;if((b|0)==1){break h}if(jc(v[d+184>>2],v[d+188>>2])){break b}if(!jc(v[d+168>>2],v[d+172>>2])){break g}break b}c=P()|0;O()|0;qb(j);break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break f}v[22452]=0;R(240,a|0,1);b=v[22452];v[22452]=0;j:{k:{l:{m:{if((b|0)!=1){wg(a);v[a+480188>>2]=4;v[a+480208>>2]=25231360;G=d,H=wb(v[d+168>>2]),v[G+16>>2]=H;e=c&2;m=wb(v[d+172>>2]);n:{o:{while(1){g=v[d+16>>2];if(!Tb(g,m)){break o}if(!Dh(a)){break o}b=x[a+480190>>1]+1|0;u[a+480190>>1]=b;v[22452]=0;l=B(b&65535,104)+a|0;i=l+484380|0;R(271,i|0,1);b=v[22452];v[22452]=0;p:{q:{if((b|0)!=1){v[22452]=0;j=Q(587,g|0,d+216|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break q}if(!j){break c}if(qt(d+216|0)){break p}break c}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}v[22452]=0;j=Q(55,d+48|0,d+216|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break n}sc(((x[a+480190>>1]<<5)+a|0)+946304|0,j);pb(j);b=w[d+252|0]|w[d+253|0]<<8|(w[d+254|0]<<16|w[d+255|0]<<24);v[i>>2]=b;v[l+484388>>2]=b;v[l+484384>>2]=w[d+248|0]|w[d+249|0]<<8|(w[d+250|0]<<16|w[d+251|0]<<24);u[l+484410>>1]=255;b=l+484414|0;u[b>>1]=x[b>>1]|2;r:{if(e){b=Gc(d+48|0,8,1,0,0);v[22452]=0;Y(210,b|0,i|0,g|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break r}}jh(d+16|0);continue}break}c=P()|0;O()|0;break j}G=d,H=wb(v[d+184>>2]),v[G+160>>2]=H;s=a+484344|0;A=c&1;o=a+484360|0;m=d+1308|0;j=d+1312|0;p=d+1304|0;C=d+1302|0;F=wb(v[d+188>>2]);D=a+484380|0;E=a+946304|0;c=1;q=1;while(1){s:{t:{u:{v:{w:{x:{e=v[d+160>>2];if(!Tb(e,F)){break x}if(!(c&1)){v[22452]=0;c=T(266,o|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break w}if(!c){break x}}uc(Kb(o));v[22452]=0;c=Q(588,e|0,d+216|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break v}if(!c|(w[C|0]|w[C+1|0]<<8)|(w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24))-5>>>0<4294967292){break c}c=Kb(o);v[22452]=0;U(5,d+48|0,5,d+216|0);b=v[22452];v[22452]=0;if((b|0)==1){break k}v[22452]=0;R(267,c|0,d+48|0);b=v[22452];v[22452]=0;if((b|0)==1){break l}pb(d+48|0);y:{if(A){b=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);v[22452]=0;U(181,d+48|0,e|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break y}c=P()|0;O()|0;break j}v[22452]=0;T(165,d+112|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break m}xD(d+48|0,d+112|0)}b=d+48|0;y=bc(d+136|0,b);qb(b);if(!A){qb(d+112|0)}Jb(d+48|0,0,64);c=1;z:{A:{B:{while(1){if((c|0)==32){break B}b=(B(c,34)+d|0)+182|0;i=b+32|0;sm(d,i);C:{D:{if(!w[v[d>>2]]){break D}e=w[b- -64|0];if(e>>>0>15){break A}b=w[b+65|0];if(b>>>0>64){break A}if(!qt(i)){break A}z=b<<2;h=e<<4;l=0;b=1;E:{while(1){r=b&65535;e=x[a+480190>>1];if(r>>>0>e>>>0){break E}v[22452]=0;U(486,d+16|0,v[d>>2],v[d+4>>2]);e=v[22452];v[22452]=0;if((e|0)==1){break C}n=ab-16|0;ab=n;k=d+16|0;qe(n+8|0,k);pQ(n,((r<<5)+a|0)+946304|0);f=v[n+8>>2];g=v[n>>2];i=v[n+12>>2];e=v[n+4>>2];if((i|0)==(e|0)){e=(_R(f,i,g,e)|0)!=0}else{e=1}ab=n+16|0;pb(k);F:{G:{if(e){break G}G=Yb(d+48|0,c),H=b,u[G>>1]=H;g=B(r,104)+a|0;i=g+484410|0;e=x[i>>1];if((e|0)==255){break F}l=b;if(w[g+484417|0]!=(h&255)){break G}if((e|0)==(z|0)){break F}}b=b+1|0;continue}break}t[g+484417|0]=h;u[i>>1]=z;break D}i=l&65535;if(!i){break D}if(!Dh(a)){break D}b=e+1|0;u[a+480190>>1]=b;G=Yb(d+48|0,c),H=b,u[G>>1]=H;g=B(x[a+480190>>1],104)+D|0;Xl(g);e=B(i,104)+D|0;b=Ln(g,e);u[g+30>>1]=z;t[g+37|0]=h;kR(b,e);e=(i<<5)+E|0;b=v[e+4>>2];g=(x[a+480190>>1]<<5)+E|0;v[g>>2]=v[e>>2];v[g+4>>2]=b;b=v[e+28>>2];v[g+24>>2]=v[e+24>>2];v[g+28>>2]=b;b=v[e+20>>2];v[g+16>>2]=v[e+16>>2];v[g+20>>2]=b;b=v[e+12>>2];v[g+8>>2]=v[e+8>>2];v[g+12>>2]=b}c=c+1|0;continue}break}break u}e=0;v[d+40>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;r=w[p|0]|w[p+1|0]<<8;g=64;i=65535;l=0;H:while(1){I:{if(l){break I}v[22452]=0;c=Q(147,d+136|0,1)|0;b=v[22452];v[22452]=0;if((b|0)==1){break z}if(c){break I}b=i;break t}g=g+1|0;if(g>>>0>=64){v[22452]=0;i=Y(356,s|0,64,0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break z}b=65535;if((i|0)==65535){break t}g=0;b=Kb(o);v[22452]=0;R(484,b|0,i|0);b=v[22452];v[22452]=0;if((b|0)==1){break z}}b=0;c=Qc(Rb(s,i&65535),g,0);while(1){if((b|0)==(r|0)){continue H}h=(d+16|0)+B(b,7)|0;f=w[h+6|0];J:{if(f){t[h+6|0]=f-1;f=w[h+4|0]|w[h+5|0]<<8;t[c+4|0]=f;t[c+5|0]=f>>>8;f=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[c|0]=f;t[c+1|0]=f>>>8;t[c+2|0]=f>>>16;t[c+3|0]=f>>>24;l=l-1|0;break J}v[22452]=0;k=Q(147,d+136|0,1)|0;f=v[22452];v[22452]=0;if((f|0)==1){break u}if(!k){break J}if(v[d+144>>2]==(w[m|0]|w[m+1|0]<<8|(w[m+2|0]<<16|w[m+3|0]<<24))){e=Kb(o);Re(e,Xt(e));e=g}v[22452]=0;k=T(197,y|0)|0;f=v[22452];v[22452]=0;K:{if((f|0)!=1){f=k<<24>>24;if((f|0)>=0){break K}k=f&127;t[h+6|0]=k;f=w[h+4|0]|w[h+5|0]<<8;t[c+4|0]=f;t[c+5|0]=f>>>8;f=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[c|0]=f;t[c+1|0]=f>>>8;t[c+2|0]=f>>>16;t[c+3|0]=f>>>24;l=l+k|0;break J}break u}if((f-1&255)>>>0<=35){t[c|0]=f+48}v[22452]=0;k=T(197,y|0)|0;f=v[22452];v[22452]=0;L:{M:{if((f|0)!=1){G=c,H=w[Yb(d+48|0,k&31)|0],t[G+1|0]=H;if(!(k&128)){break M}t[c+3|0]=w[h+3|0];t[c+5|0]=w[h+5|0];break L}break u}v[22452]=0;R(254,d|0,y|0);f=v[22452];v[22452]=0;N:{if((f|0)!=1){f=w[d|0];if(f>>>0>19){break L}t[c+3|0]=w[(f<<1)+26944|0];k=w[Zc(d)|0];t[c+5|0]=k;if((f|0)!=18|k>>>0<32){break N}t[c+3|0]=17;break L}break u}f=w[d|0];if(819137>>>f&1){break L}t[c+5|0]=w[(f<<1)+26945|0]|k&15}f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[h|0]=f;t[h+1|0]=f>>>8;t[h+2|0]=f>>>16;t[h+3|0]=f>>>24;f=w[c+4|0]|w[c+5|0]<<8;t[h+4|0]=f;t[h+5|0]=f>>>8}c=c+6|0;b=b+1|0;continue}}}q=0;break s}break u}si(o,0);v[22452]=0;c=Q(1,d+216|0,6428)|0;b=v[22452];v[22452]=0;O:{if((b|0)!=1){tb(a+1298344|0,c);pb(c);v[22452]=0;c=Q(1,d+216|0,6730)|0;b=v[22452];v[22452]=0;if((b|0)==1){break O}tb(a+1298356|0,c);pb(c);v[a+1298404>>2]=5;q=1;break b}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;qb(d+136|0);break j}P:{if(!e&g>>>0>62){break P}b=b&65535;if((b|0)==65535){break P}je(Rb(s,b),mh(Ae(ve(d,14,e&255),g)))}c=32}qb(d+136|0);if(c>>>0<32){break b}jh(d+160|0);c=0;continue}}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;pb(d+48|0);break j}c=P()|0;O()|0}Yc(d+168|0)}Yc(d+184|0)}Rd(d+200|0)}S(c|0);L()}q=0}Yc(d+168|0);Yc(d+184|0);Rd(d+200|0)}ab=d+1328|0;return q|0}function r5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=C(0),A=C(0),B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=C(0),R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=C(0),_=0,$=0,aa=C(0);a:{if(!w[a+5046|0]){break a}g=z[a+4268>>2];qJ(a);if(g==z[a+4268>>2]){break a}ax(a)}b:{if(!w[a+5045|0]){break b}o=a+44|0;if(!Ih(o)){break b}p=Gd(o,0);s=Gd(o,1);l=dd(o,0);m=dd(o,1);c:{if(!(!w[a+5044|0]|(!d|w[a+4264|0]&2))){z[l>>2]=z[a+5036>>2];z[m>>2]=z[a+5040>>2];t[a+5044|0]=0;s=s+4|0;p=p+4|0;m=m+4|0;l=l+4|0;q=d-1|0;break c}q=d}r=q;d:{if(!r){break d}V=a+4960|0;W=a+4504|0;u=a+4888|0;x=a+4864|0;X=a+4868|0;Y=a+4892|0;E=a+4628|0;F=a+4604|0;R=a+4916|0;G=a+4532|0;H=a+4508|0;I=a+4772|0;J=a+4748|0;S=a+4940|0;K=a+4676|0;L=a+4652|0;M=a+4724|0;N=a+4700|0;T=a+4844|0;O=a+4580|0;P=a+4556|0;U=a+4820|0;while(1){g=z[p>>2];g=C(C(C(z[a+5008>>2]-g)*z[a+4276>>2])+g);z[a+5008>>2]=g;$=xc(v[a+4864>>2],v[X>>2],v[a+4880>>2]),aa=g,z[$>>2]=aa;g=z[s>>2];g=C(C(C(z[a+5012>>2]-g)*z[a+4276>>2])+g);z[a+5012>>2]=g;$=xc(v[a+4888>>2],v[Y>>2],v[a+4904>>2]),aa=g,z[$>>2]=aa;g=C(C(C(C(C(zh(x,v[a+4356>>2])*C(.6800000071525574))+C(zh(x,v[a+4360>>2])*C(-.5)))-C(zh(x,v[a+4364>>2])*C(.6200000047683716)))+C(zh(x,v[a+4368>>2])*C(-.5)))-C(zh(x,v[a+4372>>2])*C(.6200000047683716)));if(t[a+4264|0]&1){e=g;g=C(z[xc(v[a+4816>>2],v[U>>2],v[a+4836>>2])>>2]+C(e*C(.6180340051651001)));$=xc(v[a+4816>>2],v[U>>2],v[a+4832>>2]),aa=C(e-C(g*C(.6180340051651001))),z[$>>2]=aa}y=z[a+4280>>2];$=a,aa=C(zh(x,v[a+4352>>2])+z[a+5020>>2]),z[$+5020>>2]=aa;e=C(zh(u,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=e;f=z[a+5020>>2];h=C(C(C(z[a+4980>>2]-z[xc(v[a+4624>>2],v[E>>2],v[a+4644>>2])>>2])*z[a+4444>>2])+z[xc(v[a+4624>>2],v[E>>2],v[a+4644>>2])>>2]);z[a+4980>>2]=h;Q=C(h*z[a+4440>>2]);j=C(e*C(.7070000171661377));i=C(f*C(-.7070000171661377));f=C(j+i);h=z[a+4272>>2];e=C(Q+C(f*h));$=xc(v[a+4624>>2],v[E>>2],v[a+4640>>2]),aa=C(f-C(h*e)),z[$>>2]=aa;f=C(C(C(z[a+4976>>2]-z[xc(v[a+4600>>2],v[F>>2],v[a+4620>>2])>>2])*z[a+4436>>2])+z[xc(v[a+4600>>2],v[F>>2],v[a+4620>>2])>>2]);z[a+4976>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4432>>2])+C(e*h));$=xc(v[a+4600>>2],v[F>>2],v[a+4616>>2]),aa=C(e-C(h*f)),z[$>>2]=aa;A=C(C(e*C(-.15000000596046448))+C(f*C(-.20000000298023224)));if(t[a+4264|0]&1){e=C(C(C(z[a+4972>>2]-z[xc(v[a+4576>>2],v[O>>2],v[a+4596>>2])>>2])*z[a+4428>>2])+z[xc(v[a+4576>>2],v[O>>2],v[a+4596>>2])>>2]);z[a+4972>>2]=e;h=z[a+4272>>2];e=C(C(e*z[a+4424>>2])+C(f*h));$=xc(v[a+4576>>2],v[O>>2],v[a+4592>>2]),aa=C(f-C(h*e)),z[$>>2]=aa;f=C(C(C(z[a+4968>>2]-z[xc(v[a+4552>>2],v[P>>2],v[a+4572>>2])>>2])*z[a+4420>>2])+z[xc(v[a+4552>>2],v[P>>2],v[a+4572>>2])>>2]);z[a+4968>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4416>>2])+C(e*h));$=xc(v[a+4552>>2],v[P>>2],v[a+4568>>2]),aa=C(e-C(h*f)),z[$>>2]=aa;A=C(C(C(e*C(.3499999940395355))+A)+C(f*C(-.3799999952316284)))}$=xc(v[a+4912>>2],v[R>>2],v[a+4928>>2]),aa=f,z[$>>2]=aa;e=C(z[xc(v[a+4912>>2],v[R>>2],v[a+4932>>2])>>2]*z[a+4496>>2]);z[a+5028>>2]=C(C(z[a+5028>>2]-e)*z[a+4500>>2])+e;e=C(C(C(z[a+4964>>2]-z[xc(v[a+4528>>2],v[G>>2],v[a+4548>>2])>>2])*z[a+4412>>2])+z[xc(v[a+4528>>2],v[G>>2],v[a+4548>>2])>>2]);z[a+4964>>2]=e;f=z[a+5028>>2];n=z[a+4272>>2];h=C(C(f*n)+C(e*z[a+4408>>2]));$=xc(v[a+4528>>2],v[G>>2],v[a+4544>>2]),aa=C(f-C(n*h)),z[$>>2]=aa;e=C(C(C(z[a+4960>>2]-z[xc(v[a+4504>>2],v[H>>2],v[a+4524>>2])>>2])*z[a+4404>>2])+z[xc(v[a+4504>>2],v[H>>2],v[a+4524>>2])>>2]);z[a+4960>>2]=e;f=C(e*z[a+4400>>2]);e=z[a+4272>>2];n=C(f+C(h*e));$=xc(v[a+4504>>2],v[H>>2],v[a+4520>>2]),aa=C(h-C(e*n)),z[$>>2]=aa;z[a+5020>>2]=n;e=C(C(C(C(C(zh(u,v[a+4380>>2])*C(.7070000171661377))+C(zh(u,v[a+4384>>2])*C(-.6000000238418579)))-C(zh(u,v[a+4388>>2])*C(.5)))+C(zh(u,v[a+4392>>2])*C(-.6000000238418579)))-C(zh(u,v[a+4396>>2])*C(.5)));if(t[a+4264|0]&1){f=e;e=C(z[xc(v[a+4840>>2],v[T>>2],v[a+4860>>2])>>2]+C(e*C(.6180340051651001)));$=xc(v[a+4840>>2],v[T>>2],v[a+4856>>2]),aa=C(f-C(e*C(.6180340051651001))),z[$>>2]=aa}Z=z[a+4280>>2];f=C(C(C(z[a+5004>>2]-z[xc(v[a+4768>>2],v[I>>2],v[a+4788>>2])>>2])*z[a+4492>>2])+z[xc(v[a+4768>>2],v[I>>2],v[a+4788>>2])>>2]);z[a+5004>>2]=f;Q=C(f*z[a+4488>>2]);f=C(i-j);i=z[a+4272>>2];j=C(Q+C(f*i));$=xc(v[a+4768>>2],v[I>>2],v[a+4784>>2]),aa=C(f-C(i*j)),z[$>>2]=aa;f=C(C(C(z[a+5e3>>2]-z[xc(v[a+4744>>2],v[J>>2],v[a+4764>>2])>>2])*z[a+4484>>2])+z[xc(v[a+4744>>2],v[J>>2],v[a+4764>>2])>>2]);z[a+5e3>>2]=f;i=z[a+4272>>2];f=C(C(f*z[a+4480>>2])+C(j*i));$=xc(v[a+4744>>2],v[J>>2],v[a+4760>>2]),aa=C(j-C(i*f)),z[$>>2]=aa;j=C(C(C(h*C(.3799999952316284))+C(j*C(-.15000000596046448)))+C(f*C(-.20000000298023224)));if(t[a+4264|0]&1){h=C(C(C(z[a+4996>>2]-z[xc(v[a+4720>>2],v[M>>2],v[a+4740>>2])>>2])*z[a+4476>>2])+z[xc(v[a+4720>>2],v[M>>2],v[a+4740>>2])>>2]);z[a+4996>>2]=h;i=z[a+4272>>2];h=C(C(h*z[a+4472>>2])+C(f*i));$=xc(v[a+4720>>2],v[M>>2],v[a+4736>>2]),aa=C(f-C(i*h)),z[$>>2]=aa;f=C(C(C(z[a+4992>>2]-z[xc(v[a+4696>>2],v[N>>2],v[a+4716>>2])>>2])*z[a+4468>>2])+z[xc(v[a+4696>>2],v[N>>2],v[a+4716>>2])>>2]);z[a+4992>>2]=f;i=z[a+4272>>2];f=C(C(f*z[a+4464>>2])+C(h*i));$=xc(v[a+4696>>2],v[N>>2],v[a+4712>>2]),aa=C(h-C(i*f)),z[$>>2]=aa;j=C(C(C(h*C(.3499999940395355))+j)+C(f*C(-.3799999952316284)))}_=s+4|0;q=p+4|0;h=C(g*y);A=C(A-C(n*C(.3799999952316284)));n=C(e*Z);$=xc(v[a+4936>>2],v[S>>2],v[a+4952>>2]),aa=f,z[$>>2]=aa;g=C(z[xc(v[a+4936>>2],v[S>>2],v[a+4956>>2])>>2]*z[a+4496>>2]);z[a+5032>>2]=C(C(z[a+5032>>2]-g)*z[a+4500>>2])+g;g=C(C(C(z[a+4988>>2]-z[xc(v[a+4672>>2],v[K>>2],v[a+4692>>2])>>2])*z[a+4460>>2])+z[xc(v[a+4672>>2],v[K>>2],v[a+4692>>2])>>2]);z[a+4988>>2]=g;e=z[a+5032>>2];f=z[a+4272>>2];g=C(C(e*f)+C(g*z[a+4456>>2]));$=xc(v[a+4672>>2],v[K>>2],v[a+4688>>2]),aa=C(e-C(f*g)),z[$>>2]=aa;f=z[a+4284>>2];e=C(C(C(z[a+4984>>2]-z[xc(v[a+4648>>2],v[L>>2],v[a+4668>>2])>>2])*z[a+4452>>2])+z[xc(v[a+4648>>2],v[L>>2],v[a+4668>>2])>>2]);z[a+4984>>2]=e;y=z[a+4272>>2];e=C(C(e*z[a+4448>>2])+C(g*y));$=xc(v[a+4648>>2],v[L>>2],v[a+4664>>2]),aa=C(g-C(y*e)),z[$>>2]=aa;z[a+5024>>2]=e;e=C(-e);y=z[a+4288>>2];k=W;e:{f:{while(1){if((k|0)==(V|0)){g:{e=C(n+C(C(C(e*C(.3799999952316284))+j)*y));g=C(h+C(C(C(g*C(.3799999952316284))+A)*f));if(!(w[a+4264|0]&2)){break g}p=q;q=_;break f}}else{B=v[k+16>>2];D=B-1|0;v[k+16>>2]=D;if((B|0)<=0){v[k+16>>2]=D+v[k+12>>2]}B=v[k+20>>2];D=B-1|0;v[k+20>>2]=D;if((B|0)<=0){v[k+20>>2]=D+v[k+12>>2]}k=k+24|0;continue}break}z[l>>2]=C(g+z[a+5036>>2])*C(.5);z[m>>2]=C(e+z[a+5040>>2])*C(.5);z[a+5040>>2]=e;z[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;q=s+8|0}s=q;z[l>>2]=g;z[m>>2]=e;m=m+4|0;l=l+4|0;r=r-1|0;if(r){continue}break d}break}t[a+5044|0]=1}ai(a,b,c,dd(o,0),dd(o,1),d)}}function mZ(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=ab-560|0;ab=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+96>>2]=1133;k=l+96|0;r=ee(l+136|0,l+144|0,k);b=v[r>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;x=Bb(k);n=Bb(l+80|0);o=Bb(l- -64|0);p=Bb(l+48|0);s=Bb(l+32|0);v[22452]=0;ma(1142,c|0,d|0,l+120|0,l+116|0,l+112|0,x|0,n|0,o|0,p|0,l+28|0);c=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{if((c|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;u=v[l+28>>2];while(1){g:{h:{i:{j:{k:{if((q|0)==4){break k}v[22452]=0;c=Q(1116,a|0,l+552|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}if(!c){break k}l:{m:{n:{o:{p:{q:{switch(t[(l+120|0)+q|0]){case 1:if((q|0)==3){break h}c=v[a>>2];v[22452]=0;c=T(1118,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}v[22452]=0;c=Y(1143,h|0,8192,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}if(c){v[22452]=0;R(1144,l+16|0,a|0);c=v[22452];v[22452]=0;if((c|0)!=1){v[22452]=0;R(49,s|0,v[l+16>>2]);c=v[22452];v[22452]=0;if((c|0)!=1){break p}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break g;case 4:break m;case 2:break n;case 3:break o;case 0:break q;default:break h}}if((q|0)==3){break h}}while(1){v[22452]=0;c=Q(1116,a|0,l+552|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}if(!c){break h}c=v[a>>2];v[22452]=0;c=T(1118,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}v[22452]=0;c=Y(1143,h|0,8192,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}if(!c){break h}v[22452]=0;R(1144,l+16|0,a|0);c=v[22452];v[22452]=0;if((c|0)!=1){v[22452]=0;R(49,s|0,v[l+16>>2]);c=v[22452];v[22452]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}c=ub(o);e=ub(p);if((c|0)==(0-e|0)){break h}d=v[a>>2];if(!(e?c:0)){if(c){v[22452]=0;c=T(1118,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}if((c|0)!=v[Eb(o)>>2]){break l}v[22452]=0;T(1120,a|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}m=ub(o)>>>0>1?o:m;break h}v[22452]=0;c=T(1118,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}if((c|0)!=v[Eb(p)>>2]){break h}v[22452]=0;T(1120,a|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}t[g|0]=1;m=ub(p)>>>0>1?p:m;break h}v[22452]=0;c=T(1118,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}if((c|0)==v[Eb(o)>>2]){v[22452]=0;T(1120,a|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}m=ub(o)>>>0>1?o:m;break h}c=v[a>>2];v[22452]=0;c=T(1118,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}if((c|0)==v[Eb(p)>>2]){v[22452]=0;T(1120,a|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}t[g|0]=1;m=ub(p)>>>0>1?p:m;break h}v[f>>2]=v[f>>2]|4;a=0;break g}if(!(q>>>0<2|m|((q|0)==2&w[l+123|0]!=0|z))){m=0;break h}c=$b(l+16|0,kd(n));r:{s:{if(!q|w[(l+q|0)+119|0]>1){break s}while(1){t:{d=rk(n);e=v[l+16>>2];if(!Tb(e,d)){break t}d=v[e>>2];v[22452]=0;d=Y(1143,h|0,8192,d|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break r}if(!d){break t}te(c);continue}break}c=kd(n);c=yt(v[l+16>>2],c);if(ub(s)>>>0>=c>>>0){B=l,C=rk(s),v[B+8>>2]=C;d=Wk(l+8|0,0-c|0);e=rk(s);k=kd(n);c=ab-16|0;ab=c;v[c>>2]=k;v[c+8>>2]=d;while(1){u:{k=Tb(d,e);if(!k){break u}if(!jc(v[d>>2],v[v[c>>2]>>2])){break u}te(c+8|0);te(c);d=v[c+8>>2];continue}break}ab=c+16|0;if(k^1){break s}}$b(l+8|0,kd(n));v[l+16>>2]=v[l+8>>2]}v[l+8>>2]=v[l+16>>2];v:{while(1){c=rk(n);if(!Tb(v[l+8>>2],c)){break v}v[22452]=0;c=Q(1116,a|0,l+552|0)|0;d=v[22452];v[22452]=0;w:{if((d|0)==1){break w}if(!c){break v}c=v[a>>2];v[22452]=0;c=T(1118,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break w}if((c|0)!=v[v[l+8>>2]>>2]){break v}v[22452]=0;T(1120,a|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}te(l+8|0);continue}break}break d}if(!y){break h}c=rk(n);if(!Tb(v[l+8>>2],c)){break h}v[f>>2]=v[f>>2]|4;a=0;break g}break d}d=0;e=v[l+112>>2];x:{while(1){y:{v[22452]=0;c=Q(1116,a|0,l+552|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break y}if(!c){break x}c=v[a>>2];v[22452]=0;c=T(1118,c|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break f}v[22452]=0;k=Y(1143,h|0,2048,c|0)|0;A=v[22452];v[22452]=0;if((A|0)==1){break f}z:{if(k){k=v[j>>2];if((k|0)==v[l+548>>2]){v[22452]=0;U(1145,i|0,j|0,l+548|0);k=v[22452];v[22452]=0;if((k|0)==1){break f}k=v[j>>2]}v[j>>2]=k+4;v[k>>2]=c;d=d+1|0;break z}if(!ub(x)|!d|(c|0)!=(e|0)){break x}if(v[l+128>>2]==(b|0)){v[22452]=0;U(1139,r|0,l+132|0,l+128|0);b=v[22452];v[22452]=0;if((b|0)==1){break f}b=v[l+132>>2]}c=b+4|0;v[l+132>>2]=c;v[b>>2]=d;b=c;d=0}v[22452]=0;T(1120,a|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!d|v[r>>2]==(b|0)){break j}if(v[l+128>>2]==(b|0)){v[22452]=0;U(1139,r|0,l+132|0,l+128|0);b=v[22452];v[22452]=0;if((b|0)==1){break e}b=v[l+132>>2]}e=b+4|0;v[l+132>>2]=e;v[b>>2]=d;break i}t[g|0]=1;break h}v[l+28>>2]=u;A:{if(!m){break A}c=1;while(1){if(ub(m)>>>0<=c>>>0){break A}v[22452]=0;d=Q(1117,a|0,l+552|0)|0;e=v[22452];v[22452]=0;B:{if((e|0)==1){break B}C:{if(!d){d=v[a>>2];v[22452]=0;d=T(1118,d|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break B}if((d|0)==v[Mj(m,c)>>2]){break C}}v[f>>2]=v[f>>2]|4;a=0;break g}v[22452]=0;T(1120,a|0)|0;d=v[22452];v[22452]=0;c=c+1|0;if((d|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;c=v[r>>2];if((c|0)==(b|0)){break g}a=0;v[l+16>>2]=0;tf(x,c,b,l+16|0);if(v[l+16>>2]){v[f>>2]=v[f>>2]|4;break g}a=1;break g}e=b}D:{if((u|0)<=0){break D}v[22452]=0;b=Q(1117,a|0,l+552|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break e}E:{if(!b){b=v[a>>2];v[22452]=0;b=T(1118,b|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break e}if((b|0)==v[l+116>>2]){break E}}v[l+28>>2]=u;v[f>>2]=v[f>>2]|4;a=0;break g}v[22452]=0;b=T(1120,a|0)|0;d=v[22452];v[22452]=0;c=u;if((d|0)==1){break e}while(1){if((c|0)<=0){u=0;break D}v[22452]=0;d=Q(1117,b|0,l+552|0)|0;k=v[22452];v[22452]=0;F:{if((k|0)==1){break F}G:{if(!d){d=v[a>>2];v[22452]=0;d=T(1118,d|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break F}v[22452]=0;d=Y(1143,h|0,2048,d|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break F}if(d){break G}}v[l+28>>2]=c;v[f>>2]=v[f>>2]|4;a=0;break g}if(v[j>>2]==v[l+548>>2]){v[22452]=0;U(1145,i|0,j|0,l+548|0);d=v[22452];v[22452]=0;if((d|0)==1){break F}}d=v[a>>2];v[22452]=0;d=T(1118,d|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break F}k=v[j>>2];v[j>>2]=k+4;v[k>>2]=d;v[22452]=0;T(1120,b|0)|0;d=v[22452];v[22452]=0;c=c-1|0;if((d|0)!=1){continue}}break}break d}if(v[i>>2]!=v[j>>2]){b=e;break h}v[l+28>>2]=u;v[f>>2]=v[f>>2]|4;a=0;break g}q=q+1|0;continue}break}Oc(s);Oc(p);Oc(o);Oc(n);pb(x);Bc(r);ab=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;v[l+28>>2]=u;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Oc(s);Oc(p);Oc(o);Oc(n);pb(x);Bc(r);S(a|0);L()}function gha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;g=ab-1344|0;ab=g;qc(b);e=ab-16|0;ab=e;i=g+768|0;wS(e+8|0,i);h=v[e+12>>2];_b(e,b,v[e+8>>2],h);j=v[e+4>>2];if((j|0)==(h|0)){Ob(b,v[e+12>>2])}ab=e+16|0;e=(h|0)==(j|0);if(!e){vS(i)}a:{if(!e){break a}if(!yS(g+768|0)){break a}if(!Hb(b,Fc(xS(g+768|0),db))){break a}if(!c){f=1;break a}r=Ap(g+760|0);b:{while(1){if((f|0)!=32){e=(f<<5)+a|0;h=e+480280|0;Le(h);i=(g+768|0)+(f<<4)|0;u[e+480284>>1]=((w[i+78|0]<<8&65280)>>>0)/255;Zj(g+496|0,1,i- -64|0);j=g+112|0;tc(j,v[g+496>>2],v[g+500>>2],w[g+504|0]);jm(e+480289|0,j);pb(j);c:{d:{switch(w[i+79|0]){case 0:k=d+1|0;break c;case 1:v[h>>2]=1024;k=f+1|0;break c;case 2:break d;default:break b}}v[h>>2]=1024;e=g+112|0;vk(e,r,f);Zl(e)}d=d+1|0;f=f+1|0;continue}break}vd(a,33554432);u[a+480188>>1]=k&255;d=g+112|0;e=Mb(d,6734);tb(a+1298344|0,e);pb(e);d=Mb(d,11048);tb(a+1298356|0,d);pb(d);v[a+1298404>>2]=5;e:{if(w[g+847|0]){break e}f=1;e=1;while(1){if((f|0)==16){while(1){if((e|0)==16){break e}d=((e<<5)+a|0)+480280|0;v[d>>2]=v[d>>2]&-1025;e=e+1|0;continue}}d=f<<4;f=f+1|0;if(w[(d+g|0)+847|0]==1){continue}break}}d=g+496|0;Qe(d,1,g+768|0);e=g+112|0;tc(e,v[g+496>>2],v[g+500>>2],w[g+504|0]);tb(a+1298308|0,e);pb(e);v[a+480208>>2]=v[a+480208>>2]&-17|(w[g+806|0]|w[g+807|0]<<8)<<4&16;v[a+480196>>2]=w[g+816|0];v[a+480204>>2]=B(w[g+817|0],1e4);v[a+480200>>2]=w[g+818|0]<<2;v[a+480228>>2]=w[g+819|0];e=w[g+804|0]|w[g+805|0]<<8;u[a+480190>>1]=0;u[a+480192>>1]=e;Cu(b,d);rq(Kb(a+484360|0),d,w[g+800|0]|w[g+801|0]<<8,65535,255);p=c&1;if(p){fg(a+484344|0,w[g+802|0]|w[g+803|0]<<8)}s=a+484344|0;A=a+480188|0;f:{while(1){g:{if((w[g+802|0]|w[g+803|0]<<8)>>>0<=m>>>0){n=c&2;j=g- -64|0;r=g+108|0;s=a+480192|0;k=1;c=0;h:while(1){if(x[s>>1]<=(c&65535)>>>0){f=32;break b}c=c+1|0;d=FB(a,c&65535,0);f=!d;e=ab-16|0;ab=e;i=g+112|0;Ub(e+8|0,i,384);h=v[e+12>>2];_b(e,b,v[e+8>>2],h);l=v[e+4>>2];if((l|0)==(h|0)){Ob(b,v[e+12>>2])}ab=e+16|0;e=(h|0)==(l|0);if(!e){Jb(i,0,384)}if(!e|f){continue}i=k&65535;e=ab-32|0;ab=e;f=g+112|0;Qe(e,1,f);h=e+16|0;tc(h,v[e>>2],v[e+4>>2],w[e+8|0]);sc(d+492|0,h);pb(h);i:{if(!(w[f+378|0]|w[f+379|0]<<8)){break i}l=d+236|0;h=0;while(1){v[e+16>>2]=120;v[e>>2]=116;if(y[zb(e+16|0,e)>>2]<=h>>>0){break i}C=Yb(l,h+12|0),D=i+w[(f+h|0)+32|0]|0,u[C>>1]=D;h=h+1|0;continue}}h=w[f+376|0]|w[f+377|0]<<8;t[d+33|0]=1;v[d>>2]=h;HA(f,d+48|0,0);HA(f,d+68|0,1);HA(f,d+88|0,2);h=w[d+100|0];if(h&1){t[d+100|0]=h|16}if(!(v[d>>2]|t[d+60|0]&1)){v[d>>2]=32767}ab=e+32|0;f=0;while(1){d=w[g+490|0]|w[g+491|0]<<8;if(d>>>0<=f>>>0){k=d+k|0;continue h}$S(b,g+48|0);j:{k:{if(Ib(r,15481,4)){break k}d=f+k|0;l=d&65535;if(l>>>0>3999){break k}u[a+480190>>1]=d;i=ab-32|0;ab=i;m=B(l,104)+a|0;h=m+484380|0;ed(h,0);d=g+48|0;Hh(i,1,d);e=i+16|0;tc(e,v[i>>2],v[i+4>>2],w[i+8|0]);ke(h+43|0,e);pb(e);q=w[d+16|0]|w[d+17|0]<<8|(w[d+18|0]<<16|w[d+19|0]<<24);v[h>>2]=q;o=w[d+20|0]|w[d+21|0]<<8|(w[d+22|0]<<16|w[d+23|0]<<24);v[h+4>>2]=o;p=w[d+24|0]|w[d+25|0]<<8|(w[d+26|0]<<16|w[d+27|0]<<24);v[h+8>>2]=p;v[h+24>>2]=w[d+28|0]|w[d+29|0]<<8|(w[d+30|0]<<16|w[d+31|0]<<24);u[h+30>>1]=w[d+32|0]<<2;u[h+28>>1]=w[d+33|0];e=w[d+48|0];if(e&1){u[h+34>>1]=x[h+34>>1]|2;e=w[d+48|0]}if(e&2){u[h+34>>1]=x[h+34>>1]|4;e=w[d+48|0]}if(e&4){v[h+8>>2]=p>>>1;v[h+4>>2]=o>>>1;v[h>>2]=q>>>1;u[h+34>>1]=x[h+34>>1]|1;e=w[d+48|0]}if(e&8){u[h+34>>1]=x[h+34>>1]|32}ab=i+32|0;d=ab-16|0;ab=d;Lu(d+8|0,m+484423|0);e=g+24|0;yq(e,v[d+8>>2],v[d+12>>2]);ab=d+16|0;sc(((l<<5)+a|0)+946304|0,e);pb(e);d=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);if(!d){break k}Md(g,b,d);d=bc(g+24|0,g);qb(g);if(n){e=Gc(g,u[m+484414>>1]&1?16:8,1,0,0);v[22452]=0;Y(210,e|0,h|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break j}}qb(g+24|0)}f=f+1|0;continue}break}break}f=P()|0;O()|0;qb(g+24|0);break f}e=xg(b);q=xg(b);d=g+48|0;Md(d,b,e-4|0);n=bc(g+112|0,d);qb(d);l:{m:{if(!p){break m}v[22452]=0;d=Y(217,s|0,m&65535,q|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break l}if(!d){break m}k=0;l=Fh(g+24|0);while(1){if(k>>>0>=q>>>0){break m}v[22452]=0;e=T(197,n|0)|0;d=v[22452];v[22452]=0;n:{if((d|0)!=1){if(e){break n}k=k+1|0;continue}break g}f=l;o=e&31;if(o>>>0<x[A>>1]){f=Qc(Rb(s,m),k,o)}if(e&32){v[22452]=0;R(254,g+48|0,n|0);d=v[22452];v[22452]=0;if((d|0)==1){break g}h=g+48|0;d=w[h|0];t[f|0]=d;C=f,D=w[Zc(h)|0],t[C+1|0]=D;o:{p:{if((d|0)==160){h=255;break p}if((d|0)==255){h=0;break p}h=0;d=(B(d>>>4|0,12)+(d&15)|0)+13|0;if(uS(d)){break o}}d=h}t[f|0]=d}d=e&192;q:{if(!d){break q}if((d|0)==192){v[22452]=0;R(346,g+48|0,n|0);d=v[22452];v[22452]=0;if((d|0)!=1){d=g+48|0;j=d;i=Zc(d);e=Me(d);d=vi(d);z=w[j|0];r:{s:{if((z|0)==12){t[g|0]=64;C=f,D=w[Qb(i,g)|0],t[C+4|0]=D;h=1;break s}h=w[e|0];t:{if((h|0)==12){t[g|0]=64;C=f,D=w[Qb(d,g)|0],t[C+4|0]=D;h=1;break t}if((z|0)==10){t[f+4|0]=(w[i|0]<<6>>>0)/255;h=2;break s}if((h|0)!=10){break r}t[f+4|0]=(w[d|0]<<6>>>0)/255;h=2}e=j;d=i}t[f+2|0]=h;h=w[e|0]}t[f+3|0]=h;t[f+5|0]=w[d|0];break q}break g}v[22452]=0;R(254,g+48|0,n|0);d=v[22452];v[22452]=0;if((d|0)==1){break g}d=g+48|0;t[f+3|0]=w[d|0];C=f,D=w[Zc(d)|0],t[C+5|0]=D}if(w[f+3|0]){d=f+3|0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=w[f+3|0];switch(h-14|0){case 19:break A;case 17:break B;case 9:break C;case 8:break D;case 6:case 7:break E;case 1:break F;case 0:break G;default:break z}}d=w[f+5|0];if(!d){d=14;break w}if((d|0)==15){break y}if((d|0)==240){t[f+5|0]=239;break x}if(d>>>0>=16){t[f+5|0]=d|15;break x}t[f+5|0]=d|240;break x}t[f+5|0]=w[f+5|0]^128;break x}d=w[f+5|0];if(d>>>0>=16){t[f+5|0]=d>>>4|240;break x}t[f+5|0]=d|224;break x}t[f+5|0]=((w[f+5|0]^-1)&254)>>>1;break x}t[f+5|0]=w[f+5|0]&15|128;break x}C=f,D=pi(w[f+5|0]<<1),t[C+5|0]=D;break x}e=32;d=0;H:{I:{J:{K:{L:{M:{N:{i=w[f+5|0];switch(i>>>4|0){case 0:break x;case 3:break H;case 5:break I;case 14:break J;case 12:case 13:break K;case 11:break L;case 10:break M;case 8:break N;default:break w}}e=64;break H}e=176;break H}e=224;break H}if(i){break x}break w}O:{switch(i&15){case 0:t[f+5|0]=119;break x;case 1:t[f+5|0]=119;break x;case 2:t[f+5|0]=121;break x;case 3:break O;default:break x}}t[f+5|0]=123;break x}e=48}t[f+5|0]=i&15|e;break x}if(h>>>0<=35){break x}break v}t[f+5|0]=254}d=h}t[f+3|0]=w[d+26608|0];if(w[f+2|0]|(d|0)!=12){break u}t[f+2|0]=1;t[f+3|0]=0;t[f+4|0]=w[f+5|0];d=f+5|0}t[d|0]=0}}vk(g+48|0,r,o);if(!sb(v[v[g+48>>2]>>2],v[g+52>>2])){continue}if(!pB(w[f+3|0],w[f+5|0])){continue}t[f+3|0]=0;continue}}m=m+1|0;qb(g+112|0);continue}}break}f=P()|0;O()|0;qb(g+112|0)}S(f|0);L()}f=f>>>0>31}ab=g+1344|0;return f|0}function Pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,T=0,V=0,W=0,X=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;e=ab-320|0;ab=e;a:{if(!Nc(b,1080)){break a}if(!Tn(b,e+316|0)){break a}vd(a,1);l=ZQ(e+296|0);if(!YQ(e+316|0,l)){break a}d=x[l+10>>1];if(!d|d>>>0>127){break a}if(!c){g=1;break a}q=a+480188|0;u[q>>1]=d;y=w[l+14|0];M=w[l+13|0];d=w[l+12|0];E=1;if(!ae(e+316|0,26874)){E=ae(e+316|0,26879)}if(w[l+15|0]){Db(a+1074312|0,5,1)}z=M?x[q>>1]==8:0;f=e+316|0;r=ae(f,16671);m=1;if(!ae(f,17435)){m=ae(e+316|0,13563)}Nc(b,0);zA(b,a+1298308|0,20);u[a+480190>>1]=31;n=(d|0)!=0;h=a+480188|0;g=1;i=r;while(1)if((g|0)==32){b:{c:{d:{e:{f:{g:{N=v[l+4>>2];if(N>>>0>=F>>>0){f=e+160|0;TQ(b,f);Nc(b,x[l+8>>1]);o=f|1;g=w[o|0];d=128;h=a+484360|0;cq(Kb(h),f|2,128);m=!g&i;i=m?s:0;f=w[f|0];h:{if(f>>>0>128){break h}d=f;if(d){break h}f=v[Kb(h)>>2];g=128;while(1){d=g;if(d>>>0<2){d=1;break h}g=d-1|0;if(!x[Yb(f,g)>>1]){continue}break}}G=(y|0)!=0;i=SQ(b,Kb(h),d&65535,j,q,i,0);if(!(!m|x[q>>1]!=8)){v[l>>2]=11237;G=1}i:{if(!z){break i}f=Kb(h);ca=e,da=wb(v[f>>2]),v[ca+144>>2]=da;g=wb(v[f+4>>2]);while(1){f=v[e+144>>2];if(!Tb(f,g)){break i}u[f>>1]=x[f>>1]>>>1;Ke(e+144|0);continue}}Re(Kb(h),w[o|0]);Q=d-1|0;d=w[o|0];if(!((Q&65535)>>>0>=d>>>0&((d|0)!=120|x[q>>1]!=4))){Re(Kb(h),0)}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;d=x[a+480188>>1];g=0;v[a+480208>>2]=0;ca=a,da=Sb(256/(d>>>0)|0,32,128),v[ca+480228>>2]=da;lh(a,0);t[e+159|0]=0;y=1;T=1;if(!(n&1)){C=e+144|5;n=0;m=0;s=0;f=r;j:while(1){if(i>>>0>(s&65535)>>>0){h=0;g=0;while(1)if((g|0)==256){s=s+1|0;continue j}else{_t(b,Fh(e+144|0));p=IA(w[e+144|0]);k:{l:{m:{n:{d=w[e+147|0];if((d-7&255)>>>0<3){f=0;break n}j=w[e+149|0];if(!((d|0)!=14|j>>>0<=1)){f=0;break m}if(!((d|0)==15&(j&255)>>>0>31)){f=p?f:0;if((d|0)!=13){break n}h=h+1|0;if((h&65535)>>>0<2){break k}}f=0;break k}if((d|0)==8){break l}if((d|0)!=14){break k}j=w[e+149|0]}if((j&240)!=128){break k}t[e+128|0]=j<<4;ca=e,da=w[$e(e+159|0,e+128|0)|0],t[ca+159|0]=da;break k}ca=e,da=w[$e(e+159|0,C)|0],t[ca+159|0]=da;d=t[e+149|0];if((d|0)>=0){n=1;break k}m=(d|0)!=-92&d>>>0>4294967183|m}y=p&y;g=g+1|0;continue}}break}g=0;g=(n^-1|m)&1?g:w[e+159|0]>47;T=f&1}Nc(b,x[l+8>>1]);m=4;m=z?m:x[q>>1];C=a+484344|0;H=i+z&65535;fg(C,H);p=a+1074312|0;aa=g^1;ba=c&1;j=0;n=0;o:{p:{q:{r:{while(1){s:{t:{if((j|0)==(H|0)){break t}u:{if(z){d=(j&65534)>>>1|0;f=j&1;if(!f){if(!Vg(C,d,64)){break t}}g=Qc(Rb(C,d),0,f<<2);break u}if(!Vg(C,j&65535,64)){break t}g=Qc(Rb(C,j),0,0)}if(ba){break s}n=0;I=0;J=0}if((y^-1|V)&1){break q}v:{if(ae(e+316|0,16671)){break v}if(ae(e+316|0,17440)){break v}if(!ae(e+316|0,13553)){break q}}v[a+480208>>2]=v[a+480208>>2]|2162688;d=Db(Db(Db(p,85,1),91,1),92,1);w:{if(w[e+159|0]>47){break w}d=Db(d,84,1);if(w[o|0]==127){break w}Db(d,83,1)}if(!(y&1)){break o}break p}d=x[q>>1];t[e+128|0]=0;f=d;d=e+128|0;W=Vt(e+144|0,f,d);f=x[q>>1];v[22452]=0;t[e+64|0]=0;X=Y(543,d|0,f|0,e- -64|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){K=0;x:while(1){if((K|0)!=64){i=0;f=0;s=0;while(1){if((i|0)==(m|0)){K=K+1|0;I=f&s|I;g=B(x[q>>1],6)+g|0;continue x}v[22452]=0;h=B(i,6)+g|0;R(544,b|0,h|0);d=v[22452];v[22452]=0;y:{z:{if((d|0)!=1){d=w[h+3|0];A:{B:{C:{if(!d){if(w[h+5|0]){break C}break B}if(!M){break C}D:{switch(d-14|0){case 0:t[h+3|0]=0;t[h+5|0]=0;break C;case 1:break D;default:break C}}if(w[h+5|0]<32){break C}t[h+5|0]=31}Mf(h);d=1;E:{F:{G:{k=w[h+3|0];switch(k-14|0){case 2:break A;case 0:break F;case 3:break G;default:break E}}n=w[h+5|0]<100|n;s=1;break B}if(!T){break B}t[h+5|0]=0;break B}if(!((k|0)!=9|aa)){d=w[h+5|0];if((d|0)==164){t[h+3|0]=20;t[h+5|0]=145;break B}ca=h,da=pi(d<<1),t[ca+5|0]=da;break B}if((k|0)!=19){break B}d=w[h+5|0];if(d>>>0>15){break B}k=d&1;d=!k;D=!k;k=Z&1;Z=(k|0)==(d|0)?Z:D;J=((d|0)!=(k|0))+J|0}d=f}if(w[h|0]){break z}f=w[h+1|0];if(!f|z){break y}k=w[Cb(v[e+144>>2],i)|0];if(!k|(f|0)==(k|0)){break y}k=Cb(v[e+128>>2],i);f=w[k|0]+1|0;t[k|0]=f;if((f&255)>>>0<4){break y}v[22452]=0;Y(258,p|0,85,1)|0;f=v[22452];v[22452]=0;if((f|0)!=1){break y}}i=P()|0;O()|0;Xb(X);break r}ca=Cb(v[e+128>>2],i),da=0,t[ca|0]=da}f=w[h+1|0];if(f){ca=Cb(v[e+144>>2],i),da=f,t[ca|0]=da}i=i+1|0;f=d;continue}}break}Xb(X);Xb(W);j=j+1|0;continue}break}i=P()|0;O()|0}Xb(W);break b}if(y&1){break p}if(r^1|w[o|0]!=127|(Q&65535)>>>0>128){break o}v[l>>2]=8481;break o}if((J|0)>6|G){break o}v[a+480208>>2]=v[a+480208>>2]|8388608}if((r|G)==1){Db(p,89,1)}if(E){Db(p,84,1)}H:{if(!(c&2)){break H}Nc(b,x[l+8>>1]+(B(m,H)<<8)|0);f=(y&r^1|_)&1;g=1;while(1){if((g|0)==32){break H}i=B(g,104)+a|0;c=i+484380|0;if(v[c>>2]){d=e+144|0;if(E){D=2}else{D=RQ(b,13824)?10:0}d=Gc(d,8,1,0,D);z=BA(d,v[c>>2])+v[b+8>>2]|0;if(!f){ca=c,da=v[Pc(c,i+484388|0)>>2],v[ca>>2]=da}eg(d,c,b);Nc(b,z)}g=g+1|0;continue}}I:{if((n&r^-1|I)&1){break I}b=QQ(e+104|0,0);c=v[b+20>>2];v[e+40>>2]=v[b+16>>2];v[e+44>>2]=c;c=v[b+12>>2];v[e+32>>2]=v[b+8>>2];v[e+36>>2]=c;c=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=c;b=e+144|0;tt(b,a,0,e+24|0);$=A[v[e+144>>2]>>3];ni(b);if(!($>=480)){break I}c=Db(p,5,1);b=PQ(e+80|0,$);d=v[b+20>>2];v[e+16>>2]=v[b+16>>2];v[e+20>>2]=d;d=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=d;d=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=d;b=e+144|0;tt(b,a,0,e);d=w[v[e+144>>2]+26|0];ni(b);if(d){Cf(c,5);break I}v[l>>2]=17023}b=e+316|0;f=b;d=b;c=ac(d);while(1){if((c|0)!=(d|0)){r=w[d|0];t[b|0]=r>>>0>32?r:32;b=b+1|0;d=d+1|0;continue}break}af(e+128|0,16776);v[22452]=0;b=Y(545,e+48|0,f|0,c|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break g}v[22452]=0;U(11,e- -64|0,1,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break f}v[22452]=0;U(136,e+144|0,e+128|0,e- -64|0);c=v[22452];v[22452]=0;if((c|0)==1){break e}c=e+144|0;tb(a+1298344|0,c);pb(c);pb(e- -64|0);pb(b);yb(e+128|0);b=Mb(c,12292);tb(a+1298356|0,b);pb(b);b=v[l>>2];if(b){pl(a+1298368|0,b)}v[a+1298404>>2]=2}g=F>>>0<=N>>>0;break a}i=P()|0;O()|0;break c}i=P()|0;O()|0;break d}i=P()|0;O()|0;pb(e- -64|0)}pb(b)}yb(e+128|0)}S(i|0);L()}else{f=B(g,104)+a|0;d=f+484380|0;p=Oz(b,e+160|0,d,((g<<5)+a|0)+946304|0,x[h>>1]==4);d=v[d>>2];J:{if(m){t[f+484417|0]=0-(w[e+184|0]<<3);break J}n=d>>>0<65536&n}f=Ab(w[e+182|0]|w[e+183|0]<<8);K:{if(f){V=!Ab(w[e+188|0]|w[e+189|0]<<8)|V;break K}_=w[e+185|0]==64|_}o=i&1;i=0;L:{if(!o){break L}s=(f<<1)+s|0;o=w[e+184|0];i=!o;if(o|!f){break L}i=w[e+185|0]==64}F=p+F|0;j=d+j|0;g=g+1|0;continue}}ab=e+320|0;return g|0}function tZ(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0;l=ab-560|0;ab=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+104>>2]=1133;k=l+104|0;s=ee(l+136|0,l+144|0,k);b=v[s>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;x=Bb(k);o=Bb(l+88|0);p=Bb(l+72|0);q=Bb(l+56|0);u=Bb(l+40|0);v[22452]=0;ma(1136,c|0,d|0,l+120|0,l+119|0,l+118|0,x|0,o|0,p|0,q|0,l+36|0);c=v[22452];v[22452]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;r=v[l+36>>2];e=0;while(1){f:{g:{h:{i:{j:{if((e|0)==4){break j}v[22452]=0;c=Q(1100,a|0,l+552|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}if(!c){break j}k:{l:{m:{n:{o:{p:{switch(t[(l+120|0)+e|0]){case 1:if((e|0)==3){break g}c=v[a>>2];v[22452]=0;c=T(1102,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}if(_g(h,8192,c)){v[22452]=0;R(1137,l+24|0,a|0);c=v[22452];v[22452]=0;if((c|0)!=1){v[22452]=0;R(47,u|0,t[l+24|0]);c=v[22452];v[22452]=0;if((c|0)!=1){break o}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break l;case 2:break m;case 3:break n;case 0:break p;default:break g}}if((e|0)==3){break g}}while(1){v[22452]=0;c=Q(1100,a|0,l+552|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}if(!c){break g}c=v[a>>2];v[22452]=0;c=T(1102,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}if(!_g(h,8192,c)){break g}v[22452]=0;R(1137,l+24|0,a|0);c=v[22452];v[22452]=0;if((c|0)!=1){v[22452]=0;R(47,u|0,t[l+24|0]);c=v[22452];v[22452]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}c=ub(p);k=ub(q);if((c|0)==(0-k|0)){break g}d=v[a>>2];if(!(k?c:0)){if(c){v[22452]=0;c=T(1102,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}if(w[oc(p,0)|0]!=(c&255)){break k}v[22452]=0;T(1104,a|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}m=ub(p)>>>0>1?p:m;break g}v[22452]=0;c=T(1102,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}if(w[oc(q,0)|0]!=(c&255)){break g}v[22452]=0;T(1104,a|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}t[g|0]=1;m=ub(q)>>>0>1?q:m;break g}v[22452]=0;c=T(1102,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}if(w[oc(p,0)|0]==(c&255)){v[22452]=0;T(1104,a|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}m=ub(p)>>>0>1?p:m;break g}c=v[a>>2];v[22452]=0;c=T(1102,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}if(w[oc(q,0)|0]==(c&255)){v[22452]=0;T(1104,a|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}t[g|0]=1;m=ub(q)>>>0>1?q:m;break g}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(e>>>0<2|m|((e|0)==2&w[l+123|0]!=0|z))){m=0;break g}A=l,B=kd(o),v[A+16>>2]=B;c=Yg(l+24|0,l+16|0);q:{if(!e|w[(e+l|0)+119|0]>1){break q}while(1){r:{A=l,B=Ff(o),v[A+16>>2]=B;if(!aj(c,l+16|0)){break r}if(!_g(h,8192,t[v[c>>2]])){break r}Fe(c);continue}break}A=l,B=kd(o),v[A+16>>2]=B;c=am(c,l+16|0);if(ub(u)>>>0>=c>>>0){A=l,B=Ff(u),v[A+16>>2]=B;d=Uz(l+16|0,c);k=Ff(u);n=kd(o);c=ab-32|0;ab=c;v[c+16>>2]=k;v[c+24>>2]=d;v[c+8>>2]=n;while(1){d=aj(c+24|0,c+16|0);if(!(!d|w[v[c+24>>2]]!=w[v[c+8>>2]])){Fe(c+24|0);Fe(c+8|0);continue}break}ab=c+32|0;if(d^1){break q}}A=l,B=kd(o),v[A+8>>2]=B;Yg(l+16|0,l+8|0);v[l+24>>2]=v[l+16>>2]}v[l+16>>2]=v[l+24>>2];s:{t:{while(1){A=l,B=Ff(o),v[A+8>>2]=B;if(!aj(l+16|0,l+8|0)){break s}v[22452]=0;c=Q(1100,a|0,l+552|0)|0;d=v[22452];v[22452]=0;u:{if((d|0)==1){break u}if(!c){break s}c=v[a>>2];v[22452]=0;c=T(1102,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break u}if(w[v[l+16>>2]]!=(c&255)){break s}v[22452]=0;T(1104,a|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break t}Fe(l+16|0);continue}break}a=P()|0;O()|0;v[l+36>>2]=r;break a}a=P()|0;O()|0;v[l+36>>2]=r;break a}if(!y){break g}A=l,B=Ff(o),v[A+8>>2]=B;if(!aj(l+16|0,l+8|0)){break g}v[f>>2]=v[f>>2]|4;a=0;break f}d=0;n=w[l+118|0];v:{while(1){w:{v[22452]=0;c=Q(1100,a|0,l+552|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break w}if(!c){break v}c=v[a>>2];v[22452]=0;c=T(1102,c|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break e}x:{if(_g(h,2048,c)){k=v[j>>2];if((k|0)==v[l+548>>2]){v[22452]=0;U(1138,i|0,j|0,l+548|0);k=v[22452];v[22452]=0;if((k|0)==1){break e}k=v[j>>2]}v[j>>2]=k+1;t[k|0]=c;d=d+1|0;break x}if(!ub(x)|!d|(n|0)!=(c&255)){break v}if(v[l+128>>2]==(b|0)){v[22452]=0;U(1139,s|0,l+132|0,l+128|0);b=v[22452];v[22452]=0;if((b|0)==1){break e}b=v[l+132>>2]}c=b+4|0;v[l+132>>2]=c;v[b>>2]=d;b=c;d=0}v[22452]=0;T(1104,a|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!d|v[s>>2]==(b|0)){break i}if(v[l+128>>2]==(b|0)){v[22452]=0;U(1139,s|0,l+132|0,l+128|0);b=v[22452];v[22452]=0;if((b|0)==1){break d}b=v[l+132>>2]}k=b+4|0;v[l+132>>2]=k;v[b>>2]=d;break h}t[g|0]=1;break g}v[l+36>>2]=r;y:{if(!m){break y}c=1;while(1){if(ub(m)>>>0<=c>>>0){break y}v[22452]=0;d=Q(1101,a|0,l+552|0)|0;e=v[22452];v[22452]=0;z:{if((e|0)==1){break z}A:{if(!d){d=v[a>>2];v[22452]=0;d=T(1102,d|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break z}if(w[oc(m,c)|0]==(d&255)){break A}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22452]=0;T(1104,a|0)|0;d=v[22452];v[22452]=0;c=c+1|0;if((d|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;c=v[s>>2];if((c|0)==(b|0)){break f}a=0;v[l+24>>2]=0;tf(x,c,b,l+24|0);if(v[l+24>>2]){v[f>>2]=v[f>>2]|4;break f}a=1;break f}k=b}B:{if((r|0)<=0){break B}v[22452]=0;b=Q(1101,a|0,l+552|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}C:{if(!b){b=v[a>>2];v[22452]=0;b=T(1102,b|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}if(w[l+119|0]==(b&255)){break C}}v[l+36>>2]=r;v[f>>2]=v[f>>2]|4;a=0;break f}v[22452]=0;b=T(1104,a|0)|0;d=v[22452];v[22452]=0;c=r;if((d|0)==1){break d}while(1){if((c|0)<=0){r=0;break B}v[22452]=0;d=Q(1101,b|0,l+552|0)|0;n=v[22452];v[22452]=0;D:{if((n|0)==1){break D}E:{if(!d){d=v[a>>2];v[22452]=0;d=T(1102,d|0)|0;n=v[22452];v[22452]=0;if((n|0)==1){break D}if(_g(h,2048,d)){break E}}v[l+36>>2]=c;v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[22452]=0;U(1138,i|0,j|0,l+548|0);d=v[22452];v[22452]=0;if((d|0)==1){break D}}d=v[a>>2];v[22452]=0;d=T(1102,d|0)|0;n=v[22452];v[22452]=0;if((n|0)==1){break D}n=v[j>>2];v[j>>2]=n+1;t[n|0]=d;v[22452]=0;T(1104,b|0)|0;d=v[22452];v[22452]=0;c=c-1|0;if((d|0)!=1){continue}}break}a=P()|0;O()|0;v[l+36>>2]=r;break a}if(v[i>>2]!=v[j>>2]){b=k;break g}v[l+36>>2]=r;v[f>>2]=v[f>>2]|4;a=0;break f}e=e+1|0;continue}break}pb(u);pb(q);pb(p);pb(o);pb(x);Bc(s);ab=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}pb(u);pb(q);pb(p);pb(o);pb(x);Bc(s);S(a|0);L()}function pM(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=C(0),D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=C(0),S=C(0),T=0,U=0,V=0,W=C(0),X=0;p=ab-48|0;ab=p;t[p+40|0]=0;h=b+223848|0;l=p+40|0;Ei(h,hi(e,fi(e,zp(e),l))+1|0);de(l,v[h>>2],v[b+223852>>2]);h=ab-16|0;ab=h;t[h+15|0]=0;Zb(p+32|0,e,hi(e,fi(e,zp(e),h+15|0)));ab=h+16|0;H=v[p+32>>2];I=v[p+36>>2];h=0;o=ab-16|0;ab=o;F=a+1074312|0;k=B(c,872)+b|0;J=k+1415|0;K=k+1304|0;L=k+1392|0;r=k+1368|0;D=k+1364|0;M=k+1336|0;N=k+1308|0;O=k+1300|0;P=k+1280|0;Q=k+1402|0;G=k+616|0;m=k+1466|0;R=C(w[m|0]);S=C(f>>>0);q=v[k+1272>>2];T=a+480188|0;i=1;n=255;while(1){if((s|0)!=(I|0)&y[l+4>>2]>h>>>0){j=w[Cb(H,s)|0];e=j-48|0;a:{b:{c:{if((e&255)>>>0<=9){break c}if((j-65&255)>>>0<=5){e=j-55|0;break c}d:{e:{f:{switch(j-97|0){case 2:e=g;if(!e){e=ml(a,b,c,3,0)}g:{if((e-1&255)>>>0>249){break g}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break g}e=py(e,47600,44700);if(!e){break g}e=eb[v[v[e>>2]+188>>2]](e,G,c)|0;j=(e|0)!=255;e=j?e:0;if(j|!q){break c}break d}if(q){break d}e=0;break c;case 21:rb(o+8|0,F,28);h:{if(!sb(v[v[o+8>>2]>>2],v[o+12>>2])){rb(o,F,1);e=0;if(!sb(v[v[o>>2]>>2],v[o+4>>2])){break h}}e=u[L>>1]}j=B(v[r>>2],v[D>>2]);e=B(v[a+1074456>>2],e+v[K>>2]|0);j=Sb((vc(pia(oia(j,j>>31,e,e>>31),db,1048576,0),db)|0)/2|0,1,127);break e;case 20:e=B(v[r>>2],v[D>>2]);j=e;E=e>>31;e=B(v[a+1074456>>2],v[M>>2]);j=Sb((vc(pia(oia(j,E,e,e>>31),db,67108864,0),db)|0)/2|0,1,127);break e;case 23:v[o+8>>2]=v[N>>2]/2;v[o>>2]=127;j=v[jd(o+8|0,o)>>2];break e;case 24:v[o+8>>2]=v[O>>2]/2;v[o>>2]=127;j=v[jd(o+8|0,o)>>2];break e;case 0:j=0;if(!q){break e}e=x[q+28>>1];if(!e){break e}j=e-1>>>7&127;break e;case 1:j=0;if(!q){break e}e=x[q+28>>1];if(!e){break e}j=e-1&127;break e;case 14:j=v[P>>2]>>>8|0;break e;case 7:j=(x[T>>1]<=c>>>0?w[Q|0]-1|0:c)&127;break e;case 12:j=w[k+704|0]>>>7|0;break e;case 15:j=0;if(!q){break e}e=w[q+30|0];if(!e){break e}j=e-1&127;break e;case 25:i:{if(!d|t[m|0]<0){break i}j:{if(h>>>0<3){break j}e=v[l>>2];if(w[Cb(e,h-3|0)|0]!=240){break j}if(w[Cb(e,h-2|0)|0]>239){break i}}A=fp(b,R,S);k:{if(A<C(4294967296)&A>=C(0)){j=~~A>>>0;break k}j=0}t[m|0]=j;n=128;break e}n=(n&255)==255?f:n;j=f;break e;case 18:l:{if(!h){e=0;break l}j=v[l>>2];e=h;while(1){e=e-1|0;E=Cb(j,e);if(!e){break l}if(w[E|0]!=240){continue}break}}if(h-e>>>0<5){break a}E=v[l>>2];if(w[Cb(E,e)|0]!=240){break a}e=e+5|0;j=0;while(1){if((e|0)!=(h|0)){j=w[Cb(E,e)|0]+j|0;e=e+1|0;continue}break};j=0-j&127;break e;case 13:break f;default:break a}}e=w[J|0];j=Kc(e)?e-1|0:0}e=((i^-1)&1)+h|0;U=Cb(v[l>>2],e),V=j,t[U|0]=V;h=e+1|0;i=1;break b}e=w[q+31|0];m:{if((e|0)==17){e=x[G+786>>1];e=(e?e-1|0:c)&15;break m}e=fj(e)?e-1&15:0}}j=Cb(v[l>>2],h);n:{if(i){t[j|0]=e;break n}t[j|0]=w[j|0]<<4|e;h=h+1|0}i=(i^-1)&1}}s=s+1|0;continue}else{if(n<<24>>24>=0){t[m|0]=n}Ub(o+8|0,v[l>>2],((i^-1)&1)+h|0);e=v[o+12>>2];v[l>>2]=v[o+8>>2];v[l+4>>2]=e;ab=o+16|0}break}o=v[p+44>>2];j=0;o:while(1){f=0;while(1){e=j;p:{q:{r:{s:{while(1){if(y[p+44>>2]<=e>>>0){break p}m=v[p+40>>2];i=Cb(m,e);h=t[i|0];if((h|0)==-16){h=e;if(o-h>>>0>=4){j=4;if((w[Cb(m,e+1|0)|0]&254)==240){break q}}t:{while(1){h=h+1|0;if(o>>>0<=h>>>0){break t}if(w[Cb(m,h)|0]!=247){continue}break}h=h-e|0;j=h+1|0;if(j>>>0>=h>>>0){break q}}U=Cb(m,o),V=247,t[U|0]=V;o=o+1|0;j=o-e|0;break r}if((h|0)<0){break s}if(f&255){e=e-1|0;U=Cb(m,e),V=f,t[U|0]=V;continue}break}j=j+1|0;continue o}U=p,V=BO(h&255),v[U+16>>2]=V;v[p+28>>2]=o-e;j=v[zb(p+16|0,p+28|0)>>2]}if(!j){break p}m=v[p+40>>2];i=Cb(m,e)}F=w[i|0];Xp(p+16|0,m,v[p+44>>2],e,j);Zb(p+8|0,v[p+16>>2],v[p+20>>2]);k=v[p+8>>2];h=g;i=0;m=ab-32|0;ab=m;n=v[p+12>>2];u:{if(!n){break u}q=zd(w[b+223884|0]);v:{s=Cb(k,0);l=w[s|0]-250|0;if(l>>>0>5|!(1<<l&37)){break v}l=x[a+480188>>1];while(1){if((i|0)==(l|0)){break v}r=(B(i,872)+b|0)+1453|0;t[r|0]=127;t[r+1|0]=0;i=i+1|0;continue}}w:{if((n|0)!=4|w[s|0]!=240){break w}l=w[Cb(k,1)|0];if((l&254)!=240){break w}s=b+223860|0;n=(B(c,872)+b|0)+616|0;r=Cb(k,2);D=w[Cb(k,3)|0];i=D<<24>>24;x:{y:{z:{A:{B:{C:{k=w[r|0];switch(k|0){case 3:break z;case 2:break A;case 1:break B;case 0:break C;default:break y}}if((l|0)==241|(i|0)<0){break y}h=B(c,872)+b|0;k=h+1453|0;if(d){i=Ng(fp(b,C(w[k|0]),C((i&255)>>>0)))}t[k|0]=i;t[h+1412|0]=0;i=mp(a,n,!(v[h+704>>2]&32768),256);if((i|0)<0|!(w[h+705|0]&2)){break u}h=a+1298300|0;if(q|td(h)^1){break u}vp(v[h>>2],c,i>>>2&255,1);break u}if((l|0)==241|(i|0)<0){break y}h=B(c,872)+b|0;k=h+1454|0;if(d){i=Ng(fp(b,C(w[k|0]),C((i&255)>>>0)))}t[k|0]=i;t[h+1411|0]=0;mp(a,n,!(v[h+704>>2]&32768),256);break u}if((l|0)==241){break x}if(i>>>0>31){break u}h=B(c,872)+b|0;t[h+1461|0]=(i&240)>>>4;mp(a,n,!(v[h+704>>2]&32768),256);break u}if((l|0)==241){break x}i=(i|0)<0;if(!h){h=ml(a,b,c,3,0)}h=h-1|0;if((h&255)>>>0>249|i){break u}t[m+24|0]=h;A=C(C(127-D|0)/C(127));if(q){i=0;k=ab-16|0;ab=k;U=k,V=Wj(m+24|0),v[U>>2]=V;h=ab-16|0;ab=h;r=ny(s,h+12|0,w[m+24|0]);n=v[r>>2];if(!n){l=ab-16|0;ab=l;i=ac(s);n=hh(h,pc(24),ih(l+8|0,i));q=v[n>>2]+16|0;i=ab-16|0;ab=i;v[i+8>>2]=v[k>>2];D=w[v[i+8>>2]];v[q+4>>2]=0;t[q|0]=D;ab=i+16|0;U=ac(n),V=1,t[U+4|0]=V;ab=l+16|0;Pg(s,v[h+12>>2],r,v[h>>2]);n=Pd(h);$k(h);i=1}l=k+8|0;Og(l,$b(h,n),i);ab=h+16|0;h=id(l);ab=k+16|0;z[h+4>>2]=A;break u}h=(B(h&255,160)+a|0)+906444|0;if(!d){z[h>>2]=A;break u}U=h,W=fp(b,z[h>>2],A),z[U>>2]=W;break u}if(k&128){break x}if((l|0)!=241){break u}}n=(i|0)<0;if(!h){h=ml(a,b,c,3,0)}r=n;n=h-1|0;if(r|(n&255)>>>0>249){break u}h=v[(B(n&255,160)+a|0)+906300>>2];if(!h){break u}k=(l|0)==241?k+128|0:k&127;A=C(C((i&255)>>>0)/C(127));if(q){U=EM(s+12|0,ZL(m+24|0,n,k)),W=A,z[U>>2]=W;break u}if(!d){eb[v[v[h>>2]+44>>2]](h,k,A);break u}V=h,X=k,W=fp(b,C(eb[v[v[h>>2]+48>>2]](h,k)),A),U=v[v[h>>2]+44>>2],eb[U](V|0,X|0,C(W));break u}if(q){break u}l=x[a+480188>>1];D:{if(l>>>0>c>>>0){i=c+1|0;break D}i=x[(B(c,872)+b|0)+1402>>1];if(!i){break u}}if(w[(B(c,872)+b|0)+707|0]&4|l>>>0<(i&65535)>>>0){break u}if(!h){h=ml(a,b,c,3,0)}if((h-1&255)>>>0>249){break u}h=v[(B(h,160)+a|0)+906140>>2];if(!h){break u}i=w[s|0];if((i|0)==240){Gg(m+16|0,k,n);i=v[v[h>>2]+72>>2];k=v[m+20>>2];v[m>>2]=v[m+16>>2];v[m+4>>2]=k;eb[i|0](h,m)|0;break u}U=m,X=BO(i),v[U+24>>2]=X;v[m+12>>2]=n;i=m+24|0;l=v[zb(i,m+12|0)>>2];v[m+24>>2]=0;gc(i,k,l);eb[v[v[h>>2]+68>>2]](h,v[m+24>>2])|0}ab=m+32|0;f=F>>>0<240?F:f;j=e+j|0;continue}break}break}ab=p+48|0}function jha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;e=ab-272|0;ab=e;qc(b);d=ab-16|0;ab=d;h=e+112|0;BS(d+8|0,h);g=v[d+12>>2];_b(d,b,v[d+8>>2],g);i=v[d+4>>2];if((i|0)==(g|0)){Ob(b,v[d+12>>2])}ab=d+16|0;d=(g|0)==(i|0);if(!d){AS(h)}a:{if(!d){break a}if(!CS(e+112|0)){break a}if(!c){f=1;break a}vd(a,v[((w[e+228|0]|w[e+229|0]<<8)<<2)+26400>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;d=e+48|0;f=Mb(d,13077);tb(a+1298344|0,f);pb(f);f=Mb(d,10274);tb(a+1298356|0,f);pb(f);f=ab-16|0;ab=f;g=e+8|0;h=Mb(f,4350);Ac(g,h);pb(h);ab=f+16|0;v[22452]=0;W(223,d|0,g|0,e+191|0,e+188|0);d=v[22452];v[22452]=0;b:{if((d|0)!=1){d=e+48|0;tb(a+1298368|0,d);pb(d);f=e+8|0;yb(f);pl(a+1298392|0,((w[e+228|0]|w[e+229|0]<<8)<<2)+26448|0);pl(a+1298380|0,v[((w[e+228|0]|w[e+229|0]<<8)<<2)+26496>>2]);v[a+1298404>>2]=5;Qe(f,2,e+112|4);tc(d,v[e+8>>2],v[e+12>>2],w[e+16|0]);tb(a+1298308|0,d);pb(d);Qe(f,2,e+148|0);tc(d,v[e+8>>2],v[e+12>>2],w[e+16|0]);c:{if(Sp(d,9711)){v[22452]=0;U(11,e+8|0,5,e+48|0);d=v[22452];v[22452]=0;if((d|0)==1){break c}d=e+8|0;tb(a+1298320|0,d);pb(d)}pb(e+48|0);u[a+480188>>1]=32;d=0;d:{while(1){if((d|0)!=32){g=(d<<5)+a|0;h=g+480280|0;Le(h);f=w[(e+d|0)+193|0];e:{if(f>>>0<=15){v[e+48>>2]=f<<4|8;v[e+8>>2]=256;z=g+480284|0,A=v[jd(e+48|0,e+8|0)>>2],u[z>>1]=A;break e}if((f|0)!=16){if((f|0)!=255){break e}u[a+480188>>1]=d;break d}u[g+480284>>1]=128;v[h>>2]=256}d=d+1|0;continue}break}d=x[a+480188>>1]}f=0;if(!(d&65535)){break a}v[e+48>>2]=w[e+225|0]<<2;v[e+8>>2]=256;z=a,A=v[zb(e+48|0,e+8|0)>>2],v[z+480200>>2]=A;v[a+480196>>2]=w[e+226|0];v[a+480204>>2]=B(w[e+227|0],1e4);if(Nc(b,w[e+230|0]|w[e+231|0]<<8|(w[e+232|0]<<16|w[e+233|0]<<24))){Vn(Kb(a+484360|0),b,w[e+234|0]+1|0,255,254)}if(!Nc(b,w[e+240|0]|w[e+241|0]<<8|(w[e+242|0]<<16|w[e+243|0]<<24))){break a}k=a+480190|0;d=w[e+248|0]+1|0;u[k>>1]=d;m=e+80|0;n=a+480180|0;h=1;while(1){f:{g:{i=h&65535;if(i>>>0>(d&65535)>>>0){break g}d=ab-16|0;ab=d;g=e+48|0;Ub(d+8|0,g,62);f=v[d+12>>2];_b(d,b,v[d+8>>2],f);j=v[d+4>>2];if((j|0)==(f|0)){Ob(b,v[d+12>>2])}ab=d+16|0;d=(f|0)==(j|0);if(!d){Jb(g,0,62)}if(!d){break g}d=0;f=B(i,104)+a|0;j=f+484380|0;ed(j,0);l=e+32|0;Qe(l,2,e+48|0);g=e+8|0;tc(g,v[e+32>>2],v[e+36>>2],w[e+40|0]);sc(((i<<5)+a|0)+946304|0,g);pb(g);Zj(l,2,m);tc(g,v[e+32>>2],v[e+36>>2],w[e+40|0]);ke(f+484423|0,g);pb(g);g=w[e+106|0]|w[e+107|0]<<8;v[f+484404>>2]=g;if(!_l(v[n>>2])){break f}while(1){if((d|0)==16){break f}if((g|0)==x[(d<<1)+26544>>1]){t[f+484417|0]=d<<4;break f}else{d=d+1|0;continue}}}h:{if(!(c&2)){break h}if(!Nc(b,w[e+244|0]|w[e+245|0]<<8|(w[e+246|0]<<16|w[e+247|0]<<24))){break h}f=a+480190|0;d=1;while(1){g=d&65535;if(g>>>0>x[f>>1]){break h}g=B(g,104)+a|0;eg(Gc(e+48|0,u[g+484414>>1]&1?16:8,1,0,1),g+484380|0,b);d=d+1|0;continue}}l=a+484344|0;fg(l,w[e+239|0]+1|0);f=Rp(a);d=ab-16|0;ab=d;v[d+12>>2]=0;ts(d+12|0,f);j=v[d+12>>2];ab=d+16|0;Nc(b,w[e+235|0]|w[e+236|0]<<8|(w[e+237|0]<<16|w[e+238|0]<<24));q=c&1;r=a+480188|0;s=a+480180|0;i=0;m=1;i:{j:{k:{while(1){if(w[e+239|0]<i>>>0){if(v[a+480180>>2]==1){break k}c=v[a+480208>>2]&-8454145;break j}l:{d=xg(b);if(d>>>0>=3){c=e+8|0;Md(c,b,d-2|0);n=bc(e+48|0,c);qb(c);m:{if(!q){break m}v[22452]=0;c=T(169,e+48|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break l}if(!c){break m}v[22452]=0;c=Y(217,l|0,i&65535,64)|0;d=v[22452];v[22452]=0;if((d|0)==1){break l}k=0;if(!c){break m}while(1){if((k|0)==64){break m}y=Of(Rb(l,i),k);n:{o:while(1){v[22452]=0;c=T(197,n|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break i}if(!c){break n}d=c&31;if(d>>>0>=x[r>>1]){break n}f=B(d,6)+y|0;if(c&32){v[22452]=0;R(254,e+8|0,n|0);d=v[22452];v[22452]=0;if((d|0)==1){break i}g=Zc(e+8|0);d=w[e+8|0];if(d){d=(d&127)-1|0;t[e+8|0]=d;d=(B((d&240)>>>4|0,12)+(d&15)|0)+13|0;t[f|0]=d;m=IA(d)&m}t[f+1|0]=w[g|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;g=f+5|0;while(1){v[22452]=0;c=Q(147,e+48|0,2)|0;d=v[22452];v[22452]=0;if((d|0)==1){break i}if(!c){continue o}p=w[g|0];c=w[f+3|0];v[22452]=0;R(254,e+8|0,n|0);d=v[22452];v[22452]=0;if((d|0)!=1){d=e+8|0;o=d;h=w[Zc(d)|0];t[g|0]=h;d=w[(w[d|0]&31)+26576|0];t[f+3|0]=d;p:{q:{r:{s:{t:{switch(d-2|0){case 0:case 1:if(h>>>0<224){break r}d=223;if(v[s>>2]!=1){break s}break r;case 11:t[e+32|0]=64;z=g,A=w[Qb(g,e+32|0)|0],t[z|0]=A;if(!zS(v[j+88>>2])){break r}t[f+2|0]=1;t[f+4|0]=w[g|0];t[f+3|0]=c;t[g|0]=p;d=c;break q;case 17:u:{switch(((h&240)>>>4|0)-8|0){case 0:t[f+3|0]=2;t[g|0]=h&15|224;break p;case 1:t[f+3|0]=3;t[g|0]=h&15|224;break p;default:break u}}if(Lt(v[j+84>>2],19)){break r}ru(f);break r;case 13:d=v[j+84>>2];if(Lt(d,15)){break r}if(!Lt(d,19)){break r}t[f+3|0]=19;t[g|0]=h&15|144;break p;case 18:d=145;if((h|0)==1){break s}if((h&240)==128){if(Lt(v[j+84>>2],20)){break r}t[f+3|0]=19;break p}t[f+3|0]=0;break p;case 4:case 5:break t;default:break q}}d=h&240;if(!d){break r}}t[g|0]=d}d=w[f+3|0]}if((d&255)!=20){break p}d=w[g|0];if(w[f+2|0]|(d&240)!=128){break p}t[f+2|0]=2;t[f+4|0]=(((d&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[g|0]=p}if(!(w[o|0]&32)){continue o}continue}break}break}break i}k=k+1|0;continue}}qb(e+48|0)}i=i+1|0;continue}break}break i}c=v[a+480208>>2]&-8454145|(x[a+480188>>1]==4?m&1?8454144:0:0)}v[a+480208>>2]=c;f=1;if(!(w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24))){break a}if(!Nc(b,w[e+249|0]|w[e+250|0]<<8|(w[e+251|0]<<16|w[e+252|0]<<24))){break a}VA(a+1298332|0,b,w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24),4);break a}d=P()|0;O()|0;qb(e+48|0);break b}u[f+484412>>1]=64;d=w[e+93|0]|w[e+94|0]<<8|(w[e+95|0]<<16|w[e+96|0]<<24);v[j>>2]=d;if(w[e+105|0]&2){g=f+484414|0;u[g>>1]=x[g>>1]|1;v[j>>2]=d>>>1}v[f+484384>>2]=w[e+97|0]|w[e+98|0]<<8|(w[e+99|0]<<16|w[e+100|0]<<24);v[f+484388>>2]=(w[e+101|0]|w[e+102|0]<<8|(w[e+103|0]<<16|w[e+104|0]<<24))-1;d=w[e+105|0];if(d&1){d=f+484414|0;u[d>>1]=x[d>>1]|2;d=w[e+105|0]}v:{w:{if(!(d&4)){break w}d=w[e+108|0];if((d|0)==255){break w}t[e+8|0]=d;t[e+32|0]=64;z=f+484410|0,A=w[Qb(e+8|0,e+32|0)|0]<<2,u[z>>1]=A;break v}d=f+484414|0;u[d>>1]=x[d>>1]|32768}x:{if(w[e+105|0]&8){d=f+484414|0;g=x[d>>1]|32;u[d>>1]=g;i=f+484408|0;f=w[e+109|0];if(f>>>0<=15){v[e+32>>2]=256;v[e+8>>2]=f<<4|8;o=v[jd(e+8|0,e+32|0)>>2]}else{o=128}u[i>>1]=o;u[d>>1]=g&65279|(w[e+109|0]==16)<<8;break x}u[f+484408>>1]=128}h=h+1|0;d=x[k>>1];continue}}d=P()|0;O()|0;pb(e+48|0);break b}d=P()|0;O()|0;yb(e+8|0)}S(d|0);L()}ab=e+272|0;return f|0}function LU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;f=ab-224|0;ab=f;qc(b);a:{b:{c:{d:{if(!hC(b,f+176|0)){break d}if(!kC(f+176|0)){break d}if(!c){n=1;break d}vd(a,2048);wg(a);d=ab-16|0;ab=d;l=f+8|0;e=Mb(d,3927);Ac(l,e);pb(e);ab=d+16|0;v[22452]=0;d=l;l=f+176|3;U(204,f+80|0,d|0,l|0);d=v[22452];v[22452]=0;e:{if((d|0)!=1){d=f+80|0;tb(a+1298344|0,d);pb(d);e=f+8|0;yb(e);g=Mb(d,11056);tb(a+1298356|0,g);pb(g);v[a+1298404>>2]=5;g=a+480188|0;u[g>>1]=w[f+216|0];u[a+480190>>1]=w[f+212|0];Qe(e,2,f+176|4);tc(d,v[f+8>>2],v[f+12>>2],w[f+16|0]);tb(a+1298308|0,d);pb(d);d=w[l|0];if(d>>>0<=8){u[g>>1]=4;gg(b,1);lh(a,1);d=w[l|0]}f:{d=d&255;if(d>>>0>=11){e=(d|0)==11?16:32;d=0;while(1){if((d|0)==(e|0)){break f}g=Gu(b);g:{if((g|0)==100){v[((d<<5)+a|0)+480280>>2]=256;break g}v[f+80>>2]=(g<<1)+128;v[f+8>>2]=0;v[f+160>>2]=256;y=((d<<5)+a|0)+480284|0,z=v[nj(f+80|0,f+8|0,f+160|0)>>2],u[y>>1]=z}d=d+1|0;continue}}if(d>>>0<9){break f}e=f+80|0;d=ab-16|0;ab=d;h:{if(!Hb(b,16)){WB(e);break h}xu(d+8|0,e);fd(d,b,v[d+8>>2],v[d+12>>2])}ab=d+16|0;d=0;while(1){if((d|0)==16){break f}u[((d<<5)+a|0)+480284>>1]=t[(f+80|0)+d|0]&1?64:192;d=d+1|0;continue}}i:{if(w[l|0]>=13){e=f+80|0;Bu(e,b);g=Zc(e);d=w[e|0];if(d>>>0<=31){t[e|0]=125;d=125}v[a+480204>>2]=B(d,1e4);v[a+480196>>2]=w[g|0];break i}v[a+480196>>2]=6;v[a+480204>>2]=125e4}e=a+484360|0;mf(Kb(e),w[f+213|0]);o=Pb(f+160|0);d=v[b+8>>2];g=w[l|0]>13;if(!g){break e}i=w[f+213|0];v[22452]=0;R(205,o|0,i|0);i=v[22452];v[22452]=0;if((i|0)!=1){break e}d=P()|0;O()|0;break b}d=P()|0;O()|0;yb(f+8|0);break a}r=d+(g<<1)|0;g=a+480188|0;d=0;j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{while(1){t:{if(w[f+213|0]<=d>>>0){d=0;if(w[l|0]!=10){break s}m=v[b+8>>2];n=a+480190|0;d=1;while(1){h=x[n>>1];if(h>>>0<(d&65535)>>>0){break t}v[22452]=0;e=Q(206,b|0,f+80|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break r}if(e){k=w[f+212|0];e=0;g=f+80|0;u:{if(w[g|0]>1){break u}i=g+46|0;if(k>>>0<(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))>>>0){break u}i=g+50|0;k=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);if(k>>>0>1048576|w[g+56|0]>64){break u}i=g+57|0;if(k>>>0<(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))>>>0){break u}e=g+61|0;e=k>>>0>=(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0}if(!e){break t}}d=d+1|0;continue}}y=Yb(v[Kb(e)>>2],d),z=d,u[y>>1]=z;if(w[l|0]>=14){v[22452]=0;i=T(185,b|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break q}y=Yb(v[o>>2],d),z=i,u[y>>1]=z}i=x[g>>1];v[22452]=0;Q(179,b|0,i<<1)|0;i=v[22452];v[22452]=0;if((i|0)==1){break q}d=d+1|0;continue}break}v[22452]=0;Q(146,b|0,m|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}d=h>>>0>=(d&65535)>>>0}m=a+480190|0;e=x[m>>1];v[22452]=0;v[f+80>>2]=0;i=Y(207,f- -64|0,e|0,f+80|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break p}n=d?59:65;k=f+80|1;e=1;v:{while(1){g=e&65535;if(g>>>0>x[m>>1]){g=Pb(f+48|0);d=w[f+214|0]|w[f+215|0]<<8;v[22452]=0;n=Y(208,b|0,g|0,d|0)|0;d=v[22452];v[22452]=0;w:{if((d|0)!=1){if(!n){break j}k=0;d=v[g>>2];if(!jc(d,v[g+4>>2])){d=wb(d);k=wb(v[g+4>>2]);e=ab-16|0;ab=e;x:{if(!Tb(d,k)){break x}v[e+8>>2]=d;while(1){Ke(e+8|0);m=v[e+8>>2];if(!Tb(m,k)){break x}d=_B(d,m)?m:d;continue}}ab=e+16|0;k=w[d|0]|w[d+1|0]<<8}v[22452]=0;m=Q(209,f+32|0,k|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break w}d=0;y:{while(1){if((d|0)==(k|0)){if(!(c&2)){break o}j=Gc(f+80|0,8,1,0,1);p=a+480190|0;e=x[p>>1];h=1;z:{A:while(1){q=h&65535;if(q>>>0>(e&65535)>>>0){break o}v[22452]=0;d=Q(147,b|0,1)|0;e=v[22452];v[22452]=0;if((e|0)==1){break z}if(!d){break o}s=v[b+8>>2];d=0;while(1){e=x[p>>1];if(e>>>0<=d>>>0){h=h+1|0;continue A}if((q|0)!=v[Fb(v[i>>2],d)>>2]){d=d+1|0;continue}v[22452]=0;Q(146,b|0,s|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){v[22452]=0;d=d+1|0;Y(210,j|0,(B(d,104)+a|0)+484380|0,b|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){continue}}break}break}d=P()|0;O()|0;break n}d=P()|0;O()|0;break n}v[22452]=0;e=T(185,b|0)|0;h=v[22452];v[22452]=0;B:{if((h|0)==1){break B}v[22452]=0;Q(179,b|0,1)|0;h=v[22452];v[22452]=0;if((h|0)==1){break B}if(e){h=w[l|0];v[22452]=0;U(181,f+8|0,b|0,B(e,3)+((h|0)==1?3:0)|0);e=v[22452];v[22452]=0;if((e|0)==1){break y}e=f+80|0;h=f+8|0;j=bc(e,h);Mc(tg(v[m>>2],d),j);qb(e);qb(h)}d=d+1|0;continue}break}d=P()|0;O()|0;break n}d=P()|0;O()|0;break n}d=P()|0;O()|0;break m}d=P()|0;O()|0;break m}C:{D:{if(w[l|0]<=9){v[22452]=0;R(211,b|0,f+80|0);h=v[22452];v[22452]=0;E:{F:{if((h|0)==1){break F}v[22452]=0;R(212,f+80|0,(B(g,104)+a|0)+484380|0);h=v[22452];v[22452]=0;if((h|0)==1){break F}Qe(f+48|0,2,k);v[22452]=0;W(213,f+8|0,v[f+48>>2],v[f+52>>2],w[f+56|0]);h=v[22452];v[22452]=0;if((h|0)==1){break E}break D}d=P()|0;O()|0;break l}d=P()|0;O()|0;break l}v[22452]=0;U(214,b|0,f+80|0,n|0);h=v[22452];v[22452]=0;if((h|0)==1){break C}v[22452]=0;U(215,f+80|0,(B(g,104)+a|0)+484380|0,d|0);h=v[22452];v[22452]=0;if((h|0)==1){break C}Qe(f+48|0,2,k);v[22452]=0;W(213,f+8|0,v[f+48>>2],v[f+52>>2],w[f+56|0]);h=v[22452];v[22452]=0;if((h|0)==1){break v}}h=f+8|0;sc(((g<<5)+a|0)+946304|0,h);pb(h);y=Fb(v[i>>2],g-1|0),z=w[f+126|0]|w[f+127|0]<<8|(w[f+128|0]<<16|w[f+129|0]<<24),v[y>>2]=z;e=e+1|0;continue}break}d=P()|0;O()|0;break l}d=P()|0;O()|0;break l}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}if(!(c&1)){break k}c=w[f+213|0];v[22452]=0;h=a+484344|0;R(216,h|0,c|0);c=v[22452];v[22452]=0;G:{if((c|0)!=1){c=a+480188|0;a=0;while(1){H:{if(w[f+213|0]<=a>>>0){break k}d=64;e=v[o>>2];if(wc(e,v[o+4>>2])>>>0>a>>>0){d=x[Yb(e,a)>>1]}v[22452]=0;d=Y(217,h|0,a&65535,d&65535)|0;e=v[22452];v[22452]=0;if((e|0)==1){break G}I:{if(d){d=x[c>>1];e=w[l|0];v[22452]=0;Q(146,b|0,B(((e>>>0>13)<<1)+(d<<1)|0,a)+r|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break G}e=Pb(f+80|0);d=x[c>>1];v[22452]=0;j=Y(208,b|0,e|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break I}d=0;J:{if(!j){break J}while(1){if(x[c>>1]<=d>>>0){break J}K:{j=Yb(v[f+80>>2],d);j=w[j|0]|w[j+1|0]<<8;if(!j|j>>>0>(w[f+214|0]|w[f+215|0]<<8)>>>0){break K}j=Yb(v[g>>2],j-1|0);j=(w[j|0]|w[j+1|0]<<8)-1&65535;if(j>>>0>=k>>>0){break K}p=Rb(h,a);q=v[m>>2];v[22452]=0;U(218,p|0,d&65535,tg(q,j)|0);j=v[22452];v[22452]=0;if((j|0)!=1){break K}break H}d=d+1|0;continue}}_c(e)}a=a+1|0;continue}}break}d=P()|0;O()|0;_c(e);break n}d=P()|0;O()|0;break n}d=P()|0;O()|0}Yc(m)}_c(g)}ec(i);break b}Yc(m)}_c(g);ec(i);_c(o)}ab=f+224|0;return n|0}d=P()|0;O()|0}_c(o)}S(d|0);L()}function cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0;d=ab-304|0;ab=d;qc(b);a:{b:{c:{d:{if(!pt(b,d+208|0)){break d}if(!lQ(d+208|0)){break d}if(!Hb(b,Fc(kQ(d+208|0),db))){break d}if(!c){s=1;break d}if(!Nc(b,w[d+208|4])){break d}vd(a,268435456);wg(a);v[a+480208>>2]=4;Db(a+1074312|0,114,1);e=d+88|0;j=Mb(e,15224);tb(a+1298344|0,j);pb(j);j=Mb(e,10243);tb(a+1298356|0,j);pb(j);v[a+1298404>>2]=5;_e(d+16|0,d+208|6,48,3);tc(e,v[d+16>>2],v[d+20>>2],w[d+24|0]);tb(a+1298308|0,e);pb(e);A=d+262|0;u[a+480188>>1]=w[A|0]+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];while(1){if(w[A|0]<=g>>>0){e:{n=d+300|0;u[a+480190>>1]=w[n|0];j=d+302|0;g=w[j|0]|w[j+1|0]<<8;e=d+192|0;h=sd(e);f:{g:{if(g){v[22452]=0;R(603,e|0,g|0);f=v[22452];v[22452]=0;if((f|0)==1){break g}mA(e,g)}break f}a=P()|0;O()|0;ec(h);S(a|0);L()}g=w[j|0]|w[j+1|0]<<8;v[22452]=0;j=e;U(598,b|0,e|0,g|0);e=v[22452];v[22452]=0;if((e|0)==1){break b}C=Pb(d+176|0);y=Pb(d+160|0);H=d+301|0;e=w[H|0];v[22452]=0;Y(366,b|0,C|0,e|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}e=w[n|0];v[22452]=0;Y(366,b|0,y|0,e|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}D=c&2;e=d+88|0;z=e|4;o=d+140|0;l=d+155|0;p=d+151|0;h=d+147|0;r=d+141|0;q=d+139|0;s=d+138|0;F=d+126|0;G=e|6;e=0;h:{while(1){g=e;if(e>>>0>=w[n|0]){s=1;if(!(c&1)){break e}v[d+68>>2]=0;i=a+484360|0;uc(Kb(i));K=d,M=wb(v[j>>2]),v[K+64>>2]=M;l=a+484344|0;c=d+88|0;D=c|5;p=c|4;F=wb(v[j+4>>2]);break h}v[22452]=0;e=g+1|0;i=B(e,104)+a|0;m=i+484380|0;R(271,m|0,0);f=v[22452];v[22452]=0;i:{if((f|0)!=1){f=Fb(v[y>>2],g);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);if(!f){continue}v[22452]=0;f=Q(146,b|0,f|0)|0;k=v[22452];v[22452]=0;j:{if((k|0)==1){break j}if(!f){continue}v[22452]=0;f=Q(599,b|0,d+88|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break j}if(!f){continue}Qe(d+72|0,2,G);v[22452]=0;W(213,d+16|0,v[d+72>>2],v[d+76>>2],w[d+80|0]);f=v[22452];v[22452]=0;if((f|0)==1){break c}f=d+16|0;sc(((e<<5)+a|0)+946304|0,f);pb(f);Zj(d+72|0,2,F);v[22452]=0;W(213,f|0,v[d+72>>2],v[d+76>>2],w[d+80|0]);f=v[22452];v[22452]=0;if((f|0)==1){break c}f=d+16|0;ke(i+484423|0,f);pb(f);if(w[s|0]<=15){f=i+484414|0;u[f>>1]=x[f>>1]|32;u[i+484408>>1]=B(w[s|0],17)}t[d+16|0]=w[q|0];t[d+72|0]=64;K=i+484412|0,M=w[Qb(d+16|0,d+72|0)|0],u[K>>1]=M;v[i+484404>>2]=w[r|0]|w[r+1|0]<<8;E=i+484384|0;k=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);v[E>>2]=k;I=i+484388|0;f=w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24);v[I>>2]=f;J=w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24);v[m>>2]=J;if(t[o|0]&1){k=k>>>1|0;v[E>>2]=k;f=f>>>1|0;v[I>>2]=f;v[m>>2]=J>>>1}k:{if(f>>>0<=k>>>0){break k}f=i+484414|0;i=x[f>>1];u[f>>1]=i|2;if(!(w[o|0]&2)){break k}u[f>>1]=i|6}ek(m);if(!D){continue}g=Fb(v[y>>2],g);g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);f=w[z|0];v[22452]=0;Q(146,b|0,g+f|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){break i}}break c}break c}g=Gc(d+16|0,t[o|0]&1?16:8,1,0,1);v[22452]=0;Y(210,g|0,m|0,b|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){continue}break}break c}while(1){l:{m:{c=v[d+64>>2];if(!Tb(c,F)){a=v[d+68>>2];b=a&63;if(!b){break m}c=Kb(i);v[22452]=0;a=a>>>6|0;c=Q(304,c|0,a&65535)|0;e=v[22452];v[22452]=0;if((e|0)!=1){if(!c){break m}a=Rb(l,x[Yb(v[Kb(i)>>2],a&65535)>>1]);v[22452]=0;R(600,a|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){break m}}break c}e=w[c+3|0];if(e>>>0>=w[H|0]){break l}z=c+2|0;if(w[z|0]>w[A|0]){break l}e=Fb(v[C>>2],e);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[22452]=0;e=Q(146,b|0,e|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break c}if(!e){break l}v[22452]=0;R(601,b|0,d+88|0);e=v[22452];v[22452]=0;if((e|0)==1){break c}if(!w[p|0]){break l}c=w[c|0]|w[c+1|0]<<8;t[d+16|0]=w[D|0];t[d+72|0]=w[A|0]-w[z|0];m=w[Qb(d+16|0,d+72|0)|0];v[d+60>>2]=c+w[p|0];K=d,M=v[Pc(d+68|0,d+60|0)>>2],v[K+68>>2]=M;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;g=c&63;o=c>>>6|0;k=0;while(1){if(w[p|0]<=k>>>0){break l}c=Kb(i);e=wc(v[c>>2],v[c+4>>2]);h=g>>>0>63;o=h+o|0;c=o&65535;if(e>>>0<=c>>>0){e=Kb(i);v[22452]=0;R(319,e|0,o+1&65535);e=v[22452];v[22452]=0;if((e|0)==1){break c}v[22452]=0;e=Y(356,l|0,64,0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break c}K=Yb(v[Kb(i)>>2],c),M=e,u[K>>1]=M}n=x[Yb(v[Kb(i)>>2],c)>>1];if(!he(l,n)){break l}e=0;r=h?0:g;g=Qc(Rb(l,n),r,w[z|0]);n:{while(1){if((e|0)==(m|0)){c=w[D|0];if(c>>>0<=m>>>0){break n}v[22452]=0;Q(179,b|0,B(c-m|0,5)|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break n}break c}v[22452]=0;R(602,d+72|0,b|0);c=v[22452];v[22452]=0;if((c|0)!=1){c=d+72|0;h=Zc(c);G=Me(c);q=vi(c);E=ac(c);f=0;c=w[c|0];if((c-1&255)>>>0<=142){f=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[(d+16|0)+e|0]=f}t[g|0]=f;c=w[h|0];t[g+2|0]=1;t[g+1|0]=c;c=w[G|0];o:{if((c|0)!=255){t[g+4|0]=c;break o}t[g+2|0]=0}c=w[q|0];p:{if(c>>>0>22){break p}t[g+3|0]=w[c+26992|0];h=w[E|0];t[g+5|0]=h;c=g+5|0;q:{switch(w[q|0]-4|0){case 3:t[c|0]=h&3|64;break p;case 4:t[c|0]=h&3|48;break p;case 7:f=v[j>>2];if(nc(f,v[j+4>>2])>>>0<=h>>>0){break p}q=c;c=Fb(f,h);c=w[c|0]|w[c+1|0]<<8;t[q|0]=c>>>6;h=Qc(Rb(l,n),r,x[a+480188>>1]-1&65535);t[h+5|0]=c&63;t[h+3|0]=14;break p;case 8:q=c;c=v[d+60>>2];t[q|0]=c>>>6;h=Qc(Rb(l,n),r,x[a+480188>>1]-1&65535);t[h+5|0]=c&63;t[h+3|0]=14;break p;case 10:t[c|0]=h&15|128;break p;case 12:t[d+15|0]=15;K=c,M=w[Qb(c,d+15|0)|0]|208,t[K|0]=M;break p;case 13:t[d+15|0]=15;K=c,M=w[Qb(c,d+15|0)|0]|192,t[K|0]=M;break p;case 14:t[d+15|0]=15;K=c,M=w[Qb(c,d+15|0)|0]|224,t[K|0]=M;break p;case 0:case 16:case 17:if(!(h&15)){break p}f=h&240;if(!f|(f|0)==240){break p}t[c|0]=h|15;break p;case 9:case 18:break q;default:break p}}if(f&255){break p}t[g|0]=w[(d+16|0)+e|0]}g=g+6|0;e=e+1|0;continue}break}break c}g=r+1|0;k=k+1|0;continue}}a=Kb(i);K=d,M=wb(v[a>>2]),v[K+88>>2]=M;b=wb(v[a+4>>2]);f=65535;while(1){a=v[d+88>>2];if(!Tb(a,b)){break e}if(x[a>>1]==65535){r:{if((f&65535)!=65535){break r}v[22452]=0;f=Y(356,l|0,64,0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break r}break c}u[a>>1]=f}Ke(d+88|0);continue}}te(d- -64|0);continue}}}else{u[((g<<5)+a|0)+480284>>1]=B(w[(d+g|0)+268|0],17);g=g+1|0;continue}break}ec(y);ec(C);ec(j)}ab=d+304|0;return s|0}g=P()|0;O()|0;ec(y);ec(C);break a}g=P()|0;O()|0}ec(j);S(g|0);L()}function kp(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;g=ab-16|0;ab=g;h=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:h;s=v[b+752>>2];k=w[b+802|0];a:{if(!k){rb(g+8|0,a+1074312|0,11);if(sb(v[v[g+8>>2]>>2],v[g+12>>2])){break a}}b:{c:{if(!h){break c}if(!Kc(k)){break c}d:{l=k-1|0;k=Yb(h+236|0,l);if(x[k>>1]){break d}rb(g+8|0,a+1074312|0,43);if(!sb(v[v[g+8>>2]>>2],v[g+12>>2])){break d}if(fj(w[h+31|0])){break d}v[b+656>>2]=h;break a}if(w[Cb(h+108|0,l)|0]>120){break a}k=x[k>>1];l=(k-1&65535)>>>0<3999?(B(k,104)+a|0)+484380|0:0;break b}l=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(k>>>0>250){break a}rb(g+8|0,a+1074312|0,43);if(sb(v[v[g+8>>2]>>2],v[g+12>>2])){if(h){l=0;if(fj(w[h+31|0])){break b}}t[b+803|0]=0;v[b+656>>2]=0;break a}l=0}k=v[b+104>>2];n=(k|0)!=0&(k|0)!=(l|0);j=v[b+656>>2];o=!h|v[a+480180>>2]!=16777216?o:v[h+44>>2]!=0;p=d^1;i=(h|0)!=(j|0);if((p|i|n)==1){u[b+774>>1]=0}r=!n;if(!(r|(i|!(d&o)))){break a}e:{if(!(d&n)){break e}k=a+1074312|0;rb(g+8|0,k,32);if(!(!sb(v[v[g+8>>2]>>2],v[g+12>>2])|!(w[a+480208|0]&8))){l=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:l}m=v[a+480180>>2];f:{if(!(h?i|!(m&1048580):1)|(m|0)==268435456){break f}if((m|0)==1){if(gi(v[b+8>>2],v[b+12>>2])){break f}}rb(g+8|0,k,79);if(!sb(v[v[g+8>>2]>>2],v[g+12>>2])){break e}if(!gi(v[b+8>>2],v[b+12>>2])){break e}}q=1}g:{if(!v[b+16>>2]|(!n|(i|!x[a+480192>>1]))){break g}rb(g+8|0,a+1074312|0,87);if(!sb(v[v[g+8>>2]>>2],v[g+12>>2])){break g}q=Kc(w[b+788|0])^1|q}h:{i:{j:{k:{l:{if(gi(v[b+8>>2],v[b+12>>2])|!(v[a+480180>>2]&16777248)){break l}if(h){if(fj(w[h+31|0])){break l}}k=1;break k}if(!(i|n)){break j}k=(h|0)!=(j|0)}if(!d){break i}rb(g+8|0,a+1074312|0,61);if(!sb(v[v[g+8>>2]>>2],v[g+12>>2])){break i}j=v[b+656>>2];if(!j){j=0;m=0;i=v[b+104>>2];if(!i){break i}break h}i=v[b+104>>2];m=0;break h}k=0}v[b+656>>2]=h;j=h;m=k;i=l}m:{if(!e){break m}n:{o:{p:{if(w[a+480180|0]&3){if(i){if(Fd(i)){break p}}if(!Kj(j)){break m}}if(!i){break o}}if(u[i+34>>1]<0){break m}h=x[i+30>>1];break n}h=0;if(!j|!w[j+34|0]){break n}h=v[b+656>>2];q:{if(h){h=v[h+4>>2]<<2;break q}h=v[b+688>>2]}}v[b+688>>2]=h}if(q){if(!((i|0)!=0&n)){break a}rb(g+8|0,a+1074312|0,85);if(sb(v[v[g+8>>2]>>2],v[g+12>>2])){u[b+772>>1]=t[i+37|0]}if(v[a+480180>>2]!=2){break a}if(!Fd(i)){break a}v[b+704>>2]=v[i+24>>2];break a}t[b+803|0]=0;r:{if(!j){break r}rb(g+8|0,a+1074312|0,29);if(z=0,A=(D=sb(v[v[g+8>>2]>>2],v[g+12>>2]),E=1,F=i,F?D:E),C=w[j+34|0]|m,C?z:A){break r}t[b+798|0]=w[j+16|0]}h=64;v[b+752>>2]=64;if(i){h=x[i+32>>1];v[b+752>>2]=h}if(j){v[b+752>>2]=B(v[j+4>>2],h)>>>6}s:{if(!(v[a+480180>>2]&1048580?e:1)){break s}rb(g+8|0,a+1074312|0,48);if(sb(v[v[g+8>>2]>>2],v[g+12>>2])){break s}lM(a,b,j,i)}t:{u:{v:{if(!f){break v}e=a+1074312|0;rb(g+8|0,e,19);w:{x:{y:{z:{A:{B:{C:{D:{if(sb(v[v[g+8>>2]>>2],v[g+12>>2])){if(!v[b+76>>2]){h=1;break C}if(!(!c|p)){h=(w[a+480208|0]&8)>>>3|0;if(h){break C}break D}h=0;if(c){break D}break C}c=v[a+480180>>2]&17301536;E:{if(!(!d|!c)){h=1;if(!v[b+76>>2]|w[a+480208|0]&8){break E}if(!(w[b+89|0]&16)){break z}h=!v[b+696>>2];break E}h=1;if(!c){break y}}if(!j|m){break A}if(!h){break z}h=v[b+88>>2];c=h&6144;break B}if(d){break C}if(!(w[b+89|0]&24)){h=0;break C}h=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|m){break A}if(!h){break z}h=v[b+88>>2];c=h&2048}v[b+88>>2]=h|2097152;if(!j){break w}if(c){break x}if(!(w[j+60|0]&8)){$i(b+724|0)}if(!(w[j+80|0]&8)){$i(b+732|0)}if(w[j+100|0]&8){break w}$i(b+740|0);break w}if(h){break y}}if(j){if(t[j+60|0]&1){break v}rb(g+8|0,e,32);if(sb(v[v[g+8>>2]>>2],v[g+12>>2])){$i(b+724|0);break v}Ml(b);break v}h=0;if(!i){break u}break t}v[b+88>>2]=v[b+88>>2]|2097152;if(!j){break w}}Ml(b)}rb(g+8|0,e,21);if(sb(v[v[g+8>>2]>>2],v[g+12>>2])){break v}t[b+818|0]=0;v[b+756>>2]=0}h=0;if(i){break t}if(!j){break u}h=1;if(fj(w[j+31|0])){break t}}v[b+752>>2]=0;v[b+104>>2]=0;break a}F:{G:{H:{I:{J:{if(!(!d|!i|v[b+104>>2]!=(i|0))){c=v[a+480180>>2];if(v[b+76>>2]?c&16777250:0){break a}if((c|0)!=4){break J}rb(g+8|0,a+1074312|0,40);if(!sb(v[v[g+8>>2]>>2],v[g+12>>2])|w[b+789|0]){break J}c=v[b+88>>2];break I}v[b+88>>2]=v[b+88>>2]&-6145;c=a+1074312|0;rb(g+8|0,c,18);K:{if(z=sb(v[v[g+8>>2]>>2],v[g+12>>2]),A=1,C=v[a+480180>>2]&16777248,C?z:A){e=-640;if(!(v[b+104>>2]!=(i|0)|m)){break K}}e=-768}v[b+88>>2]=e&v[b+88>>2];L:{if(!j){break L}t[b+730|0]=w[j+60|0];t[b+738|0]=w[j+80|0];t[b+746|0]=w[j+100|0];M:{if((w[j+100|0]&17)!=17){break M}rb(g+8|0,c,36);if(sb(v[v[g+8>>2]>>2],v[g+12>>2])|w[b+837|0]){break M}t[b+837|0]=127}c=w[j+21|0];if(wq(c)){z=b,A=xq(c),t[z+837|0]=A}c=w[j+22|0];if(!wq(c)){break L}z=b,A=xq(c),t[z+838|0]=A}if(h){break H}if(!d){break F}break G}c=v[b+88>>2]&-6145}v[b+88>>2]=c&-640;if(!h){break G}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break F}c=a+1074312|0;rb(g+8|0,c,54);if(!sb(v[v[g+8>>2]>>2],v[g+12>>2])){rb(g,c,39);if(!sb(v[v[g>>2]>>2],v[g+4>>2])){break F}}v[b+8>>2]=0;v[b+12>>2]=0}N:{if(w[b+788|0]!=255){break N}rb(g+8|0,a+1074312|0,100);if(!sb(v[v[g+8>>2]>>2],v[g+12>>2])|(!(v[a+480208>>2]&4)|r)){break N}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+752>>2]=s;v[b+688>>2]=x[i+30>>1];if(!(w[i+34|0]&32)){break a}xp(b,x[i+28>>1],a);break a}v[b+104>>2]=i;v[b+76>>2]=v[i>>2];v[b+80>>2]=v[i+4>>2];v[b+84>>2]=v[i+8>>2];e=a+1074312|0;rb(g+8|0,e,83);if(!(!sb(v[v[g+8>>2]>>2],v[g+12>>2])|v[b+80>>2])){v[b+84>>2]=v[i>>2]}v[b+88>>2]=v[b+88>>2]|x[i+34>>1]&1023;rb(g+8|0,e,21);if(sb(v[v[g+8>>2]>>2],v[g+12>>2])){t[b+818|0]=0;v[b+756>>2]=0}O:{P:{if(o){v[b+704>>2]=v[i+24>>2];t[b+851|0]=w[b+851|0]|64;c=0;break P}if(!(n|p)){d=v[a+480180>>2];if(d&5){break O}}v[b+704>>2]=v[i+24>>2];c=t[i+37|0]}u[b+772>>1]=c;d=v[a+480180>>2]}if(_l(d)){c=t[i+36|0]}else{c=0}u[b+770>>1]=c;rb(g+8|0,e,69);if(!(sb(v[v[g+8>>2]>>2],v[g+12>>2])|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+852>>2]=0;h=v[b+88>>2];if(h&8){v[b+80>>2]=v[i+12>>2];v[b+84>>2]=v[i+16>>2];h=h>>>2&4|h|2;v[b+88>>2]=h}Q:{if(!(h&2)){h=v[b+76>>2];break Q}h=v[b+76>>2];c=v[b+84>>2];if(h>>>0<=c>>>0){break Q}v[b+76>>2]=c;h=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<h>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}ab=g+16|0}function d9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=ab+-64|0;ab=i;v[22452]=0;e=T(169,b|0)|0;d=v[22452];v[22452]=0;a:{b:{c:{d:{if((d|0)==1){break d}e:{f:{if(e){d=0;f=Pb(i+48|0);g:{h:{i:{if(c&16){break i}v[22452]=0;j=(c|0)!=0;g=Y(798,f|0,b|0,j|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break e}e=4;j:{if(g){break j}v[22452]=0;g=Y(799,f|0,b|0,j|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break e}e=5;if(g){break j}v[22452]=0;g=Y(800,f|0,b|0,j|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break e}e=6;if(g){break j}g=0;v[22452]=0;j=Y(801,f|0,b|0,j|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break e}e=3;if(!j){break i}}if(!c){e=1;break h}g=v[f>>2];if(!jc(g,v[f+4>>2])){Uu(b,g+12|0)}g=e}e=0;if(c&32){break h}d=31552;k:{while(1){e=d;if((d|0)!=32068){j=v[e+8>>2];h=(j>>1)+a|0;d=v[e+4>>2];d=j&1?v[v[h>>2]+d>>2]:d;v[22452]=0;j=Y(d|0,h|0,b|0,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}d=e+12|0;if(!j){continue}break k}break}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){e=(e|0)!=32068;d=0;break h}if(!(v[a+480184>>2]|!g)){v[a+480184>>2]=g}v[22452]=0;d=1;R(741,a+1298264|0,1);g=v[22452];v[22452]=0;e=1;if((g|0)==1){break g}}kL(f);if(d){break f}break a}break c}v[22452]=0;R(240,a|0,0);d=v[22452];v[22452]=0;if((d|0)==1){break d}v[22452]=0;R(741,a+1298264|0,1);d=v[22452];v[22452]=0;if((d|0)==1){break d}v[a+1074304>>2]=19923456}e=0;while(1){if((e|0)==127){j=a+1298300|0;d=1;while(1){e=d&65535;if(e>>>0>x[a+480190>>1]){d=0;j=a+480180|0;e=0;l:{while(1){g=e&65535;if(g>>>0>x[a+480192>>1]){m:{u[a+480192>>1]=d;d=a+480204|0;if(y[a+480204>>2]>=1e4){break m}v[d>>2]=125e4;break l}}else{f=v[((g<<2)+a|0)+900380>>2];if(f){g=v[j>>2];mc(f,65536);mc(f+4|0,64);mc(f+8|0,256);lg(f+28|0,16384);jf(f+30|0,128);jf(f+31|0,17);if(w[f+16|0]>=4){t[f+16|0]=0}if(w[f+17|0]>=5){t[f+17|0]=0}if(w[f+18|0]>=3){t[f+18|0]=0}jf(f+19|0,64);jf(f+20|0,100);h=224;d=t[f+26|0];n:{if((d|0)>=-32){h=32;if((d|0)<33){break n}}t[f+26|0]=h}jf(f+23|0,64);jf(f+24|0,64);cz(f+48|0,64);cz(f+68|0,64);cz(f+88|0,(g|0)==4096?255:64);g=f+108|0;h=0;while(1){o:{if((h|0)==128){if(!bo(w[f+14|0])){t[f+14|0]=5}if(w[f+34|0]>=251){t[f+34|0]=0}break o}d=Cb(g,h);if((w[d|0]-121&255)>>>0<=135){t[d|0]=h+1}h=h+1|0;continue}break}d=e}e=e+1|0;continue}break}mc(d,65535e4)}if(!v[a+480196>>2]){v[a+480196>>2]=6}e=a+480220|0;d=v[a+480216>>2];if(d>>>0>y[a+480220>>2]){v[e>>2]=d}d=a+480216|0;mc(d,65536);mc(e,65536);mc(a+480200|0,256);p:{e=a+480248|0;if(!jc(v[e>>2],v[a+480252>>2])){d=v[d>>2];v[22452]=0;R(802,e|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break p}}v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];d=v[a+480220>>2];e=a+1074408|0;v[e>>2]=v[a+480216>>2];v[e+4>>2]=d;v[a+1074456>>2]=v[a+480200>>2];ty(a+1074376|0);d=a+1074446|0;u[d>>1]=0;u[d+2>>1]=0;u[d+4>>1]=0;u[d+6>>1]=65535;v[a+1074392>>2]=-2;d=a+1074384|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074380>>2]=0;d=a+1074424|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074432>>2]=0;d=a+1074396|0;v[d>>2]=0;v[d+4>>2]=0;if(_l(v[a+480180>>2])){v[22452]=0;Q(259,a+1074312|0,7)|0;d=v[22452];v[22452]=0;if((d|0)==1){break p}}u[a+480276>>1]=0;bp(a);d=a+484360|0;n=i,o=vg(d),v[n+48>>2]=o;e=ug(d);while(1){g=v[i+48>>2];if(!Tb(g,e)){q:{r:{j=v[a+480180>>2];if(j){ts(a+8|0,Rp(a));if(v[a+1074308>>2]){v[22452]=0;Z(803,a|0);d=v[22452];v[22452]=0;if((d|0)==1){break p}}l=Pb(i+48|0);s:{if((c&12)!=12){break s}g=a+1298464|0;e=0;t:{u:{v:{w:{x:{y:{while(1){if((e|0)==250){break s}f=B(e,160)+a|0;k=f+906300|0;d=k+16|0;z:{c=k+20|0;A:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)|(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)))){break A}v[22452]=0;R(804,k|0,a|0);c=v[22452];v[22452]=0;B:{if((c|0)!=1){h=v[k>>2];if(!h){break B}d=v[f+906448>>2];c=v[v[h>>2]+56>>2];v[22452]=0;R(c|0,h|0,d|0);c=v[22452];v[22452]=0;if((c|0)!=1){break A}}a=P()|0;O()|0;break q}m=wb(v[l>>2]);c=wb(v[l+4>>2]);h=ab-16|0;ab=h;v[h+8>>2]=m;while(1){C:{if(!Tb(m,c)){break C}d=v[m>>2];if((w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))==(w[k+20|0]|w[k+21|0]<<8|(w[k+22|0]<<16|w[k+23|0]<<24))){d=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==(w[k+16|0]|w[k+17|0]<<8|(w[k+18|0]<<16|w[k+19|0]<<24))}else{d=0}if(d){break C}te(h+8|0);m=v[h+8>>2];continue}break}ab=h+16|0;if(Tb(m,wb(v[l+4>>2]))){break A}v[22452]=0;v[i+32>>2]=f+906316;R(805,l|0,i+32|0);c=v[22452];v[22452]=0;if((c|0)==1){break z}v[22452]=0;d=Q(1,i+16|0,17645)|0;c=v[22452];v[22452]=0;if((c|0)==1){break y}v[22452]=0;R(806,i|0,k|0);c=v[22452];v[22452]=0;if((c|0)==1){break x}v[22452]=0;U(2,i+32|0,d|0,i|0);c=v[22452];v[22452]=0;if((c|0)==1){break w}c=v[g>>2];v[22452]=0;U(364,c|0,2,i+32|0);c=v[22452];v[22452]=0;if((c|0)==1){break v}pb(i+32|0);pb(i);pb(d)}e=e+1|0;continue}break}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;break u}a=P()|0;O()|0;pb(i+32|0)}pb(i)}pb(d);break q}c=w[a+1074368|0];v[22452]=0;R(807,a|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break r}ec(l)}e=(j|0)!=0;break a}a=P()|0;O()|0}ec(l);break b}v[22452]=0;Z(808,g|0);d=v[22452];v[22452]=0;if((d|0)!=1){if(wc(v[g>>2],v[g+4>>2])>>>0<=x[g+28>>1]){Re(g,0)}_y(i+48|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}h=B(e,104)+a|0;f=h+484380|0;D:{if(Fd(f)){ii(f,a);break D}g=h+484414|0;e=x[g>>1];if(e&16384){break D}v[f>>2]=0;v[f+4>>2]=0;v[f+16>>2]=0;v[f+8>>2]=0;v[f+12>>2]=0;u[g>>1]=e&65505}e=h+484412|0;if(x[e>>1]>=65){u[e>>1]=64}E:{F:{if(!(w[h+484415|0]&2)){break F}if(!Oj(j)){break F}v[22452]=0;Z(809,a|0);e=v[22452];v[22452]=0;if((e|0)==1){break E}}d=d+1|0;continue}break}a=P()|0;O()|0;break b}g=(e<<5)+a|0;lg(g+480286|0,64);d=g+480284|0;if(x[d>>1]>=257){u[d>>1]=128}d=g+480288|0;if(w[d|0]>=251){t[d|0]=0}Dn((B(e,872)+a|0)+1074992|0,a,e&65535,134217728);e=e+1|0;continue}}break c}a=P()|0;O()|0;break b}a=P()|0;O()|0;kL(f)}qb(b);S(a|0);L()}qb(b);ab=i- -64|0;return e|0}function Mda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=ab-272|0;ab=d;qc(b);f=ab-16|0;ab=f;j=d+120|0;WP(f+8|0,j);g=v[f+12>>2];_b(f,b,v[f+8>>2],g);h=v[f+4>>2];if((h|0)==(g|0)){Ob(b,v[f+12>>2])}ab=f+16|0;f=(g|0)==(h|0);if(!f){VP(j)}a:{b:{c:{d:{if(!f){break d}if(!XP(d+120|0)){break d}if(!c){l=1;break d}vd(a,4194304);f=d+32|0;g=Mb(f,16982);tb(a+1298344|0,g);pb(g);g=Mb(f,10098);tb(a+1298356|0,g);pb(g);v[a+1298404>>2]=5;n=a,o=Ld(w[d+198|0]|w[d+199|0]<<8,w[d+200|0]|w[d+201|0]<<8,127),u[n+480188>>1]=o;g=w[d+189|0];v[a+480228>>2]=(g|0)==255?48:g;v[a+480196>>2]=w[d+187|0];v[a+480204>>2]=B(w[d+188|0],1e4);_e(d+96|0,d+120|4,59,3);tc(f,v[d+96>>2],v[d+100>>2],w[d+104|0]);tb(a+1298308|0,f);pb(f);f=w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24);e:{if(f>>>0<5){break e}if(!Nc(b,f-4|0)){break e}if(!oh(b,14230)){break e}Vn(Kb(a+484360|0),b,w[d+192|0]|w[d+193|0]<<8,65535,65535)}f:{f=w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24);if(f>>>0<5){break f}if(!Nc(b,f-4|0)){break f}if(!oh(b,13763)){break f}while(1){if((e|0)==32){break f}f=(e<<5)+a|0;Le(f+480280|0);n=f+480284|0,o=((((ue(b)^-1)&15)<<8|8)>>>0)/15|0,u[n>>1]=o;e=e+1|0;continue}}e=w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24);g:{if(e>>>0<5){break g}if(!Nc(b,e-4|0)){break g}if(!oh(b,14087)){break g}e=d+32|0;Md(e,b,(w[d+196|0]|w[d+197|0]<<8)<<6);k=c&2;j=a+480190|0;g=bc(d+96|0,e);qb(e);l=d+45|0;e=0;h:{while(1){if((e&65535)>>>0>=(w[d+196|0]|w[d+197|0]<<8)>>>0){break h}v[22452]=0;f=Q(629,g|0,d+32|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break b}if(!f){break h}f=w[d+77|0]|w[d+78|0]<<8;u[d+30>>1]=f;i:{j:{if((f-1&65535)>>>0>3998){break j}f=(B(f,104)+a|0)+484380|0;if(Fd(f)){break j}n=j,o=x[Ne(j,d+30|0)>>1],u[n>>1]=o;v[22452]=0;R(630,d+32|0,f|0);f=v[22452];v[22452]=0;if((f|0)==1){break i}_e(d,l,24,1);v[22452]=0;W(213,d+16|0,v[d>>2],v[d+4>>2],w[d+8|0]);f=v[22452];v[22452]=0;if((f|0)==1){break b}f=d+16|0;sc(((x[d+30>>1]<<5)+a|0)+946304|0,f);pb(f);if(!k){break j}f=w[d+69|0]|w[d+70|0]<<8|(w[d+71|0]<<16|w[d+72|0]<<24);v[22452]=0;Q(146,b|0,f|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break i}f=1;i=d+16|0;h=d+79|0;m=Gc(i,w[h|0]&4?16:8,1,0,0);h=w[h|0];k:{l:{if(h&8){break l}f=2;if(h&16){break l}if(h&127){break k}}nf(m,f)}v[22452]=0;Y(210,i|0,(B(x[d+30>>1],104)+a|0)+484380|0,b|0)|0;f=v[22452];v[22452]=0;if((f|0)!=1){break j}break b}e=e+1|0;continue}break}break b}qb(g)}l=1;if(!(c&1)){break d}m:{c=w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24);if(c>>>0<5){break m}if(!Nc(b,c-4|0)){break m}if(!oh(b,13613)){break m}h=a+484344|0;fg(h,w[d+194|0]|w[d+195|0]<<8);k=d+16|2;f=0;while(1){if((w[d+194|0]|w[d+195|0]<<8)>>>0<=f>>>0){break m}if(!eA(b,d+16|0)){break m}n:{e=w[d+16|0]|w[d+17|0]<<8;if(e>>>0>3){c=d+96|0;Md(c,b,(e+15&131056)-4|0);g=bc(d+32|0,c);qb(c);c=w[k|0];v[22452]=0;c=Y(217,h|0,f&65535,c|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break n}j=0;o:{if(!c){break o}while(1){p:{v[22452]=0;c=Q(147,d+32|0,1)|0;e=v[22452];v[22452]=0;q:{if((e|0)!=1){e=w[k|0];if(!(c&e>>>0>(j&255)>>>0)){break p}v[22452]=0;e=T(197,g|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}if(e){break q}j=j+1|0;continue}break c}c=Rb(h,f);u[d+96>>1]=e&31;u[d>>1]=x[a+480188>>1]-1;c=Qc(c,j,x[Lc(d+96|0,d)>>1]);if(e&128){v[22452]=0;R(254,d+96|0,g|0);i=v[22452];v[22452]=0;if((i|0)==1){break c}i=d+96|0;t[c|0]=w[i|0]+36;n=c,o=w[Zc(i)|0],t[n+1|0]=o}if(e&64){t[c+2|0]=1;v[22452]=0;i=T(197,g|0)|0;m=v[22452];v[22452]=0;if((m|0)==1){break c}t[d+96|0]=i;t[d|0]=64;n=c,o=w[Qb(d+96|0,d)|0],t[n+4|0]=o}if(!(e&32)){continue}v[22452]=0;R(254,d+96|0,g|0);e=v[22452];v[22452]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((e|0)!=1){e=w[Zc(d+96|0)|0];t[c+5|0]=e;switch(w[d+96|0]-1|0){case 71:break s;case 70:break t;case 69:break u;case 60:break v;case 59:break w;case 52:break x;case 51:break y;case 50:break z;case 49:break A;case 42:break B;case 41:break C;case 40:break D;case 39:break E;case 30:break F;case 29:break G;case 22:break H;case 21:break I;case 20:break J;case 19:break K;case 16:break L;case 15:break M;case 14:break N;case 13:break O;case 12:break P;case 11:break Q;case 10:break R;case 9:break S;case 3:break T;case 2:break U;case 1:break V;case 0:break W;default:break r}}break c}t[c+3|0]=11;t[c+5|0]=e<<4|15;continue}t[c+3|0]=11;t[c+5|0]=e<<4;continue}t[c+3|0]=11;t[c+5|0]=e|240;continue}t[c+3|0]=11;t[c+5|0]=e&15;continue}t[c+3|0]=2;t[c+5|0]=e|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=e|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=e|16;continue}t[c+3|0]=6;t[c+5|0]=e<<4;continue}t[c+3|0]=6;t[c+5|0]=e&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=e|48;continue}t[c+3|0]=7;t[c+5|0]=e<<4;continue}t[c+3|0]=7;t[c+5|0]=e&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=e|64;continue}t[c+3|0]=10;v[22452]=0;e=T(197,g|0)|0;i=v[22452];v[22452]=0;if((i|0)!=1){t[c+5|0]=e;v[22452]=0;Q(179,d+32|0,1)|0;c=v[22452];v[22452]=0;if((c|0)!=1){continue}}break c}t[c+3|0]=15;t[c+5|0]=e&15;continue}t[c+3|0]=20;t[c+5|0]=e|192;continue}t[c+3|0]=20;t[c+5|0]=e|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=e|176;continue}t[c+3|0]=20;t[c+5|0]=e|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=e&15|32;continue}t[c+3|0]=20;t[c+5|0]=e&15|128;continue}t[c+3|0]=0;continue}break}if((e|0)==64){break o}je(Rb(h,f),mh(Ae(ve(d+96|0,14,0),w[k|0]-1|0)))}qb(d+32|0)}f=f+1|0;continue}break}break c}c=w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24);if(!c){break d}Nc(b,c);VA(a+1298332|0,b,xg(b),4)}ab=d+272|0;return l|0}e=P()|0;O()|0;qb(d+32|0);break a}e=P()|0;O()|0;qb(g)}S(e|0);L()}function G$(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0;m=ab-560|0;ab=m;v[m+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){x=1;A=5257;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){x=1;A=5260;break a}x=e&1;A=x?5263:5258;F=!x}b:{if((g&2146435072)==2146435072){d=x+3|0;uf(a,32,c,d,e&-65537);df(a,A,x);f=f&32;df(a,b!=b?f?9939:13768:f?11044:14130,3);uf(a,32,c,d,e^8192);i=(c|0)>(d|0)?c:d;break b}z=m+16|0;c:{d:{e:{b=DG(b,m+44|0);b=b+b;if(b!=0){g=v[m+44>>2];v[m+44>>2]=g-1;u=f|32;if((u|0)!=97){break e}break c}u=f|32;if((u|0)==97){break c}l=v[m+44>>2];n=(d|0)<0?6:d;break d}l=g-29|0;v[m+44>>2]=l;b=b*268435456;n=(d|0)<0?6:d}r=(l|0)<0?m+48|0:m+336|0;h=r;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}v[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;k=r;break f}k=r;d=l;while(1){d=d>>>0<29?d:29;g=h-4|0;g:{if(k>>>0>g>>>0){break g}i=0;while(1){q=v[g>>2];p=d&31;C=i;if((d&63)>>>0>=32){i=q<<p;q=0}else{i=(1<<p)-1&q>>>32-p;q=q<<p}p=C+q|0;i=i+E|0;i=p>>>0<q>>>0?i+1|0:i;i=ria(p,i,1e9,0);q=oia(i,db,-1e9,-1)+p|0;v[g>>2]=q;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;v[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[m+44>>2]-d|0;v[m+44>>2]=d;h=g;if((d|0)>0){continue}break}}h=(n+25>>>0)/9|0;if((d|0)<0){y=h+1|0;p=(u|0)==102;while(1){d=0-d|0;i=d>>>0<9?d:9;h:{if(g>>>0>k>>>0){q=1e9>>>i|0;E=-1<<i^-1;d=0;h=k;while(1){C=d;d=v[h>>2];v[h>>2]=C+(d>>>i|0);d=B(q,d&E);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=v[k>>2];if(!d){break h}v[g>>2]=d;g=g+4|0;break h}h=v[k>>2]}d=i+v[m+44>>2]|0;v[m+44>>2]=d;k=(!h<<2)+k|0;h=p?r:k;g=g-h>>2>(y|0)?h+(y<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=k>>>0){break i}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break i}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=(n-((u|0)==102?0:d)|0)-((u|0)==103&(n|0)!=0)|0;if((h|0)<(B(g-r>>2,9)-9|0)){i=h+9216|0;p=(i|0)/9|0;l=((((l|0)<0?4:292)+m|0)+(p<<2)|0)-4048|0;h=10;i=i+B(p,-9)|0;if((i|0)<=7){while(1){h=B(h,10);i=i+1|0;if((i|0)!=8){continue}break}}p=v[l>>2];y=(p>>>0)/(h>>>0)|0;i=B(y,h);p=p-i|0;q=l+4|0;j:{if(!p&(q|0)==(g|0)){break j}k:{if(!(y&1)){b=9007199254740992;if(!(t[l-4|0]&1)|((h|0)!=1e9|k>>>0>=l>>>0)){break k}}b=9007199254740994}s=(g|0)==(q|0)?1:1.5;q=h>>>1|0;s=p>>>0<q>>>0?.5:(q|0)==(p|0)?s:1.5;if(!(w[A|0]!=45|F)){s=-s;b=-b}v[l>>2]=i;if(b+s==b){break j}d=h+i|0;v[l>>2]=d;if(d>>>0>=1e9){while(1){v[l>>2]=0;l=l-4|0;if(l>>>0<k>>>0){k=k-4|0;v[k>>2]=0}d=v[l>>2]+1|0;v[l>>2]=d;if(d>>>0>999999999){continue}break}}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break j}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){h=g;i=g>>>0<=k>>>0;if(!i){g=h-4|0;if(!v[g>>2]){continue}}break}l:{if((u|0)!=103){l=e&8;break l}g=n?n:1;l=(g|0)>(d|0)&(d|0)>-5;n=(l?d^-1:-1)+g|0;f=(l?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(i){break m}p=v[h-4>>2];if(!p){break m}i=10;g=0;if((p>>>0)%10|0){break m}while(1){l=g;g=g+1|0;i=B(i,10);if(!((p>>>0)%(i>>>0)|0)){continue}break}g=l^-1}i=B(h-r>>2,9);if((f&-33)==70){l=0;g=(g+i|0)-9|0;g=(g|0)>0?g:0;n=(g|0)>(n|0)?n:g;break l}l=0;g=((d+i|0)+g|0)-9|0;g=(g|0)>0?g:0;n=(g|0)>(n|0)?n:g}i=-1;u=l|n;if(((u?2147483645:2147483646)|0)<(n|0)){break b}p=(((u|0)!=0)+n|0)+1|0;q=f&-33;n:{if((q|0)==70){if((2147483647-p|0)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=Vm(g+d^g,0,z);if((z-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((z-g|0)<2){continue}break}}y=g-2|0;t[y|0]=f;t[g-1|0]=(d|0)<0?45:43;g=z-y|0;if((g|0)>(2147483647-p|0)){break b}}d=g+p|0;if((d|0)>(x^2147483647)){break b}f=d+x|0;uf(a,32,c,f,e);df(a,A,x);uf(a,48,c,f,e^65536);o:{p:{q:{if((q|0)==70){g=m+16|0;d=g|8;l=g|9;i=k>>>0>r>>>0?r:k;k=i;while(1){g=Vm(v[k>>2],0,l);r:{if((i|0)!=(k|0)){if(m+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}t[m+24|0]=48;g=d}df(a,g,l-g|0);k=k+4|0;if(r>>>0>=k>>>0){continue}break}if(u){df(a,16715,1)}if((n|0)<=0|h>>>0<=k>>>0){break q}while(1){g=Vm(v[k>>2],0,l);if(g>>>0>m+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}}df(a,g,(n|0)<9?n:9);g=n-9|0;k=k+4|0;if(h>>>0<=k>>>0){break p}d=(n|0)>9;n=g;if(d){continue}break}break p}s:{if((n|0)<0){break s}i=h>>>0>k>>>0?h:k+4|0;d=m+16|0;r=d|9;d=d|8;h=k;while(1){g=Vm(v[h>>2],0,r);if((r|0)==(g|0)){t[m+24|0]=48;g=d}t:{if((h|0)!=(k|0)){if(m+16>>>0>=g>>>0){break t}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break t}df(a,g,1);g=g+1|0;if(!(l|n)){break t}df(a,16715,1)}C=g;g=r-g|0;df(a,C,(g|0)<(n|0)?g:n);n=n-g|0;h=h+4|0;if(i>>>0<=h>>>0){break s}if((n|0)>=0){continue}break}}uf(a,48,n+18|0,18,0);df(a,y,z-y|0);break o}g=n}uf(a,48,g+9|0,9,0)}uf(a,32,c,f,e^8192);i=(c|0)>(f|0)?c:f;break b}n=(f<<26>>31&9)+A|0;u:{if(d>>>0>11){break u}g=12-d|0;s=16;while(1){s=s*16;g=g-1|0;if(g){continue}break}if(w[n|0]==45){b=-(s+(-b-s));break u}b=b+s-s}l=x|2;k=f&32;h=v[m+44>>2];g=h>>31;g=Vm(g^g+h,0,z);if((z|0)==(g|0)){t[m+15|0]=48;g=m+15|0}r=g-2|0;t[r|0]=f+15;t[g-1|0]=(h|0)<0?45:43;i=e&8;h=m+16|0;while(1){f=h;if(D(b)<2147483648){g=~~b}else{g=-2147483648}t[h|0]=k|w[g+73088|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i|(d|0)>0)&b==0|(h-(m+16|0)|0)!=1)){t[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}i=-1;p=z-r|0;f=p+l|0;if((2147483645-f|0)<(d|0)){break b}v:{w:{if(!d){break w}k=h-(m+16|0)|0;if((k-2|0)>=(d|0)){break w}g=d+2|0;break v}k=h-(m+16|0)|0;g=k}d=g+f|0;uf(a,32,c,d,e);df(a,n,l);uf(a,48,c,d,e^65536);df(a,m+16|0,k);uf(a,48,g-k|0,0,0);df(a,r,p);uf(a,32,c,d,e^8192);i=(c|0)>(d|0)?c:d}ab=m+560|0;return i|0}function Vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ab-208|0;ab=e;qc(c);a:{if(!Wn(c,e+192|0)){break a}if(Ib(e+192|0,13794,4)){break a}h=e+200|0;if(Ib(h,14163,4)){if(Ib(h,14267,4)){break a}}g=ab-32|0;ab=g;i=e+176|0;f=Ye(i);b:{c:{d:{e:{f:{while(1){v[22452]=0;j=Q(147,c|0,8)|0;k=v[22452];v[22452]=0;if((k|0)==1){break d}if(!j){break e}v[22452]=0;R(763,g|0,c|0);j=v[22452];v[22452]=0;if((j|0)!=1){v[22452]=0;R(764,f|0,g|0);j=v[22452];v[22452]=0;if((j|0)==1){break f}Tc(g);continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;Tc(g);break c}ab=g+32|0;break b}a=P()|0;O()|0}Rd(f);S(a|0);L()}v[22452]=0;U(687,e+152|0,i|0,1129270605);c=v[22452];v[22452]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){v[22452]=0;c=Q(688,e+152|0,e+128|0)|0;g=v[22452];v[22452]=0;n:{o:{if((g|0)!=1){if(!c){break g}g=e+128|2;if(!Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))){break g}if((Ab(w[e+128|0]|w[e+129|0]<<8)-3&65535)>>>0<65534){break g}f=e+128|6;if((Ab(w[f|0]|w[f+1|0]<<8)-65&65535)>>>0<65472){break g}v[e+124>>2]=1162760014;c=1;if(!Ib(h,14267,4)){v[22452]=0;c=Q(572,e+152|0,e+124|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break o}if(!c){break g}c=v[e+124>>2]!=1936684916}v[22452]=0;U(687,e+104|0,e+176|0,1397968452);h=v[22452];v[22452]=0;p:{q:{if((h|0)!=1){v[22452]=0;l=Q(689,e+104|0,e+96|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break p}if(l){break q}break h}c=P()|0;O()|0;break j}h=((Ab(w[f|0]|w[f+1|0]<<8)-1|0)/8|0)-1|0;i=h<<3;f=i&31;f=Gc(e+88|0,(h>>>0<7?(i&63)>>>0>=32?4196360>>>f|0:((1<<f)-1&4196360)<<32-f|136321040>>>f:8)&255,(Ab(w[e+128|0]|w[e+129|0]<<8)|0)==2?2:1,c,0);c=v[e+124>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}nf(f,3);break r}nf(f,17);vh(f,16);break r}nf(f,16);vh(f,16);break r}nf(f,1)}if(d){XM(f)}c=w[e+96|0]|w[e+97|0]<<8|(w[e+98|0]<<16|w[e+99|0]<<24);v[22452]=0;c=Q(147,e+104|0,Wb(c)|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break l}if(c){c=w[e+96|0]|w[e+97|0]<<8|(w[e+98|0]<<16|w[e+99|0]<<24);v[22452]=0;Q(179,e+104|0,Wb(c)|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break l}}Ls(a,b);v[22452]=0;c=B(b,104)+a|0;h=c+484380|0;R(271,h|0,0);d=v[22452];v[22452]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((d|0)==1){break D}n=h,o=Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24)),v[n>>2]=o;j=c+484404|0;d=0;c=e+128|0;g=w[c+13|0]|(w[c+11|0]<<16|w[c+10|0]<<24|w[c+12|0]<<8);i=30-w[c+9|0]|0;while(1){c=g;if(i&255){g=c>>>1|0;i=i-1|0;d=c;continue}break}v[j>>2]=c+(d&1);v[22452]=0;Y(210,f|0,h|0,e+104|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break D}v[22452]=0;U(687,e- -64|0,e+176|0,1296126539);c=v[22452];v[22452]=0;if((c|0)==1){break C}v[22452]=0;c=T(169,e- -64|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break B}if(!c){break u}v[22452]=0;U(687,e+16|0,e+176|0,1229869908);c=v[22452];v[22452]=0;if((c|0)==1){break A}v[22452]=0;c=Q(690,e+16|0,e+40|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break z}qb(e+16|0);if(!c){break u}v[22452]=0;d=T(265,e- -64|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break y}g=Pb(e+16|0);v[22452]=0;R(691,g|0,d|0);c=v[22452];v[22452]=0;if((c|0)==1){break w}i=e|6;c=0;while(1){if((c|0)==(d|0)){break x}v[22452]=0;f=Q(692,e- -64|0,e|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break w}if(!f){break x}v[22452]=0;R(693,g|0,e|0);f=v[22452];v[22452]=0;if((f|0)==1){break w}f=w[i|0];v[22452]=0;Q(179,e- -64|0,f+((f^-1)&1)|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break w}c=c+1|0;continue}}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break m}c=P()|0;O()|0;break m}c=P()|0;O()|0;qb(e+16|0);break m}c=P()|0;O()|0;break m}if(Ab(w[e+48|0]|w[e+49|0]<<8)){c=(B(b,104)+a|0)+484414|0;d=x[c>>1]|8;u[c>>1]=d;n=c,o=d&65519|((Ab(w[e+48|0]|w[e+49|0]<<8)|0)==2)<<4,u[n>>1]=o}if(Ab(w[e+54|0]|w[e+55|0]<<8)){c=(B(b,104)+a|0)+484414|0;d=x[c>>1]|2;u[c>>1]=d;n=c,o=d&65531|((Ab(w[e+54|0]|w[e+55|0]<<8)|0)==2)<<2,u[n>>1]=o}n=e,o=wb(v[g>>2]),v[n>>2]=o;c=B(b,104)+a|0;f=c+484388|0;i=c+484384|0;j=c+484396|0;k=c+484392|0;m=wb(v[g+4>>2]);while(1){d=v[e>>2];if(!Tb(d,m)){break v}c=Ab(w[d|0]|w[d+1|0]<<8);if((c|0)==(Ab(w[e+50|0]|w[e+51|0]<<8)|0)){n=k,o=Wb(w[d+2|0]|w[d+3|0]<<8|(w[d+4|0]<<16|w[d+5|0]<<24)),v[n>>2]=o;c=Ab(w[d|0]|w[d+1|0]<<8)}if((Ab(w[e+52|0]|w[e+53|0]<<8)|0)==(c|0)){n=j,o=Wb(w[d+2|0]|w[d+3|0]<<8|(w[d+4|0]<<16|w[d+5|0]<<24)),v[n>>2]=o;c=Ab(w[d|0]|w[d+1|0]<<8)}if((Ab(w[e+56|0]|w[e+57|0]<<8)|0)==(c|0)){n=i,o=Wb(w[d+2|0]|w[d+3|0]<<8|(w[d+4|0]<<16|w[d+5|0]<<24)),v[n>>2]=o;c=Ab(w[d|0]|w[d+1|0]<<8)}if((c|0)==(Ab(w[e+58|0]|w[e+59|0]<<8)|0)){n=f,o=Wb(w[d+2|0]|w[d+3|0]<<8|(w[d+4|0]<<16|w[d+5|0]<<24)),v[n>>2]=o}v[e>>2]=v[e>>2]+7;continue}}c=P()|0;O()|0;TM(g);break m}ek(h);TM(g)}v[22452]=0;U(687,e+16|0,e+176|0,1312902469);c=v[22452];v[22452]=0;if((c|0)==1){break n}v[22452]=0;c=T(169,e+16|0)|0;d=v[22452];v[22452]=0;E:{if((d|0)==1){break E}F:{if(c){v[22452]=0;c=T(151,e+16|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break E}v[22452]=0;U(307,e+16|0,((b<<5)+a|0)+946304|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){break F}break E}v[22452]=0;c=Q(55,e|0,21598)|0;d=v[22452];v[22452]=0;if((d|0)==1){break E}sc(((b<<5)+a|0)+946304|0,c);pb(c)}Ws(h,v[a+480180>>2]);ii(h,a);qb(e+16|0);qb(e- -64|0);break h}c=P()|0;O()|0;qb(e+16|0);break m}c=P()|0;O()|0;break k}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break m}c=P()|0;O()|0;break i}qb(e- -64|0);break k}c=P()|0;O()|0}qb(e+104|0)}qb(e+152|0)}Rd(e+176|0);S(c|0);L()}qb(e+104|0)}qb(e+152|0);Rd(e+176|0)}ab=e+208|0;return l|0}function wda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0;e=ab-224|0;ab=e;qc(b);a:{if(!st(b,e+160|0)){break a}if(!yP(e+160|0)){break a}if(!Hb(b,Fc(xP(e+160|0),db))){break a}if(!c){d=1;break a}vd(a,256);lj(e+144|0,2,e+160|0);d=e+48|0;tc(d,v[e+144>>2],v[e+148>>2],w[e+152|0]);tb(a+1298308|0,d);pb(d);h=e+210|0;g=w[h|0]|w[h+1|0]<<8;v[a+480260>>2]=64;v[a+480264>>2]=32767;u[a+480188>>1]=4;u[a+480190>>1]=g;Db(a+1074312|0,107,1);g=w[e+203|0];g=g?g:96;l=xz(g);v[a+480196>>2]=g>>>4;v[a+480204>>2]=l;t[e+48|0]=64;D=a,E=w[Qb(e+202|0,d)|0]<<2,v[D+480200>>2]=E;d=0;b:{c:{d:{e:{f:{g:{while(1){if((d|0)==4){h:{l=Pb(e+144|0);o=Pb(e+128|0);d=e+192|0;d=w[d|0]|w[d+1|0]<<8;v[22452]=0;Q(146,b|0,d<<4)|0;d=v[22452];v[22452]=0;i:{if((d|0)==1){break i}n=e+208|0;d=w[n|0]|w[n+1|0]<<8;v[22452]=0;Y(208,b|0,l|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break i}d=e+194|0;d=w[d|0]|w[d+1|0]<<8;v[22452]=0;Q(146,b|0,d<<4)|0;d=v[22452];v[22452]=0;if((d|0)==1){break i}d=w[h|0]|w[h+1|0]<<8;v[22452]=0;Y(208,b|0,o|0,d|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break i}d=e+196|0;d=w[d|0]|w[d+1|0]<<8;v[22452]=0;Q(146,b|0,(d<<4)+32|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break i}g=a+484360|0;d=Kb(g);f=e+212|0;f=w[f|0]|w[f+1|0]<<8;v[22452]=0;R(319,d|0,f|0);d=v[22452];v[22452]=0;if((d|0)==1){break i}d=Kb(g);D=e,E=wb(v[d>>2]),v[D+48>>2]=E;d=wb(v[d+4>>2]);j:{while(1){f=v[e+48>>2];if(!Tb(f,d)){d=0;if(!AP(Kb(g))){break b}k=c&2;g=e- -64|0;m=e+48|1;d=1;break j}v[22452]=0;k=T(197,b|0)|0;m=v[22452];v[22452]=0;k:{if((m|0)==1){break k}u[f>>1]=k;v[22452]=0;Q(179,b|0,4)|0;f=v[22452];v[22452]=0;if((f|0)==1){break k}Ke(e+48|0);continue}break}d=P()|0;O()|0;break c}l:{m:{n:{o:{while(1){f=d&65535;if(f>>>0>(w[h|0]|w[h+1|0]<<8)>>>0){break l}i=Yb(v[o>>2],f-1|0);i=w[i|0]|w[i+1|0]<<8;v[22452]=0;i=Q(146,b|0,i<<4)|0;j=v[22452];v[22452]=0;p:{if((j|0)!=1){if(i){break p}d=0;break b}d=P()|0;O()|0;break c}v[22452]=0;Q(638,b|0,e+48|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break o}v[22452]=0;i=(B(f,104)+a|0)+484380|0;U(639,e+48|0,i|0,0);j=v[22452];v[22452]=0;if((j|0)==1){break o}Zj(e+16|0,2,m);v[22452]=0;W(213,e+32|0,v[e+16>>2],v[e+20>>2],w[e+24|0]);j=v[22452];v[22452]=0;if((j|0)==1){break n}j=((f<<5)+a|0)+946304|0;f=e+32|0;sc(j,f);pb(f);f=NP(e+48|0);q:{r:{if(!k|!(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))){break r}v[22452]=0;f=Q(146,b|0,f|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break m}if(!f){break r}f=e+32|0;MP(f,e+48|0,1);v[22452]=0;Y(210,f|0,i|0,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break q}}d=d+1|0;continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}t[e+15|0]=1;d=v[l>>2];s:{if(jc(d,v[l+4>>2])){break s}h=e+188|0;if((w[h|0]|w[h+1|0]<<8)==26){break s}g=w[d|0]|w[d+1|0]<<8;d=0;v[22452]=0;g=Q(146,b|0,g<<4)|0;f=v[22452];v[22452]=0;if((f|0)==1){break h}if(!g){break b}v[22452]=0;d=T(185,b|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break h}if((d|0)!=(w[h|0]|w[h+1|0]<<8)){break s}t[e+15|0]=0}i=c&1;if(i){c=w[n|0]|w[n+1|0]<<8;v[22452]=0;R(216,a+484344|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break h}}m=a+484344|0;c=e+48|0;j=c|5;q=c|3;r=c|4;s=c|2;y=c|1;z=a+480188|0;h=0;while(1){t:{if(!i|(w[n|0]|w[n+1|0]<<8)>>>0<=h>>>0){break t}v[22452]=0;c=Y(217,m|0,h&65535,64)|0;d=v[22452];v[22452]=0;if((d|0)==1){break g}if(!c){break t}c=Yb(v[l>>2],h);c=w[c|0]|w[c+1|0]<<8;v[22452]=0;c=Q(146,b|0,c<<4)|0;d=v[22452];v[22452]=0;if((d|0)==1){break g}d=0;if(!c){break b}if(!w[e+15|0]){v[22452]=0;c=T(185,b|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break g}if(c>>>0>2112){break b}}u[e+16>>1]=65535;v[e+32>>2]=63;u:while(1){A=Of(Rb(m,h),d);v:while(1){c=d;while(1){if(c>>>0<=63){v[22452]=0;k=T(197,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break f}if(!k){d=64;if(c>>>0>62){continue v}d=c+1|0;continue u}C=Fh(e+48|0);g=k&31;d=g>>>0<x[z>>1];g=B(g,6)+A|0;if(k&32){v[22452]=0;R(254,e+8|0,b|0);f=v[22452];v[22452]=0;w:{x:{y:{if((f|0)!=1){f=e+8|0;p=Zc(f);f=w[f|0];if(f>>>0>239){break y}f=LP((B(f>>>4|0,12)+(f&15)|0)+37|0);break x}d=P()|0;O()|0;break c}z:{switch(f-254|0){case 0:break x;case 1:break z;default:break w}}f=0}t[(d?g:e+48|0)|0]=f}t[(d?g+1|0:y)|0]=w[p|0]}if(k&64){v[22452]=0;f=T(197,b|0)|0;p=v[22452];v[22452]=0;if((p|0)==1){break e}t[e+8|0]=f;t[(d?g+2|0:s)|0]=1;t[e+7|0]=64;D=d?g+4|0:r,E=w[Qb(e+8|0,e+7|0)|0],t[D|0]=E}if(!(k&128)){continue}v[22452]=0;R(254,e+8|0,b|0);f=v[22452];v[22452]=0;if((f|0)==1){break d}f=e+8|0;t[(d?g+3|0:q)|0]=w[f|0];D=d?g+5|0:j,E=w[Zc(f)|0],t[D|0]=E;zP(d?g:C,c,255,e+16|0,e+32|0);continue}break}break}break}c=x[e+16>>1];if((c|0)!=65535){je(Rb(m,h),dm(Ae(ve(e+48|0,12,c&255),v[e+32>>2])))}h=h+1|0;continue}break}v[22452]=0;b=Q(1,e+48|0,6049)|0;c=v[22452];v[22452]=0;A:{B:{C:{if((c|0)!=1){tb(a+1298344|0,b);pb(b);v[22452]=0;b=Q(1,e+48|0,5235)|0;c=v[22452];v[22452]=0;if((c|0)==1){break C}tb(a+1298356|0,b);pb(b);v[a+1298404>>2]=5;v[22452]=0;R(641,e+32|0,4366);b=v[22452];v[22452]=0;if((b|0)==1){break B}v[22452]=0;U(298,e+48|0,e+32|0,e+15|0);b=v[22452];v[22452]=0;if((b|0)==1){break A}b=a+1298368|0;a=e+48|0;tb(b,a);pb(a);yb(e+32|0);d=1;break b}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;yb(e+32|0);break c}d=P()|0;O()|0;break c}}else{g=(d<<5)+a|0;Le(g+480280|0);u[g+480284>>1]=d&1?64:192;d=d+1|0;continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0}_c(o);_c(l);S(d|0);L()}_c(o);_c(l)}ab=e+224|0;return d|0}function Nga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;f=ab-208|0;ab=f;if(oh(b,13809)){if(d){t[d|0]=1}m=a+480216|0;n=a+480220|0;o=a+480224|0;k=a+1074368|0;q=a+480228|0;r=a+480232|0;p=a+480200|0;s=a+484360|0;l=a+480268|0;z=a+1298320|0;A=a+480248|0;C=It(a+1074312|0);D=a+480180|0;E=a+480190|0;a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Hb(b,7)){break a}d=jg(b);e=xg(b);if((d|0)==(w[21574]|w[21575]<<8|(w[21576]<<16|w[21577]<<24))){gg(b,6);break a}if(!(d&1616928864)|d&-2139062144){break a}if(!Hb(b,e)){break a}h=f+24|0;Md(h,b,e);g=bc(f+184|0,h);qb(h);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((d|0)!=1127099950){if((d|0)==1129797166){break w}if((d|0)==1130917459){break o}if((d|0)==1145525806){break s}if((d|0)==1448301654){break t}if((d|0)==1196316499){break m}if((d|0)==1213486401){break p}if((d|0)==1280530262){break v}if((d|0)==1297303086){break l}if((d|0)==1347243310){break x}if((d|0)==1347244882){break q}z:{if((d|0)!=1380340804){if((d|0)==1380986414){break r}if((d|0)==1380991534){break z}if((d|0)==1380994350){break k}if((d|0)==1397052739){break n}if((d|0)==1397768494){break u}if((d|0)==1414344238){break y}if((d|0)!=1146367534){break j}v[22452]=0;U(398,g|0,e|0,f+24|0);d=v[22452];v[22452]=0;if((d|0)==1){break i}v[a+480204>>2]=B(v[f+24>>2],1e4)+(y[a+480204>>2]%1e4|0);break j}v[22452]=0;U(398,g|0,e|0,f+24|0);d=v[22452];v[22452]=0;if((d|0)!=1){d=v[a+480204>>2];v[a+480204>>2]=d-((d>>>0)%1e4|0)+y[f+24>>2]%1e4;break j}e=P()|0;O()|0;break b}v[22452]=0;U(398,g|0,e|0,m|0);d=v[22452];v[22452]=0;if((d|0)!=1){break j}break c}if(c){break j}v[22452]=0;u[f+24>>1]=0;U(399,g|0,e|0,f+24|0);d=v[22452];v[22452]=0;if((d|0)!=1){F=a,G=Ld(x[f+24>>1],x[a+480188>>1],127),u[F+480188>>1]=G;break j}e=P()|0;O()|0;break b}v[22452]=0;U(400,g|0,e|0,o|0);d=v[22452];v[22452]=0;if((d|0)==1){break c}break j}v[22452]=0;U(401,g|0,e|0,k|0);d=v[22452];v[22452]=0;if((d|0)==1){break c}break j}v[22452]=0;v[f+24>>2]=0;U(398,g|0,e|0,f+24|0);d=v[22452];v[22452]=0;if((d|0)!=1){v[a+1074304>>2]=v[f+24>>2];break j}e=P()|0;O()|0;break b}v[22452]=0;v[f+24>>2]=0;U(398,g|0,e|0,f+24|0);d=v[22452];v[22452]=0;if((d|0)==1){break h}d=v[f+24>>2];if(!d){break j}v[a+1074308>>2]=d;break j}v[22452]=0;U(398,g|0,e|0,q|0);d=v[22452];v[22452]=0;if((d|0)==1){break c}break j}v[22452]=0;U(398,g|0,e|0,r|0);d=v[22452];v[22452]=0;if((d|0)==1){break c}break j}v[22452]=0;U(398,g|0,e|0,p|0);d=v[22452];v[22452]=0;if((d|0)==1){break c}break j}if(v[D>>2]==4){break j}v[22452]=0;U(399,g|0,e|0,f+24|0);d=v[22452];v[22452]=0;if((d|0)!=1){Re(Kb(s),x[f+24>>1]);break j}e=P()|0;O()|0;break b}v[22452]=0;U(402,g|0,e|0,l|0);d=v[22452];v[22452]=0;if((d|0)==1){break c}if(bo(w[l|0])){break j}t[l|0]=5;break j}d=Bb(f+24|0);v[22452]=0;e=T(151,f+184|0)|0;h=v[22452];v[22452]=0;A:{if((h|0)==1){break A}v[22452]=0;U(403,g|0,d|0,e|0);e=v[22452];v[22452]=0;if((e|0)==1){break A}v[22452]=0;U(11,f+168|0,0,d|0);e=v[22452];v[22452]=0;if((e|0)==1){break A}e=f+168|0;tb(z,e);pb(e);pb(d);break j}e=P()|0;O()|0;pb(d);break b}if(e&1|e>>>0>126){break j}d=64;u[f+24>>1]=(e>>>1|0)- -64;u[f+168>>1]=127;e=x[Lc(f+24|0,f+168|0)>>1];i=e>>>0>64?e:64;while(1){if((d|0)==(i|0)){break j}v[22452]=0;R(254,f+24|0,g|0);e=v[22452];v[22452]=0;if((e|0)==1){break g}B:{if(w[f+24|0]==255){break B}h=w[Zc(f+24|0)|0];e=(d<<5)+a|0;j=e+480284|0;u[j>>1]=128;u[e+480286>>1]=h;h=e+480280|0;v[h>>2]=0;v[h>>2]=(w[f+24|0]&128)<<3;e=w[f+24|0]&127;t[f+24|0]=e;if(e>>>0<65){u[j>>1]=e<<2;e=w[f+24|0]}if((e&255)!=100){break B}v[h>>2]=v[h>>2]|256}d=d+1|0;continue}}if(e>>>0<3){break j}v[22452]=0;d=T(185,g|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break f}if(!d|d>>>0>x[E>>1]){break j}d=(B(d,104)+a|0)+484448|0;h=nS(d);while(1){if((d|0)==(h|0)){break j}v[22452]=0;i=Q(147,f+184|0,4)|0;e=v[22452];v[22452]=0;C:{if((e|0)!=1){e=268435456;if(!i){break C}v[22452]=0;e=T(148,g|0)|0;i=v[22452];v[22452]=0;if((i|0)!=1){break C}}e=P()|0;O()|0;break b}v[d>>2]=e;d=d+4|0;continue}}if(e>>>0<3){break j}v[22452]=0;R(404,f+8|0,f+184|0);d=v[22452];v[22452]=0;D:{E:{F:{G:{if((d|0)!=1){v[22452]=0;U(405,f+168|0,v[f+8>>2],v[f+12>>2]);d=v[22452];v[22452]=0;if((d|0)==1){break G}v[22452]=0;d=Q(80,f+24|0,f+168|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break F}pb(f+168|0);Xb(f+8|0);v[22452]=0;e=T(151,f+184|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break D}v[22452]=0;U(406,f+24|0,A|0,e|0);e=v[22452];v[22452]=0;if((e|0)==1){break D}ef(d);break j}e=P()|0;O()|0;break b}e=P()|0;O()|0;break E}e=P()|0;O()|0;pb(f+168|0)}Xb(f+8|0);break b}e=P()|0;O()|0;ef(d);break b}e=0;h=It(C);H:while(1){v[22452]=0;d=Q(147,f+184|0,1)|0;i=v[22452];v[22452]=0;if((i|0)==1){break d}if(!(d&e>>>0<117)){break j}v[22452]=0;i=T(197,g|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue H}I:{if(!(i>>>d&1)|e>>>0>116){break I}v[22452]=0;Y(258,h|0,e|0,1)|0;j=v[22452];v[22452]=0;if((j|0)!=1){break I}e=P()|0;O()|0;break b}e=e+1|0;d=d+1|0;continue}}}v[22452]=0;U(398,g|0,e|0,n|0);d=v[22452];v[22452]=0;if((d|0)==1){break c}}qb(f+184|0);continue}break}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}qb(f+184|0);S(e|0);L()}b=v[a+8>>2];jo(a+480204|0,B(v[b+20>>2],1e4),B(v[b+24>>2],1e4));if(w[a+480224|0]>=3){t[o|0]=0}if(w[k|0]>=6){t[k|0]=0}mc(p,256);mc(m,65536);mc(n,65536)}ab=f+208|0}function BG(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0,D=0,E=0,F=0;i=ab-80|0;ab=i;v[i+76>>2]=b;D=i+55|0;s=i+56|0;b=0;a:{b:{c:{d:{e:while(1){if((2147483647-o|0)<(b|0)){break d}o=b+o|0;f:{g:{h:{k=v[i+76>>2];b=k;h=w[b|0];if(h){while(1){i:{h=h&255;j:{if(!h){h=b;break j}if((h|0)!=37){break i}h=b;while(1){if(w[b+1|0]!=37){break j}j=b+2|0;v[i+76>>2]=j;h=h+1|0;l=w[b+2|0];b=j;if((l|0)==37){continue}break}}b=h-k|0;C=2147483647-o|0;if((b|0)>(C|0)){break d}if(a){df(a,k,b)}if(b){continue e}r=-1;h=1;b=v[i+76>>2];j=t[b+1|0];if(!(!Dj(j)|w[b+2|0]!=36)){r=j-48|0;y=1;h=3}b=h+b|0;v[i+76>>2]=b;p=0;m=t[b|0];j=m-32|0;k:{if(j>>>0>31){h=b;break k}h=b;j=1<<j;if(!(j&75913)){break k}while(1){h=b+1|0;v[i+76>>2]=h;p=j|p;m=t[b+1|0];j=m-32|0;if(j>>>0>=32){break k}b=h;j=1<<j;if(j&75913){continue}break}}l:{if((m|0)==42){b=t[h+1|0];m:{if(!(!Dj(b)|w[h+2|0]!=36)){v[((b<<2)+e|0)-192>>2]=10;m=h+3|0;q=v[((t[h+1|0]<<3)+d|0)-384>>2];y=1;break m}if(y){break h}m=h+1|0;if(!a){v[i+76>>2]=m;y=0;q=0;break l}b=v[c>>2];v[c>>2]=b+4;q=v[b>>2];y=0}v[i+76>>2]=m;if((q|0)>=0){break l}q=0-q|0;p=p|8192;break l}q=AG(i+76|0);if((q|0)<0){break d}m=v[i+76>>2]}b=0;l=-1;n:{if(w[m|0]!=46){j=m;h=0;break n}if(w[m+1|0]==42){h=t[m+2|0];o:{if(!(!Dj(h)|w[m+3|0]!=36)){v[((h<<2)+e|0)-192>>2]=10;j=m+4|0;l=v[((t[m+2|0]<<3)+d|0)-384>>2];break o}if(y){break h}j=m+2|0;l=0;if(!a){break o}h=v[c>>2];v[c>>2]=h+4;l=v[h>>2]}v[i+76>>2]=j;h=(l^-1)>>>31|0;break n}v[i+76>>2]=m+1;l=AG(i+76|0);j=v[i+76>>2];h=1}z=h;while(1){n=b;h=28;x=j;if(t[j|0]-123>>>0<4294967238){break c}j=x+1|0;v[i+76>>2]=j;b=w[(t[x|0]+B(n,58)|0)+72559|0];if(b-1>>>0<8){continue}break}p:{q:{if((b|0)!=27){if(!b){break c}if((r|0)>=0){v[(r<<2)+e>>2]=b;b=(r<<3)+d|0;h=v[b+4>>2];v[i+64>>2]=v[b>>2];v[i+68>>2]=h;break q}if(!a){break f}zG(i- -64|0,b,c,g);break p}if((r|0)>=0){break c}}b=0;if(!a){continue e}}m=p&-65537;j=p&8192?m:p;p=0;r=5247;h=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{b=t[x|0];b=n?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(b-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((b|0)==83){break w}break g}n=v[i+64>>2];k=v[i+68>>2];r=5247;break z}b=0;I:{switch(n&255){case 0:v[v[i+64>>2]>>2]=o;continue e;case 1:v[v[i+64>>2]>>2]=o;continue e;case 2:h=v[i+64>>2];v[h>>2]=o;v[h+4>>2]=o>>31;continue e;case 3:u[v[i+64>>2]>>1]=o;continue e;case 4:t[v[i+64>>2]]=o;continue e;case 6:v[v[i+64>>2]>>2]=o;continue e;case 7:break I;default:continue e}}h=v[i+64>>2];v[h>>2]=o;v[h+4>>2]=o>>31;continue e}l=l>>>0>8?l:8;j=j|8;b=120}m=s;E=b&32;n=v[i+64>>2];k=v[i+68>>2];if(n|k){while(1){m=m-1|0;t[m|0]=E|w[(n&15)+73088|0];F=!k&n>>>0>15|(k|0)!=0;x=k;k=k>>>4|0;n=(x&15)<<28|n>>>4;if(F){continue}break}}k=m;if(!(j&8)|!(v[i+64>>2]|v[i+68>>2])){break y}r=(b>>>4|0)+5247|0;p=2;break y}b=s;n=v[i+64>>2];k=v[i+68>>2];if(n|k){while(1){b=b-1|0;t[b|0]=n&7|48;x=!k&n>>>0>7|(k|0)!=0;m=k;k=m>>>3|0;n=(m&7)<<29|n>>>3;if(x){continue}break}}k=b;if(!(j&8)){break y}b=s-k|0;l=(b|0)<(l|0)?l:b+1|0;break y}b=v[i+68>>2];k=b;n=v[i+64>>2];if((b|0)<0){k=0-(k+((n|0)!=0)|0)|0;n=0-n|0;v[i+64>>2]=n;v[i+68>>2]=k;p=1;r=5247;break z}if(j&2048){p=1;r=5248;break z}p=j&1;r=p?5249:5247}k=Vm(n,k,s)}if((l|0)<0?z:0){break d}j=z?j&-65537:j;m=v[i+64>>2];b=v[i+68>>2];if(!((m|b)!=0|l)){k=s;h=k;l=0;break g}b=!(b|m)+(s-k|0)|0;l=(b|0)<(l|0)?l:b;break g}b=v[i+64>>2];k=b?b:17016;b=k;h=(l|0)<0?2147483647:l;j=Jt(b,0,h);b=j?j-b|0:h;h=b+k|0;if((l|0)>=0){j=m;l=b;break g}j=m;l=b;if(w[h|0]){break d}break g}if(l){h=v[i+64>>2];break u}b=0;uf(a,32,q,0,j);break t}v[i+12>>2]=0;v[i+8>>2]=v[i+64>>2];h=i+8|0;v[i+64>>2]=h;l=-1}b=0;J:{while(1){k=v[h>>2];if(!k){break J}k=yG(i+4|0,k);m=(k|0)<0;if(!(m|k>>>0>l-b>>>0)){h=h+4|0;b=b+k|0;if(l>>>0>b>>>0){continue}break J}break}if(m){break b}}h=61;if((b|0)<0){break c}uf(a,32,q,b,j);if(!b){b=0;break t}k=0;h=v[i+64>>2];while(1){l=v[h>>2];if(!l){break t}l=yG(i+4|0,l);k=l+k|0;if(k>>>0>b>>>0){break t}df(a,i+4|0,l);h=h+4|0;if(b>>>0>k>>>0){continue}break}}uf(a,32,q,b,j^8192);b=(b|0)<(q|0)?q:b;continue e}if((l|0)<0?z:0){break d}h=61;b=eb[f|0](a,A[i+64>>3],q,l,j,b)|0;if((b|0)>=0){continue e}break c}t[i+55|0]=v[i+64>>2];l=1;k=D;j=m;break g}j=b+1|0;v[i+76>>2]=j;h=w[b+1|0];b=j;continue}}if(a){break a}if(!y){break f}b=1;while(1){a=v[(b<<2)+e>>2];if(a){zG((b<<3)+d|0,a,c,g);o=1;b=b+1|0;if((b|0)!=10){continue}break a}break}o=1;if(b>>>0>=10){break a}h=0;while(1){if(h){break h}b=b+1|0;if((b|0)==10){break a}h=v[(b<<2)+e>>2];continue}}h=28;break c}m=h-k|0;n=(l|0)<(m|0)?m:l;if((n|0)>(2147483647-p|0)){break d}h=61;l=n+p|0;b=(l|0)>(q|0)?l:q;if((C|0)<(b|0)){break c}uf(a,32,b,l,j);df(a,r,p);uf(a,48,b,l,j^65536);uf(a,48,n,m,0);df(a,k,m);uf(a,32,b,l,j^8192);continue}break}o=0;break a}h=61}v[114934]=h}o=-1}ab=i+80|0;return o}function Ada(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=ab-336|0;ab=d;Nc(b,60);i=15;a:{if(!oh(b,14115)){Nc(b,124);i=31;if(!oh(b,15275)){break a}}vd(a,536870912);u[a+480190>>1]=i;qc(b);b:{while(1){if(x[a+480190>>1]>f>>>0){h=hm(b);v[(d+208|0)+(f<<2)>>2]=h;f=f+1|0;if(h>>>0<=131072){continue}break b}break}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;f=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;lh(a,1);Ob(b,4);h=hq(b);if(h>>>0<178){break a}p=a,q=xe(1776930/+(h>>>0)*1e4),v[p+480204>>2]=q;Ob(b,14);j=d+62|0;i=0;l=1;c:while(1){o=l&65535;if(o>>>0<=x[a+480190>>1]){f=d+40|0;OQ(b,f);e=v[((o<<2)+d|0)+204>>2];m=ab-16|0;ab=m;k=(B(o,104)+a|0)+484380|0;ed(k,1);v[k>>2]=e;t[k+37|0]=w[f+24|0]<<4;t[m+15|0]=w[f+25|0];t[m+14|0]=64;p=k,q=w[Qb(m+15|0,m+14|0)|0]<<2,u[p+30>>1]=q;h=f+26|0;g=Ab(w[h|0]|w[h+1|0]<<8);d:{if(!e){break d}h=f+28|0;h=w[h|0]|w[h+1|0]<<8;v[k+4>>2]=g;h=(Ab(h)<<1)+g|0;v[k+8>>2]=h;if(e>>>0<=g>>>0){g=e-1|0;v[k+4>>2]=g}if(e>>>0<h>>>0){v[k+8>>2]=e;h=e}if(!(!(h>>>0<4|g>>>0>h>>>0)&h-g>>>0>3)){v[k+4>>2]=0;v[k+8>>2]=0;break d}if(g>>>0>=h>>>0){break d}u[k+34>>1]=x[k+34>>1]|2}ab=m+16|0;while(1)if((f|0)==(j|0)){if(i>>>0>127){break b}gl(d+176|0,3,d+40|0);h=d+192|0;tc(h,v[d+176>>2],v[d+180>>2],w[d+184|0]);sc(((o<<5)+a|0)+946304|0,h);l=l+1|0;pb(h);continue c}else{if((w[f|0]-1&255)>>>0<=30){t[f|0]=32;i=i+1|0}f=f+1|0;continue}}break}i=1;e:{f:{g:{f=a+946336|0;h=Mb(d+40|0,13982);if(!GP(f,h)){v[22452]=0;e=Q(55,d+192|0,13993)|0;i=v[22452];v[22452]=0;if((i|0)==1){break g}i=GP(f,e);pb(e)}pb(h);f=0;h=d+40|0;e=NQ(b,h);if(!e){Iz(h)}if(!e){break a}if(!JP(d+40|0)){break a}if(!c){break e}u[d+38>>1]=0;while(1){h=w[d+40|0];if(h>>>0<=f>>>0){e=a+484360|0;g=Kb(e);f=d+40|0;k=w[f|1];Re(g,h>>>0>k>>>0?k:0);cq(Kb(e),f|2,w[d+40|0]);if(x[a+480190>>1]==31){Ob(b,4)}v[d+32>>2]=0;v[d+28>>2]=0;v[d+24>>2]=0;t[d+23|0]=0;m=c&1;if(m){fg(a+484344|0,x[d+38>>1])}k=a+484344|0;l=0;while(1){h:{i:{j:{if(x[d+38>>1]<=l>>>0){if(!(c&2)){break j}f=1;while(1){i=x[a+480190>>1];c=f&65535;if(i>>>0<c>>>0){break i}c=(B(c,104)+a|0)+484380|0;if(v[c>>2]){eg(Gc(d+192|0,8,1,0,0),c,b)}f=f+1|0;continue}}k:{if(m){h=0;if(Vg(k,l&65535,64)){break k}}Ob(b,1024);break h}l:while(1){if((h|0)==64){break h}f=0;o=Qc(Rb(k,l),h,0);while(1)if((f|0)==4){h=h+1|0;continue l}else{g=d+192|0;nm(g,b);e=o+B(f,6)|0;m:{n:{o:{p:{if(w[Cb(g,0)|0]!=255){break p}t[(d+32|0)+f|0]=0;t[(d+24|0)+f|0]=0;g=Cb(d+192|0,1);j=w[g|0];if((j|0)==252&i){t[g|0]=254;break n}switch(j-252|0){case 1:break m;case 2:break n;case 0:break o;default:break p}}g=v[d+192>>2];v[d+16>>2]=g;v[d+8>>2]=g;Nt(d+8|0,e);g=w[e|0];q:{if(!g){break q}t[(d+24|0)+f|0]=0;t[(d+32|0)+f|0]=g;if(g>>>0>48){break q}t[d+176|0]=8;p=d,q=w[$e(d+23|0,d+176|0)|0],t[p+23|0]=q}r:{s:{t:{u:{v:{w:{switch(w[e+3|0]){case 1:t[e+3|0]=1;break m;case 2:g=w[e+5|0];if(g&240){t[e+3|0]=3;t[e+5|0]=g>>>4;break m}g=g&15;if(g){t[e+3|0]=2;t[e+5|0]=g;break m}t[e+5|0]=0;break s;case 3:if(w[(d+24|0)+f|0]){break t}t[e+3|0]=19;t[e+5|0]=0;break m;case 4:if(w[(d+24|0)+f|0]){break t}t[e+3|0]=19;t[e+5|0]=1;break m;case 5:if(!w[e+1|0]){break t}t[e+3|0]=13;t[d+176|0]=63;t[d+15|0]=w[e+5|0]+(x[(B(w[e+1|0],104)+a|0)+484410>>1]>>>2|0);p=e,q=w[Qb(d+176|0,d+15|0)|0],t[p+5|0]=q;if(!w[(d+24|0)+f|0]){break v}t[e+2|0]=1;t[e+4|0]=w[e+5|0];t[e+5|0]=0;break s;case 6:g=w[e+1|0];if(!g){break t}t[e+3|0]=13;g=x[(B(g,104)+a|0)+484410>>1]>>>2|0;j=w[e+5|0];g=g>>>0<j>>>0?0:g-j|0;t[e+5|0]=g;if(!w[(d+24|0)+f|0]){break m}t[e+4|0]=g;t[e+2|0]=1;t[e+5|0]=0;break s;case 7:g=w[(d+32|0)+f|0];j=w[e+5|0];n=g-(j>>>4|0)|0;t[(d+28|0)+f|0]=n;t[e+3|0]=3;j=j&15;t[(d+24|0)+f|0]=j;p=e,q=FP(j,n&255,g),t[p+5|0]=q;break m;case 8:j=w[(d+32|0)+f|0];g=w[e+5|0];n=j+(g>>>4|0)|0;t[(d+28|0)+f|0]=n;t[e+3|0]=2;g=g&15;t[(d+24|0)+f|0]=g;p=e,q=FP(g,j,n&255),t[p+5|0]=q;break m;case 0:break u;case 9:break w;default:break s}}t[d+176|0]=8;p=d,q=w[$e(d+23|0,d+176|0)|0],t[p+23|0]=q;break s}if(!w[e+3|0]){break r}break m}if(!w[e+5|0]){break r}break s}t[e+5|0]=0}t[e+3|0]=0}j=w[(d+24|0)+f|0];if(!j){break m}n=(d+28|0)+f|0;g=w[n|0];if(g){t[(d+32|0)+f|0]=g;t[e|0]=g;t[e+5|0]=j;t[n|0]=0}t[e+3|0]=4;break m}t[e+3|0]=14;t[d+23|0]=9;break m}t[e+3|0]=13}f=f+1|0;continue}}}i=x[a+480190>>1]}x:{y:{if((i&65535)==15){b=d+176|0;af(b,4379);v[22452]=0;U(298,d+192|0,b|0,d+23|0);b=v[22452];v[22452]=0;if((b|0)!=1){break y}i=P()|0;O()|0;yb(d+176|0);break f}v[22452]=0;Q(1,d+192|0,12296)|0;b=v[22452];v[22452]=0;if((b|0)==1){break x}}b=d+192|0;tb(a+1298344|0,b);pb(b);if((i&65535)==15){yb(d+176|0)}pl(a+1298356|0,x[a+480190>>1]==15?5243:15092);v[a+1298404>>2]=2;break e}i=P()|0;O()|0;break f}l=l+1|0;continue}}else{u[d+192>>1]=w[(d+f|0)+42|0]+1;p=d,q=x[Ne(d+38|0,d+192|0)>>1],u[p+38>>1]=q;f=f+1|0;continue}}}i=P()|0;O()|0;pb(h)}S(i|0);L()}f=1;break a}f=0}ab=d+336|0;return f|0}function Nea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0;d=ab-1824|0;ab=d;qc(b);e=ab-16|0;ab=e;h=d+1224|0;KQ(e+8|0,h);j=b;b=v[e+12>>2];_b(e,j,v[e+8>>2],b);i=v[e+4>>2];if((i|0)==(b|0)){Ob(j,v[e+12>>2])}ab=e+16|0;b=(b|0)==(i|0);if(!b){JQ(h)}a:{if(!b){break a}if(!LQ(d+1224|0)){break a}if(!Nz(j,16,0)){break a}v[d+1216>>2]=v[d+1240>>2];b=v[d+1228>>2];v[d+1200>>2]=v[d+1224>>2];v[d+1204>>2]=b;b=d+1232|0;e=v[b+4>>2];v[d+1208>>2]=v[b>>2];v[d+1212>>2]=e;vd(a,1);Db(Db(Cf(a+1074312|0,83),84,1),85,1);u[a+480188>>1]=4;v[d+1196>>2]=0;u[a+480190>>1]=15;Nc(j,20);k=a+480188|0;g=1;i=1;while(1){b:{if((g|0)==16){b=d+1064|0;TQ(j,b);n=a+484360|0;cq(Kb(n),b|2,128);g=0;o=SQ(j,Kb(n),w[b|0],f,k,0,1);e=b|1;if(!(w[b|0]?1:w[e|0]|o>>>0>1)){break a}if(Ze(j)+65536>>>0<(o<<10)+f>>>0){break a}if(c){break b}g=1;break a}e=B(g,104)+a|0;h=e+484380|0;b=((g<<5)+a|0)+946304|0;Oz(j,d+16|0,h,b,1);l=v[h>>2];c:{if(!w[Cb(b,0)|0]){break c}d:{if(Ib(b,16717,3)){if(Ib(b,16721,3)){break d}}if(w[Cb(b,5)|0]==58){break c}}i=0}if(Ab(w[d+44|0]|w[d+45|0]<<8)>>>0>=2){y=e+484384|0,z=Ab(w[d+42|0]|w[d+43|0]<<8),v[y>>2]=z;y=e+484388|0,z=Ab(w[d+42|0]|w[d+43|0]<<8)+(Ab(w[d+44|0]|w[d+45|0]<<8)<<1)|0,v[y>>2]=z;ek(h)}e:{if(Ab(w[d+38|0]|w[d+39|0]<<8)>>>0<=4999){if(Ab(w[d+42|0]|w[d+43|0]<<8)>>>0<1e4){break e}}v[d+1064>>2]=5;y=d,z=v[Ee(d+1196|0,d+1064|0)>>2],v[y+1196>>2]=z}f=f+l|0;g=g+1|0;continue}break}if(!w[e|0]){t[e|0]=120}if(!Ib(d+1200|0,14904,6)){t[e|0]=120}v[a+480204>>2]=125e4;b=w[e|0];f:{if((b|0)==120){break f}y=a,z=xe(1773447.5/(+(240-b|0)*122)*1e4),v[y+480204>>2]=z;if(v[d+1196>>2]>=2){v[d+16>>2]=i&1?4:5;y=d,z=v[Ee(d+1196|0,d+16|0)>>2],v[y+1196>>2]=z;break f}v[d+16>>2]=i&1?1:2;y=d,z=v[Ee(d+1196|0,d+16|0)>>2],v[y+1196>>2]=z}v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|2097152;lj(d+1048|0,3,d+1200|0);b=d+16|0;tc(b,v[d+1048>>2],v[d+1052>>2],w[d+1056|0]);tb(a+1298308|0,b);pb(b);lh(a,0);r=i&1;s=v[j+8>>2];i=0;l=0;while(1){u[d+1046>>1]=i;g:{if((i&65535)>>>0<o>>>0){b=Kb(n);b=Tb(Hz(vg(b),ug(b),d+1046|0),ug(b));IQ(j,d+16|0);h:{if(b){l=Lz(d+16|0,0)+l|0;if(l>>>0>512){break h}}k=0;b=0;f=0;i:while(1){if((f|0)==64){break g}g=0;x=Hc(d+16|0,f);while(1){e=b;if((g|0)==4){f=f+1|0;continue i}else{p=Fb(x,g);m=w[Cb(p,2)|0]&15;h=w[Cb(p,3)|0];b=0;j:{if(!(e&255)){break j}if(Ib(p,26884,4)){break j}b=e+1|0;if((b&255)>>>0<33){break j}v[d+1196>>2]=6}k:{l:{m:{switch(m-1|0){case 0:case 1:e=v[d+1196>>2];if((e|0)==1&h>>>0>=32){break l}m=(m|0)!=1;if(!(m|!h|h>>>0>2)){v[d+1048>>2]=2;y=d,z=v[Ee(d+1196|0,d+1048|0)>>2],v[y+1196>>2]=z;break k}if(m|(h|0)!=55&(h|0)!=71){break k}if((e|0)<=2){break l}break k;case 10:v[d+1196>>2]=6;break k;case 11:case 12:case 13:v[d+1048>>2]=2;y=d,z=v[Ee(d+1196|0,d+1048|0)>>2],v[y+1196>>2]=z;if((m|0)!=13){break k}k=((f|h)!=0)+k|0;b=1;break k;case 14:break m;default:break k}}v[d+1048>>2]=3;y=d,z=v[Ee(d+1196|0,d+1048|0)>>2],v[y+1196>>2]=z;break k}v[d+1196>>2]=r}g=g+1|0;continue}}}}g=0;break a}if(!(v[d+1196>>2]!=6|o+32>>>0>=q>>>0)){v[d+1196>>2]=5}Nc(j,s);n=c&1;if(n){fg(a+484344|0,o)}m=a+484344|0;i=0;while(1){if((i|0)==(o|0)){g=21598;b=v[d+1196>>2];if(b>>>0<7){g=v[(b<<2)+26896>>2]}b=d+16|0;f=Mb(b,8291);tb(a+1298344|0,f);pb(f);b=Mb(b,10717);tb(a+1298356|0,b);pb(b);pl(a+1298368|0,g);v[a+1298404>>2]=2;g=1;if(!(c&2)){break a}c=1;while(1){if((c|0)==16){break a}b=B(c,104)+a|0;f=b+484384|0;Ob(j,v[f>>2]);e=v[f>>2];v[f>>2]=0;f=b+484380|0;v[f>>2]=v[f>>2]-e;b=b+484388|0;v[b>>2]=v[b>>2]-e;b=d+16|0;Gc(b,8,1,1,0);eg(b,f,j);c=c+1|0;continue}}IQ(j,d+16|0);n:{if(!n){break n}if(!Vg(m,i&65535,64)){break n}l=0;v[d+1048>>2]=0;o:while(1){if((l|0)==64){break n}g=0;p=Qc(Rb(m,i),l,0);q=Hc(d+16|0,l);while(1)if((g|0)==4){l=l+1|0;continue o}else{b=Fb(q,g);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+8>>2]=b;v[d+12>>2]=b;e=p+B(g,6)|0;Nt(d+8|0,e);h=w[e+3|0];b=h;p:{q:{r:{f=w[e+5|0];if(f){b=14;if((h|0)!=14){break r}}t[(d+1048|0)+g|0]=0;if((b|f)&255){break q}break p}b=h;k=w[(d+1048|0)+g|0];if(!k){break q}s:{if(k>>>0>=16){t[e+2|0]=3;k=k>>>4|0;break s}t[e+2|0]=4}t[e+4|0]=k}t:{u:{v:{w:{x:{y:{switch((b&255)-12|0){case 1:b=v[d+1196>>2];if((b|0)==6){break u}h=10;t[e+3|0]=10;break v;case 0:f=f&127;break x;case 2:if(f>>>0<=1&v[d+1196>>2]>3){break t}h=10;t[e+3|0]=10;t[(d+1048|0)+g|0]=f;break w;case 3:break y;default:break w}}f=f&15}t[e+5|0]=f}b=v[d+1196>>2]}if((b|0)>1){break t}z:{A:{B:{switch(h|0){case 0:if(f>>>0>2){break A}break;case 2:break z;case 1:break A;default:break B}}t[e+3|0]=0;break p}t[e+3|0]=1;break p}b=f&15;if(b){t[e+3|0]=2;t[e+5|0]=b;break p}if(f>>>0<16){break p}t[e+3|0]=3;t[e+5|0]=f>>>4;break p}t[e+5|0]=0}Mf(e)}g=g+1|0;continue}}}i=i+1|0;continue}}if((k-1&255)>>>0<2){v[d+1196>>2]=6}i=i+1|0;q=(k&255)+q|0;continue}}ab=d+1824|0;return g|0}function cH(a,b,c,d,e,f){var g=0,h=C(0),i=0,j=0,k=C(0),l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,A=C(0),D=C(0),E=0,F=0,G=0,H=C(0),I=C(0),J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=B(s,2304)+b|0;v=0;q=(c|0)>0?c:0;n=ab-128|0;x=n+96|0;y=n- -64|0;E=n+32|0;while(1){if((q|0)!=(v|0)){o=G+(v<<2)|0;w=0;i=n;p=i;j=0;while(1){if((j|0)!=8){k=z[B(15-j|0,72)+o>>2];g=B(j,72)+o|0;h=z[g+1152>>2];l=C(k+h);m=z[g>>2];A=z[B(31-j|0,72)+o>>2];D=C(m+A);z[p>>2]=l+D;g=B(j,12);k=C(C(k-h)*z[g+67280>>2]);h=C(C(m-A)*z[g+67284>>2]);z[p+64>>2]=k+h;m=C(D-l);l=z[g+67288>>2];z[p+32>>2]=m*l;z[p+96>>2]=C(h-k)*l;p=p+4|0;j=j+1|0;continue}break}while(1){if((w|0)!=4){l=z[i+8>>2];m=z[i+20>>2];h=C(l+m);A=z[i+4>>2];D=z[i+24>>2];H=C(A+D);k=C(h+H);I=z[i+12>>2];J=z[i+16>>2];K=C(I+J);L=z[i>>2];M=z[i+28>>2];N=C(L+M);O=C(K+N);z[i>>2]=k+O;z[i+16>>2]=C(O-k)*C(.7071067690849304);k=C(N-K);h=C(C(k+C(H-h))*C(.7071067690849304));z[i+24>>2]=C(k-h)*C(1.3065630197525024);z[i+8>>2]=C(k+h)*C(.5411961078643799);k=C(L-M);h=C(l-m);l=C(A-D);m=C(C(h+l)*C(.7071067690849304));A=C(k+m);D=C(C(I-J)+h);h=C(l+k);l=C(D-C(h*C(.1989123672246933)));h=C(C(l*C(.3826834261417389))+h);z[i+28>>2]=C(A-h)*C(2.562915563583374);z[i+4>>2]=C(A+h)*C(.509795606136322);k=C(k-m);h=C(l-C(h*C(.1989123672246933)));z[i+20>>2]=C(k+h)*C(.8999761939048767);z[i+12>>2]=C(k-h)*C(.601344883441925);i=i+32|0;w=w+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;z[o>>2]=z[p+n>>2];k=z[p+x>>2];i=i+1|0;j=i<<2;h=z[j+x>>2];z[o+72>>2]=C(z[p+y>>2]+k)+h;z[o+144>>2]=z[p+E>>2]+z[j+E>>2];z[o+216>>2]=h+C(k+z[j+y>>2]);o=o+288|0;continue}break}z[o>>2]=z[n+28>>2];k=z[n+124>>2];z[o+72>>2]=z[n+92>>2]+k;h=z[n+60>>2];z[o+216>>2]=k;z[o+144>>2]=h;v=v+1|0;continue}break}s=s+1|0;continue}break}E=gc(f,a,3840);G=d<<5;s=0;while(1){if((c|0)>(s|0)){i=ab-32|0;ab=i;o=E+(s<<8)|0;v=(s<<2)+b|0;z[o+4080>>2]=z[v+1152>>2];f=d-1|0;w=v+B(f,2304)|0;z[o+4084>>2]=z[w+1152>>2];z[o+4088>>2]=z[v>>2];z[o+4092>>2]=z[w>>2];z[o+4336>>2]=z[v+1156>>2];z[o+4340>>2]=z[w+1156>>2];z[o+4344>>2]=z[v+4>>2];z[o+4348>>2]=z[w+4>>2];x=(B(s,G)<<1)+e|0;y=x+(f<<1)|0;Ir(y,d,o+244|0);f=d<<6;Ir(f+y|0,d,o+500|0);Ir(x,d,o+240|0);Ir(f+x|0,d,o+496|0);F=o+3840|0;p=14;n=67376;while(1){if((p|0)>=0){g=p<<4;j=g+F|0;f=B(31-p|0,72);z[j>>2]=z[f+v>>2];z[j+4>>2]=z[f+w>>2];f=f|4;z[j+8>>2]=z[f+v>>2];z[j+12>>2]=z[f+w>>2];f=B(p,72);q=f+76|0;z[j+256>>2]=z[q+v>>2];z[j+260>>2]=z[q+w>>2];f=f+72|0;z[j-248>>2]=z[f+v>>2];z[j-244>>2]=z[f+w>>2];q=p<<2;t=g+o|0;k=z[n+4>>2];h=z[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=z[g+j>>2];m=z[g+t>>2];z[g+(i+16|0)>>2]=C(l*h)-C(k*m);z[i+g>>2]=C(l*k)+C(h*m);f=f+1|0;continue}break}j=F+(q<<2)|0;q=j-3584|0;t=j-256|0;k=z[n+12>>2];h=z[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=z[n+20>>2];h=z[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=z[n+28>>2];h=z[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=z[n+36>>2];h=z[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=z[n+44>>2];h=z[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=z[n+52>>2];h=z[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=z[n+60>>2];h=z[n+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=z[j+q>>2];m=z[g+j>>2];z[t>>2]=z[t>>2]+C(C(l*k)+C(h*m));j=j+(i+16|0)|0;z[j>>2]=C(C(m*k)-C(h*l))+z[j>>2];f=f+1|0;continue}break}f=B(15-p|0,d)<<1;P=f+y|0,Q=Ti(z[i+20>>2]),u[P>>1]=Q;j=B(p+17|0,d)<<1;P=j+y|0,Q=Ti(z[i+4>>2]),u[P>>1]=Q;P=f+x|0,Q=Ti(z[i+16>>2]),u[P>>1]=Q;P=j+x|0,Q=Ti(z[i>>2]),u[P>>1]=Q;f=B(47-p|0,d)<<1;P=f+y|0,Q=Ti(z[i+28>>2]),u[P>>1]=Q;j=B(p+49|0,d)<<1;P=j+y|0,Q=Ti(z[i+12>>2]),u[P>>1]=Q;P=f+x|0,Q=Ti(z[i+24>>2]),u[P>>1]=Q;P=j+x|0,Q=Ti(z[i+8>>2]),u[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}ab=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}z[(s<<2)+a>>2]=z[E+(b+s<<2)>>2];s=s+2|0;continue}}gc(a,E+(b<<2)|0,3840)}}function HH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=ab-48|0;ab=g;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(Kr(c)){b=b+24|0;i=v[b>>2]+484344|0;if(he(i,c&65535)){break j}}c=a;a=Bb(g+32|0);b=Bb(g+16|0);Vh(c,a,b);pb(b);pb(a);break i}c=Rb(i,c);if(!(v[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Bb(g+32|0);b=Bb(g+16|0);Vh(c,a,b);pb(b);pb(a);break i}if(!(x[v[b>>2]+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Bb(g+32|0);b=Bb(g+16|0);Vh(c,a,b);pb(b);pb(a);break i}if(f>>>0>=6){c=a;a=Bb(g+32|0);b=Bb(g+16|0);Vh(c,a,b);pb(b);pb(a);break i}c=Qc(c,d,e&65535);k:{switch(f|0){case 0:l:{m:{n:{d=w[c|0];if(!Kc(d)){if(!ap(d)){break n}}e=g+16|0;aL(e,v[b>>2],d,w[c+1|0]);v[22452]=0;R(986,g+32|0,e|0);d=v[22452];v[22452]=0;b=1;if((d|0)!=1){break m}c=P()|0;O()|0;break b}b=0;v[22452]=0;Q(55,g+32|0,16709)|0;d=v[22452];v[22452]=0;if((d|0)==1){break l}}c=w[c|0];o:{if(Kc(c)){v[22452]=0;Q(55,g|0,9929)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}break o}if(ap(c)){v[22452]=0;Q(55,g|0,10239)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break o}break c}v[22452]=0;Q(55,g|0,16709)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}}c=a;a=g+32|0;Vh(c,a,g);pb(g);pb(a);if(!b){break i}pb(g+16|0);break i}c=P()|0;O()|0;break a;case 1:b=c+1|0;p:{if(w[c+1|0]){vt(g+32|0,b);break p}Mb(g+32|0,16714)}q:{if(w[b|0]){v[22452]=0;Q(55,g+16|0,10729)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break q}break d}v[22452]=0;Q(55,g+16|0,16714)|0;b=v[22452];v[22452]=0;if((b|0)==1){break d}}c=a;a=g+32|0;b=g+16|0;Vh(c,a,b);pb(b);pb(a);break i;case 2:r:{if(Lg(w[c|0])){Mb(g+32|0,17769);break r}d=w[c+2|0];if(d){ze(g+32|0,1,BK(v[v[v[b>>2]+8>>2]+88>>2],d));break r}Mb(g+32|0,17769)}s:{if(Lg(w[c|0])){v[22452]=0;Q(55,g+16|0,17769)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}break s}if(w[c+2|0]){v[22452]=0;Q(55,g+16|0,5466)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break s}break e}v[22452]=0;Q(55,g+16|0,17769)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}}c=a;a=g+32|0;b=g+16|0;Vh(c,a,b);pb(b);pb(a);break i;case 4:b=w[c+2|0];t:{if(Lg(w[c|0])){l=g,m=Lj(b,w[c+4|0])&255,v[l>>2]=m;Yz(g+32|0,g);break t}if(b){vt(g+32|0,c+4|0);break t}Mb(g+32|0,16714)}u:{if(Lg(w[c|0])){v[22452]=0;Q(55,g+16|0,5450)|0;b=v[22452];v[22452]=0;if((b|0)==1){break f}break u}if(w[c+2|0]){v[22452]=0;Q(55,g+16|0,5450)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break u}break f}v[22452]=0;Q(55,g+16|0,16714)|0;b=v[22452];v[22452]=0;if((b|0)==1){break f}}c=a;a=g+32|0;b=g+16|0;Vh(c,a,b);pb(b);pb(a);break i;case 3:d=w[c+3|0];v:{if(Lg(w[c|0])){l=g,m=(Lj(d,w[c+5|0])&3840)!=0,t[l|0]=m;e=ab-32|0;ab=e;t[e+24|0]=44;v[e+16>>2]=-1;v[e+20>>2]=0;v[e+8>>2]=1058;v[e+12>>2]=1;k=g+32|0;b=ab+-64|0;ab=b;i=e+8|0;h=v[i>>2]&2?16:10;f=ab-32|0;ab=f;d=ze(f+16|0,1,0);w:{x:{y:{while(1){j=Eb(d);Yw(f+8|0,j,ub(d)+j|0,w[g|0],h);if(!v[f+12>>2]){break y}j=If(ub(d));v[22452]=0;R(59,d|0,j|0);j=v[22452];v[22452]=0;if((j|0)!=1){continue}break}break x}h=v[f+8>>2];j=Eb(d);v[22452]=0;R(60,d|0,h-j|0);h=v[22452];v[22452]=0;z:{if((h|0)!=1){v[22452]=0;R(61,b|0,d|0);h=v[22452];v[22452]=0;if((h|0)!=1){break z}break x}break x}pb(d);ab=f+32|0;break w}a=P()|0;O()|0;pb(d);S(a|0);L()}d=b+16|0;Ik(d,b,v[i>>2]);f=v[i+4>>2];h=v[i>>2];v[22452]=0;W(75,b+32|0,d|0,h|0,f|0);d=v[22452];v[22452]=0;A:{B:{C:{D:{E:{if((d|0)!=1){v[22452]=0;U(76,b+48|0,b+32|0,i|0);d=v[22452];v[22452]=0;if((d|0)==1){break E}v[22452]=0;R(58,k|0,b+48|0);d=v[22452];v[22452]=0;if((d|0)==1){break D}pb(b+48|0);pb(b+32|0);pb(b+16|0);pb(b);ab=b- -64|0;break A}a=P()|0;O()|0;break B}a=P()|0;O()|0;break C}a=P()|0;O()|0;pb(b+48|0)}pb(b+32|0)}pb(b+16|0);pb(b);S(a|0);L()}ab=e+32|0;break v}if(d){ze(g+32|0,1,AK(v[v[v[b>>2]+8>>2]+84>>2],d));break v}Mb(g+32|0,16715)}F:{if(Lg(w[c|0])){v[22452]=0;Q(55,g+16|0,12281)|0;b=v[22452];v[22452]=0;if((b|0)==1){break g}break F}if(w[c+3|0]){v[22452]=0;Q(55,g+16|0,12281)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break F}break g}v[22452]=0;Q(55,g+16|0,16715)|0;b=v[22452];v[22452]=0;if((b|0)==1){break g}}c=a;a=g+32|0;b=g+16|0;Vh(c,a,b);pb(b);pb(a);break i;case 5:b=w[c+3|0];G:{if(Lg(w[c|0])){l=g,m=Lj(b,w[c+5|0])&255,v[l>>2]=m;Yz(g+32|0,g);break G}if(b){vt(g+32|0,c+5|0);break G}Mb(g+32|0,16714)}H:{if(Lg(w[c|0])){v[22452]=0;Q(55,g+16|0,11073)|0;b=v[22452];v[22452]=0;if((b|0)==1){break h}break H}if(w[c+3|0]){v[22452]=0;Q(55,g+16|0,11073)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break H}break h}v[22452]=0;Q(55,g+16|0,16714)|0;b=v[22452];v[22452]=0;if((b|0)==1){break h}}c=a;a=g+32|0;b=g+16|0;Vh(c,a,b);pb(b);pb(a);break i;default:break k}}c=a;a=Bb(g+32|0);b=Bb(g+16|0);Vh(c,a,b);pb(b);pb(a)}ab=g+48|0;return}c=P()|0;O()|0;pb(g+32|0);break a}c=P()|0;O()|0;pb(g+32|0);break a}c=P()|0;O()|0;pb(g+32|0);break a}c=P()|0;O()|0;pb(g+32|0);break a}c=P()|0;O()|0;pb(g+32|0);break a}c=P()|0;O()|0;pb(g+32|0);if(!b){break a}}pb(g+16|0)}S(c|0);L()}function Xca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=ab-144|0;ab=d;qc(c);a:{b:{c:{d:{if(!Wn(c,d+128|0)){break d}if(Ib(d+128|0,13794,4)){break d}f=d+136|0;e:{if(!Ib(f,13485,4)){break e}if(!Ib(f,13543,4)){break e}if(Ib(f,14225,4)){break d}}e=ab-32|0;ab=e;k=Ye(d+112|0);f:{g:{h:{i:{j:{while(1){v[22452]=0;j=Q(147,c|0,8)|0;h=v[22452];v[22452]=0;if((h|0)==1){break h}if(!j){break i}v[22452]=0;R(767,e|0,c|0);j=v[22452];v[22452]=0;if((j|0)!=1){v[22452]=0;R(768,k|0,e|0);j=v[22452];v[22452]=0;if((j|0)==1){break j}Tc(e);continue}break}a=P()|0;O()|0;break g}a=P()|0;O()|0;Tc(e);break g}ab=e+32|0;break f}a=P()|0;O()|0}Rd(k);S(a|0);L()}v[22452]=0;j=T(165,d+88|0)|0;c=v[22452];v[22452]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if((c|0)!=1){k=Gc(d+84|0,8,1,1,0);if(Ib(f,14225,4)){break t}v[22452]=0;U(681,d- -64|0,d+112|0,1296581714);c=v[22452];v[22452]=0;if((c|0)==1){break q}v[22452]=0;U(681,d+40|0,d+112|0,1296318804);c=v[22452];v[22452]=0;if((c|0)==1){break c}c=d+40|0;e=Mc(j,c);qb(c);c=0;v[22452]=0;f=T(682,d- -64|0)|0;i=v[22452];v[22452]=0;g=1;if((i|0)==1){break c}i=0;if(!f){break u}v[22452]=0;e=T(169,e|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break c}i=0;if(!e){break u}v[22452]=0;i=T(273,d- -64|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}v[22452]=0;e=T(265,d- -64|0)|0;c=v[22452];v[22452]=0;w:{if((c|0)==1){break w}v[22452]=0;Q(179,d- -64|0,2)|0;c=v[22452];v[22452]=0;if((c|0)==1){break w}v[22452]=0;c=T(273,d- -64|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){break v}}break c}g=P()|0;O()|0;break a}v[22452]=0;R(594,d+40|0,d- -64|0);f=v[22452];v[22452]=0;g=1;if((f|0)==1){break c}f=Ab(w[d+40|0]|w[d+41|0]<<8);if(!f){break u}c=(c>>>0)/(f>>>0)|0;g=d+40|0;f=ac(g);l=Me(g);g=1;f=Ab(w[f|0]|w[f+1|0]<<8);if((f|0)!=(Ab(w[l|0]|w[l+1|0]<<8)+1|0)){break u}if((f|0)==2){eo(k,2)}x:{if((e|0)!=16){if((e|0)!=8){break u}y:{switch(Ab(w[d+46|0]|w[d+47|0]<<8)|0){case 0:nf(k,1);break x;case 2:nf(k,17);break x;case 3:break y;default:break u}}nf(k,16);break x}if(Ab(w[d+46|0]|w[d+47|0]<<8)){break u}vh(k,16)}g=0}qb(d- -64|0);l=0;if(!g){break s}g=0;break k}v[22452]=0;U(681,d- -64|0,d+112|0,1447576658);c=v[22452];v[22452]=0;z:{A:{if((c|0)!=1){v[22452]=0;U(681,d+40|0,d+112|0,1128808782);c=v[22452];v[22452]=0;if((c|0)==1){break A}v[22452]=0;U(681,d+16|0,d+112|0,1112491097);c=v[22452];v[22452]=0;if((c|0)==1){break m}c=d+16|0;h=Mc(j,c);qb(c);v[22452]=0;m=T(169,h|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break z}c=0;e=0;B:{if(!m){break B}v[22452]=0;m=T(169,d- -64|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break z}c=0;e=0;if(!m){break B}v[22452]=0;m=Q(683,d- -64|0,d+16|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break z}c=0;e=0;if(!m){break B}e=Ib(f,13485,4);v[22452]=0;i=T(273,d+40|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break m}if(e){Gc(d+12|0,16,1,0,0);v[d+84>>2]=v[d+12>>2]}if((i|0)==6){eo(k,3)}c=d+16|0;f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c|4;m=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=w[d+28|0]|w[d+29|0]<<8;l=w[d+32|0]|w[d+33|0]<<8|(w[d+34|0]<<16|w[d+35|0]<<24);v[22452]=0;h=T(151,h|0)|0;n=v[22452];v[22452]=0;o=1;if((n|0)==1){break m}e=B((i|0)==6?2:1,e?2:1);i=(h>>>0)/(e>>>0)|0;l=Wb(l);c=Ab(c);n=(Wb(m)>>>0)/(e>>>0)|0;e=(Wb(f)>>>0)/(e>>>0)|0}qb(d+40|0);qb(d- -64|0);if(o){break r}break k}g=P()|0;O()|0;break b}g=P()|0;O()|0;break l}break m}e=0}Ls(a,b);v[22452]=0;g=B(b,104)+a|0;f=g+484380|0;R(271,f|0,0);h=v[22452];v[22452]=0;if((h|0)==1){break p}v[f>>2]=i;h=e+n|0;v[g+484388>>2]=h;v[g+484384>>2]=e;if(!(i>>>0<h>>>0|h>>>0<=e+4>>>0)){e=(B(b,104)+a|0)+484414|0;u[e>>1]=x[e>>1]|2}e=B(b,104)+a|0;v[e+484404>>2]=c?c:22050;c=l>>>8|0;u[e+484410>>1]=(l&16776960)>>>0>65536?256:c&65535?c:256;Ws(f,v[a+480180>>2]);v[22452]=0;U(681,d- -64|0,d+112|0,1312902469);c=v[22452];v[22452]=0;if((c|0)==1){break o}v[22452]=0;c=T(169,d- -64|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break n}C:{D:{if(c){v[22452]=0;c=T(151,d- -64|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break n}v[22452]=0;U(320,d- -64|0,((b<<5)+a|0)+946304|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){break D}break n}v[22452]=0;c=Q(55,d+40|0,21598)|0;e=v[22452];v[22452]=0;if((e|0)==1){break C}sc(((b<<5)+a|0)+946304|0,c);pb(c)}v[22452]=0;Y(210,k|0,f|0,j|0)|0;b=v[22452];v[22452]=0;g=1;if((b|0)==1){break n}ii(f,a);qb(d- -64|0);break k}break n}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;qb(d- -64|0);break b}g=P()|0;O()|0;qb(d+40|0)}qb(d- -64|0);break b}qb(j);Rd(d+112|0)}ab=d+144|0;return g|0}g=P()|0;O()|0;qb(d- -64|0)}qb(j)}Rd(d+112|0);S(g|0);L()}function Jca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;h=ab-208|0;ab=h;qc(b);a:{b:{c:{if(!LA(b,h+160|0)){break c}if(!QO(h+160|0)){break c}if(!c){i=1;break c}if(!Hb(b,Fc(PO(w[h+207|0]),db))){break c}vd(a,128);f=h+144|0;Qe(f,2,h+175|0);d=h+72|0;tc(d,v[h+144>>2],v[h+148>>2],w[h+152|0]);tb(a+1298308|0,d);pb(d);i=Mb(d,8440);tb(a+1298344|0,i);pb(i);i=Mb(d,6017);tb(a+1298356|0,i);pb(i);f=Mb(f,17484);v[22452]=0;U(696,d|0,f|0,v[(w[h+174|0]<<2)+26860>>2]);d=v[22452];v[22452]=0;if((d|0)==1){break b}d=h+72|0;tb(a+1298368|0,d);pb(d);pb(f);v[a+480208>>2]=12;v[a+1298404>>2]=5;dB(a+1298332|0,b,w[h+207|0]<<5,32,0);n=a+480190|0;f=ue(b);u[n>>1]=f;i=1;while(1){m=i&65535;if(m>>>0>(f&65535)>>>0){Vn(Kb(a+484360|0),b,256,255,254);i=0;d=ue(b);if(d>>>0>=127){break c}f=a+480188|0;u[f>>1]=d+1;d=ue(b);while(1){if(x[f>>1]<=i>>>0){n=a+484344|0;q=d+1|0;fg(n,q);f=0;while(1){g=f&65535;if(g>>>0>d>>>0){l=0;r=a+480188|0;d:while(1){e:{s=l&65535;f=x[r>>1];if(s>>>0>=f>>>0){d=h+8|0;i=Fn(d);t[d+16|0]=0;u[d+14>>1]=0;u[d+12>>1]=f;v[22452]=0;R(698,i|0,f|0);f=v[22452];v[22452]=0;if((f|0)==1){a=P()|0;O()|0;Be(i);S(a|0);L()}v[22452]=0;U(697,h+32|0,n|0,d|0);f=v[22452];v[22452]=0;i=1;if((f|0)==1){break e}Be(h+32|0);Be(d);if(!(c&2)){break c}c=a+480190|0;f=1;while(1){d=f&65535;if(d>>>0>x[c>>1]){break c}d=B(d,104)+a|0;eg(Gc(h+72|0,u[d+484414>>1]&1?16:8,1,0,0),d+484380|0,b);f=f+1|0;continue}}m=0;g=Fh(h+72|0);while(1){f:{if((m|0)!=(q|0)){if(Hb(b,5)){break f}}l=l+1|0;continue d}f=0;i=Qc(Rb(n,m),0,s);while(1){j=w[h+174|0];d=ab-16|0;ab=d;o=1;e=ue(b);if((e|0)==252){o=ue(b);e=ue(b)}t[g|0]=(e-1&255)>>>0<60?e+36|0:0;e=d+8|0;nm(e,b);t[g+1|0]=w[e|0];k=w[Zc(e)|0];t[d+7|0]=k&15;t[d+6|0]=k>>>4;y=d,z=w[Me(e)|0],t[y+5|0]=z;y=d,z=w[vi(e)|0],t[y+4|0]=z;MO(d+7|0,d+5|0,j);MO(d+6|0,d+4|0,j);j=w[d+7|0];k=(j|0)!=10;e=w[d+6|0];g:{if(!(k|(e|0)!=10)){j=w[d+5|0];e=w[d+4|0];t[g+3|0]=10;j=j|e<<8;t[g+5|0]=j>>>6;if(j>>>0<16384){break g}t[g+2|0]=15;t[g+4|0]=e>>>6;break g}h:{i:{j:{k:{if(!k){k=w[d+5|0];p=k<<2;y=d,z=pm(p),t[y+5|0]=z;if(k>>>0<64){break k}if(ti(e)>>>0>=jz(10)>>>0){break k}t[g+5|0]=p;t[g+2|0]=15;t[g+3|0]=10;t[g+4|0]=k>>>6;break g}if((e|0)==10){e=w[d+4|0];k=e<<2;y=d,z=pm(k),t[y+4|0]=z;if(e>>>0<64){break h}if(ti(j)>>>0>=jz(10)>>>0){break h}t[g+5|0]=k;t[g+2|0]=15;t[g+3|0]=10;t[g+4|0]=e>>>6;break g}if((e|0)!=(j|0)){break k}e=0;t[d+6|0]=0;break j}if((e|0)==13){break i}}if((j|0)==13|e){break h}}Tg(d+7|0,d+6|0);Tg(d+5|0,d+4|0)}e=d+6|0;j=d+4|0;k=d+7|0;p=d+5|0;qu(e,j,k,p);Yn(d,k,p,e,j);t[g+2|0]=w[d+7|0];t[g+4|0]=w[d+5|0];t[g+3|0]=w[d+6|0];t[g+5|0]=w[d+4|0]}ab=d+16|0;e=f+o|0;f=e>>>0>64?64-f|0:o;if(f){while(1){if(f){d=v[h+72>>2];t[i|0]=d;t[i+1|0]=d>>>8;t[i+2|0]=d>>>16;t[i+3|0]=d>>>24;d=x[h+76>>1];t[i+4|0]=d;t[i+5|0]=d>>>8;f=f-1|0;i=B(x[r>>1],6)+i|0;continue}break}d=e>>>0<64;f=d?e:64;if(d){continue}}break}m=m+1|0;continue}}break}a=P()|0;O()|0;Be(d);break a}f=f+1|0;i=0;if(Vg(n,g,64)){continue}break}}else{g=(i<<5)+a|0;Le(g+480280|0);l=g+480284|0;l:{if(w[h+174|0]>=51){g=(ue(b)<<4|8)&248;break l}g=i&1?192:64}u[l>>1]=g;i=i+1|0;continue}break}}else{m:{if(w[h+174|0]>=52){d=h+72|0;if(!dT(b,d)){eB(d)}break m}d=ab-32|0;ab=d;v[d+28>>2]=64;v[d+8>>2]=66;f=v[zb(d+28|0,d+8|0)>>2];if(!Hb(b,f)){f=Ze(b)}g=d+8|0;e=h+72|0;Yt(g,e);l=Zb(d+16|0,v[d+8>>2],f);_b(d,b,v[l>>2],v[l+4>>2]);Yt(g,e);Jb(v[d+8>>2]+f|0,0,66-f|0);Ob(b,v[d+28>>2]);ab=d+32|0;d=w[h+134|0]|w[h+135|0]<<8;t[h+136|0]=d;t[h+137|0]=d>>>8;t[h+134|0]=171;t[h+135|0]=32}f=ab-32|0;ab=f;d=(B(m,104)+a|0)+484380|0;ed(d,0);WA(d);l=h+72|0;g=l;Zj(f,2,g+32|0);e=f+16|0;tc(e,v[f>>2],v[f+4>>2],w[f+8|0]);ke(d+43|0,e);pb(e);e=g+56|0;o=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=g+52|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);n:{if(o>>>0<=e>>>0){break n}v[d>>2]=o-e;e=g+44|0;v[d+12>>2]=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=g+48|0;v[f+16>>2]=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);y=d,z=v[zb(f+16|0,d)>>2],v[y+16>>2]=z;u[d+30>>1]=w[g+60|0];e=g+62|0;v[d+24>>2]=w[e|0]|w[e+1|0]<<8;e=g- -64|0;e=w[e|0]|w[e+1|0]<<8;if(e){Tp(d,+(e<<16>>16)/393216)}e=g+61|0;g=w[e|0];if(g&8){u[d+34>>1]=x[d+34>>1]|8;g=w[e|0]}if(g&16){u[d+34>>1]=x[d+34>>1]|16;g=w[e|0]}if(!(g&4)){break n}u[d+34>>1]=x[d+34>>1]|1;v[d+12>>2]=v[d+12>>2]>>>1;v[d+16>>2]=v[d+16>>2]>>>1}ab=f+32|0;Qe(h+56|0,2,l);d=h+144|0;tc(d,v[h+56>>2],v[h+60>>2],w[h+64|0]);sc(((m<<5)+a|0)+946304|0,d);i=i+1|0;pb(d);f=x[n>>1];continue}break}}ab=h+208|0;return i|0}a=P()|0;O()|0;pb(f)}S(a|0);L()}function wd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;m=ab-96|0;ab=m;o=i&65535;p=h;A=h<<15|g>>>17;q=(e^i)&-2147483648;l=e&65535;s=l;y=l;l=0;B=(o&131071)<<15|h>>>17;z=i>>>16&32767;J=e>>>16&32767;a:{b:{if(z-32767>>>0>4294934529&J-32767>>>0>=4294934530){break b}k=e&2147483647;j=d;if(!(!j&(k|0)==2147418112?!(b|c):k>>>0<2147418112)){n=d;q=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){n=h;q=i|32768;b=f;c=g;break a}if(!(b|j|(k^2147418112|c))){if(!(f|h|(e|g))){q=2147450880;b=0;c=0;break a}q=q|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){d=b|j;e=c|k;b=0;c=0;if(!(d|e)){q=2147450880;break a}q=q|2147418112;break a}if(!(b|j|(c|k))){b=0;c=0;break a}if(!(f|h|(e|g))){b=0;c=0;break a}if((k|0)==65535|k>>>0<65535){j=b;h=!(d|s);i=h<<6;k=E(h?b:d)+32|0;b=E(h?c:s);b=i+((b|0)==32?k:b)|0;zf(m+80|0,j,c,d,s,b-15|0);t=16-b|0;d=v[m+88>>2];y=v[m+92>>2];c=v[m+84>>2];b=v[m+80>>2]}if(e>>>0>65535){break b}e=!(o|p);h=e<<6;i=E(e?f:p)+32|0;e=E(e?g:o);e=h+((e|0)==32?i:e)|0;zf(m- -64|0,f,g,p,o,e-15|0);t=(t-e|0)+16|0;e=v[m+76>>2];i=v[m+72>>2];f=v[m+64>>2];g=v[m+68>>2];A=i<<15|g>>>17;B=(e&131071)<<15|i>>>17}e=f;p=e<<15&-32768;w=c;o=oia(p,0,c,0);c=db;x=c;e=c;r=(g&131071)<<15|f>>>17;k=0;c=b;i=0;f=oia(r,k,b,i);b=f+o|0;j=db+e|0;e=b;b=e>>>0<f>>>0?j+1|0:j;h=0;g=oia(c,i,p,i);f=h+g|0;j=db+e|0;j=f>>>0<g>>>0?j+1|0:j;g=j;C=(e|0)==(j|0)&f>>>0<h>>>0|e>>>0>j>>>0;u=d;K=oia(p,i,d,0);G=db;j=oia(w,k,r,k);d=j+K|0;h=db+G|0;h=d>>>0<j>>>0?h+1|0:h;L=d;s=oia(A,0,c,i);d=d+s|0;j=db+h|0;H=d;j=d>>>0<s>>>0?j+1|0:j;s=j;d=j;j=(b|0)==(x|0)&e>>>0<o>>>0|b>>>0<x>>>0;x=b;b=b+H|0;e=d+j|0;e=b>>>0<x>>>0?e+1|0:e;x=b;o=e;D=y|65536;M=oia(p,i,D,l);I=db;d=oia(u,n,r,k);b=d+M|0;j=db+I|0;j=b>>>0<d>>>0?j+1|0:j;N=b;d=oia(w,k,A,n);b=b+d|0;p=j;j=j+db|0;j=b>>>0<d>>>0?j+1|0:j;O=b;F=B&2147483647|-2147483648;c=oia(F,0,c,i);b=b+c|0;y=j;j=j+db|0;B=b;i=b>>>0<c>>>0?j+1|0:j;c=0;b=c+x|0;e=e+B|0;e=b>>>0<c>>>0?e+1|0:e;P=b;c=b;b=b+C|0;C=e;j=b>>>0<c>>>0?e+1|0:e;c=j;t=((J+z|0)+t|0)-16383|0;l=oia(u,n,A,n);d=db;r=oia(r,k,D,n);e=r+l|0;j=db+d|0;j=e>>>0<r>>>0?j+1|0:j;r=e;e=j;z=(d|0)==(e|0)&l>>>0>r>>>0|d>>>0>e>>>0;l=oia(F,n,w,k);d=l+r|0;j=db+e|0;j=d>>>0<l>>>0?j+1|0:j;l=d;d=j;k=(e|0)==(j|0)&l>>>0<r>>>0|e>>>0>j>>>0;e=z+k|0;j=0;j=e>>>0<k>>>0?1:j;k=oia(F,n,D,n);e=k+e|0;j=db+j|0;j=e>>>0<k>>>0?j+1|0:j;k=j;w=l;z=e;e=(h|0)==(G|0)&K>>>0>L>>>0|h>>>0<G>>>0;h=(h|0)==(s|0)&H>>>0<L>>>0|h>>>0>s>>>0;e=e+h|0;j=0;j=e>>>0<h>>>0?1:j;l=e;h=w+e|0;e=d+j|0;e=h>>>0<l>>>0?e+1|0:e;r=h;l=e;e=(e|0)==(d|0)&h>>>0<w>>>0|d>>>0>e>>>0;d=z+e|0;j=k;w=d;e=d>>>0<e>>>0?j+1|0:j;k=oia(F,n,u,n);h=db;u=oia(A,n,D,n);d=u+k|0;j=db+h|0;j=d>>>0<u>>>0?j+1|0:j;u=d;d=j;j=(h|0)==(j|0)&k>>>0>u>>>0|h>>>0>j>>>0;k=d+w|0;e=e+j|0;e=k>>>0<d>>>0?e+1|0:e;w=k;k=0;d=k+r|0;j=l+u|0;j=d>>>0<k>>>0?j+1|0:j;h=j;k=(l|0)==(j|0)&d>>>0<r>>>0|j>>>0<l>>>0;l=w+k|0;u=l;l=l>>>0<k>>>0?e+1|0:e;k=d;e=(p|0)==(I|0)&M>>>0>N>>>0|p>>>0<I>>>0;p=(p|0)==(y|0)&N>>>0>O>>>0|p>>>0>y>>>0;e=e+p|0;e=e+((i|0)==(y|0)&B>>>0<O>>>0|i>>>0<y>>>0)|0;d=i+d|0;e=h+e|0;e=d>>>0<i>>>0?e+1|0:e;i=(e|0)==(h|0)&d>>>0<k>>>0|e>>>0<h>>>0;h=i+u|0;j=l;p=h;h=h>>>0<i>>>0?j+1|0:j;l=d;i=e;d=(o|0)==(s|0)&x>>>0<H>>>0|o>>>0<s>>>0;o=(o|0)==(C|0)&x>>>0>P>>>0|o>>>0>C>>>0;d=d+o|0;j=0;j=d>>>0<o>>>0?1:j;o=d;d=l+d|0;e=e+j|0;e=d>>>0<o>>>0?e+1|0:e;l=(e|0)==(i|0)&d>>>0<l>>>0|e>>>0<i>>>0;i=l+p|0;j=h;h=i;j=h>>>0<l>>>0?j+1|0:j;i=j;c:{if(j&65536){t=t+1|0;break c}o=g>>>31|0;l=0;j=i<<1|h>>>31;h=h<<1|e>>>31;i=j;j=e<<1|d>>>31;d=d<<1|c>>>31;e=j;j=g<<1|f>>>31;f=f<<1;g=j;j=c<<1|b>>>31;b=b<<1|o;c=j|l}if((t|0)>=32767){q=q|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){j=1-t|0;if(j>>>0>=128){b=0;c=0;break a}l=t+127|0;zf(m+48|0,f,g,b,c,l);zf(m+32|0,d,e,h,i,l);Yl(m+16|0,f,g,b,c,j);Yl(m,d,e,h,i,j);f=v[m+32>>2]|v[m+16>>2]|(v[m+48>>2]|v[m+56>>2]|(v[m+52>>2]|v[m+60>>2]))!=0;g=v[m+36>>2]|v[m+20>>2];b=v[m+40>>2]|v[m+24>>2];c=v[m+44>>2]|v[m+28>>2];d=v[m>>2];e=v[m+4>>2];i=v[m+12>>2];h=v[m+8>>2];break d}i=i&65535|t<<16}n=h|n;q=i|q;if(!(!b&(c|0)==-2147483648?!(f|g):(c|0)>0|(c|0)>=0)){b=d+1|0;h=b?e:e+1|0;c=h;f=(e|0)==(h|0)&b>>>0<d>>>0|e>>>0>h>>>0;d=f+n|0;e=q;n=d;q=d>>>0<f>>>0?e+1|0:e;break a}if(b|f|(c^-2147483648|g)){b=d;c=e;break a}h=q;c=d&1;b=c+d|0;j=b>>>0<c>>>0?e+1|0:e;c=j;e=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;d=e+n|0;n=d;q=d>>>0<e>>>0?h+1|0:h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=n;v[a+12>>2]=q;ab=m+96|0}function QL(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;f=ab-16|0;ab=f;a:{if(!Kc(d&255)){break a}o=a+1074376|0;l=(o+B(b,872)|0)+616|0;b:{c:{d:{e:{f:{if(!(v[a+480180>>2]&17825824)){break f}g=x[a+480192>>1];if(!g){break f}if(!e){break e}}e=B(b,872)+a|0;if(!Kj(v[e+1075648>>2])){break d}g=x[a+480192>>1]}e=B(b,872)+a|0;m=v[e+1075096>>2];c=c>>>0>g>>>0?0:c;p=e+1075648|0;h=v[(c?((c<<2)+a|0)+900380|0:p)>>2];if(!h){break b}i=d-1|0;c=x[Yb(h+236|0,i)>>1];g=a+1074312|0;rb(f+8|0,g,104);g:{if(sb(v[v[f+8>>2]>>2],v[f+12>>2])){rb(f,g,34);if(sb(v[v[f>>2]>>2],v[f+4>>2])){break g}}d=w[Cb(h+108|0,i)|0]}if((c-1&65535)>>>0>3998){break c}m=(B(c,104)+a|0)+484380|0;break b}d=e+1075068|0;if(!v[d>>2]){break a}c=B(b,872)+a|0;e=v[c+1075080>>2];if(e&1024){break a}g=c+1075012|0;c=c+1075016|0;if(!(v[g>>2]|v[c>>2])){break a}h:{if(!(e&512)){break h}e=a+1298300|0;if(!td(e)){break h}cj(v[e>>2],b,0);break a}e=hy(a,b);if((e|0)==65535){break a}j=B(e,872);e=a+1074992|0;a=j+e|0;hp(a,l);t[a+831|0]=0;t[a+805|0]=0;u[a+786>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;Kn(a+788|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[l>>2]=0;v[l+4>>2]=0;a=e+B(b,872)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[g>>2]=0;v[c>>2]=0;break a}rb(f+8|0,g,43);if(!sb(v[v[f+8>>2]>>2],v[f+12>>2])){break b}if(!fj(w[h+31|0])){break a}}if(w[e+1075081|0]&4){break a}r=b>>>0>256?b:256;g=a+1298300|0;n=a+1074312|0;s=b+1|0;y=a+480188|0;c=b;i:{while(1){if((c|0)==(r|0)){j:{e=0;c=0;if(!Kj(v[p>>2])){break i}c=0;if(!Kc(w[(B(b,872)+a|0)+1075789|0])){break i}d=ml(a,o,b,2,1);c=0;if((d-1&255)>>>0>249){break i}e=v[(B(d,160)+a|0)+906140>>2];if(e){break j}e=0;c=0;break i}}else{k:{if((b|0)!=(c|0)&x[y>>1]>c>>>0){break k}e=B(c,872)+a|0;if(x[e+1075778>>1]!=(s|0)&(b|0)!=(c|0)){break k}q=e+1075648|0;i=v[q>>2];if(!i){break k}k=e+1074992|0;l:{m:{n:{o:{p:{q:{r:{switch(w[i+17|0]-1|0){case 0:if(!d){break k}j=w[e+1075789|0]==(d|0)&(h|0)==(i|0);if(!h){break q}if(j){break n}break k;case 1:if(!m|v[e+1075096>>2]!=(m|0)){break k}if((h|0)==(i|0)){break l}rb(f+8|0,n,104);if(!sb(v[v[f+8>>2]>>2],v[f+12>>2])){break l}break k;case 3:break p;case 2:break r;default:break k}}if(h){break o}j=(h|0)==(i|0)}if(j){break l}break k}if(!h){break k}j=w[h+34|0];if(!j){break k}if((j|0)==w[i+34|0]){break m}break k}if((h|0)!=(i|0)){break k}}if(!w[h+34|0]){break l}}if(!w[e+1075789|0]|w[i+18|0]>2){break l}rb(f+8|0,n,34);Ll(a,c&65535,pO(k,sb(v[v[f+8>>2]>>2],v[f+12>>2]))+255|0,0);t[e+1075792|0]=0}s:{t:{switch(w[v[q>>2]+18|0]){case 0:tn(a,k);v[e+1075680>>2]=0;if(!(w[e+1075081|0]&2)){break s}if(!td(g)){break s}cj(v[g>>2],c&65535,1);break s;case 1:tn(a,k);if(!(w[e+1075081|0]&2)){break s}if(!td(g)){break s}Nj(v[g>>2],c&65535);break s;case 2:break t;default:break s}}k=e+1075080|0;i=v[k>>2];v[k>>2]=i|4096;if(!(i&512)){break s}if(!td(g)){break s}rb(f+8|0,n,105);if(sb(v[v[f+8>>2]>>2],v[f+12>>2])){break s}Nj(v[g>>2],c&65535)}if(v[e+1075680>>2]){break k}v[e+1075688>>2]=0;e=e+1075080|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;continue}break}rb(f+8|0,n,34);c=(A=e,C=pO(l,sb(v[v[f+8>>2]>>2],v[f+12>>2])),D=b,z=v[v[e>>2]+100>>2],eb[z](A|0,C|0,D|0)|0)}d=(B(b,872)+a|0)+1075e3|0;if(!(gi(v[d>>2],v[d+4>>2])?1:c)){break a}h=hy(a,b);if((h|0)==65535){break a}i=B(h,872)+a|0;d=i+1075080|0;m=i+1074992|0;u:{if(!(w[i+1075081|0]&2)){break u}if(!td(g)){break u}cj(v[g>>2],h,1)}m=hp(m,l);v[d>>2]=v[d>>2]&-917505;t[i+1075823|0]=0;k=x[a+480188>>1];t[i+1075797|0]=0;u[i+1075778>>1]=b>>>0<k>>>0?b+1|0:0;v:{if(!(c&(e|0)!=0)){break v}c=w[(B(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break v}Ll(a,b,255,0);t[(B(b,872)+a|0)+1075792|0]=0}w:{x:{switch(w[(B(b,872)+a|0)+1075790|0]){case 2:tn(a,m);if(!(w[d+1|0]&2)){break w}if(!td(g)){break w}Nj(v[g>>2],b);rb(f+8|0,n,105);if(!sb(v[v[f+8>>2]>>2],v[f+12>>2])){break w}Ty(v[g>>2],b,h);break w;case 0:v[(B(h,872)+a|0)+1075688>>2]=0;c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break w}if(!td(g)){break w}cj(v[g>>2],b,1);break w;case 3:c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break w}if(!td(g)){break w}rb(f+8|0,n,105);e=sb(v[v[f+8>>2]>>2],v[f+12>>2]);c=v[g>>2];if(e){Ty(c,b,h);break w}Nj(c,b);break w;case 1:break x;default:break w}}if(!(w[d+1|0]&2)){break w}if(!td(g)){break w}Ty(v[g>>2],b,h)}if(!v[(B(h,872)+a|0)+1075680>>2]){v[(B(h,872)+a|0)+1075688>>2]=0;v[d>>2]=v[d>>2]|2101248}a=B(b,872)+a|0;v[a+1075068>>2]=0;v[l>>2]=0;v[l+4>>2]=0;a=a+1075084|0;v[a>>2]=0;v[a+4>>2]=0}ab=f+16|0}function iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=ab-112|0;ab=f;qc(b);a:{b:{c:{d:{e:{if(!oQ(b,14111)){break e}i=Pb(f+96|0);j=Pb(f+80|0);v[22452]=0;v[f+72>>2]=0;v[f+76>>2]=0;R(240,a|0,32768);d=v[22452];v[22452]=0;if((d|0)==1){break b}v[22452]=0;d=Q(1,f+40|0,8156)|0;h=v[22452];v[22452]=0;if((h|0)==1){break c}tb(a+1298344|0,d);pb(d);v[22452]=0;d=Q(1,f+40|0,6021)|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}tb(a+1298356|0,d);pb(d);v[a+1298404>>2]=2;m=a+484360|0;h=f- -64|4;k=a+480280|0;while(1){v[22452]=0;d=Q(147,b|0,8)|0;e=v[22452];v[22452]=0;f:{g:{h:{if((e|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}v[22452]=0;d=Q(593,b|0,f- -64|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break m}if(!d){break n}d=h;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[22452]=0;U(181,f+16|0,b|0,Wb(d)|0);d=v[22452];v[22452]=0;if((d|0)==1){break l}d=f+40|0;e=f+16|0;g=bc(d,e);qb(e);v[22452]=0;d=T(169,d|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break j}if(d){break k}qb(f+40|0)}if(x[a+480188>>1]){break i}d=0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}o:{p:{q:{r:{s:{t:{d=f- -64|0;d=Wb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));if((d|0)!=1397769541){if((d|0)==1346458708){break s}if((d|0)==1346522948){break r}if((d|0)==1347175758){break t}if((d|0)!=1396788560){if((d|0)==1396854596){break q}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(x[a+480188>>1]){break f}v[22452]=0;d=T(151,f+40|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break j}if(d>>>0<8){break f}e=0;v[22452]=0;R(594,f+16|0,g|0);d=v[22452];v[22452]=0;if((d|0)==1){break j}while(1)if((e|0)==4){if(c){break f}d=1;break o}else{d=x[a+480188>>1];g=Yb(f+16|0,e);u:{if(!Ab(w[g|0]|w[g+1|0]<<8)){g=(e&3)-1|0;break u}g=f+72|0;o=Cb(g,d),p=1,t[o|0]=p;o=Cb(g,x[a+480188>>1]+1|0),p=255,t[o|0]=p;Le(k+(x[a+480188>>1]<<5)|0);g=x[a+480188>>1];d=g+1|0;u[a+480188>>1]=d;l=k+(g<<5)|0;g=(e&3)-1|0;u[l+4>>1]=g>>>0<2?192:64}Le(k+((d&65535)<<5)|0);d=x[a+480188>>1];u[a+480188>>1]=d+1;u[(k+(d<<5)|0)+4>>1]=g>>>0<2?192:64;e=e+1|0;continue}}if(x[a+480190>>1]){break f}v[22452]=0;R(595,g|0,a|0);d=v[22452];v[22452]=0;if((d|0)!=1){break f}break j}v[22452]=0;d=T(151,f+40|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break j}if(d>>>0<2){break f}v[22452]=0;d=T(265,g|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break j}o=a,p=Ld(d,1,255),v[o+480196>>2]=p;break f}v[22452]=0;d=T(151,f+40|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break j}if(d>>>0<2){break f}v[22452]=0;n=T(265,g|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){break f}break j}d=Kb(m);v[22452]=0;e=T(151,f+40|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break j}v[22452]=0;ea(337,d|0,g|0,e|0,255,254)|0;d=v[22452];v[22452]=0;if((d|0)!=1){break f}break j}if(Ef(v[i>>2],v[i+4>>2])>>>0>255){break f}v[22452]=0;R(596,i|0,g|0);d=v[22452];v[22452]=0;if((d|0)==1){break j}break f}if(Ef(v[j>>2],v[j+4>>2])>>>0>3998){break f}v[22452]=0;d=T(151,f+40|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break j}if(!d){break f}v[22452]=0;R(596,j|0,g|0);d=v[22452];v[22452]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}d=0}qb(f+40|0);break g}a=P()|0;O()|0;qb(f+40|0);break a}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=Kb(m);v[22452]=0;R(319,b|0,n&65535);b=v[22452];v[22452]=0;if((b|0)==1){break b}v:{if(!(c&1)){break v}b=v[i+4>>2];d=v[i>>2];e=0;v[22452]=0;R(216,a+484344|0,Ef(d,b)&65535);b=v[22452];v[22452]=0;if((b|0)==1){break b}while(1){h=v[i>>2];b=e&65535;if(Ef(h,v[i+4>>2])>>>0<=b>>>0){break v}v[22452]=0;d=v[f+76>>2];g=v[f+72>>2];v[f+8>>2]=g;v[f+12>>2]=d;v[f>>2]=g;v[f+4>>2]=d;W(597,tg(h,b)|0,b|0,a|0,f|0);b=v[22452];v[22452]=0;if((b|0)!=1){e=e+1|0;continue}break}a=P()|0;O()|0;break a}h=c&2;d=1;e=1;b=0;while(1){if(x[a+480190>>1]<=e>>>0){break g}if(!h|Ef(v[j>>2],v[j+4>>2])>>>0<=b>>>0){break g}c=(B(e,104)+a|0)+484380|0;fo(c);w:{if(v[c>>2]){g=v[j>>2];v[22452]=0;g=T(151,tg(g,b)|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break h}mc(c,g);g=Gc(f+40|0,8,1,1,0);k=v[j>>2];v[22452]=0;Y(210,g|0,c|0,tg(k,b)|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break w}b=b+1|0}e=e+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Yc(j);Yc(i);break e}qb(f+40|0);continue}}ab=f+112|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Yc(j);Yc(i);S(a|0);L()}function Jea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=ab-208|0;ab=d;qc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!Wn(b,d+192|0)){break l}if(!GQ(d+192|0)){break l}j=Nh(d+168|0);k=Bb(d+152|0);Qt(d+88|0);v[22452]=0;e=Q(561,b|0,d+80|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break h}m:{if(!e){break m}e=d+80|4;h=Wb(Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-4|0);t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24;h=0;while(1){f=Wb(Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-8|0);t[e|0]=f;t[e+1|0]=f>>>8;t[e+2|0]=f>>>16;t[e+3|0]=f>>>24;n:{if(c){break n}f=d+80|0;if((Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))|0)!=1347699796){break n}h=1;break m}f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[22452]=0;U(181,d+56|0,b|0,Wb(f)|0);f=v[22452];v[22452]=0;if((f|0)==1){break d}g=d+8|0;i=d+56|0;f=bc(g,i);qb(i);v[22452]=0;i=T(169,g|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break b}o:{if(!i){break o}p:{g=d+80|0;g=Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));if((g|0)!=1129139796){if((g|0)!=1229866575){if((g|0)==1347699796){break p}if((g|0)!=1447383635){break o}v[22452]=0;Q(179,d+8|0,4)|0;g=v[22452];v[22452]=0;if((g|0)==1){break b}v[22452]=0;g=T(562,f|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break b}if(!g){break o}g=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));if(g>>>0<7){break o}v[22452]=0;U(563,f|0,k|0,g-6|0);f=v[22452];v[22452]=0;if((f|0)==1){break b}break o}v[22452]=0;m=Q(564,f|0,d+88|0)|0;f=v[22452];v[22452]=0;if((f|0)!=1){break o}break b}Uu(j,f);break o}v[22452]=0;h=Y(565,a|0,f|0,c|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break b}}qb(d+8|0);if(i){v[22452]=0;f=Q(561,b|0,d+80|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break i}if(f){continue}}break}if(pd(k)){v[22452]=0;b=Q(1,d+8|0,14856)|0;c=v[22452];v[22452]=0;if((c|0)==1){break g}tb(k,b);pb(b)}q:{if(!(h&m&1)){break q}b=d+130|0;b=w[b|0]|w[b+1|0]<<8;v[22452]=0;c=Ab(b)&256;Y(258,a+1074312|0,5,!c|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break f}b=d+126|0;if(Ab(w[b|0]|w[b+1|0]<<8)){u[d+8>>1]=64;n=d,o=Ab(w[b|0]|w[b+1|0]<<8),u[n+56>>1]=o;n=a,o=x[Lc(d+8|0,d+56|0)>>1],v[n+480228>>2]=o}b=d+128|0;b=Ab(w[b|0]|w[b+1|0]<<8);if(!(!c|!b)){v[a+480204>>2]=B(b,1e4)}if(w[d+88|0]){Qe(d+56|0,2,d+88|0);v[22452]=0;W(213,d+8|0,v[d+56>>2],v[d+60>>2],w[d+64|0]);b=v[22452];v[22452]=0;if((b|0)==1){break e}b=d+8|0;tb(a+1298308|0,b);pb(b)}c=d+134|0;if(!Fp(c,1,12)){break q}e=d+132|0;if(!Fp(e,1,31)){break q}f=d+138|0;if(!Fp(f,0,23)){break q}g=d+140|0;if(!Fp(g,0,59)){break q}i=d+142|0;if(!Fp(i,0,59)){break q}b=bq(d+8|0);l=d+136|0;n=b,o=Ab(w[l|0]|w[l+1|0]<<8),v[n+20>>2]=o;n=b,o=Ab(w[c|0]|w[c+1|0]<<8)-1|0,v[n+16>>2]=o;n=b,o=Ab(w[e|0]|w[e+1|0]<<8),v[n+12>>2]=o;n=b,o=Ab(w[f|0]|w[f+1|0]<<8),v[n+8>>2]=o;n=b,o=Ab(w[g|0]|w[g+1|0]<<8),v[n+4>>2]=o;n=b,o=Ab(w[i|0]|w[i+1|0]<<8),v[n>>2]=o;v[22452]=0;R(392,a+1298408|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break q}a=P()|0;O()|0;break a}if(h&1){v[22452]=0;b=T(169,j|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break h}if(b){b=Bb(d+8|0);v[22452]=0;U(262,j|0,b|0,32);c=v[22452];v[22452]=0;if((c|0)==1){break c}if(Sp(b,13712)){v[22452]=0;U(11,d+56|0,2,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break c}c=d+56|0;tb(a+1298320|0,c);pb(c)}v[22452]=0;c=T(566,j|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}if(!c){v[22452]=0;c=T(193,j|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}v[22452]=0;ga(306,a+1298332|0,j|0,c|0,40,0);c=v[22452];v[22452]=0;if((c|0)==1){break c}}pb(b)}v[22452]=0;b=Q(1,d+56|0,17472)|0;c=v[22452];v[22452]=0;if((c|0)==1){break k}v[22452]=0;U(436,d+8|0,b|0,k|0);c=v[22452];v[22452]=0;if((c|0)==1){break j}c=d+8|0;tb(a+1298368|0,c);pb(c);pb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[22452]=0;a=Y(258,a+1074312|0,84,1)|0;b=v[22452];v[22452]=0;if((b|0)==1){break h}v[22452]=0;a=Y(258,a|0,83,1)|0;b=v[22452];v[22452]=0;if((b|0)==1){break h}v[22452]=0;Q(259,a|0,85)|0;a=v[22452];v[22452]=0;if((a|0)==1){break h}}pb(k);qb(j)}ab=d+208|0;return h&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;pb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;pb(b);break a}a=P()|0;O()|0;qb(d+8|0)}pb(k);qb(j);S(a|0);L()}function xU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=ab-112|0;ab=e;qc(b);a:{if(!pq(b,11748)){break a}if(!vu(b,e+96|0)){break a}if(!UB(e+96|0)){break a}if(!Hb(b,Fc(TB(e+96|0),db))){break a}if(!Ob(b,w[e+105|0]|w[e+106|0]<<8)){break a}b:{if(!c){break b}vd(a,4096);v[a+480208>>2]=12;d=e+96|0;u[a+480188>>1]=(w[d|2]&31)+1;g=a+480190|0;i=d|3;u[g>>1]=w[i|0];lh(a,1);k=e+24|0;h=Mb(k,8463);tb(a+1298344|0,h);pb(h);h=Mb(k,7011);tb(a+1298356|0,h);pb(h);h=ab-16|0;ab=h;f=Mb(h,4208);Ac(e,f);pb(f);ab=h+16|0;v[22452]=0;W(223,k|0,e|0,d|1,d|0);d=v[22452];v[22452]=0;c:{if((d|0)!=1){d=e+24|0;tb(a+1298368|0,d);pb(d);yb(e);v[a+1298404>>2]=5;d=w[i|0];k=e+80|0;v[k>>2]=0;v[k+4>>2]=0;mi(k+8|0,0);if(d){vq(k,d);HC(k,d,0)}d=1;d:{while(1){h=d&65535;if(h>>>0>x[g>>1]){v[22452]=0;Q(224,b|0,a+1298308|0)|0;h=v[22452];v[22452]=0;d=1;e:{if((h|0)==1){break e}h=a+480190|0;while(1){g=d&65535;if(g>>>0>x[h>>1]){d=0;h=a+480188|0;f:{while(1){if(x[h>>1]<=d>>>0){h=e+96|4;d=w[h|0]|w[h+1|0]<<8;v[22452]=0;i=a+484344|0;R(216,i|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break e}d=0;break f}g=(d<<5)+a|0;Le(g+480280|0);v[22452]=0;R(225,b|0,g+480289|0);g=v[22452];v[22452]=0;if((g|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}g:{h:{i:{j:{while(1){if((w[h|0]|w[h+1|0]<<8)>>>0<=d>>>0){v[22452]=0;f=T(185,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break h}if(!f){break i}v[22452]=0;d=Q(147,b|0,f|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break h}if(d){break j}break i}v[22452]=0;g=Q(226,b|0,e+24|0)|0;f=v[22452];v[22452]=0;k:{if((f|0)==1){break k}v[22452]=0;f=Y(217,i|0,d&65535,64)|0;j=v[22452];v[22452]=0;if((j|0)==1){break k}if((f&g)==1){g=Rb(i,d);v[22452]=0;R(227,g|0,e+24|0);g=v[22452];v[22452]=0;if((g|0)==1){break k}}d=d+1|0;continue}break}b=P()|0;O()|0;break d}g=Pb(e+24|0);v[22452]=0;U(228,b|0,g|0,f|0);d=v[22452];v[22452]=0;l:{if((d|0)!=1){d=Bb(e);v[22452]=0;R(46,d|0,f|0);f=v[22452];v[22452]=0;m:{if((f|0)==1){break m}m=e,n=wb(v[g>>2]),v[m+48>>2]=n;j=wb(v[g+4>>2]);while(1){n:{f=v[e+48>>2];if(!Tb(f,j)){v[22452]=0;W(229,e+48|0,5,6,d|0);f=v[22452];v[22452]=0;if((f|0)==1){break n}j=e+48|0;f=tb(d,j);pb(j);j=Eb(f);l=ub(f);v[22452]=0;ga(230,a+1298332|0,j|0,l|0,76,0);j=v[22452];v[22452]=0;if((j|0)==1){break m}pb(f);Xb(g);break i}o:{f=w[f|0];if(f&128){m=e,n=Ff(d),v[m+64>>2]=n;Yg(e+72|0,e- -64|0);v[22452]=0;W(231,d|0,v[e+72>>2],f&127,32);f=v[22452];v[22452]=0;if((f|0)!=1){break o}break m}v[22452]=0;R(47,d|0,f<<24>>24);f=v[22452];v[22452]=0;if((f|0)!=1){break o}break m}Fe(e+48|0);continue}break}}b=P()|0;O()|0;pb(d);break l}b=P()|0;O()|0}Xb(g);break d}d=Kb(a+484360|0);g=e+96|6;g=w[g|0]|w[g+1|0]<<8;v[22452]=0;ea(232,d|0,b|0,g|0,65535,65535)|0;d=v[22452];v[22452]=0;if((d|0)==1){break h}g=c&1;d=0;while(1){p:{q:{if((w[h|0]|w[h+1|0]<<8)>>>0>d>>>0){v[22452]=0;f=Q(147,b|0,4)|0;j=v[22452];v[22452]=0;if((j|0)==1){break p}if(f){break q}}if(!(c&2)){break g}h=a+480190|0;d=1;while(1){c=d&65535;if(c>>>0>x[h>>1]){break g}g=B(c,104)+a|0;i=x[g+484414>>1];rb(e+24|0,v[k>>2],c-1|0);c=Gc(e,i&1?16:8,1,0,sb(v[v[e+24>>2]>>2],v[e+28>>2])?6:0);v[22452]=0;Y(210,c|0,g+484380|0,b|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}v[22452]=0;f=T(148,b|0)|0;j=v[22452];v[22452]=0;r:{s:{if((j|0)!=1){v[22452]=0;U(181,e|0,b|0,f|0);f=v[22452];v[22452]=0;if((f|0)==1){break s}f=bc(e+24|0,e);qb(e);if(!g){break r}if(!he(i,d&65535)){break r}j=Rb(i,d);v[22452]=0;U(233,j|0,0,f|0);f=v[22452];v[22452]=0;if((f|0)!=1){break r}b=P()|0;O()|0;qb(e+24|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}d=d+1|0;qb(e+24|0);continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}Be(k);break b}v[22452]=0;Q(234,b|0,((g<<5)+a|0)+946304|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[22452]=0;R(235,b|0,e+24|0);i=v[22452];v[22452]=0;t:{if((i|0)==1){break t}v[22452]=0;R(236,e+24|0,(B(h,104)+a|0)+484380|0);i=v[22452];v[22452]=0;if((i|0)==1){break t}i=w[e+40|0];rb(e,v[k>>2],h-1|0);mg(e,(i&3)!=0);d=d+1|0;continue}break}b=P()|0;O()|0}Be(k);break c}b=P()|0;O()|0;yb(e)}S(b|0);L()}d=1}ab=e+112|0;return d|0}function Z7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0;e=ab-144|0;ab=e;d=-1;a:{b:{c:{if(!Fj(v[v[b>>2]-12>>2]+b|0)){b=yl(e+40|0,b);v[22452]=0;d=Q(408,e+24|0,13942)|0;f=v[22452];v[22452]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){v[22452]=0;v[e+16>>2]=83886084;v[e+20>>2]=0;U(409,b|0,d|0,e+16|0);f=v[22452];v[22452]=0;if((f|0)==1){break A}yb(d);t[e+15|0]=0;v[22452]=0;d=Q(408,e+24|0,14720)|0;f=v[22452];v[22452]=0;if((f|0)==1){break z}v[22452]=0;U(410,b|0,e+15|0,d|0);f=v[22452];v[22452]=0;if((f|0)==1){break y}yb(d);v[22452]=0;f=w[e+15|0];d=Q(408,e+24|0,15750)|0;g=v[22452];v[22452]=0;if((g|0)==1){break x}v[22452]=0;f=f?0:c;W(857,b|0,a+40|0,d|0,f|0);c=v[22452];v[22452]=0;if((c|0)==1){break w}yb(d);u[e+12>>1]=65535;v[22452]=0;c=Q(408,e+24|0,15420)|0;d=v[22452];v[22452]=0;if((d|0)==1){break v}v[22452]=0;Y(438,b|0,e+12|0,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break u}yb(c);u[e+10>>1]=0;v[22452]=0;c=Q(408,e+24|0,15258)|0;d=v[22452];v[22452]=0;if((d|0)==1){break t}v[22452]=0;Y(438,b|0,e+10|0,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break s}yb(c);u[a>>1]=x[e+10>>1];v[22452]=0;c=Q(408,e+24|0,15023)|0;d=v[22452];v[22452]=0;if((d|0)==1){break r}v[22452]=0;W(858,b|0,a+52|0,c|0,f|0);d=v[22452];v[22452]=0;if((d|0)==1){break q}yb(c);v[22452]=0;c=Q(408,e+24|0,14966)|0;d=v[22452];v[22452]=0;if((d|0)==1){break p}v[22452]=0;U(849,b|0,a+36|0,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break o}yb(c);v[22452]=0;c=Q(408,e+24|0,15427)|0;d=v[22452];v[22452]=0;if((d|0)==1){break n}v[22452]=0;h=a+4|0;U(859,b|0,h|0,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break m}yb(c);v[22452]=0;c=Q(408,e+24|0,15260)|0;d=v[22452];v[22452]=0;if((d|0)==1){break l}v[22452]=0;f=a+28|0;U(860,b|0,f|0,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break k}yb(c);v[22452]=0;c=Q(408,e+24|0,15137)|0;d=v[22452];v[22452]=0;if((d|0)==1){break j}v[22452]=0;U(860,b|0,a+30|0,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break i}yb(c);v[22452]=0;c=Q(408,e+24|0,14995)|0;d=v[22452];v[22452]=0;if((d|0)==1){break h}v[22452]=0;U(861,b|0,a+32|0,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break g}yb(c);u[e+8>>1]=0;v[22452]=0;c=Q(408,e+24|0,14939)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}v[22452]=0;Y(438,b|0,e+8|0,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break f}yb(c);i=gK(z[a+32>>2]);z[a+32>>2]=i;d=-1;if(!Hl(i)){break d}k=e,l=wb(v[a+4>>2]),v[k+24>>2]=l;c=wb(v[a+8>>2]);while(1){g=v[e+24>>2];if(!Tb(g,c)){break e}if(!Hl(z[g>>2])){break d}te(e+24|0);continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}a=P()|0;O()|0;yb(c);break a}if(w[b+3|0]&64){break d}c=x[f>>1];if((c+300&65535)>>>0>600){break d}g=x[a>>1];if(g>>>0>3|(g|0)==2){break d}j=u[a+30>>1];if((j|0)<0){break d}k=e,l=oi(v[a+36>>2]),v[k+24>>2]=l;v[e+16>>2]=0;k=a,l=v[nj(e+24|0,e+16|0,43984)>>2],v[k+36>>2]=l;if(nc(v[a+4>>2],v[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:f=u[e+8>>1];if((f|0)<=0){break d}u[e+6>>1]=j;z[e+24>>2]=z[a+32>>2];v[22452]=0;u[e+16>>1]=c;u[e+18>>1]=(c+f|0)-1;a=da(862,a|0,e+6|0,e+24|0,e+16|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;O()|0;break a;case 0:g=u[e+8>>1];if((g|0)<=0){break d}z[e+24>>2]=z[a+32>>2];v[22452]=0;u[e+16>>1]=c;u[e+18>>1]=(c+g|0)-1;a=ea(863,a|0,h|0,e+24|0,e+16|0,f|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;O()|0;break a;default:break C}}v[22452]=0;Z(864,a|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}}d=1}Sg(b)}ab=e+144|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}Sg(b);S(a|0);L()}function mha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;d=ab-320|0;ab=d;qc(b);f=ab-16|0;ab=f;ES(f+8|0,d+96|0);g=v[f+12>>2];_b(f,b,v[f+8>>2],g);h=v[f+4>>2];if((h|0)==(g|0)){Ob(b,v[f+12>>2])}ab=f+16|0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=(h|0)){break g}if(!GS(d+96|0)){break g}if(!Hb(b,Fc(FS(w[d+312|0],w[d+313|0]),db))){break g}if(!c){e=1;break g}vd(a,2);wg(a);v[a+480188>>2]=524296;z=a,A=xe(455e3),v[z+480204>>2]=A;Db(a+1074312|0,110,1);v[a+480208>>2]=v[a+480208>>2]|16777216;Qe(d- -64|0,2,d+127|0);f=d+80|0;tc(f,v[d+64>>2],v[d+68>>2],w[d+72|0]);tb(a+1298308|0,f);pb(f);h:{i:{while(1){if((e|0)==8){j:{l=a+484360|0;e=Kb(l);o=w[d+312|0];m=o+1|0;Vn(e,b,m,65535,65535);f=Pb(d+80|0);v[22452]=0;U(228,b|0,f|0,m|0);e=v[22452];v[22452]=0;if((e|0)==1){break j}z=d,A=wb(v[f>>2]),v[z+64>>2]=A;e=wb(v[f+4>>2]);while(1){g=v[d+64>>2];p=Tb(g,e);if(p){if((w[g|0]-9&255)>>>0<248){break h}Fe(d- -64|0);continue}break}z=a,A=w[Cb(v[f>>2],0)|0],v[z+480196>>2]=A;e=w[d+311|0];h=w[d+313|0];g=Pb(d- -64|0);v[22452]=0;n=h+1|0;U(228,b|0,g|0,n|0);h=v[22452];v[22452]=0;k:{if((h|0)==1){break k}v[22452]=0;h=a+484344|0;R(216,h|0,n|0);i=v[22452];v[22452]=0;if((i|0)==1){break k}q=e+1|0;if(!(c&1)){break i}c=0;while(1){if((c|0)==(n|0)){break i}e=w[Cb(v[g>>2],c)|0];v[22452]=0;e=Y(217,h|0,e|0,q|0)|0;i=v[22452];v[22452]=0;l:{if((i|0)!=1){if(!e){break i}j=0;r=Rb(h,w[Cb(v[g>>2],c)|0]);m:while(1){s=j&65535;if(s>>>0>7){break l}j=j+1|0;e=0;while(1){if(y[r+12>>2]<=e>>>0){continue m}v[22452]=0;i=T(197,b|0)|0;k=v[22452];v[22452]=0;n:{o:{if((k|0)!=1){if(!(i&128)){break o}e=(i&127)+e|0;break n}e=P()|0;O()|0;break b}k=Qc(r,e,s);if((i|0)==1){t[k|0]=254;break n}if((i-1&255)>>>0>96){break n}t[k+1|0]=j;t[k|0]=i+12}e=e+1|0;continue}}}e=P()|0;O()|0;break b}c=c+1|0;continue}}e=P()|0;O()|0;break b}}else{g=(d+96|0)+B(e,19)|0;KA(d+80|0,g+63|0);f=d- -64|0;tc(f,v[d+80>>2],v[d+84>>2],w[d+88|0]);jm(((e<<5)+a|0)+480289|0,f);pb(f);e=e+1|0;i=B(e,104)+a|0;l=i+484380|0;ed(l,2);v[d+72>>2]=0;v[d+64>>2]=0;v[d+68>>2]=0;h=w[g+78|0]|w[g+79|0]<<8|(w[g+80|0]<<16|w[g+81|0]<<24);t[f+7|0]=h;t[f+8|0]=h>>>8;t[f+9|0]=h>>>16;t[f+10|0]=h>>>24;h=w[g+75|0]|w[g+76|0]<<8|(w[g+77|0]<<16|w[g+78|0]<<24);g=w[g+71|0]|w[g+72|0]<<8|(w[g+73|0]<<16|w[g+74|0]<<24);t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;t[f+4|0]=h;t[f+5|0]=h>>>8;t[f+6|0]=h>>>16;t[f+7|0]=h>>>24;v[d+8>>2]=v[d+72>>2];f=v[d+68>>2];v[d>>2]=v[d+64>>2];v[d+4>>2]=f;fl(l,1,d);v[i+484404>>2]=8215;f=d+48|0;tc(f,v[d+80>>2],v[d+84>>2],w[d+88|0]);sc(((e<<5)+a|0)+946304|0,f);pb(f);continue}break}e=P()|0;O()|0;break a}i=o+1|0;e=0;p:{q:{while(1){if((e|0)==(i|0)){v[22452]=0;b=Q(1,d+48|0,8587)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break p}e=P()|0;O()|0;break b}b=Kb(l);v[22452]=0;c=e&65535;b=Q(304,b|0,c|0)|0;j=v[22452];v[22452]=0;if((j|0)!=1){r:{if(!b){v[22452]=0;b=Y(356,h|0,q|0,0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break q}if((b|0)==65535){break r}z=Yb(v[Kb(l)>>2],e),A=b,u[z>>1]=A}z=d,A=ug(Rb(h,x[Yb(v[Kb(l)>>2],e)>>1])),v[z+48>>2]=A;b=JA(d+48|0,1);k=w[b+5|0];j=w[Cb(v[f>>2],(e+1>>>0)%(m>>>0)|0)|0];if((k|0)==(j|0)){break r}s:{if(w[b+3|0]!=16){break s}k=Kb(l);v[22452]=0;c=Q(357,k|0,c|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break c}if((c|0)==65535){break s}z=d,A=ug(Rb(h,c)),v[z+48>>2]=A;b=JA(d+48|0,1)}t[b+5|0]=j;t[b+3|0]=16}e=e+1|0;continue}break}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}tb(a+1298344|0,b);pb(b);v[22452]=0;b=Q(1,d+48|0,6010)|0;c=v[22452];v[22452]=0;if((c|0)==1){break f}tb(a+1298356|0,b);pb(b);lj(d+16|0,2,d+107|0);v[22452]=0;W(213,d+32|0,v[d+16>>2],v[d+20>>2],w[d+24|0]);b=v[22452];v[22452]=0;if((b|0)==1){break e}v[22452]=0;U(11,d+48|0,5,d+32|0);b=v[22452];v[22452]=0;if((b|0)==1){break d}b=d+48|0;tb(a+1298368|0,b);pb(b);pb(d+32|0);v[a+1298404>>2]=5;Xb(g)}Xb(f);e=p^1}ab=d+320|0;return e|0}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;pb(d+32|0);break b}e=P()|0;O()|0}Xb(g)}Xb(f);S(e|0);L()}function aL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;k=ab-16|0;ab=k;a:{b:{c:{d:{if(!Kc(c)|!d|v[b+480180>>2]!=16777216|x[b+480192>>1]<d>>>0){break d}d=v[((d<<2)+b|0)+900380>>2];if(!d){break d}d=v[d+44>>2];if(!d){break d}u[k+14>>1]=c-61;c=ab-80|0;ab=c;e:{f:{e=u[d+28>>1];g=k+14|0;b=u[g>>1];if((e|0)<=(b|0)){if((b|0)<=(nc(v[d+4>>2],v[d+8>>2])+e<<16)-65536>>16){break f}}Bb(a);break e}g:{e=x[d+30>>1];if(!e){b=d+52|0;m=c,n=vx(b,g),v[m+56>>2]=n;m=c,n=Af(b),v[m+40>>2]=n;if(!Qg(c+56|0,c+40|0)){break g}Rf(a,id(c+56|0)+4|0);break e}b=ln(b,e<<16>>16);u[c+78>>1]=b;e=Bb(a);a=d+52|0;m=c,n=vx(a,c+78|0),v[m+72>>2]=n;m=c,n=Af(a),v[m+56>>2]=n;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(Qg(c+72|0,c+56|0)){a=id(c+72|0);v[22452]=0;R(126,e|0,a+4|0);a=v[22452];v[22452]=0;if((a|0)==1){break u}a=u[d+30>>1];b=u[g>>1];v[22452]=0;m=c,n=ux(b,a)+5|0,v[m+40>>2]=n;R(123,c+56|0,c+40|0);a=v[22452];v[22452]=0;v:{if((a|0)!=1){v[22452]=0;Q(89,e|0,c+56|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break v}pb(c+56|0);break e}a=P()|0;O()|0;break h}a=P()|0;O()|0;pb(c+56|0);break h}if(u[d+30>>1]>26){break r}v[22452]=0;b=Y(489,c+40|0,1,(b<<24)+1090519040>>24)|0;a=v[22452];v[22452]=0;if((a|0)==1){break t}v[22452]=0;U(11,c+56|0,0,b|0);a=v[22452];v[22452]=0;if((a|0)==1){break s}a=c+56|0;f=tb(e,a);pb(a);pb(b);v[22452]=0;Q(124,f|0,14621)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break q}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;pb(b);break h}v[22452]=0;a=b<<16>>16;v[c+36>>2]=(a|0)%16;R(816,c+40|0,c+36|0);f=v[22452];v[22452]=0;if((f|0)==1){break p}v[22452]=0;v[c+20>>2]=((a|0)/16<<16>>16)%16;R(816,c+24|0,c+20|0);a=v[22452];v[22452]=0;if((a|0)==1){break o}v[22452]=0;U(2,c+56|0,c+40|0,c+24|0);a=v[22452];v[22452]=0;if((a|0)==1){break n}a=c+56|0;f=tb(e,a);pb(a);pb(c+24|0);pb(c+40|0);if(b<<16>>16<256){break q}v[22452]=0;U(8,c+8|0,0,f|0);a=v[22452];v[22452]=0;if((a|0)==1){break l}h=c+40|0;b=c+8|0;i=kd(b);j=Ff(b);l=kd(b);a=ab-32|0;ab=a;v[a+16>>2]=j;v[a+24>>2]=i;v[a+8>>2]=l;while(1){if(aj(a+24|0,a+16|0)){i=a+24|0;j=gp(t[v[i>>2]]);l=a+8|0;t[v[l>>2]]=j;Fe(i);Fe(l);continue}break}ab=a+32|0;Ac(h,b);v[22452]=0;U(11,c+56|0,0,h|0);a=v[22452];v[22452]=0;if((a|0)==1){break k}a=c+56|0;tb(f,a);pb(a);pb(c+40|0);pb(c+8|0)}a=u[d+30>>1];b=u[g>>1];v[22452]=0;m=c,n=ux(b,a)+5|0,v[m+40>>2]=n;R(123,c+56|0,c+40|0);a=v[22452];v[22452]=0;if((a|0)==1){break j}v[22452]=0;Q(89,e|0,c+56|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break i}pb(c+56|0);break e}a=P()|0;O()|0;break h}a=P()|0;O()|0;break m}a=P()|0;O()|0;pb(c+24|0)}pb(c+40|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;pb(c+40|0);pb(c+8|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;pb(c+56|0)}break b}e=ab-16|0;ab=e;f=ab-32|0;ab=f;d=ze(f+16|0,1,0);w:{while(1){i=f+8|0;b=Eb(d);j=ub(d)+b|0;h=u[g>>1];if(!((b|0)==(j|0)|(h|0)>=0)){t[b|0]=45;h=0-(h&65535)&65535;b=b+1|0}_w(i,b,j,h&65535);if(!v[f+12>>2]){break w}b=If(ub(d));v[22452]=0;R(59,d|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){continue}break}break a}b=v[f+8>>2];g=Eb(d);v[22452]=0;R(60,d|0,b-g|0);b=v[22452];v[22452]=0;x:{if((b|0)!=1){v[22452]=0;R(73,e|0,d|0);b=v[22452];v[22452]=0;if((b|0)!=1){break x}break a}break a}pb(d);ab=f+32|0;v[22452]=0;R(72,a|0,e|0);a=v[22452];v[22452]=0;y:{if((a|0)!=1){pb(e);ab=e+16|0;break y}a=P()|0;O()|0;break b}}ab=c+80|0;break c}e=v[b>>2];b=ab-32|0;ab=b;z:{if(ap(c)){v[b+16>>2]=v[8024];d=v[8023];v[b+8>>2]=v[8022];v[b+12>>2]=d;d=v[8021];v[b>>2]=v[8020];v[b+4>>2]=d;Mb(a,(b+(c<<2)|0)-1004|0);break z}if(Kc(c)){d=Bb(b);v[22452]=0;c=c-1|0;f=(c|0)/12|0;c=Q(817,d|0,e+(B(f,-12)+c<<16>>16<<2)|0)|0;e=v[22452];v[22452]=0;A:{if((e|0)==1){break A}v[22452]=0;c=Q(818,c|0,(f<<24)+805306368>>24)|0;e=v[22452];v[22452]=0;if((e|0)==1){break A}v[22452]=0;Q(3,a|0,c|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break A}pb(c);break z}break a}if(!c){Mb(a,16709);break z}Mb(a,14592)}ab=b+32|0}ab=k+16|0;return}pb(e);S(a|0);L()}a=P()|0;O()|0;pb(d);S(a|0);L()}function Vw(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0;l=ab-48|0;ab=l;v[l+44>>2]=0;if(i?1:d|g|h){j=g?l+44|0:0;a:{if(!j){break a}k=v[j>>2];if(!k){break a}xb(k);v[j>>2]=0}v[22452]=0;X(95);k=v[22452];v[22452]=0;b:{c:{if((k|0)==1){m=Ra(88408,49056,49112,58760,88584,88688,88636,88528,88516,88832,88800,88768,88756,88980,0)|0;d:{e:{n=O()|0;if((n|0)==(fa(88408)|0)){k=_(m|0)|0;v[22452]=0;R(1024,j|0,k|0);j=v[22452];v[22452]=0;k=277;if((j|0)==1){break e}break b}if((fa(49056)|0)==(n|0)){k=_(m|0)|0;v[22452]=0;R(1024,j|0,k|0);j=v[22452];v[22452]=0;k=358;if((j|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break c}break d}if((fa(49112)|0)==(n|0)){k=_(m|0)|0;v[22452]=0;R(1024,j|0,k|0);j=v[22452];v[22452]=0;k=359;if((j|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break c}break d}if((fa(58760)|0)==(n|0)){k=_(m|0)|0;v[22452]=0;R(1024,j|0,k|0);j=v[22452];v[22452]=0;k=357;if((j|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break c}break d}if((fa(88584)|0)==(n|0)){k=_(m|0)|0;v[22452]=0;R(1024,j|0,k|0);j=v[22452];v[22452]=0;k=300;if((j|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break c}break d}if((fa(88688)|0)==(n|0)){k=_(m|0)|0;v[22452]=0;R(1024,j|0,k|0);j=v[22452];v[22452]=0;k=299;if((j|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break c}break d}if((fa(88636)|0)==(n|0)){k=_(m|0)|0;v[22452]=0;R(1024,j|0,k|0);j=v[22452];v[22452]=0;k=298;if((j|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break c}break d}if((fa(88528)|0)==(n|0)){k=_(m|0)|0;v[22452]=0;R(1024,j|0,k|0);j=v[22452];v[22452]=0;k=297;if((j|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break c}break d}if((fa(88516)|0)==(n|0)){k=_(m|0)|0;v[22452]=0;R(1024,j|0,k|0);j=v[22452];v[22452]=0;k=296;if((j|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break c}break d}if((fa(88832)|0)==(n|0)){k=_(m|0)|0;v[22452]=0;R(1024,j|0,k|0);j=v[22452];v[22452]=0;k=289;if((j|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break c}break d}if((fa(88800)|0)==(n|0)){k=_(m|0)|0;v[22452]=0;R(1024,j|0,k|0);j=v[22452];v[22452]=0;k=288;if((j|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break c}break d}if((fa(88768)|0)==(n|0)){k=_(m|0)|0;v[22452]=0;R(1024,j|0,k|0);j=v[22452];v[22452]=0;k=287;if((j|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break c}break d}if((fa(88756)|0)==(n|0)){k=_(m|0)|0;v[22452]=0;R(1024,j|0,k|0);j=v[22452];v[22452]=0;k=286;if((j|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break c}break d}o=fa(88980)|0;k=257;m=_(m|0)|0;if((n|0)!=(o|0)){break b}v[22452]=0;R(1024,j|0,m|0);j=v[22452];v[22452]=0;k=267;if((j|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break d}break c}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break c}}V(0)|0;O()|0;Gb()}L()}S(a|0);L()}$()}o=!g;if(d){j=eb[d|0](k,e)|0}else{j=3}if(!(o|!(j&2))){v[g+16>>2]=k;m=v[l+44>>2];f:{if(m){o=$d(m);break f}o=$d(21598)}v[g+20>>2]=o}if(h){v[h>>2]=k}if(i){g=v[l+44>>2];g:{if(g){g=$d(g);break g}g=$d(21598)}v[i>>2]=g}g=v[l+44>>2];if(g){xb(g);v[l+44>>2]=0}h:{if(!(j&1)){break h}v[22452]=0;R(1022,l+32|0,a|0);g=v[22452];v[22452]=0;i:{j:{if((g|0)!=1){k:{if(f){v[22452]=0;R(1023,f|0,l+32|0);g=v[22452];v[22452]=0;if((g|0)!=1){break k}break j}g=Eb(l+32|0);if(b){v[22452]=0;R(b|0,g|0,c|0);g=v[22452];v[22452]=0;if((g|0)==1){break j}break k}as(g,l)}pb(l+32|0);break h}g=V(0)|0;O()|0;break i}g=V(0)|0;O()|0;pb(l+32|0)}_(g|0)|0;v[l+28>>2]=f;v[l+24>>2]=e;v[l+20>>2]=d;v[l+16>>2]=c;v[l+12>>2]=b;v[l+8>>2]=a?a:21598;v[l+4>>2]=250;v[l>>2]=9145;_I(17814,l);$r(89336);$()}ab=l+48|0}function bU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=ab-3056|0;ab=e;qc(b);f=ab-16|0;ab=f;i=e+1096|0;xB(f+8|0,i);j=b;b=v[f+12>>2];_b(f,j,v[f+8>>2],b);h=v[f+4>>2];if((h|0)==(b|0)){Ob(j,v[f+12>>2])}ab=f+16|0;b=(b|0)==(h|0);if(!b){wB(i)}a:{if(!b){break a}if(!yB(e+1096|0)){break a}if(!c){d=1;break a}if(!Hb(j,Fc(1024,0))){break a}vB(j,e+576|0);vB(j,e- -64|0);while(1){if((g|0)!=128){f=g<<2;b=f+(e+576|0)|0;i=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(i>>>0>16777215){break a}b=f+(e- -64|0)|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(b-4097>>>0<4294963202){break a}g=g+1|0;if(Qq(j,(b+i|0)+2978|0)){continue}break a}break}vd(a,2);wg(a);b=e+40|0;d=Mb(b,13819);tb(a+1298344|0,d);pb(d);d=Mb(b,14737);tb(a+1298356|0,d);pb(d);b=Mb(b,15443);tb(a+1298368|0,b);pb(b);v[a+1298404>>2]=5;b=w[e+1096|0];v[a+480204>>2]=143e4;v[a+480196>>2]=b;i=a+484360|0;Re(Kb(i),w[e+1097|0]);v[a+480188>>2]=4194317;Db(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;while(1){if((d|0)==4){b:{d=0;while(1){c:{if((d|0)==32){g=0;break c}b=d+1|0;g=B(b,104)+a|0;h=g+484380|0;ed(h,2);Hh(e+16|0,1,(B(d,13)+e|0)+1098|0);f=e+40|0;tc(f,v[e+16>>2],v[e+20>>2],w[e+24|0]);sc(((b<<5)+a|0)+946304|0,f);pb(f);d=(e+1096|0)+(d<<4)|0;f=d+422|0;v[h>>2]=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);if((w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24))>>>0<=(w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24))>>>0){v[g+484384>>2]=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);d=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);u[g+484414>>1]=2;v[g+484388>>2]=d}v[g+484404>>2]=8287;d=b;continue}break}while(1){if((g|0)!=32){d=g+33|0;f=(B(d,104)+a|0)+484380|0;ed(f,2);Hh(e+16|0,1,(B(g,13)+e|0)+2026|0);b=e+40|0;tc(b,v[e+16>>2],v[e+20>>2],w[e+24|0]);sc(((d<<5)+a|0)+946304|0,b);pb(b);v[e+48>>2]=0;v[e+40>>2]=0;v[e+44>>2]=0;d=(e+1096|0)+B(g,11)|0;o=Cb(b,0),p=w[d+1347|0],t[o|0]=p;o=Cb(b,1),p=w[d+1352|0],t[o|0]=p;o=Cb(b,2),p=w[d+1348|0],t[o|0]=p;o=Cb(b,3),p=w[d+1353|0],t[o|0]=p;o=Cb(b,4),p=w[d+1349|0],t[o|0]=p;o=Cb(b,5),p=w[d+1354|0],t[o|0]=p;o=Cb(b,6),p=w[d+1350|0],t[o|0]=p;o=Cb(b,7),p=w[d+1355|0],t[o|0]=p;o=Cb(b,8),p=w[d+1351|0],t[o|0]=p;o=Cb(b,9),p=w[d+1356|0],t[o|0]=p;o=Cb(b,10),p=w[d+1346|0],t[o|0]=p;v[e+8>>2]=v[e+48>>2];b=v[e+44>>2];v[e>>2]=v[e+40>>2];v[e+4>>2]=b;fl(f,1,e);g=g+1|0;continue}break}rq(Kb(i),e+2794|0,256,255,65535);m=a+484344|0;fg(m,128);n=c&1;g=0;while(1){d:{e:{if((g|0)!=128){f=g<<2;b=f+(e+576|0)|0;Nc(j,(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+2978|0);d=e+16|0;b=f+(e- -64|0)|0;Md(d,j,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));f=bc(e+40|0,d);qb(d);if(!n){break d}v[22452]=0;b=Y(217,m|0,g&65535,64)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}if(!b){break d}d=0;i=Rb(m,g);while(1){if(d>>>0>63){break d}v[22452]=0;b=Q(147,e+40|0,1)|0;h=v[22452];v[22452]=0;f:{if((h|0)!=1){if(!b){break d}v[22452]=0;b=T(197,f|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break b}if(b>>>0>12){break f}h=Qc(i,d,b);v[22452]=0;R(254,e+16|0,f|0);k=v[22452];v[22452]=0;if((k|0)==1){break b}k=e+16|0;l=w[k|0];b=b>>>0>3;t[h|0]=((l&15)+(b?13:37)|0)+B(l>>>4&7,12);l=Zc(k);t[h+1|0]=((w[l|0]>>>4|0)+(b?33:1)|0)+(w[k|0]>>>3&16);uB(h,w[l|0],b);continue}break b}h=b-32|0;if((h&255)>>>0<=12){h=Qc(i,d,h&65535);v[22452]=0;k=T(197,f|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break b}uB(h,k,b>>>0>35);continue}if((b|0)!=64){if((b|0)!=96){break e}if(!d){break d}o=Qc(i,d-1|0,0),p=14,t[o+3|0]=p;break d}v[22452]=0;b=T(197,f|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break b}d=b+d|0;continue}}d=1;if(!(c&2)){break a}g=1;while(1){if((g|0)==33){break a}eg(Gc(e+40|0,8,1,0,1),(B(g,104)+a|0)+484380|0,j);g=g+1|0;continue}}qb(e+40|0);d=0;break a}g=g+1|0;qb(e+40|0);continue}}}else{u[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;continue}break}a=P()|0;O()|0;qb(e+40|0);S(a|0);L()}ab=e+3056|0;return d|0}function EG(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,C=0;i=ab-560|0;ab=i;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;k=g+B(s,-24)|0;o=v[(e<<2)+69776>>2];j=d-1|0;if((o+j|0)>=0){g=d+o|0;c=s-j|0;while(1){A[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+v[(c<<2)+69792>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;t=(o|0)>0?o:0;g=0;while(1){f=0;if((d|0)>0){h=g+j|0;c=0;while(1){f=A[(c<<3)+a>>3]*A[(i+320|0)+(h-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;c=(g|0)==(t|0);g=g+1|0;if(!c){continue}break}z=47-k|0;u=48-k|0;C=k-25|0;g=o;a:{while(1){f=A[(g<<3)+i>>3];c=0;h=g;l=(g|0)<=0;if(!l){while(1){n=(i+480|0)+(c<<2)|0;m=f*5.960464477539063e-8;b:{if(D(m)<2147483648){j=~~m;break b}j=-2147483648}m=+(j|0);f=m*-16777216+f;c:{if(D(f)<2147483648){j=~~f;break c}j=-2147483648}v[n>>2]=j;h=h-1|0;f=A[(h<<3)+i>>3]+m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=xj(f,q);f=f+H(f*.125)*-8;d:{if(D(f)<2147483648){n=~~f;break d}n=-2147483648}f=f-+(n|0);e:{f:{g:{w=(q|0)<=0;h:{if(!w){h=(g<<2)+i|0;j=v[h+476>>2];c=j>>u;r=h;h=j-(c<<u)|0;v[r+476>>2]=h;n=c+n|0;j=h>>z;break h}if(q){break g}j=v[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break e}break f}j=2;if(f>=.5){break f}j=0;break e}c=0;h=0;if(!l){while(1){r=(i+480|0)+(c<<2)|0;x=v[r>>2];l=16777215;i:{j:{if(h){break j}l=16777216;if(x){break j}h=0;break i}v[r>>2]=l-x;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}k:{if(w){break k}c=8388607;l:{switch(C|0){case 1:c=4194303;break;case 0:break l;default:break k}}l=(g<<2)+i|0;v[l+476>>2]=v[l+476>>2]&c}n=n+1|0;if((j|0)!=2){break e}f=1-f;j=2;if(!h){break e}f=f-xj(1,q)}if(f==0){c=1;l=0;h=g;m:{if((g|0)<=(o|0)){break m}while(1){h=h-1|0;l=v[(i+480|0)+(h<<2)>>2]|l;if((h|0)>(o|0)){continue}break}if(!l){break m}k=q;while(1){k=k-24|0;g=g-1|0;if(!v[(i+480|0)+(g<<2)>>2]){continue}break}break a}while(1){h=c;c=c+1|0;if(!v[(i+480|0)+(o-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;A[(i+320|0)+(j<<3)>>3]=v[(s+g<<2)+69792>>2];c=0;f=0;if((d|0)>0){while(1){f=A[(c<<3)+a>>3]*A[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}break}f=xj(f,24-k|0);n:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f*5.960464477539063e-8;o:{if(D(m)<2147483648){c=~~m;break o}c=-2147483648}f=+(c|0)*-16777216+f;p:{if(D(f)<2147483648){a=~~f;break p}a=-2147483648}v[d>>2]=a;g=g+1|0;break n}if(D(f)<2147483648){c=~~f}else{c=-2147483648}k=q}v[(i+480|0)+(g<<2)>>2]=c}f=xj(1,k);if((g|0)>=0){d=g;while(1){a=d;A[(a<<3)+i>>3]=f*+v[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}a=0;h=g;while(1){d=a>>>0<t>>>0?a:t;c=0;f=0;while(1){f=A[(c<<3)+72560>>3]*A[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}A[(i+160|0)+(g-h<<3)>>3]=f;h=h-1|0;c=(a|0)!=(g|0);a=a+1|0;if(c){continue}break}}q:{r:{s:{switch(e|0){case 3:t:{if((g|0)<=0){break t}d=(i+160|0)+(g<<3)|0;f=A[d>>3];c=g;while(1){m=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;y=A[h>>3];f=y+f;A[e+(c<<3)>>3]=m+(y-f);A[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break t}f=A[d>>3];c=g;while(1){m=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=A[e>>3];f=p+f;A[d+(c<<3)>>3]=m+(p-f);A[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+A[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[i+160>>3];if(j){break r}A[b>>3]=f;f=A[i+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break q;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+A[(i+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;break q;case 1:case 2:break s;default:break q}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+A[(i+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;f=A[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+A[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break q}A[b>>3]=-f;f=A[i+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}ab=i+560|0;return n&7}function Jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;d=ab-752|0;ab=d;qc(b);e=ab-16|0;ab=e;h=d+144|0;SP(e+8|0,h);f=v[e+12>>2];_b(e,b,v[e+8>>2],f);i=v[e+4>>2];if((i|0)==(f|0)){Ob(b,v[e+12>>2])}ab=e+16|0;e=(f|0)==(i|0);if(!e){RP(h)}a:{if(!e){break a}if(!UP(d+144|0)){break a}if(!Hb(b,Fc(TP(d+144|0),db))){break a}if(!c){n=1;break a}vd(a,262144);f=d+104|0;dl(f,2,d+144|0);e=d+24|0;tc(e,v[d+104>>2],v[d+108>>2],w[d+112|0]);tb(a+1298308|0,e);pb(e);h=Mb(e,8304);tb(a+1298344|0,h);pb(h);e=Mb(e,10086);tb(a+1298356|0,e);pb(e);e=ab-16|0;ab=e;g=f;f=Mb(e,4154);Ac(g,f);pb(f);ab=e+16|0;t[d+8|0]=w[d+174|0];e=w[d+173|0];v[22452]=0;t[d+127|0]=e;R(631,d+128|0,d+127|0);e=v[22452];v[22452]=0;b:{c:{d:{if((e|0)!=1){v[22452]=0;W(244,d+24|0,d+104|0,d+8|0,d+128|0);e=v[22452];v[22452]=0;if((e|0)!=1){e=d+24|0;tb(a+1298368|0,e);pb(e);pb(d+128|0);f=d+104|0;yb(f);v[a+480208>>2]=12;v[a+1298404>>2]=5;h=a+480188|0;u[h>>1]=w[d+182|0]|w[d+183|0]<<8;u[d+24>>1]=w[d+178|0]|w[d+179|0]<<8;u[d+104>>1]=3999;C=a,D=x[Lc(e,f)>>1],u[C+480190>>1]=D;JS(Kb(a+484360|0),d+240|0,w[d+176|0]|w[d+177|0]<<8);e=0;while(1)if(x[h>>1]<=e>>>0){e=d+24|0;Md(e,b,B(w[d+178|0]|w[d+179|0]<<8,80));h=c&2;k=bc(d+104|0,e);qb(e);i=d+72|0;e=0;e:{f:{while(1){if(x[a+480190>>1]<=e>>>0){n=1;if(c&1){break f}break b}v[22452]=0;R(632,k|0,d+24|0);f=v[22452];v[22452]=0;if((f|0)==1){break e}dl(d+8|0,2,i);v[22452]=0;W(213,d+128|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);f=v[22452];v[22452]=0;if((f|0)==1){break e}e=e+1|0;f=d+128|0;sc(((e<<5)+a|0)+946304|0,f);pb(f);v[22452]=0;g=f;f=(B(e,104)+a|0)+484380|0;U(633,g|0,d+24|0,f|0);g=v[22452];v[22452]=0;g:{if((g|0)==1){break g}if(!h|!v[f>>2]){continue}g=w[d+42|0]|w[d+43|0]<<8|(w[d+44|0]<<16|w[d+45|0]<<24);v[22452]=0;g=Q(146,b|0,g|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break g}if(!g){continue}v[22452]=0;Y(210,d+128|0,f|0,b|0)|0;f=v[22452];v[22452]=0;if((f|0)!=1){continue}}break}break e}c=w[d+180|0]|w[d+181|0]<<8;v[22452]=0;l=a+484344|0;R(216,l|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break e}c=d+24|0;q=c|4;r=c|2;s=c|5;y=c|3;z=c|1;o=a+480188|0;h=0;while(1){if((w[d+180|0]|w[d+181|0]<<8)>>>0<=h>>>0){break b}v[22452]=0;a=Y(217,l|0,h&65535,64)|0;c=v[22452];v[22452]=0;if((c|0)==1){break e}h:{if(!a){break h}a=(h<<1)+d|0;a=w[a+496|0]|w[a+497|0]<<8;if(!a){break h}v[22452]=0;a=Q(146,b|0,a<<4)|0;c=v[22452];v[22452]=0;if((c|0)==1){break e}if(!a){break h}m=0;c=Qc(Rb(l,h),0,0);while(1){if(m>>>0>63){break h}v[22452]=0;a=Q(147,b|0,1)|0;e=v[22452];v[22452]=0;i:{if((e|0)!=1){if(!a){break h}v[22452]=0;i=T(197,b|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break e}if(i){break i}m=m+1|0;c=B(x[o>>1],6)+c|0;continue}break e}u[d+28>>1]=0;v[d+24>>2]=0;A=Fh(d+24|0);a=i&31;e=a>>>0<x[o>>1];f=B(a,6)+c|0;j:{if(!(i&32)){break j}v[22452]=0;R(254,d+128|0,b|0);a=v[22452];v[22452]=0;if((a|0)==1){break e}g=e?f:d+24|0;j=d+128|0;a=w[j|0];t[g|0]=a;C=e?f+1|0:z,D=w[Zc(j)|0],t[C|0]=D;k:{if(a){if((a|0)==254){break k}if(a>>>0<121){break j}}a=0}t[g|0]=a}l:{if(!(i&64)){break l}v[22452]=0;R(254,d+128|0,b|0);a=v[22452];v[22452]=0;if((a|0)==1){break e}g=e?f+3|0:y;p=d+128|0;a=w[p|0];t[g|0]=a;j=e?f+5|0:s;C=j,D=w[Zc(p)|0],t[C|0]=D;m:{if(a>>>0>=16){if(a>>>0<=23){a=w[a+26999|0];t[g|0]=a;break m}t[g|0]=0;break l}Mf(e?f:A);a=w[g|0]}if((a|0)!=23){if((a|0)!=9){break l}t[g|0]=20;t[d+8|0]=w[j|0]>>>3;t[d+127|0]=1;C=j,D=w[$e(d+8|0,d+127|0)|0]-1&15|128,t[C|0]=D;break l}t[d+8|0]=64;C=j,D=w[Qb(j,d+8|0)|0]<<1,t[C|0]=D}if(!(i&128)){continue}t[(e?f+2|0:r)|0]=1;v[22452]=0;a=T(197,b|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break e}t[(e?f+4|0:q)|0]=a;continue}}h=h+1|0;continue}}e=P()|0;O()|0;qb(k);break c}else{f=(e<<5)+a|0;Le(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+208|0]<<4|4)&244;e=e+1|0;continue}}e=P()|0;O()|0;pb(d+128|0);break d}e=P()|0;O()|0}yb(d+104|0)}S(e|0);L()}qb(k)}ab=d+752|0;return n|0}function xZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=ab+-64|0;ab=h;v[h+56>>2]=b;v[e>>2]=0;zc(h,d);v[22452]=0;i=T(1111,h|0)|0;j=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Nb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Nb(h);S(a|0);L()}YE(a,f+24|0,h+56|0,c,e,i);break b}XE(a,f+16|0,h+56|0,c,e,i);break b}g=a;i=b;a=eb[v[v[a+8>>2]+12>>2]](a+8|0)|0;b=Eb(a);k=h,l=zj(g,i,c,d,e,f,b,b+(ub(a)<<2)|0),v[k+56>>2]=l;break b}a=Gi(h+56|0,c,e,i,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}g=v[19959];v[h+24>>2]=v[19958];v[h+28>>2]=g;g=v[19957];v[h+16>>2]=v[19956];v[h+20>>2]=g;g=v[19955];v[h+8>>2]=v[19954];v[h+12>>2]=g;g=v[19953];v[h>>2]=v[19952];v[h+4>>2]=g;k=h,l=zj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}g=v[19967];v[h+24>>2]=v[19966];v[h+28>>2]=g;g=v[19965];v[h+16>>2]=v[19964];v[h+20>>2]=g;g=v[19963];v[h+8>>2]=v[19962];v[h+12>>2]=g;g=v[19961];v[h>>2]=v[19960];v[h+4>>2]=g;k=h,l=zj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=Gi(h+56|0,c,e,i,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Gi(h+56|0,c,e,i,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Gi(h+56|0,c,e,i,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Gi(h+56|0,c,e,i,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Gi(h+56|0,c,e,i,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+56|0;b=ab-16|0;ab=b;v[b+8>>2]=c;while(1){H:{if(!ur(a,b+8|0)){break H}if(!xk(i,8192,yk(v[a>>2]))){break H}Sm(a);continue}break}if(wk(a,b+8|0)){v[e>>2]=v[e>>2]|2}ab=b+16|0;break b}b=h+56|0;a=eb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((ub(a)|0)==(0-ub(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=hr(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=gc(h,79872,44);k=g,l=zj(a,b,c,d,e,f,g,g+44|0),v[k+56>>2]=l;break b}v[h+16>>2]=v[19984];g=v[19983];v[h+8>>2]=v[19982];v[h+12>>2]=g;g=v[19981];v[h>>2]=v[19980];v[h+4>>2]=g;k=h,l=zj(a,b,c,d,e,f,h,h+20|0),v[k+56>>2]=l;break b}a=Gi(h+56|0,c,e,i,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}g=v[19995];v[h+24>>2]=v[19994];v[h+28>>2]=g;g=v[19993];v[h+16>>2]=v[19992];v[h+20>>2]=g;g=v[19991];v[h+8>>2]=v[19990];v[h+12>>2]=g;g=v[19989];v[h>>2]=v[19988];v[h+4>>2]=g;k=h,l=zj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=Gi(h+56|0,c,e,i,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=eb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=eb[v[v[a+8>>2]+24>>2]](a+8|0)|0;b=Eb(a);k=h,l=zj(g,i,c,d,e,f,b,b+(ub(a)<<2)|0),v[k+56>>2]=l;break b}WE(f+20|0,h+56|0,c,e,i);break b}a=Gi(h+56|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=ab-16|0;ab=a;v[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(wk(c,a+8|0)){break M}b=4;if((Jm(i,yk(v[c>>2]))|0)!=37){break M}b=2;if(!wk(Sm(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}ab=a+16|0}a=v[h+56>>2]}ab=h- -64|0;return a|0}function T7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0;d=ab-128|0;ab=d;g=-1;a:{b:{c:{d:{if(!uh(v[v[b>>2]-12>>2]+b|0)){break d}e=d+112|0;Xd(e,b);f=v[e+8>>2];l=v[e+12>>2];e=d+104|0;nl(e);b=Ck(b,e,8);if(Ib(e,16685,8)){a=Zg(d+88|0,f,l);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;yj(b,d+8|0);break d}u[d+86>>1]=0;Kf(b,d+86|0);l=x[d+86>>1];if((l&65534)!=2){break d}f=d+78|0;nl(f);e=Ck(b,f,8);if(Ib(f,14272,8)){break d}u[d+76>>1]=0;Kf(e,d+76|0);f=u[d+76>>1];if((f-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{if(f>>>0<=3){b=Bb(d+112|0);v[22452]=0;h=Y(442,e|0,b|0,65535)|0;k=v[22452];v[22452]=0;if((k|0)==1){break b}if(!h){break i}v[22452]=0;U(11,d- -64|0,c|0,b|0);h=v[22452];v[22452]=0;if((h|0)!=1){break j}break b}b=Bb(d+112|0);v[22452]=0;h=Q(444,e|0,b|0)|0;k=v[22452];v[22452]=0;if((k|0)==1){break c}if(!h){break h}v[22452]=0;U(11,d- -64|0,c|0,b|0);h=v[22452];v[22452]=0;if((h|0)==1){break c}}h=d- -64|0;tb(a+40|0,h);pb(h);pb(b);u[d+62>>1]=0;Kf(e,d+62|0);u[d+60>>1]=0;Kf(e,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;k:{if((f|0)<=3){v[d+112>>2]=0;Xj(e,d+112|0);b=v[d+112>>2];if(b>>>0>65535){break d}b=Wt(b);u[d+58>>1]=b;break k}Kf(e,d+58|0);b=x[d+58>>1]}h=a+52|0;k=b&65535;n=(f|0)>3;f=0;l:{m:{while(1){if(k>>>0<=(f&65535)>>>0){break l}b=Bb(d+112|0);v[22452]=0;u[d+40>>1]=0;R(868,e|0,d+40|0);i=v[22452];v[22452]=0;if((i|0)==1){break g}n:{if(!n){v[22452]=0;i=Y(442,e|0,b|0,65535)|0;j=v[22452];v[22452]=0;if((j|0)==1){break g}if(i){break n}break e}v[22452]=0;i=Q(444,e|0,b|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break g}if(!i){break e}}v[22452]=0;U(11,d- -64|0,c|0,b|0);i=v[22452];v[22452]=0;if((i|0)!=1){v[22452]=0;i=Q(865,h|0,d+40|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break m}j=i;i=d- -64|0;tb(j,i);pb(i);pb(b);f=f+1|0;continue}break}g=P()|0;O()|0;break f}g=P()|0;O()|0;pb(d- -64|0);break f}c=d- -64|0;nl(c);b=Ck(e,c,8);if(Ib(c,14216,8)){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;e=l<<16>>16;o:{if((e|0)<=2){if(eK(b,c)){break o}break d}if(!dK(b,c)){break d}}o=d,p=wb(v[a+4>>2]),v[o+112>>2]=p;c=wb(v[a+8>>2]);while(1){f=v[d+112>>2];if(Tb(f,c)){if(!Hl(z[f>>2])){break d}te(d+112|0);continue}break}c=a+16|0;p:{if((e|0)<=2){if(eK(b,c)){break p}break d}if(!dK(b,c)){break d}}o=d,p=wb(v[a+16>>2]),v[o+112>>2]=p;c=wb(v[a+20>>2]);while(1){e=v[d+112>>2];if(Tb(e,c)){if(!Hl(z[e>>2])){break d}te(d+112|0);continue}break}o=a,p=nc(v[a+16>>2],v[a+20>>2]),v[o+36>>2]=p;u[d+56>>1]=0;Kf(b,d+56|0);c=x[d+56>>1];u[a+28>>1]=c;if((c-201&65535)>>>0<65135){break d}u[d+54>>1]=0;Kf(b,d+54|0);c=u[d+54>>1];u[a+30>>1]=c;if((c|0)<0){break d}v[d+48>>2]=0;Vo(b,d+48|0);m=gK(z[d+48>>2]);z[a+32>>2]=m;if(!Hl(m)){break d}c=d+40|0;nl(c);Ck(b,c,8);if(Ib(c,16676,8)){break d}b=nc(v[a+4>>2],v[a+8>>2]);if(b>>>0>32767){break d}c=u[a+30>>1];e=a+32|0;q:{if(!(z[e>>2]<=C(0)?0:(c|0)>0)){if(!x[a>>1]){break q}break d}r:{switch(x[a>>1]-1|0){case 0:case 2:break r;default:break q}}if(b>>>0<c>>>0){break d}}b=0;c=v[a+36>>2];if(c){b=c-1|0;v[a+36>>2]=b}o=d,p=oi(b),v[o+112>>2]=p;v[d+32>>2]=0;o=a,p=v[nj(d+112|0,d+32|0,43984)>>2],v[o+36>>2]=p;Wo(a);g=1;if(x[a>>1]!=3){break d}if((u[a+30>>1]-u[a+28>>1]|0)>(oK(nc(v[a+4>>2],v[a+8>>2]))|0)){break d}c=Pb(d+112|0);b=0;while(1){s:{if(u[a+30>>1]<=(b|0)){b=x[a+28>>1];u[d+32>>1]=b;o=d,p=(nc(v[a+4>>2],v[a+8>>2])+b|0)-1|0,u[o+34>>1]=p;v[22452]=0;u[d+30>>1]=0;ea(863,a|0,c|0,e|0,d+32|0,d+30|0)|0;a=v[22452];v[22452]=0;g=1;if((a|0)==1){break s}ec(c);break d}g=u[a+28>>1];f=v[a+4>>2];v[22452]=0;R(869,c|0,Fb(f,b-g|0)|0);g=v[22452];v[22452]=0;if((g|0)!=1){b=b+1|0;continue}}break}g=P()|0;O()|0;ec(c);break a}pb(b);break d}pb(b);break d}g=P()|0;O()|0}pb(b);break a}pb(b)}ab=d+128|0;return g|0}g=P()|0;O()|0;pb(b);break a}g=P()|0;O()|0;pb(b)}S(g|0);L()}function Rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;d=ab-336|0;ab=d;qc(b);a:{if(!Wn(b,d+320|0)){break a}if(!bT(d+320|0)){break a}if(!Ib(d+320|0,14139,4)){Ob(b,4)}if(!Mh(b,d+312|0)){break a}if(Ib(d+312|0,14115,4)){break a}if(!c){f=1;break a}n=d+312|4;e=n;BB(b,d+120|0,w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));if((w[d+156|0]|w[d+157|0]<<8)>>>0>128|(w[d+162|0]|w[d+163|0]<<8)>>>0>16|((w[d+160|0]|w[d+161|0]<<8)>>>0>256|(w[d+154|0]|w[d+155|0]<<8)>>>0>128)){break a}vd(a,8192);i=d+32|0;e=Mb(i,6500);tb(a+1298344|0,e);pb(e);e=Mb(i,10102);tb(a+1298356|0,e);pb(e);v[a+1298404>>2]=5;e=d+96|0;dl(e,2,d+120|0);tc(i,v[d+96>>2],v[d+100>>2],w[d+104|0]);tb(a+1298308|0,i);pb(i);u[d+32>>1]=w[d+162|0]|w[d+163|0]<<8;u[d+96>>1]=1;g=x[Ne(i,e)>>1];u[a+480188>>1]=g;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+32|0]=w[d+164|0];t[d+96|0]=64;e=w[Qb(i,e)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=w[d+165|0];b:{if((e|0)==128){v[d+32>>2]=256/(g>>>0);v[d+96>>2]=128;e=v[zb(d+32|0,d+96|0)>>2];break b}e=e&127}v[a+480228>>2]=e;while(1){if((f|0)==16){i=a+484360|0;o=Kb(i);g=d+184|0;k=ab-16|0;ab=k;v[k+12>>2]=w[d+156|0]|w[d+157|0]<<8;e=k+12|0;mc(e,128);mc(e,65535);e=x[k+12>>1];mf(o,e);f=0;while(1){if((e|0)==(f|0)){ab=k+16|0}else{p=w[f+g|0];s=yi(v[o>>2],v[o+4>>2],f),y=(p|0)==255?-1:(p|0)==254?-2:p,u[s>>1]=y;f=f+1|0;continue}break}e=w[d+154|0]|w[d+155|0]<<8;if(e>>>0<(w[d+156|0]|w[d+157|0]<<8)>>>0){Re(Kb(i),e)}k=c&2;q=a+484344|0;f=1;o=c&1;p=d+68|0;i=a+480188|0;while(1){if(!Mh(b,d+312|0)){break a}c=d+32|0;Md(c,b,w[n|0]|w[n+1|0]<<8|(w[n+2|0]<<16|w[n+3|0]<<24));l=bc(d+96|0,c);qb(c);c:{d:{if(!(Ib(d+312|0,13553,4)|!o)){v[22452]=0;g=r&65535;e=Y(217,q|0,g|0,64)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}if(!e){break c}v[22452]=0;Q(179,d+96|0,2)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}kh(d+32|0);m=0;e:{while(1){v[22452]=0;e=Q(147,d+96|0,1)|0;c=v[22452];v[22452]=0;f:{if((c|0)!=1){if(!(e&m>>>0<64)){break e}v[22452]=0;h=T(197,l|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}if(h){break f}m=m+1|0;continue}break d}j=d+32|0;c=h&15;if(c>>>0<x[i>>1]){j=Qc(Rb(q,g),m,c)}g:{if(!(h&128)){break g}v[22452]=0;e=T(197,l|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}if(!e){break g}t[j|0]=e>>>0<109?e+12|0:e}if(h&64){v[22452]=0;e=T(197,l|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}t[j+1|0]=e}if(h&32){t[j+2|0]=1;v[22452]=0;e=T(197,l|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}t[d+16|0]=e;t[d|0]=64;s=j,y=w[Qb(d+16|0,d)|0],t[s+4|0]=y}if(!(h&16)){continue}v[22452]=0;R(254,d+16|0,l|0);c=v[22452];v[22452]=0;if((c|0)!=1){e=d+16|0;h=Zc(e);h:{i:{j:{k:{l:{c=w[e|0];switch(c-17|0){case 2:break k;case 0:case 1:break l;default:break j}}c=c&15;break i}t[e|0]=33;t[h|0]=145;c=w[e|0];break h}if(c>>>0<17){break h}c=(c&240)==32?9:-1}t[e|0]=c}t[j+3|0]=c;t[j+5|0]=w[h|0];Mf(j);continue}break}break d}r=r+1|0;break c}if(Ib(d+312|0,13558,4)){break c}if(!Dh(a)){break c}e=x[a+480190>>1]+1|0;u[a+480190>>1]=e;v[22452]=0;R(314,l|0,d+32|0);c=v[22452];v[22452]=0;m:{if((c|0)==1){break m}v[22452]=0;g=(B(e&65535,104)+a|0)+484380|0;R(315,d+32|0,g|0);c=v[22452];v[22452]=0;if((c|0)==1){break m}dl(d,2,p);v[22452]=0;W(213,d+16|0,v[d>>2],v[d+4>>2],w[d+8|0]);c=v[22452];v[22452]=0;if((c|0)==1){break m}c=d+16|0;sc(((x[a+480190>>1]<<5)+a|0)+946304|0,c);pb(c);if(!k){break c}e=d+16|0;m=Gc(e,8,1,0,1);j=2;h=d+45|0;c=w[h|0]|w[h+1|0]<<8;n:{if(!(c&64)){j=0;if(!(c&2)){break n}}nf(m,j)}if(w[h|0]&4){vh(m,16)}v[22452]=0;Y(210,e|0,g|0,l|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break c}}}a=P()|0;O()|0;qb(d+96|0);S(a|0);L()}qb(d+96|0);continue}}g=(f<<5)+a|0;Le(g+480280|0);e=w[(d+f|0)+168|0];if(e>>>0<=128){u[g+480284>>1]=e<<1}f=f+1|0;continue}}ab=d+336|0;return f|0}function qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=ab-256|0;ab=e;qc(b);a:{if(!vT(b,e+184|0)){break a}if(!vQ(e+184|0)){break a}if(!Hb(b,Fc(uQ(e+184|0),db))){break a}b:{if(!c){break b}vd(a,16);f=e+24|0;g=e+184|0;lj(f,2,g|4);d=e+48|0;tc(d,v[e+24>>2],v[e+28>>2],w[e+32|0]);tb(a+1298308|0,d);pb(d);l=a+480190|0;u[l>>1]=w[e+214|0];u[a+480188>>1]=w[e+217|0];h=Mb(d,8352);tb(a+1298344|0,h);pb(h);h=Mb(d,10090);tb(a+1298356|0,h);pb(h);af(f,4172);g=w[g|3];v[e>>2]=g>>>4;v[22452]=0;v[e+180>>2]=g&15;W(295,d|0,f|0,e|0,e+180|0);d=v[22452];v[22452]=0;c:{d:{e:{if((d|0)!=1){d=e+48|0;tb(a+1298368|0,d);pb(d);yb(e+24|0);v[a+1298404>>2]=5;g=1;while(1){j=g&65535;if(j>>>0>x[l>>1]){g=0;d=a+480188|0;while(1)if(x[d>>1]<=g>>>0){d=e+48|0;f=ab-16|0;ab=f;h=b;f:{if(!Hb(b,128)){b=d;g=d+128|0;while(1){if((b|0)!=(g|0)){rf(b);b=b+1|0;continue}break}break f}PR(f+8|0,d);fd(f,h,v[f+8>>2],v[f+12>>2])}ab=f+16|0;tC(Kb(a+484360|0),d,w[e+211|0]+1|0);b=w[e+216|0];Md(e,h,B(w[e+208|0]|w[e+209|0]<<8,192));i=bc(e+24|0,e);qb(e);n=c&1;if(n){d=w[e+210|0];v[22452]=0;R(216,a+484344|0,d+1|0);d=v[22452];v[22452]=0;if((d|0)==1){break d}}o=b?b:64;p=a+484344|0;q=a+480188|0;while(1){if(w[e+210|0]<m>>>0){b=w[e+212|0]|w[e+213|0]<<8;if(b){v[22452]=0;ga(306,a+1298332|0,h|0,b|0,39,1);b=v[22452];v[22452]=0;if((b|0)==1){break d}}if(!(c&2)){break e}b=a+480190|0;g=1;while(1){c=g&65535;if(c>>>0>x[b>>1]){break e}c=B(c,104)+a|0;d=Gc(e,u[c+484414>>1]&1?16:8,1,0,1);v[22452]=0;Y(210,d|0,c+484380|0,h|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){g=g+1|0;continue}break}break d}g:{h:{if(n){v[22452]=0;b=Y(217,p|0,m&65535,o|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break d}k=0;if(b){break h}}v[22452]=0;Q(179,h|0,64)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break g}break d}while(1){d=k&65535;if(d>>>0>31){break g}v[22452]=0;b=T(185,h|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break d}i:{if(!b|b>>>0>(w[e+208|0]|w[e+209|0]<<8)>>>0|d>>>0>=x[q>>1]){break i}v[22452]=0;Q(146,i|0,B(b,192)-192|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break d}l=0;g=Qc(Rb(p,m),0,d);while(1){if((l|0)==(o|0)){break i}v[22452]=0;R(496,e|0,i|0);b=v[22452];v[22452]=0;if((b|0)!=1){j=Zc(e);d=Me(e);b=w[e|0];if(b>>>0>=4){t[g|0]=(b>>>2|0)+37;b=w[e|0]}t[g+1|0]=b<<4&48|w[j|0]>>>4;b=w[d|0];d=0;f=0;j:{k:{l:{m:{n:{o:{j=w[j|0]&15;switch(j-8|0){case 0:break l;case 6:break n;case 2:break o;default:break m}}b=(b&240?-16:15)&b;j=10;break k}j=14;r=(b+16&240)>>>4|0;if(r>>>0>8){break k}if(1<<r&435){break l}break k}d=j;f=b}j=d;b=f;if(!((d|f)&255)){break j}}t[g+5|0]=b;t[g+3|0]=j;Mf(g)}l=l+1|0;g=B(x[q>>1],6)+g|0;continue}break}break d}k=k+1|0;continue}}m=m+1|0;continue}}else{f=(g<<5)+a|0;Le(f+480280|0);u[f+480284>>1]=(w[(e+g|0)+218|0]<<4|8)&248;g=g+1|0;continue}}else{f=e+48|0;lC(b,f);h=ab-16|0;ab=h;d=(B(j,104)+a|0)+484380|0;ed(d,0);u[h+14>>1]=w[f+35|0]<<2;u[h+12>>1]=256;s=d,y=x[Lc(h+14|0,h+12|0)>>1],u[s+30>>1]=y;i=w[f+22|0]|w[f+23|0]<<8|(w[f+24|0]<<16|w[f+25|0]<<24);p:{if(i>>>0<3){break p}v[d>>2]=i;v[d+4>>2]=w[f+26|0]|w[f+27|0]<<8|(w[f+28|0]<<16|w[f+29|0]<<24);v[h+8>>2]=w[f+30|0]|w[f+31|0]<<8|(w[f+32|0]<<16|w[f+33|0]<<24);v[h+4>>2]=1;s=d,y=v[Pc(h+8|0,h+4|0)>>2]-1|0,v[s+8>>2]=y;mc(d+8|0,i);k=v[d+8>>2];i=v[d+4>>2];q:{if(k>>>0<=i+4>>>0){v[d+4>>2]=0;v[d+8>>2]=0;k=0;i=0;break q}u[d+34>>1]=x[d+34>>1]|2;k=k>>>1|0;i=i>>>1|0}t[d+37|0]=w[f+34|0];s=d,y=tu(0,t[f+34|0]<<4),v[s+24>>2]=y;if(!(t[f+36|0]&1)){break p}v[d+8>>2]=k;v[d+4>>2]=i;u[d+34>>1]=x[d+34>>1]|1;v[d>>2]=v[d>>2]>>>1}ab=h+16|0;gl(e,2,f);d=e+24|0;tc(d,v[e>>2],v[e+4>>2],w[e+8|0]);sc(((j<<5)+a|0)+946304|0,d);g=g+1|0;pb(d);continue}}}g=P()|0;O()|0;yb(e+24|0);break c}v[a+480260>>2]=64;v[a+480264>>2]=32767;qb(i);break b}g=P()|0;O()|0;qb(i)}S(g|0);L()}g=1}ab=e+256|0;return g|0}function fha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=ab-736|0;ab=i;a:{b:{if(d>>>0<=511){a=ab-16|0;ab=a;f=i+56|0;Ub(a+8|0,f,554);d=v[a+12>>2];_b(a,b,v[a+8>>2],d);h=v[a+4>>2];if((h|0)==(d|0)){Ob(b,v[a+12>>2])}ab=a+16|0;a=(d|0)==(h|0);if(!a){Jb(f,0,554)}if(!a){break b}b=ab-32|0;ab=b;c:{a=i+56|0;if(Ib(a,13972,4)){break c}zq(b,a+32|0);d=b+16|0;tc(d,v[b>>2],v[b+4>>2],w[b+8|0]);sc(c+492|0,d);pb(d);Hh(b,1,a+4|0);tc(d,v[b>>2],v[b+4>>2],w[b+8|0]);sc(c+524|0,d);pb(d);d=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=d<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];f=c+108|0;h=c+236|0;while(1)if((e|0)==120){d=w[c+60|0]&-2|t[a+17|0]&1;t[c+60|0]=d;d=d&-3|w[a+17|0]&2;t[c+60|0]=d;t[c+60|0]=d&251|w[a+17|0]&4;f=c+61|0;t[f|0]=w[a+18|0];h=c+62|0;t[h|0]=w[a+19|0];g=c+63|0;t[g|0]=w[a+20|0];j=c- -64|0;t[j|0]=w[a+21|0];d=c+48|0;Wg(d,25);k=v[c+48>>2];e=0;while(1){d:{if((e|0)!=25){l=Fb(k,e);m=e<<1;n=w[(a+m|0)+504|0];u[l>>1]=n;if((n|0)!=255){break d}Wg(d,e)}a=$e(f,h);if(Td(d)>>>0<=w[a|0]){t[c+60|0]=w[c+60|0]&253}a=$e(g,j);if(Td(d)>>>0>w[a|0]){break c}t[c+60|0]=w[c+60|0]&251;break c}t[l+2|0]=w[(a+(m|1)|0)+504|0];e=e+1|0;continue}}else{g=a+(e<<1)|0;d=w[g- -64|0];o=Yb(h,e),p=w[g+65|0],u[o>>1]=p;o=Cb(f,e),p=(d>>>0<120?d:e)+1|0,t[o|0]=p;e=e+1|0;continue}}ab=b+32|0;break b}h=v[b+8>>2];e=ab-32|0;ab=e;v[e+28>>2]=674;v[e+8>>2]=674;f=v[zb(e+28|0,e+8|0)>>2];if(!Hb(b,f)){f=Ze(b)}g=e+8|0;d=i+56|0;tS(g,d);j=Zb(e+16|0,v[e+8>>2],f);_b(e,b,v[j>>2],v[j+4>>2]);tS(g,d);Jb(v[e+8>>2]+f|0,0,674-f|0);Ob(b,v[e+28>>2]);ab=e+32|0;f=v[a+480180>>2];a=0;e=ab-32|0;ab=e;if(!Ib(d,13972,4)){zq(e,d+32|0);a=e+16|0;tc(a,v[e>>2],v[e+4>>2],w[e+8|0]);sc(c+492|0,a);pb(a);Hh(e,1,d+4|0);tc(a,v[e>>2],v[e+4>>2],w[e+8|0]);sc(c+524|0,a);pb(a);v[c>>2]=(w[d+20|0]|w[d+21|0]<<8)<<5;v[c+4>>2]=w[d+24|0]>>>1;mc(c+4|0,64);g=w[d+25|0]&127;v[c+8>>2]=g>>>0>64?128:g<<2;t[c+15|0]=w[c+15|0]&254|((w[d+25|0]^-1)&128)>>>7;t[e+16|0]=w[d+26|0];t[e|0]=100;o=c,p=w[Qb(a,e)|0],t[o+20|0]=p;t[e+16|0]=w[d+27|0];t[e|0]=64;o=c,p=w[Qb(a,e)|0],t[o+19|0]=p;t[c+16|0]=w[d+17|0];t[c+17|0]=w[d+18|0];t[c+18|0]=w[d+19|0];t[c+26|0]=w[d+22|0];t[c+27|0]=w[d+23|0];a=w[d+58|0];rm(c,a&127,a>>>7|0);a=w[d+59|0];qm(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{a=w[d+28|0]|w[d+29|0]<<8;switch(a-529|0){case 1:case 2:break g;case 0:case 3:break h;default:break i}}if((a|0)==544){break h}if((a|0)!=514){break g}}a=w[d+61|0];if((a|0)==255){break g}if(a>>>0<=128){t[c+30|0]=a}a=w[d+62|0]|w[d+63|0]<<8;if(a>>>0<129){break f}break e}a=t[d+61|0];if((a|0)>=0){t[c+30|0]=a+1}a=w[d+62|0];a=a<<24>>24>=0?a+1|0:0;g=t[d+63|0];if((g|0)<0){break f}a=((g&255)<<7)+a|0}u[c+28>>1]=a}a=t[d+60|0];t[c+31|0]=a;if((a|0)<0){t[c+31|0]=0;t[c+34|0]=a^128}a=0;f=f&16777216?240:25;Pu(d+304|0,c+48|0,0,f);Pu(d+386|0,c+68|0,32,f);Pu(d+468|0,c+88|0,32,f);t[c+100|0]=w[c+100|0]&239|w[d+468|0]>>>3&16;g=c+108|0;j=c+236|0;while(1){if((a|0)!=120){k=d+(a<<1)|0;f=w[k- -64|0];o=Yb(j,a),p=w[k+65|0],u[o>>1]=p;o=Cb(g,a),p=(f>>>0<120?f:a)+1|0,t[o|0]=p;a=a+1|0;continue}break}a=554}ab=e+32|0;if(a){j:{e=d+550|0;if(Ib(e,13490,4)){if(Ib(e,13804,4)){break j}}e=c+236|0;a=0;while(1){if((a|0)!=120){f=Yb(e,a);u[f>>1]=x[f>>1]|w[(a+d|0)+554|0]<<8;a=a+1|0;continue}break}a=674}}else{a=0}Nc(b,a+h|0);if(!oh(b,13977)){break b}d=i+8|0;Md(d,b,jg(b));a=bc(i+32|0,d);qb(d);v[22452]=0;T(151,a|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break a}v[22452]=0;b=Q(359,a|0,13727)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}if(b){v[22452]=0;b=T(197,a|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}t[c+34|0]=b>>>0>250?0:b}qb(a)}ab=i+736|0;return}b=P()|0;O()|0;qb(a);S(b|0);L()}function DZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=ab-32|0;ab=h;v[h+24>>2]=b;v[e>>2]=0;i=h+8|0;zc(i,d);v[22452]=0;i=T(18,i|0)|0;j=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Nb(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Nb(h+8|0);S(a|0);L()}$E(a,f+24|0,h+24|0,c,e,i);break b}_E(a,f+16|0,h+24|0,c,e,i);break b}g=a;i=b;a=eb[v[v[a+8>>2]+12>>2]](a+8|0)|0;b=Eb(a);k=h,l=Aj(g,i,c,d,e,f,b,ub(a)+b|0),v[k+24>>2]=l;break b}a=Hi(h+24|0,c,e,i,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;k=h,l=Aj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;k=h,l=Aj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=Hi(h+24|0,c,e,i,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Hi(h+24|0,c,e,i,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Hi(h+24|0,c,e,i,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Hi(h+24|0,c,e,i,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Hi(h+24|0,c,e,i,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+24|0;b=ab-16|0;ab=b;v[b+8>>2]=c;while(1){H:{if(!Eo(a,b+8|0)){break H}if(!_g(i,8192,Ak(v[a>>2]))){break H}vl(a);continue}break}if(Cj(a,b+8|0)){v[e>>2]=v[e>>2]|2}ab=b+16|0;break b}b=h+24|0;a=eb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((ub(a)|0)==(0-ub(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=jr(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=w[79796]|w[79797]<<8|(w[79798]<<16|w[79799]<<24);t[h+15|0]=g;t[h+16|0]=g>>>8;t[h+17|0]=g>>>16;t[h+18|0]=g>>>24;g=w[79793]|w[79794]<<8|(w[79795]<<16|w[79796]<<24);v[h+8>>2]=w[79789]|w[79790]<<8|(w[79791]<<16|w[79792]<<24);v[h+12>>2]=g;k=h,l=Aj(a,b,c,d,e,f,h+8|0,h+19|0),v[k+24>>2]=l;break b}t[h+12|0]=w[79804];v[h+8>>2]=w[79800]|w[79801]<<8|(w[79802]<<16|w[79803]<<24);k=h,l=Aj(a,b,c,d,e,f,h+8|0,h+13|0),v[k+24>>2]=l;break b}a=Hi(h+24|0,c,e,i,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;k=h,l=Aj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=Hi(h+24|0,c,e,i,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=eb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=eb[v[v[a+8>>2]+24>>2]](a+8|0)|0;b=Eb(a);k=h,l=Aj(g,i,c,d,e,f,b,ub(a)+b|0),v[k+24>>2]=l;break b}ZE(f+20|0,h+24|0,c,e,i);break b}a=Hi(h+24|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=ab-16|0;ab=a;v[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(Cj(c,a+8|0)){break M}b=4;if((Km(i,Ak(v[c>>2]))|0)!=37){break M}b=2;if(!Cj(vl(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}ab=a+16|0}a=v[h+24>>2]}ab=h+32|0;return a|0}function x4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=ab-128|0;ab=f;a:{if(pd(b)){break a}e=w[BI(b)|0];if((e|0)==33){d=1}else{if((e|0)!=63){break a}d=0}e=f+112|0;$q(e,b,0,ub(b)-1|0);tb(b,e);pb(e)}g=f+112|0;Dd(g);e=v[f+112>>2];Dd(f+96|0);e=AI(e,v[f+100>>2],b);Dd(g);b:{c:{d:{e:{if((e|0)==v[f+116>>2]){if(ge(b,21598)){a=aa(8)|0;v[22452]=0;U(930,f+112|0,17577,c|0);b=v[22452];v[22452]=0;if((b|0)==1){break d}lc(a,f+112|0);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(f+112|0);break c}if(!d){break e}a=aa(8)|0;v[22452]=0;U(930,f+80|0,17613,b|0);b=v[22452];v[22452]=0;f:{g:{h:{i:{j:{if((b|0)!=1){v[22452]=0;R(941,f+96|0,f+80|0);b=v[22452];v[22452]=0;if((b|0)==1){break j}v[22452]=0;U(491,f+112|0,f+96|0,c|0);b=v[22452];v[22452]=0;d=1;if((b|0)==1){break i}lc(a,f+112|0);v[22452]=0;U(110,a|0,58760,928);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;pb(f+112|0);d=0;break h}b=P()|0;O()|0;break f}b=P()|0;d=1;O()|0;break g}b=P()|0;O()|0}pb(f+96|0)}pb(f+80|0);if(!d){break c}}ba(a|0);break c}k:{switch(v[e+4>>2]){case 0:qe(f+72|0,b);b=ab-192|0;ab=b;e=b+16|0;ch(e,c);v[22452]=0;R(79,b+32|0,e|0);c=v[22452];v[22452]=0;l:{m:{n:{o:{p:{if((c|0)!=1){v[22452]=0;c=Q(80,b+48|0,b+32|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break p}pb(b+32|0);pb(b+16|0);e=v[v[c>>2]-12>>2];v[22452]=0;g=ha(62)|0;h=v[22452];v[22452]=0;if((h|0)==1){break n}v[22452]=0;U(63,b+8|0,e+(b+48|0)|0,g|0);e=v[22452];v[22452]=0;if((e|0)==1){break n}Nb(b+8|0);v[22452]=0;Q(1041,c|0,b+32|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break n}e=Fj(v[v[c>>2]-12>>2]+(b+48|0)|0);g=w[b+32|0];ef(c);ab=b+192|0;b=(e^-1)&(g|0)!=0;break l}a=P()|0;O()|0;break o}a=P()|0;O()|0;pb(b+32|0)}pb(b+16|0);break m}a=P()|0;O()|0;ef(c)}S(a|0);L()}c=v[f+76>>2];v[f>>2]=v[f+72>>2];v[f+4>>2]=c;VI(a,f,b,d);break e;case 1:qe(f- -64|0,b);b=ab-192|0;ab=b;e=b+16|0;ch(e,c);v[22452]=0;R(79,b+32|0,e|0);c=v[22452];v[22452]=0;q:{r:{s:{t:{u:{if((c|0)!=1){v[22452]=0;c=Q(80,b+48|0,b+32|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break u}pb(b+32|0);pb(b+16|0);e=v[v[c>>2]-12>>2];v[22452]=0;g=ha(62)|0;h=v[22452];v[22452]=0;if((h|0)==1){break s}v[22452]=0;U(63,b+8|0,e+(b+48|0)|0,g|0);e=v[22452];v[22452]=0;if((e|0)==1){break s}Nb(b+8|0);v[22452]=0;Q(86,c|0,b+32|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break s}e=Fj(v[v[c>>2]-12>>2]+(b+48|0)|0);g=v[b+32>>2];h=v[b+36>>2];ef(c);ab=b+192|0;b=e?0:g;c=e?0:h;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;pb(b+32|0)}pb(b+16|0);break r}a=P()|0;O()|0;ef(c)}S(a|0);L()}e=v[f+68>>2];v[f+8>>2]=v[f+64>>2];v[f+12>>2]=e;TI(a,f+8|0,b,c,d);break e;case 2:qe(f+56|0,b);b=ab-192|0;ab=b;e=b+16|0;ch(e,c);v[22452]=0;R(79,b+32|0,e|0);c=v[22452];v[22452]=0;v:{w:{x:{y:{z:{if((c|0)!=1){v[22452]=0;c=Q(80,b+48|0,b+32|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break z}pb(b+32|0);pb(b+16|0);e=v[v[c>>2]-12>>2];v[22452]=0;g=ha(62)|0;h=v[22452];v[22452]=0;if((h|0)==1){break x}v[22452]=0;U(63,b+8|0,e+(b+48|0)|0,g|0);e=v[22452];v[22452]=0;if((e|0)==1){break x}Nb(b+8|0);v[22452]=0;Q(87,c|0,b+32|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break x}e=Fj(v[v[c>>2]-12>>2]+(b+48|0)|0);i=A[b+32>>3];ef(c);ab=b+192|0;i=e?0:i;break v}a=P()|0;O()|0;break y}a=P()|0;O()|0;pb(b+32|0)}pb(b+16|0);break w}a=P()|0;O()|0;ef(c)}S(a|0);L()}b=v[f+60>>2];v[f+16>>2]=v[f+56>>2];v[f+20>>2]=b;UI(a,f+16|0,i,d);break e;case 3:break k;default:break e}}qe(f+48|0,b);qe(f+40|0,c);b=v[f+52>>2];v[f+32>>2]=v[f+48>>2];v[f+36>>2]=b;b=v[f+44>>2];v[f+24>>2]=v[f+40>>2];v[f+28>>2]=b;SI(a,f+32|0,f+24|0,d)}ab=f+128|0;return}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function KL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=ab-16|0;ab=f;h=a+1074376|0;g=B(b,872);e=(h+g|0)+616|0;d=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+g|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}c=B(b,872)+a|0;if(hj(v[c+1075648>>2])){u[c+1075764>>1]=d-8;a=c+1075843|0;t[a|0]=w[a|0]|64;break a}if(v[a+480180>>2]!=64){b=B(b,872)+a|0;u[b+1075764>>1]=d<<28>>24;c=x[(d<<1)+33440>>1];v[b+1075696>>2]=c;e=b+1075692|0;if(!v[e>>2]){break a}l=e,m=Kg(a,w[b+1075789|0],d<<28>>24,c),v[l>>2]=m;break a}a=B(b,872)+a|0;b=v[a+1075096>>2];if(!b){break a}v[a+1075696>>2]=v[b+24>>2]+B(d,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075814|0]=c&3;break a}rb(f+8|0,a+1074312|0,21);if(sb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075817|0]=c&3;break a}rb(f+8|0,a+1074312|0,21);if(sb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075817|0]=c&7;break a;case 4:rb(f+8|0,a+1074312|0,21);if(sb(v[v[f+8>>2]>>2],v[f+12>>2])){a=B(b,872)+a|0;t[a+1075813|0]=0;t[a+1075820|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+d;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(d>>>0<=2){d=x[a+480188>>1];i=d>>>0>256?d:256;e=a+1298300|0;j=b+1|0;k=(c&15)-1|0;while(1){if((d|0)==(i|0)){break a}c=B(d,872)+a|0;c:{if((j|0)!=x[c+1075778>>1]){break c}d:{e:{switch(k|0){case 0:tn(a,c+1074992|0);if(!(w[c+1075081|0]&2)){break d}if(!td(e)){break d}Nj(v[e>>2],d&65535);break d;case 1:g=c+1075080|0;h=v[g>>2];v[g>>2]=h|4096;if(!(h&512)){break d}if(!td(e)){break d}Nj(v[e>>2],d&65535);break d;default:break e}}v[c+1075688>>2]=0;g=c+1075080|0;h=v[g>>2];v[g>>2]=h|4096;if(!(h&512)){break d}if(!td(e)){break d}cj(v[e>>2],d&65535,1)}h=v[c+1075648>>2];if(!h){break c}g=w[h+34|0];if(!g){break c}g=v[(B(g,160)+a|0)+906140>>2];if(!g){break c}eb[v[v[g>>2]+92>>2]](g,h,w[c+1075789|0]+255|0,0,b)}d=d+1|0;continue}}nO(e,d,a);break a;case 7:if(!(w[a+480209|0]&16)){break a}Nl(a,e,d,4);break a;case 8:b=v[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(d&15){case 0:v[e+88>>2]=v[e+88>>2]&-257;break f;case 1:v[e+692>>2]=128;v[e+88>>2]=v[e+88>>2]|256;break f;case 8:v[e+88>>2]=v[e+88>>2]&-25165825|16777216;break f;case 9:v[e+88>>2]=v[e+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=b&-16385;break f;case 11:v[a+480208>>2]=b|16384;break f;case 12:v[a+480208>>2]=b&-8193;break f;case 13:v[a+480208>>2]=b|8192;break f;case 14:v[e+88>>2]=v[e+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(v[e>>2]|v[e+4>>2]){break h}a=v[e+76>>2];if(!a){break h}if(!(l=Kc(w[e+788|0]),m=1,n=w[e+88|0]&2,n?l:m)){break h}v[e>>2]=-1;v[e+4>>2]=a-1}v[e+88>>2]=v[e+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,872)+a|0;t[c+1075828|0]=d;rb(f+8|0,a+1074312|0,35);if(sb(v[v[f+8>>2]>>2],v[f+12>>2])){break a}if(!Kc(w[c+1075780|0])){break a}b=v[(B(b,872)+a|0)+1075068>>2];a=d<<16;if(b>>>0<=a>>>0){break a}v[e+4>>2]=a;break a;case 10:if(!(w[a+480209|0]&16)){break a}Hs(a,h,e,d);break a;case 11:i:{if(d){break i}d=1;c=v[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}rb(f+8|0,a+1074312|0,30);if(sb(v[v[f+8>>2]>>2],v[f+12>>2])){c=1}else{c=v[a+480180>>2]==2}gy(a,b,d,c);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,872)+a|0)+1075836|0]=d}ab=f+16|0}function Gj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=1;o(+b);f=j(1)|0;e=j(0)|0;a:{b:{m=f&2147483647;g=e;c:{if(!(m|e)){break c}o(+a);e=j(1)|0;t=j(0)|0;if(!t&(e|0)==1072693248){break c}q=e&2147483647;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(t|0)!=0|m>>>0>2146435072)&(!g|(m|0)!=2146435072))){return a+b}d:{e:{f:{r=0;g:{if((e|0)>0|(e|0)>=0){break g}r=2;if(m>>>0>1128267775){break g}r=0;if(m>>>0<1072693248){break g}h=m>>>20|0;if(m>>>0<1094713344){break f}d=1075-h|0;h=g>>>d|0;r=0;if((g|0)!=h<<d){break g}r=2-(h&1)|0}d=r;if(!g){break e}break d}if(g){break d}g=1043-h|0;h=m>>>g|0;d=0;if((m|0)!=h<<g){break e}d=2-(h&1)|0}if((m|0)==2146435072){if(!(q-1072693248|t)){break c}if(q>>>0>=1072693248){return(f|0)>0|(f|0)>=0?b:0}return(f|0)>0|(f|0)>=0?0:-b}if((m|0)==1072693248){if((f|0)>0|(f|0)>=0){return a}return 1/a}if((f|0)==1073741824){return a*a}if((f|0)!=1071644672|(e|0)<0){break d}return K(a)}c=D(a);if(!((q?(e&1073741823)!=1072693248:0)|t)){k=(f|0)<0?1/c:c;if((e|0)>0|(e|0)>=0){break c}if(!(q-1072693248|d)){a=k-k;return a/a}return(d|0)==1?-k:k}h:{if((e|0)>0|(e|0)>=0){break h}i:{switch(d|0){case 0:a=a-a;return a/a;case 1:break i;default:break h}}k=-1}j:{if(m>>>0>=1105199105){if(m>>>0>=1139802113){if(q>>>0<=1072693247){return(f|0)<0?N:0}return(f|0)>0?N:0}if(q>>>0<=1072693246){return(f|0)<0?k*1e300*1e300:k*1e-300*1e-300}if(q>>>0>=1072693249){return(f|0)>0?k*1e300*1e300:k*1e-300*1e-300}a=c+-1;c=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;i=c;c=a*1.4426950216293335;o(+(i+c));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();c=i-(a-c);break j}a=c*9007199254740992;g=q>>>0<1048576;c=g?a:c;o(+a);d=j(1)|0;j(0)|0;h=g?d:q;e=h&1048575;d=e|1072693248;h=(h>>20)+(g?-1076:-1023)|0;g=0;k:{if(e>>>0<235663){break k}if(e>>>0<767610){g=1;break k}d=e|1071644672;h=h+1|0}e=g<<3;w=A[e+3536>>3];o(+c);j(1)|0;q=0;l(0,j(0)|q);l(1,d|0);p=+n();s=A[e+3520>>3];i=p-s;u=1/(s+p);c=i*u;o(+c);m=j(1)|0;j(0)|0;l(0,0);l(1,m|0);a=+n();x=a;l(0,q|0);l(1,((g<<18)+(d>>>1|0)|0)+537395200|0);v=a*a;y=i;i=+n();p=u*(y-a*i-a*(p-(i-s)));i=p*(c+a);a=c*c;s=i+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();i=x*a;c=p*a+c*(s-(a+-3-v));o(+(i+c));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();c=w+(a*-7.028461650952758e-9+(c-(a-i))*.9617966939259756);i=c;p=A[e+3552>>3];c=a*.9617967009544373;s=+(h|0);o(+(p+(i+c)+s));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();c=i-(a-s-p-c)}l(0,0);l(1,f|0);p=+n();c=(b-p)*a+c*b;b=a*p;a=c+b;o(+a);e=j(1)|0;d=j(0)|0;l:{f=e;if((e|0)>=1083179008){if(d|f-1083179008){break b}if(!(c+8.008566259537294e-17>a-b)){break l}break b}if((f&2147482624)>>>0<1083231232){break l}if(d|f+1064252416){break a}if(!(c<=a-b)){break l}break a}g=0;h=f&2147483647;if(h>>>0>=1071644673){d=f+(1048576>>>(h>>>20|0)-1022|0)|0;f=d>>>20&2047;g=(d&1048575|1048576)>>>1043-f|0;g=(e|0)<0?0-g|0:g;l(0,0);l(1,d&-1048576>>f-1023);b=b-+n();o(+(c+b));e=j(1)|0;j(0)|0}l(0,0);l(1,e|0);a=+n();p=a*.6931471824645996;c=(c-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=p+c;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);i=a*b/(b+-2);b=a;a=c-(a-p);a=b-(i-(b*a+a))+1;o(+a);d=j(1)|0;e=j(0)|0;d=(g<<20)+d|0;m:{if((d|0)<=1048575){a=xj(a,g);break m}l(0,e|0);l(1,d|0);a=+n()}k=k*a}return k}return k*1e300*1e300}return k*1e-300*1e-300}function SI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=ab-176|0;ab=e;f=v[b+4>>2];a:{if(!f){break a}g=v[b>>2];h=w[Gk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Pk(e,g,f,f-1|0);f=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=f}Dd(e);f=v[e>>2];Dd(e+152|0);h=Fk(f,v[e+156>>2],b);Dd(e);f=v[b+4>>2];g=v[b>>2];b:{c:{d:{e:{if((h|0)==v[e+4>>2]){a=kc(e+168|0,21598);if(yc(g,f,v[a>>2],v[a+4>>2])){d=aa(8)|0;v[22452]=0;c=Q(938,e+152|0,c|0)|0;a=v[22452];v[22452]=0;f:{g:{h:{if((a|0)!=1){v[22452]=0;U(939,e|0,17577,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}lc(d,e);a=0;v[22452]=0;U(110,d|0,58760,928);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;pb(e);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}pb(c);if(!a){break c}}ba(d|0);break c}if(!d){break e}d=aa(8)|0;v[22452]=0;f=Q(938,e+120|0,b|0)|0;a=v[22452];v[22452]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[22452]=0;U(939,e+136|0,17613,f|0);a=v[22452];v[22452]=0;if((a|0)==1){break q}v[22452]=0;R(941,e+152|0,e+136|0);b=v[22452];v[22452]=0;a=1;if((b|0)==1){break p}v[22452]=0;c=Q(938,e+104|0,c|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break o}v[22452]=0;U(943,e|0,e+152|0,c|0);b=v[22452];v[22452]=0;a=1;if((b|0)==1){break n}lc(d,e);v[22452]=0;U(110,d|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(e);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}pb(c)}pb(e+152|0)}pb(e+136|0)}pb(f);if(!a){break c}}ba(d|0);break c}d=kc(e+96|0,21598);if(yc(g,f,v[d>>2],v[d+4>>2])){d=aa(8)|0;v[22452]=0;c=Q(938,e+152|0,c|0)|0;a=v[22452];v[22452]=0;r:{s:{t:{if((a|0)!=1){v[22452]=0;U(939,e|0,17577,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break t}lc(d,e);a=0;v[22452]=0;U(110,d|0,58760,928);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;pb(e);break s}b=P()|0;O()|0;break r}b=P()|0;a=1;O()|0}pb(c);if(!a){break c}}ba(d|0);break c}f=v[b>>2];g=v[b+4>>2];d=kc(e+88|0,12327);if(yc(f,g,v[d>>2],v[d+4>>2])){b=v[c>>2];d=v[c+4>>2];f=kc(e+80|0,5562);if(yc(b,d,v[f>>2],v[f+4>>2])){v[a+52>>2]=0;break e}f=kc(e+72|0,11259);if(yc(b,d,v[f>>2],v[f+4>>2])){v[a+52>>2]=1;break e}f=b;b=kc(e- -64|0,9177);if(yc(f,d,v[b>>2],v[b+4>>2])){v[a+52>>2]=2;break e}d=aa(8)|0;v[22452]=0;c=Q(938,e+152|0,c|0)|0;a=v[22452];v[22452]=0;u:{v:{w:{if((a|0)!=1){v[22452]=0;U(939,e|0,14598,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break w}lc(d,e);a=0;v[22452]=0;U(110,d|0,58760,928);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;pb(e);break v}b=P()|0;O()|0;break u}b=P()|0;a=1;O()|0}pb(c);if(!a){break c}}ba(d|0);break c}d=v[b>>2];f=v[b+4>>2];b=kc(e+56|0,11496);if(!yc(d,f,v[b>>2],v[b+4>>2])){break e}b=0;x:{d=v[c>>2];c=v[c+4>>2];f=kc(e+48|0,15540);if(yc(d,c,v[f>>2],v[f+4>>2])){break x}b=1;f=kc(e+40|0,15545);if(yc(d,c,v[f>>2],v[f+4>>2])){break x}b=2;f=kc(e+32|0,12601);if(yc(d,c,v[f>>2],v[f+4>>2])){break x}b=3;f=c;c=kc(e+24|0,9241);if(yc(d,f,v[c>>2],v[c+4>>2])){break x}a=aa(8)|0;v[22452]=0;c=Q(55,e|0,11532)|0;b=v[22452];v[22452]=0;if((b|0)==1){break d}lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(c);break c}v[a+56>>2]=b;a=a+24|0;if(!v[v[a>>2]+24668>>2]){break e}a=v[a>>2];c=a+24664|0;d=v[c+4>>2];v[e+16>>2]=v[c>>2];v[e+20>>2]=d;c=a+24656|0;d=v[c+4>>2];v[e+8>>2]=v[c>>2];v[e+12>>2]=d;c=v[a+24652>>2];v[e>>2]=v[a+24648>>2];v[e+4>>2]=c;i=e,j=yI(b),v[i+20>>2]=j;if(!Rw(e,a+24648|0)){break e}Sx(a,e)}ab=e+176|0;return}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function oha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=ab-976|0;ab=f;qc(b);d=ab-16|0;ab=d;i=f+872|0;MS(d+8|0,i);g=v[d+12>>2];_b(d,b,v[d+8>>2],g);h=v[d+4>>2];if((h|0)==(g|0)){Ob(b,v[d+12>>2])}ab=d+16|0;d=(g|0)==(h|0);if(!d){LS(i)}a:{if(!d){break a}if(!OS(f+872|0)){break a}if(!Hb(b,Fc(NS(f+872|0),db))){break a}b:{if(!c){break b}vd(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[f+947|0];v[a+480208>>2]=16;v[a+480200>>2]=256;v[a+480204>>2]=8e5;Db(a+1074312|0,7,1);e=f+96|0;d=Mb(e,8211);tb(a+1298344|0,d);pb(d);d=Mb(e,8883);tb(a+1298356|0,d);pb(d);v[a+1298404>>2]=5;KS(f+16|0,f+872|4);tc(e,v[f+16>>2],v[f+20>>2],w[f+24|0]);tb(a+1298308|0,e);pb(e);e=0;while(1){if((e|0)==16){c:{e=w[f+968|0]|w[f+969|0]<<8;if(e){dB(a+1298332|0,b,e,132,0)}e=0;d=ab-16|0;ab=d;i=f+96|0;Ub(d+8|0,i,771);g=v[d+12>>2];_b(d,b,v[d+8>>2],g);h=v[d+4>>2];if((h|0)==(g|0)){Ob(b,v[d+12>>2])}ab=d+16|0;d=(g|0)==(h|0);if(!d){Jb(i,0,771)}if(!d){break a}e=a+484360|0;JS(Kb(e),f+96|0,w[f+353|0]);Re(Kb(e),w[f+354|0]);Nc(b,w[f+919|0]|w[f+920|0]<<8);n=a+484344|0;p=c&1;i=0;while(1){d:{if((i|0)==256){e=1;if(!(c&2)){break a}oB(b,f- -64|0);e=0;while(1){if((e|0)==64){break b}if(!(w[f- -64+(e>>>3)|0]>>>(e&7)&1)){e=e+1|0;continue}if(!LA(b,f+16|0)){break b}e=e+1|0;u[a+480190>>1]=e;c=f+16|0;Qe(f,1,c);i=f+72|0;tc(i,v[f>>2],v[f+4>>2],w[f+8|0]);sc(((x[a+480190>>1]<<5)+a|0)+946304|0,i);pb(i);d=(B(e,104)+a|0)+484380|0;ed(d,0);j=w[c+32|0]|w[c+33|0]<<8|(w[c+34|0]<<16|w[c+35|0]<<24);v[d>>2]=j;g=w[c+38|0]|w[c+39|0]<<8|(w[c+40|0]<<16|w[c+41|0]<<24);v[d+4>>2]=g;h=w[c+42|0]|w[c+43|0]<<8|(w[c+44|0]<<16|w[c+45|0]<<24);v[d+24>>2]=16726;v[d+8>>2]=h;u[d+30>>1]=w[c+37|0]<<4;if(t[c+46|0]&1){h=h>>>1|0;v[d+8>>2]=h;g=g>>>1|0;v[d+4>>2]=g;v[d>>2]=j>>>1}if(!(!(w[c+47|0]&8)|g>>>0>=h>>>0)){u[d+34>>1]=x[d+34>>1]|2}Gc(i,t[c+46|0]&1?16:8,1,0,0);eg(i,d,b);continue}}e:{e=(i<<1)+f|0;g=w[e+355|0]|w[e+356|0]<<8;if(g){d=f+72|0;Md(d,b,g);o=bc(f+16|0,d);qb(d);j=((w[e+355|0]|w[e+356|0]<<8)-2|0)/64|0;f:{if(!p){break f}v[22452]=0;e=Y(217,n|0,i&65535,j|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break e}if(!e){break f}v[22452]=0;e=T(197,o|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}v[22452]=0;Q(179,f+16|0,1)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}q=e?e>>>0<j-2>>>0?e+1|0:-1:-1;g=0;g:while(1){h:{d=Rb(n,i);if((g|0)==(j|0)){break h}e=0;l=Of(d,g);while(1){if((e|0)==16){g=g+1|0;continue g}v[22452]=0;R(346,f+72|0,o|0);d=v[22452];v[22452]=0;if((d|0)==1){break d}d=f+72|0;h=Me(d);m=vi(d);d=w[d|0];if((d-1&255)>>>0<=71){k=B(e,6)+l|0;t[k|0]=d+36;r=k,s=w[Zc(f+72|0)|0]+1|0,t[r+1|0]=s}if((w[h|0]-1&255)>>>0<=15){d=B(e,6)+l|0;t[d+2|0]=1;t[d+4|0]=((w[h|0]<<6)+-64>>>0)/15}d=B(e,6)+l|0;k=w[m|0];h=k&15;t[d+5|0]=h;i:{j:{switch((w[m|0]>>>4|0)-1|0){case 0:case 1:t[d+5|0]=k|240;break i;case 2:t[d+5|0]=h<<2;break i;case 3:t[d+5|0]=(6/(h+1>>>0)|0)+1;break i;case 5:case 6:t[d+5|0]=h<<3;break i;case 9:t[d+4|0]=(h<<2)+4;t[d+2|0]=1;break i;case 10:t[d+5|0]=h|128;break i;case 11:break j;default:break i}}t[d+5|0]=(6/(h+1>>>0)|0)+1|13}t[d+3|0]=w[(w[m|0]>>>4|0)+26384|0];e=e+1|0;continue}}break}je(d,mh(Ae(ve(f+72|0,14,0),q)))}qb(f+16|0)}i=i+1|0;continue}}break}}}else{d=(e<<5)+a|0;g=d+480280|0;Le(g);h=g;g=(f+872|0)+e|0;v[h>>2]=!w[g+50|0]<<10;u[d+480284>>1]=(w[g+76|0]<<4|8)&248;e=e+1|0;continue}break}a=P()|0;O()|0;qb(f+16|0);S(a|0);L()}e=1}ab=f+976|0;return e|0}function Q9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ab-112|0;ab=e;f=e+88|0;g=a+140|0;kj(f,g,1296125513);v[22452]=0;f=T(169,f|0)|0;h=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(f){f=Bb(e+32|0);v[22452]=0;h=T(151,e+88|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break p}v[22452]=0;U(752,e+88|0,f|0,h|0);h=v[22452];v[22452]=0;if((h|0)==1){break p}h=x[a+174>>1];v[22452]=0;U(753,e+72|0,h|0,f|0);h=v[22452];v[22452]=0;if((h|0)==1){break o}v[22452]=0;U(8,e+8|0,c|0,e+72|0);c=v[22452];v[22452]=0;if((c|0)==1){break n}c=e+8|0;sc(d,c);pb(c);pb(e+72|0);pb(f)}if(w[a+176|0]){v[22452]=0;R(754,e+32|0,d|0);c=v[22452];v[22452]=0;if((c|0)==1){break e}c=e+32|0;ke(b+43|0,c);pb(c)}v[22452]=0;U(747,e+32|0,g|0,1413894985);c=v[22452];v[22452]=0;if((c|0)==1){break l}v[22452]=0;f=T(755,e+32|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break k}g=e+32|0;qb(g);c=a+40|0;qc(c);v[22452]=0;g=Q(756,c|0,g|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break j}if(g){q:{if((w[e+60|0]|w[e+61|0]<<8|(w[e+62|0]<<16|w[e+63|0]<<24))>>>0<2){break q}v[22452]=0;g=Q(757,c|0,e+8|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break i}if(!g){break q}IK(e+8|0,b+12|0,b+16|0,v[b>>2],b+34|0,8,16,f)}v[22452]=0;c=Q(757,c|0,e+8|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break i}if(c){IK(e+8|0,b+4|0,b+8|0,v[b>>2],b+34|0,2,4,f)}c=w[e+44|0]|w[e+45|0]<<8|(w[e+46|0]<<16|w[e+47|0]<<24);t[b+42|0]=c&128?0:c+1|0;ek(b)}r:{if(w[b+42|0]){break r}v[22452]=0;c=a+60|0;f=Q(619,c|0,7)|0;g=v[22452];v[22452]=0;if((g|0)==1){break j}if(!f){break r}qc(c);v[22452]=0;c=Q(758,c|0,e+8|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break d}if(!c){break r}c=t[e+8|0];t[b+42|0]=(c|0)<0?0:c+1|0}v[22452]=0;h=a+120|0;c=T(169,h|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break j}if(!c){break f}v[22452]=0;c=T(148,h|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break c}v[e+72>>2]=c;mc(e+72|0,9);g=b+68|0;f=e+8|4;i=v[e+72>>2];c=0;while(1){if((c|0)==(i|0)){break g}v[22452]=0;R(759,h|0,e+8|0);j=v[22452];v[22452]=0;if((j|0)==1){break h}k=Fb(g,c),l=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),v[k>>2]=l;c=c+1|0;continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}a=P()|0;O()|0;pb(e+72|0)}pb(f);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;qb(e+32|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Bz(g+(i<<2)|0,nS(g),42840)}a=a+80|0;qc(a);v[22452]=0;c=Q(760,a|0,e+8|0)|0;f=v[22452];v[22452]=0;s:{if((f|0)==1){break s}if(!c){break b}if(w[e+8|0]&32){u[b+34>>1]=x[b+34>>1]|32}c=e+8|0;f=c|4;u[e+72>>1]=w[f|0]|w[f+1|0]<<8;u[e+6>>1]=256;k=b,l=x[Lc(e+72|0,e+6|0)>>1],u[k+28>>1]=l;c=c|6;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;u[e+6>>1]=256;k=b,l=x[Lc(e+72|0,e+6|0)>>1],u[k+30>>1]=l;u[e+72>>1]=w[e+16|0]|w[e+17|0]<<8;u[e+6>>1]=64;k=b,l=x[Lc(e+72|0,e+6|0)>>1],u[k+32>>1]=l;t[b+38|0]=w[e+20|0];t[b+39|0]=w[e+21|0];t[b+40|0]=w[e+22|0];t[b+41|0]=w[e+23|0];v[22452]=0;c=Q(147,a|0,32)|0;f=v[22452];v[22452]=0;if((f|0)==1){break s}if(!c){break b}v[22452]=0;R(761,a|0,d|0);c=v[22452];v[22452]=0;if((c|0)==1){break s}v[22452]=0;c=T(193,a|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break s}v[22452]=0;U(762,a|0,b+43|0,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}qb(e+88|0);ab=e+112|0;return}qb(e+88|0);S(a|0);L()}function An(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;d=ab-112|0;ab=d;y=Ny(v[a+24>>2],w[a+32|0]);l=ej(y);c=v[a>>2];f=ad(c,v[a+4>>2]);a:{if(l>>>0>f>>>0){h=ab-32|0;ab=h;f=l-f|0;c=v[vb(a)>>2];e=v[a+4>>2];b:{if(f>>>0<=(c-e|0)/12>>>0){e=ab-16|0;ab=e;f=kt(e,a,f);g=v[f+4>>2];c=v[f+8>>2];while(1){if((c|0)==(g|0)){dc(f);ab=e+16|0}else{fN(g);g=g+12|0;v[f+4>>2]=g;continue}break}break b}c=vb(a);i=ql(h+8|0,to(a,ad(v[a>>2],e)+f|0),ad(v[a>>2],v[a+4>>2]),c);c=ab-16|0;ab=c;e=mP(c,i+8|0,f);f=v[e>>2];while(1){if(v[e+4>>2]!=(f|0)){fN(f);f=v[e>>2]+12|0;v[e>>2]=f;continue}break}xd(e);ab=c+16|0;c=v[a>>2];f=v[a+4>>2];e=i+4|0;while(1){if((c|0)!=(f|0)){f=f-12|0;zz(v[e>>2]-12|0,f);v[e>>2]=v[e>>2]-12;continue}break}cc(a,e);cc(a+4|0,i+8|0);cc(vb(a),ic(i));v[i>>2]=v[i+4>>2];e=v[i+4>>2];while(1){c=v[i+8>>2];if((c|0)!=(e|0)){c=c-12|0;v[i+8>>2]=c;Be(c);continue}break}c=v[i>>2];if(c){Yq(i);xb(c)}}ab=h+32|0;break a}if(f>>>0>l>>>0){lN(a,c+B(l,12)|0)}}if(b){c=a+12|0;qp(c,Kd(c));z=vb(c),A=0,v[z>>2]=A;e=c;c=ac(c);v[e>>2]=c;v[c>>2]=0;v[a+28>>2]=0}m=Pb(d+96|0);c=Ps(v[a+24>>2]+484344|0);v[22452]=0;n=Y(570,d+80|0,c|0,30220)|0;c=v[22452];v[22452]=0;c:{if((c|0)!=1){k=a+12|0;d:{while(1){if((j|0)==(l|0)){_c(n);Xb(m);ab=d+112|0;return}o=x[Yb(v[y>>2],j)>>1];c=rN(a,o);v[d+76>>2]=c;h=ld(v[a>>2],j);e:{f:{if(b){v[22452]=0;t[d+40|0]=0;U(742,h|0,c|0,d+40|0);c=v[22452];v[22452]=0;if((c|0)!=1){break f}g=P()|0;O()|0;break d}v[22452]=0;R(698,h|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break e}}v[22452]=0;e=Q(304,y|0,j&65535)|0;c=v[22452];v[22452]=0;if((c|0)==1){break e}g:{if(!e){break g}v[d+40>>2]=b?0:v[h+4>>2];i=v[zb(d+40|0,d+76|0)>>2];s=Af(k);c=x[Yb(v[n>>2],o)>>1];if((c|0)!=65535){Ql(d+40|0,c,i);c=pN(k,x[d+40>>1],v[d+44>>2]);v[d+72>>2]=c;z=d,A=Af(k),v[z+16>>2]=A;h:{if(Qg(d+72|0,d+16|0)){Ql(d+40|0,x[Yb(v[n>>2],o)>>1],v[d+76>>2]);e=pN(k,x[d+40>>1],v[d+44>>2]);break h}e=Af(k)}v[d+64>>2]=e;v[d+56>>2]=c;while(1){i:{if(!Qg(d+56|0,d- -64|0)){break g}h=Pb(d+40|0);c=Fm(id(d+56|0)+8|0);v[22452]=0;R(743,h|0,c|0);c=v[22452];v[22452]=0;if((c|0)!=1){mi(d+24|0,s);c=Ql(d+16|0,j,v[id(d+56|0)+4>>2]);v[22452]=0;e=da(744,k|0,v[d+24>>2],c|0,h|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break i}v[d+32>>2]=e;Uj(d+32|0);s=v[d+32>>2];Ud(h);Uj(d+56|0);continue}}break}g=P()|0;O()|0;Ud(h);break d}h=Rb(v[a+24>>2]+484344|0,o);c=oj(v[v[h+48>>2]+12>>2]);v[22452]=0;t[d+40|0]=0;U(722,m|0,c|0,d+40|0);c=v[22452];v[22452]=0;if((c|0)!=1){p=v[d+76>>2];j:while(1){k:{if((i|0)==(p|0)){if(i){break g}z=Yb(v[n>>2],o),A=j,u[z>>1]=A;break g}q=1;r=0;p=p-1|0;g=Of(h,p);while(1){if(q>>>0<16&oj(v[v[h+48>>2]+12>>2])>>>0>r>>>0){c=Cb(v[m>>2],r);f=w[c|0];l:{m:{n:{switch(w[g+3|0]-19|0){case 1:e=w[g+5|0];if((e&240)==176){break m}break l;case 0:break n;default:break l}}e=w[g+5|0];if((e&240)!=96){break l}}t[c|0]=e&15;c=w[Cb(v[m>>2],r)|0];f=c?c:f}c=f&255;q=B(c?c+1|0:1,q);g=g+6|0;r=r+1|0;continue}else{o:{if(q>>>0<=1){continue j}e=Pb(d+40|0);v[22452]=0;R(743,e|0,q|0);c=v[22452];v[22452]=0;if((c|0)==1){break o}mi(d+8|0,s);c=Ql(d+16|0,j,p);v[22452]=0;s=da(744,k|0,v[d+8>>2],c|0,e|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break k}Ud(e);continue j}}break}}break}g=P()|0;O()|0;Ud(e);break d}g=P()|0;O()|0;break d}j=j+1|0;continue}break}g=P()|0;O()|0}_c(n);break c}g=P()|0;O()|0}Xb(m);S(g|0);L()}function RU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=ab-576|0;ab=e;qc(b);d=ab-16|0;ab=d;f=e+72|0;wC(d+8|0,f);g=v[d+12>>2];_b(d,b,v[d+8>>2],g);k=v[d+4>>2];if((k|0)==(g|0)){Ob(b,v[d+12>>2])}ab=d+16|0;d=(g|0)==(k|0);if(!d){vC(f)}a:{if(!d){break a}if(!yC(e+72|0)){break a}b:{if(!c){break b}if(!Hb(b,Fc(xC(w[e+182|0],w[e+183|0]),db))){break a}vd(a,64);v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480204>>2]=78e4;v[a+480196>>2]=4;u[a+480188>>1]=8;Db(a+1074312|0,7,1);d=e+40|0;g=Mb(d,14634);tb(a+1298344|0,g);pb(g);d=Mb(d,14667);tb(a+1298356|0,d);pb(d);pl(a+1298368|0,Ib(e+72|0,11060,2)?14662:14634);v[a+1298404>>2]=5;f=w[e+182|0];u[a+480190>>1]=f;g=1;while(1){k=g&65535;if(k>>>0<=f>>>0){f=ab-16|0;ab=f;d=e+40|0;Ub(f+8|0,d,25);j=v[f+12>>2];_b(f,b,v[f+8>>2],j);i=v[f+4>>2];if((i|0)==(j|0)){Ob(b,v[f+12>>2])}ab=f+16|0;if((i|0)!=(j|0)){t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;t[d+24|0]=0;t[d+16|0]=0;t[d+17|0]=0;t[d+18|0]=0;t[d+19|0]=0;t[d+20|0]=0;t[d+21|0]=0;t[d+22|0]=0;t[d+23|0]=0;t[d+8|0]=0;t[d+9|0]=0;t[d+10|0]=0;t[d+11|0]=0;t[d+12|0]=0;t[d+13|0]=0;t[d+14|0]=0;t[d+15|0]=0}if((w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24))>>>0>67108863){break a}f=(B(k,104)+a|0)+484380|0;ed(f,0);v[f+24>>2]=8363;j=e+40|0;d=j;i=w[d+13|0]|w[d+14|0]<<8|(w[d+15|0]<<16|w[d+16|0]<<24);v[f>>2]=i;l=w[d+17|0]|w[d+18|0]<<8|(w[d+19|0]<<16|w[d+20|0]<<24);v[f+4>>2]=l;d=w[d+21|0]|w[d+22|0]<<8|(w[d+23|0]<<16|w[d+24|0]<<24);d=d>>>0>i>>>0?l?d:0:d;v[f+8>>2]=d;if(d){u[f+34>>1]=2;ek(f)}Hh(e+8|0,2,j);d=e+24|0;tc(d,v[e+8>>2],v[e+12>>2],w[e+16|0]);sc(((k<<5)+a|0)+946304|0,d);g=g+1|0;pb(d);f=x[a+480190>>1];continue}break}h=e+72|2;Se(e+24|0,3,h,36);d=e+40|0;tc(d,v[e+24>>2],v[e+28>>2],w[e+32|0]);tb(a+1298308|0,d);pb(d);g=0;uC(a+1298332|0,h,108,36,0);d=a+484360|0;tC(Kb(d),e+185|0,128);j=v[Kb(d)>>2];h=w[e+184|0];if(x[Yb(j,h)>>1]<w[e+183|0]){Re(Kb(d),h)}while(1)if((g|0)==8){k=a+484344|0;fg(k,w[e+183|0]);n=c&1;f=0;while(1){if(w[e+183|0]<=f>>>0){h=1;if(!(c&2)){break a}c=Gc(e+40|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>x[a+480190>>1]){break b}eg(c,(B(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}c:{d:{if(n){if(Vg(k,f&65535,64)){break d}}Ob(b,1536);break c}v[e+24>>2]=-1;v[e+28>>2]=-1;j=0;e:while(1){if((j|0)==64){d=(e+72|0)+f|0;if(w[d+369|0]<63){je(Rb(k,f),mh(Ae(ve(e+40|0,14,0),w[d+369|0])))}je(Rb(k,f),mh(ve(e+40|0,16,w[d+241|0])));break c}g=0;h=Of(Rb(k,f),j);while(1){if((g|0)==8){j=j+1|0;continue e}i=e+40|0;tq(i,b);d=Zc(i);m=Me(i);l=w[d|0];d=w[i|0];if(d>>>0<=253){t[h|0]=(d>>>2|0)+37;t[h+1|0]=(d<<4&48|l>>>4)+1;t[(e+24|0)+g|0]=255;d=w[i|0]}if((d&255)!=255){t[h+2|0]=1;t[h+4|0]=(((l&15)<<6|8)>>>0)/15}d=w[m|0];if((d|0)!=255){t[(e+24|0)+g|0]=d}i=(e+24|0)+g|0;f:{g:{if(d&15?0:(d|0)!=48){break g}l=w[i|0];if((l|0)==255){break f}m=l<<24>>24;d=m&15;t[h+5|0]=d;h:{if((m|0)<0){break h}l=l>>>4|0;t[h+3|0]=w[l+26168|0];i:{switch(l-3|0){case 0:t[h+5|0]=d|32;break g;case 1:t[h+5|0]=d|m<<4;break f;case 2:break g;case 3:break i;default:break f}}j:{switch(d|0){case 0:t[h+5|0]=79;break f;case 1:break j;default:break h}}t[h+5|0]=244;break f}t[h+3|0]=0;break f}t[i|0]=255}h=h+6|0;g=g+1|0;continue}}}f=f+1|0;continue}}else{d=(g<<5)+a|0;Le(d+480280|0);u[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}ab=e+576|0;return h|0}function yda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=ab-192|0;ab=e;qc(b);a:{if(!LA(b,e+144|0)){break a}if(!DP(e+144|0)){break a}if(!Hb(b,Fc(CP(w[e+175|0],w[e+177|0]),db))){break a}b:{if(!c){break b}vd(a,256);g=e+32|0;lj(g,2,e+144|0);d=e- -64|0;tc(d,v[e+32>>2],v[e+36>>2],w[e+40|0]);tb(a+1298308|0,d);pb(d);f=Mb(d,15243);tb(a+1298344|0,f);pb(f);d=Mb(d,10081);tb(a+1298356|0,d);pb(d);af(g,4232);v[22452]=0;R(243,e+128|0,e+175|0);d=v[22452];v[22452]=0;c:{d:{if((d|0)!=1){v[22452]=0;W(640,e- -64|0,e+32|0,e+174|0,e+128|0);d=v[22452];v[22452]=0;if((d|0)!=1){d=e- -64|0;tb(a+1298368|0,d);pb(d);pb(e+128|0);yb(e+32|0);v[a+1298404>>2]=5;d=Db(a+1074312|0,107,1);v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;Db(d,107,1);f=w[e+176|0];d=w[e+175|0];if(d>>>0<=20){g=((f&255)>>>0)/10|0;f=g<<4|B(g,-10)+f}g=(f&255?f:96)&255;f=xz(g);v[a+480196>>2]=g>>>4;v[a+480204>>2]=f;f=0;if(d>>>0>=11){t[e+64|0]=64;o=a,p=w[Qb(e+178|0,e- -64|0)|0]<<2,v[o+480200>>2]=p}while(1)if((f|0)==4){f=1;while(1){if((f|0)!=32){rt(b,e+32|0);d=w[e+44|0];if(d?(d|0)!=46:0){break c}g=ab-32|0;ab=g;d=(B(f,104)+a|0)+484380|0;ed(d,0);k=e+32|0;h=k;Zj(g,2,h);i=g+16|0;tc(i,v[g>>2],v[g+4>>2],w[g+8|0]);ke(d+43|0,i);pb(i);j=h+24|0;v[d+24>>2]=w[j|0]|w[j+1|0]<<8;t[g+16|0]=w[h+22|0];t[g|0]=64;o=d,p=w[Qb(i,g)|0]<<2,u[o+30>>1]=p;i=h+16|0;i=w[i|0]|w[i+1|0]<<8;v[d>>2]=i;j=h+18|0;j=w[j|0]|w[j+1|0]<<8;v[d+4>>2]=j;h=h+20|0;h=w[h|0]|w[h+1|0]<<8;v[d+8>>2]=h;e:{if(i>>>0<=1){v[d>>2]=0;break e}if((h|0)==65535|i>>>0<=j>>>0|h>>>0<=j>>>0){break e}u[d+34>>1]=2;o=d,p=v[zb(d+8|0,d)>>2],v[o+8>>2]=p}ab=g+32|0;Zj(e+16|0,2,k);d=e+128|0;tc(d,v[e+16>>2],v[e+20>>2],w[e+24|0]);sc(((f<<5)+a|0)+946304|0,d);pb(d);u[((f<<1)+e|0)+62>>1]=w[e+46|0]|w[e+47|0]<<8;f=f+1|0;continue}break}d=a+484360|0;Vn(Kb(d),b,w[e+175|0]?128:64,65535,65535);f=0;if(!AP(Kb(d))){break a}m=c&1;if(m){fg(a+484344|0,w[e+177|0])}j=a+484344|0;h=0;while(1){if(w[e+177|0]<=h>>>0){f=1;if(!(c&2)){break a}c=Gc(e+32|0,8,1,0,0);while(1){if((f|0)==32){break b}d=B(f,104)+a|0;g=d+484380|0;f:{if(!v[g>>2]|!x[d+484410>>1]){break f}d=x[((f<<1)+e|0)+62>>1];if(d>>>0<4){break f}if(!Nc(b,d<<4)){break f}eg(c,g,b)}f=f+1|0;continue}}f=0;g:{h:{if(m){if(Vg(j,h&65535,64)){break h}}while(1){if((f|0)==256){break g}if((ue(b)+2&255)>>>0<=252){Ob(b,3)}f=f+1|0;continue}}o=e,p=vg(Rb(j,h)),v[o+128>>2]=p;u[e+14>>1]=65535;v[e+16>>2]=63;i=0;i:while(1){f=0;if((i|0)==64){d=x[e+14>>1];if((d|0)==65535){break g}je(Rb(j,h),dm(Ae(ve(e+32|0,12,d&255),v[e+16>>2])));break g}while(1){j:{k:{l:{if((f&65535)>>>0<=3){d=0;k=0;l=0;n=0;m:{n:{o:{p:{g=ue(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}t[v[e+128>>2]]=254;break j}d=e+32|0;tq(d,b);k=w[Cb(d,0)|0];l=w[Cb(d,1)|0];n=w[Cb(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(B(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=v[e+128>>2];t[d|0]=g;break k}i=i+1|0;continue i}d=v[e+128>>2]}t[d+1|0]=(k&248)>>>3;g=l>>>1&120|k&7;if(g>>>0<=64){t[d+4|0]=g;t[d+2|0]=1}t[d+5|0]=n;t[d+3|0]=l&15;zP(d,i,w[e+175|0],e+14|0,e+16|0)}f=f+1|0;ui(e+128|0);continue}}}h=h+1|0;continue}}else{d=(f<<5)+a|0;Le(d+480280|0);u[d+480284>>1]=f&1?64:192;f=f+1|0;continue}}f=P()|0;O()|0;pb(e+128|0);break d}f=P()|0;O()|0}yb(e+32|0);S(f|0);L()}f=0;break a}f=1}ab=e+192|0;return f|0}function ey(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0,C=0,D=0,E=0;f=ab-16|0;ab=f;l=B(b,872)+a|0;m=l+1075800|0;i=w[m|0];k=a+1074312|0;rb(f+8|0,k,23);g=c&15;a:{b:{c:{if(sb(v[v[f+8>>2]>>2],v[f+12>>2])){if(!(v[a+1074392>>2]|!w[(B(b,872)+a|0)+1075780|0])){t[m|0]=g;break c}e=w[m|0];if(e){h=e-1|0;t[m|0]=h;e=0;if(h&255){break c}}t[m|0]=g;e=1;break c}rb(f+8|0,k,52);d:{e:{h=c&256;if(!(!h|!sb(v[v[f+8>>2]>>2],v[f+12>>2]))){h=v[a+480208>>2]&4096;if(!h){break e}e=B(b,872)+a|0;if(w[e+1075781|0]){i=uS(w[e+1075780|0])?1:i}if(w[(B(b,872)+a|0)+1075784|0]?w[e+1075782|0]==1:0){break b}e=0;if(g>>>0>i>>>0){break c}if(!h){break d}if(Kc(w[(B(b,872)+a|0)+1075780|0])){break c}break d}j=v[a+480180>>2];if(j&16777250){e=!(i?(i>>>0)%((g?g:1)>>>0)|0:1);i=i+1|0;break c}f:{if((j|0)!=16){if((j|0)!=1){break f}h=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!h){if(Kc(w[(B(b,872)+a|0)+1075780|0])){break a}}e=g?!((h>>>0)%(g>>>0)|0):e;break c}e=v[a+1074392>>2]==(g|0)&(g|0)!=0;break c}g:{if(!h){break g}e=B(b,872)+a|0;if(w[e+1075782|0]!=1){break g}g=(w[e+1075785|0]>15)+g|0}h:{if(v[a+480208>>2]&4096?h:1){g=g?g:1;e=0;e=!v[a+1074416>>2]|h?e:!(y[a+1074392>>2]%(g>>>0)|0);i=i+1|0;break h}e=0;i=j&1048580?0:i}if(!(!(w[(B(b,872)+a|0)+1075780|0]|!h?v[a+1074392>>2]:1)|(i&255)>>>0<g>>>0)){e=1}rb(f+8|0,k,52);if(!sb(v[v[f+8>>2]>>2],v[f+12>>2])|c){break c}e=!v[a+1074392>>2];break c}if(g>>>0>i>>>0){break c}}i=0;e=1}n=(B(b,872)+a|0)+1075068|0;i:{if(v[n>>2]){break i}rb(f+8|0,k,38);if(!sb(v[v[f+8>>2]>>2],v[f+12>>2])){break i}if(!Kj(v[(B(b,872)+a|0)+1075648>>2])){break a}}rb(f+8|0,k,106);if(C=0,D=sb(v[v[f+8>>2]>>2],v[f+12>>2]),E=v[(B(b,872)+a|0)+1075688>>2],E?C:D){break a}if(e){h=B(b,872)+a|0;q=h+1075680|0;g=v[q>>2];v[f+4>>2]=g;e=c>>>4&15;j:{if(!e){e=v[h+1075080>>2];break j}rb(f+8|0,k,52);k:{if(C=sb(v[v[f+8>>2]>>2],v[f+12>>2]),D=0,E=w[(B(b,872)+a|0)+1075782|0]==1,E?C:D){break k}if(!(16191>>>e&1)){v[f+4>>2]=(B(g,t[e+33856|0])|0)/16;break k}v[f+4>>2]=g+(t[e+33872|0]<<2)}ce(f+4|0,0,256);g=(B(b,872)+a|0)+1075080|0;e=v[g>>2]|2097152;v[g>>2]=e}h=B(b,872)+a|0;r=h+1075692|0;s=v[r>>2];g=w[h+1075794|0];j=0;if(e&512){rb(f+8|0,k,108);j=sb(v[v[f+8>>2]>>2],v[f+12>>2])}if(!((j^-1)&v[a+480180>>2]==2|(!v[n>>2]|(g-1&255)>>>0>119))){QL(a,b,0,g,1)}e=l+1074992|0;l=h+1075080|0;l:{if(!(v[a+480180>>2]&1048580)){break l}u=(c|0)<256;if((c|0)>255){break l}h=w[(B(b,872)+a|0)+1075781|0];if(!h){break l}u=1;kp(a,e,h,0,0,1)}o=B(b,872)+a|0;p=o+1075652|0;z=v[p>>2];A=v[l>>2];v[p>>2]=0;rb(f+8|0,k,23);h=1;m:{if(sb(v[v[f+8>>2]>>2],v[f+12>>2])){break m}h=0;if(v[a+480180>>2]!=2){break m}h=(j^1)&v[n>>2]!=0}Is(a,e,g,h,u,0,b);if(!w[o+1075781|0]){v[p>>2]=z}if(!(!(A&4096)|v[a+480180>>2]!=4)){v[l>>2]=v[l>>2]|4096}j=o+1075780|0;v[q>>2]=v[f+4>>2];if(x[a+480192>>1]){t[j|0]=g;OL(a,b)}g=v[a+480180>>2];if(!(!(g&16777248)|(w[j|0]|!s))){v[r>>2]=s}if(h){v[e>>2]=0;v[e+4>>2]=0}g=g&16777250;n:{if(d-11>>>0<4294967286){break n}h=v[(B(b,872)+a|0)+1075096>>2];if(!h){break n}o:{if((d|0)==1){b=v[(B(b,872)+a|0)+1075656>>2];break o}j=(B(b,872)+a|0)+1075656|0;b=v[Fb(h+68|0,d-2|0)>>2];v[j>>2]=b}yn(a,e,b)}i=g?i:0}a=f+8|0;rb(a,k,52);b=v[v[f+8>>2]>>2];d=v[f+12>>2];rb(a,k,23);if(sb(v[v[f+8>>2]>>2],v[f+12>>2])){break a}i=(sb(b,d)&c>>>8)+i|0}t[m|0]=i}ab=f+16|0}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ab-128|0;ab=e;a:{if(!Hb(c,8)){break a}Ob(c,4);while(1){m=Dt(c);if(m){break a}n=ab-288|0;ab=n;f=HN(n);i=ab-384|0;ab=i;g=i+96|0;HN(g);g=gc(f,g,282);f=0;b:{c:{d:{e:{f:{if(oh(c,13618)){gg(c,4);j=_d(i+72|0,c);v[22452]=0;k=Q(733,j|0,g|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break f}g:{if(!k){break g}k=w[g+26|0];v[22452]=0;k=Q(147,j|0,k|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break f}if(!k){break g}k=0;h:{while(1){if(w[g+26|0]<=f>>>0){f=0;v[22452]=0;k=k&65535;h=Q(147,j|0,k|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break d}if(!h){break g}v[22452]=0;Q(179,j|0,k|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break d}gg(j,JN(g));f=dh(i- -64|0);h=i+96|0;Py(h);v[22452]=0;R(734,j|0,h|0);h=v[22452];v[22452]=0;if((h|0)!=1){u[i+118>>1]=0;u[i+120>>1]=0;f=Qy(f,i+96|0,i+123|0);h=w[g+26|0];v[22452]=0;Q(179,j|0,h|0)|0;h=v[22452];v[22452]=0;if((h|0)!=1){break h}}f=P()|0;O()|0;break c}v[22452]=0;h=T(189,j|0)|0;l=v[22452];v[22452]=0;if((l|0)!=1){t[(f+g|0)+27|0]=h;f=f+1|0;k=h+k|0;continue}break}f=P()|0;O()|0;break c}l=f;f=g+27|0;l=Qy(l,f,f+w[g+26|0]|0);v[22452]=0;U(181,i+16|0,j|0,k|0);f=v[22452];v[22452]=0;if((f|0)==1){break e}h=i+16|0;k=bc(i+40|0,h);qb(h);f=0;v[22452]=0;R(524,h|0,k|0);h=v[22452];v[22452]=0;if((h|0)==1){f=P()|0;O()|0;qb(k);break c}h=i+16|0;PB(i+8|0,h);o=l;l=v[i+8>>2];l=Qy(o,l,Cb(l,v[i+12>>2]));rc(h);qb(k);if(v[l>>2]!=(w[g+22|0]|w[g+23|0]<<8|(w[g+24|0]<<16|w[g+25|0]<<24))){break g}f=JN(g);v[22452]=0;Q(179,c|0,f|0)|0;g=v[22452];v[22452]=0;f=1;if((g|0)==1){break d}}qb(j)}ab=i+384|0;break b}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}qb(j);S(f|0);L()}ab=n+288|0;if(f){continue}break}}t[d|0]=w[d|0]!=0|m;qc(c);i:{j:{k:{l:{m:{n:{if(m){i=jg(c);d=e+80|0;Md(d,c,Ze(c));f=bc(e+104|0,d);qb(d);b=x[a+34>>1]&-66|w[b|0]>15|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=i>>>(b&1)>>>(b>>>6&1);v[e+76>>2]=0;v[e+72>>2]=0;v[22452]=0;R(524,d|0,f|0);b=v[22452];v[22452]=0;if((b|0)==1){break n}b=Sd(e+80|0);d=v[e+80>>2];i=Wz(b,oi(d),e+76|0,e+72|0);v[22452]=0;c=v[e+76>>2];Q(179,f|0,c|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){if(!i){break j}sg(a);b=b+c|0;d=d-c|0;m=v[e+72>>2];c=0;while(1){o:{if(m){if(!d|(m|0)!=1){break k}if(y[a>>2]>c>>>0){break o}break k}if(y[a>>2]<=c>>>0){break k}}if(!Fd(a)){break k}v[e+68>>2]=0;v[e+64>>2]=0;m=iR(i,b,oi(d),e+68|0,e+60|0,e- -64|0);v[22452]=0;Q(179,f|0,m|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break m}Jh(e- -64|0,oi(v[a>>2]-c|0));g=v[e+64>>2];p:{if((g|0)<=0){break p}j=v[e+68>>2];k=x[a+34>>1];if((qd(k)|0)!=(j|0)){break p}if(k&1){ag(e+48|0,v[a+20>>2]+(B(c,j)<<1)|0,j,g);ag(e+32|0,v[e+60>>2],v[e+68>>2],g);v[22452]=0;ka(525,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2]);j=v[22452];v[22452]=0;if((j|0)!=1){break p}break m}ag(e+16|0,v[a+20>>2]+B(c,j)|0,j,g);ag(e,v[e+60>>2],v[e+68>>2],g);v[22452]=0;ka(526,v[e+16>>2],v[e+20>>2],v[e+24>>2],v[e>>2],v[e+4>>2],v[e+8>>2]);j=v[22452];v[22452]=0;if((j|0)==1){break m}}d=d-m|0;b=b+m|0;c=c+g|0;m=hR(i);continue}}break m}eg(b,a,c);a=1;break i}c=P()|0;O()|0;break l}c=P()|0;O()|0;rc(e+80|0)}qb(f);S(c|0);L()}gR(i)}rc(e+80|0);qb(f);a=(i|0)!=0}ab=e+128|0;return a|0}function zL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0;if(b){h=a+327720|0;c=ab-400|0;ab=c;FN(c+384|0,8);v[22452]=0;sa(735,c+368|0,9);i=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((i|0)!=1){v[22452]=0;i=Q(736,c+352|0,14)|0;e=v[22452];v[22452]=0;if((e|0)==1){break l}v[22452]=0;R(737,c+384|0,i|0);e=v[22452];v[22452]=0;if((e|0)==1){break k}v[22452]=0;R(737,c+368|0,i|0);e=v[22452];v[22452]=0;if((e|0)==1){break k}EN(c+280|0,4900);EN(c+208|0,32e3);wN(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[22452]=0;e=Q(738,c+104|0,c+384|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break j}Ss(c+120|0,c+280|0,e);Ud(e);v[22452]=0;e=Q(738,c+72|0,c+368|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break i}Ss(c+88|0,c+208|0,e);Ud(e);v[22452]=0;e=Q(738,c+40|0,c+120|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break h}Ss(c+56|0,c+136|0,e);Ud(e);v[22452]=0;e=Q(738,c+8|0,c+88|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break g}g=c+24|0;Ss(g,c+136|0,e);Ud(e);e=c+120|0;tp(e);l=c+56|0;tp(l);m=c+88|0;tp(m);tp(g);p=c+368|0;tp(p);sp(v[c+120>>2],v[c+124>>2],bj(h,0));sp(v[c+56>>2],v[c+60>>2],bj(h,1));sp(v[c+88>>2],v[c+92>>2],bj(h,2));sp(v[c+24>>2],v[c+28>>2],bj(h,3));sp(v[c+368>>2],v[c+372>>2],bj(h,4));Ud(g);Ud(l);Ud(m);Ud(e);Vj(i);Ud(p);Ud(c+384|0);ab=c+400|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ud(c+56|0)}Ud(c+88|0)}Ud(c+120|0)}Vj(i)}Ud(c+368|0)}Ud(c+384|0);S(a|0);L()}Hx(a+131112|0,9.6377,.97);Hx(a+196648|0,8.5,.5);Hx(a+262184|0,2.7625,.425)}c=a+368680|0;if(!(t=0,x=LK(c,a),y=b,y?t:x)){e=a+24|0;r=A[a+8>>3];g=w[a+16|0];h=ab+-64|0;ab=h;m:while(1){if((n|0)!=8193){s=+(n-4096|0)*.0001220703125;b=0;o=0;while(1)if((b|0)==8){j=1/o;l=n<<3;b=0;while(1)if((b|0)==8){n=n+1|0;continue m}else{m=e+(b+l<<1)|0;d=H(A[h+(b<<3)>>3]*32768*j+.5);d=d<-32768?-32768:F(d,32768);n:{if(D(d)<2147483648){i=~~d;break n}i=-2147483648}u[m>>1]=i;b=b+1|0;continue}}else{j=r;f=1;d=+(b|0)-s;q=d+-3.5;if(!(D(q)<1e-8)){o:{p:{switch(g|0){case 0:f=Ge(d*.8975979010256552)*-.5+.5;break o;case 1:f=Ge(d*.8975979010256552)*-.46+.54;break o;case 2:f=Ge(d*1.7951958020513104)*.08+(Ge(d*.8975979010256552)*-.5+.42);break o;case 3:f=Ge(d*1.7951958020513104)*.05677+(Ge(d*.8975979010256552)*-.49364+.44959);break o;case 4:f=Ge(d*1.7951958020513104)*.07922+(Ge(d*.8975979010256552)*-.49755+.42323);break o;case 5:f=Ge(d*1.7951958020513104);k=Ge(d*.8975979010256552);f=Ge(d*2.6927937030769655)*-.01168+(f*.14128+(k*-.48829+.35875));break o;case 6:f=Ge(d*1.7951958020513104);k=Ge(d*.8975979010256552);f=Ge(d*2.6927937030769655)*-.00183+(f*.09392+(k*-.49703+.40217));break o;case 7:break p;default:break o}}f=Ge(d*1.7951958020513104);k=Ge(d*.8975979010256552);f=Ge(d*2.6927937030769655)*-.00122+(f*.09831+(k*-.49804+.40243))}d=q*3.141592653589793;j=ki(d*j)/d}j=f*j;A[h+(b<<3)>>3]=j;o=o+j;b=b+1|0;continue}}break}ab=h- -64|0;b=v[a+20>>2];v[c+16>>2]=v[a+16>>2];v[c+20>>2]=b;b=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=b;b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b}}function iX(){var a=0;Nd(465272);v[116318]=79992;v[116320]=0;v[116321]=0;dh(465288);t[465416]=0;v[22452]=0;X(1183);a=v[22452];v[22452]=0;if((a|0)==1){a=P()|0;O()|0;Fv(465280);S(a|0);L()}IE(30);v[22452]=0;Q(55,465424,14270)|0;a=v[22452];v[22452]=0;a:{b:{c:{if((a|0)!=1){uc(465280);Nd(464960);v[116240]=81316;v[22452]=0;X(1152);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(464968);v[116242]=81348;v[22452]=0;X(1153);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(464976);v[116244]=80012;v[116246]=75952;t[464988]=0;v[22452]=0;X(1154);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(464992);v[116248]=80496;v[22452]=0;X(1155);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465e3);v[116250]=80644;v[22452]=0;X(1156);a=v[22452];v[22452]=0;if((a|0)==1){break c}v[22452]=0;X(1157);a=v[22452];v[22452]=0;if((a|0)==1){break c}v[22452]=0;X(1158);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465024);v[116256]=80792;v[22452]=0;X(1159);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465032);v[116258]=80908;v[22452]=0;X(1160);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465040);u[232524]=11310;v[116260]=80112;Bb(465052);v[22452]=0;X(1161);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465064);v[116268]=46;v[116269]=44;v[116266]=80152;Bb(465080);v[22452]=0;X(1162);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465096);v[116274]=81380;v[22452]=0;X(1163);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465104);v[116276]=81624;v[22452]=0;X(1164);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465112);v[116278]=81836;v[22452]=0;X(1165);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465120);v[116280]=82068;v[22452]=0;X(1166);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465128);v[116282]=83052;v[22452]=0;X(1167);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465136);v[116284]=83200;v[22452]=0;X(1168);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465144);v[116286]=83316;v[22452]=0;X(1169);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465152);v[116288]=83432;v[22452]=0;X(1170);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465160);v[116290]=83548;v[22452]=0;X(1171);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465168);v[116292]=83712;v[22452]=0;X(1172);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465176);v[116294]=83876;v[22452]=0;X(1173);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465184);v[116296]=84040;v[22452]=0;X(1174);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465192);v[116300]=85296;v[116300]=82316;v[116298]=82268;v[22452]=0;X(1175);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465208);v[116304]=85332;v[116304]=82580;v[116302]=82532;v[22452]=0;X(1176);a=v[22452];v[22452]=0;if((a|0)==1){break c}v[22452]=0;X(1177);a=v[22452];v[22452]=0;if((a|0)==1){break c}v[22452]=0;X(1178);a=v[22452];v[22452]=0;if((a|0)==1){break c}v[22452]=0;X(1179);a=v[22452];v[22452]=0;if((a|0)==1){break c}v[22452]=0;X(1180);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465256);v[116314]=84204;v[22452]=0;X(1181);a=v[22452];v[22452]=0;if((a|0)==1){break c}Nd(465264);v[116316]=84324;v[22452]=0;X(1182);a=v[22452];v[22452]=0;if((a|0)==1){break c}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;pb(465424)}Fv(465280);S(a|0);L()}v[115914]=465272}function qJ(a){var b=C(0),c=0,d=C(0),e=C(0),f=0,g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=0,p=0,q=C(0),r=C(0),s=C(0),u=0,w=C(0);k=ab-16|0;ab=k;c=gj(C(z[a+4256>>2]*C(3)));v[a+4264>>2]=c;d=C(v[v[a+16>>2]+24620>>2]>>>((c>>>1^-1)&1)>>>0);z[a+4268>>2]=d;u=a,w=C(pJ(z[a+4244>>2])*C(.0061803399585187435)),z[u+4272>>2]=w;u=k,w=fe(C(10),C(C($w(z[a+4208>>2])+C(C(z[a+4228>>2]*C(11e3))+C(-1e4)))/C(2e3))),z[u+12>>2]=w;v[k+8>>2]=1065353216;u=a,w=C(z[El(k+12|0,k+8|0)>>2]*C(.7609999775886536)),z[u+4280>>2]=w;b=fe(C(10),C(C($w(z[a+4212>>2])/C(100))/C(10)));if(b!=C(1)){d=Po(C(C(oJ(z[a+4252>>2])*C(6.2831854820251465))/d));g=C(b+b);e=C(b*b);m=By(C(C(C(C(d*g)+C(-2))+C(K(C(C(C(C(d*C(C(d*e)*C(4)))+C(b*C(8)))-C(e*C(4)))-C(C(d*b)*C(8))))))/C(g+C(-2))),C(0),C(1))}else{m=C(0)}z[a+4276>>2]=m;j=ab-16|0;ab=j;b=z[a+4268>>2];d=C(z[a+4232>>2]*C(.30000001192092896));z[j+12>>2]=z[a+4240>>2]*C(.10000000149011612);v[j+8>>2]=1000593162;g=z[gx(j+12|0,j+8|0)>>2];e=C(b*C(C(d+g)+C(.007000000216066837)));a:{if(C(D(e))<C(2147483648)){i=~~e;break a}i=-2147483648}v[a+4352>>2]=i;c=1;while(1){if((c|0)==12){u=j,w=C(C(C(pJ(z[a+4248>>2])/C(100))+C(.10000000149011612))*C(.9090999960899353)),z[u+12>>2]=w;v[j+8>>2]=1065353216;d=z[El(j+12|0,j+8|0)>>2];g=C(b*C(C(d*C(75))/C(1e3)));d=C(b*C(C(d*C(67))/C(1e3)));c=0;while(1){if((c|0)==6){i=a+4348|0;d=C(b*C(.0035299998708069324));b:{if(C(D(d))<C(2147483648)){f=~~d;break b}f=-2147483648}v[i>>2]=f;i=a+4344|0;d=C(b*C(.0032500000670552254));c:{if(C(D(d))<C(2147483648)){f=~~d;break c}f=-2147483648}v[i>>2]=f;i=a+4340|0;b=C(b*C(.009999999776482582));d:{if(C(D(b))<C(2147483648)){f=~~b;break d}f=-2147483648}v[i>>2]=f}else{o=(c<<2)+a|0;i=o+4316|0;p=c+p|0;e=fe(C(.9300000071525574),C(p|0));h=C(g*e);e:{if(C(D(h))<C(2147483648)){f=~~h;break e}f=-2147483648}v[i>>2]=f;i=o+4292|0;e=C(d*e);f:{if(C(D(e))<C(2147483648)){f=~~e;break f}f=-2147483648}v[i>>2]=f;c=c+1|0;continue}break}c=0;while(1){if((c|0)!=15){sJ((B(c,24)+a|0)+4504|0,v[((c<<2)+a|0)+4292>>2]);c=c+1|0;continue}break}ab=j+16|0}else{i=((B(c&1,24)+a|0)+(c<<1&-4)|0)+4352|0;e=C(b*C(C(g*z[(c<<2)+47056>>2])+d));g:{if(C(D(e))<C(2147483648)){f=~~e;break g}f=-2147483648}v[i>>2]=f;c=c+1|0;continue}break}c=ab-16|0;ab=c;d=bh(a,5);e=bh(a,11);b=C(d*bh(a,4));d=C(C(b*C(.03999999910593033))+C(C(d*C(.02250000089406967))+C(0)));g=C(e*bh(a,10));e=C(C(g*C(.03999999910593033))+C(C(e*C(.02250000089406967))+C(0)));if(t[a+4264|0]&1){h=bh(a,3);l=bh(a,9);h=C(b*h);b=C(h*bh(a,2));d=C(C(b*C(.1444000005722046))+C(C(h*C(.12250000238418579))+d));h=C(g*l);g=C(h*bh(a,8));e=C(C(g*C(.1444000005722046))+C(C(h*C(.12250000238418579))+e))}bh(a,12);h=z[a+4496>>2];l=bh(a,1);n=bh(a,7);r=bh(a,0);s=bh(a,6);u=c,w=fe(C(10),C(C($w(z[a+4208>>2])+C(C(z[a+4236>>2]*C(12e3))+C(-1e4)))/C(2e3))),z[u+12>>2]=w;v[c+8>>2]=1065353216;q=z[El(c+12|0,c+8|0)>>2];m=b;b=C(h*h);h=C(l*C(m*b));l=C(r*h);b=C(n*C(g*b));g=C(s*b);n=C(C(C(l+g)*C(-.5))+C(1));z[a+4284>>2]=q*C(K(C(n/C(C(l*C(.1444000005722046))+C(C(b*C(.1444000005722046))+d)))));z[a+4288>>2]=q*C(K(C(n/C(C(g*C(.1444000005722046))+C(C(h*C(.1444000005722046))+e)))));ab=c+16|0;t[a+5046|0]=0;ab=k+16|0}function rga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=ab-176|0;ab=g;Xd(g+160|0,b);e=ab-48|0;ab=e;v[e+44>>2]=0;Xj(b,e+44|0);a:{b:{c:{if(v[e+44>>2]!=(om(14079)|0)){break c}v[e+40>>2]=0;f=ab-32|0;ab=f;v[f+28>>2]=0;ov(f+8|0,f+28|0);_m(f+16|0,b,v[f+8>>2],v[f+12>>2]);v[f+16>>2]=v[f+28>>2];v[e+40>>2]=w[f+16|0]|w[f+17|0]<<8|(w[f+18|0]<<16|w[f+19|0]<<24);ab=f+32|0;f=-1;i=v[e+40>>2];if(i-3>>>0<4294967294){break c}d:{e:{f:{if(i>>>0<=1){i=Bb(e+24|0);v[22452]=0;h=Y(442,b|0,i|0,256)|0;j=v[22452];v[22452]=0;if((j|0)==1){break b}if(!h){break e}v[22452]=0;U(11,e+8|0,d|0,i|0);h=v[22452];v[22452]=0;if((h|0)!=1){break f}break b}i=Bb(e+24|0);v[22452]=0;h=Q(444,b|0,i|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break b}if(!h){break d}v[22452]=0;U(11,e+8|0,d|0,i|0);h=v[22452];v[22452]=0;if((h|0)==1){break b}}h=e+8|0;tb(c,h);pb(h);pb(i);Kf(b,h);i=0;v[e+24>>2]=0;Xj(b,e+24|0);h=v[e+24>>2];if(h>>>0>50){break c}while(1){if((h|0)!=(i|0)){if(!cK(a,b,d)){break c}i=i+1|0;continue}break}v[e+24>>2]=0;Xj(b,e+24|0);f=v[e+24>>2]==(om(14125)|0)?1:-1;break c}pb(i);break c}pb(i)}ab=e+48|0;break a}a=P()|0;O()|0;pb(i);S(a|0);L()}g:{if(f){break g}Im(v[v[b>>2]-12>>2]+b|0,0);f=v[g+172>>2];v[g+16>>2]=v[g+168>>2];v[g+20>>2]=f;f=v[g+164>>2];v[g+8>>2]=v[g+160>>2];v[g+12>>2]=f;f=yl(g+56|0,yj(b,g+8|0));v[22452]=0;b=Q(408,g+40|0,14264)|0;e=v[22452];v[22452]=0;h:{if((e|0)!=1){v[22452]=0;v[g+32>>2]=3;v[g+36>>2]=0;U(409,f|0,b|0,g+32|0);e=v[22452];v[22452]=0;if((e|0)!=1){yb(b);t[g+31|0]=0;v[22452]=0;b=Q(408,g+40|0,14720)|0;e=v[22452];v[22452]=0;if((e|0)!=1){v[22452]=0;U(410,f|0,g+31|0,b|0);e=v[22452];v[22452]=0;if((e|0)!=1){yb(b);v[22452]=0;e=w[g+31|0];b=T(423,f|0)|0;i=v[22452];v[22452]=0;if((i|0)!=1){v[22452]=0;i=T(424,f|0)|0;h=v[22452];v[22452]=0;if((h|0)!=1){d=e?0:d;v[g+32>>2]=b;i:{j:{k:{l:{while(1){if(!Tb(b,i)){a=v[f>>2];Sg(f);f=a&1073741824?-1:1;break g}v[22452]=0;b=Q(408,g+40|0,15750)|0;e=v[22452];v[22452]=0;if((e|0)==1){break k}v[22452]=0;e=Y(425,f|0,v[g+32>>2],b|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break j}yb(b);m:{n:{if(!e){v[22452]=0;W(426,f|0,g+32|0,c|0,d|0);b=v[22452];v[22452]=0;if((b|0)!=1){break n}break i}v[22452]=0;b=Q(408,g+40|0,15420)|0;e=v[22452];v[22452]=0;o:{p:{if((e|0)!=1){v[22452]=0;e=Y(425,f|0,v[g+32>>2],b|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break p}yb(b);if(e){break o}v[22452]=0;U(427,f|0,g+32|0,g+28|0);b=v[22452];v[22452]=0;if((b|0)==1){break i}break n}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b);break h}v[22452]=0;b=Q(408,g+40|0,15258)|0;e=v[22452];v[22452]=0;if((e|0)==1){break m}v[22452]=0;e=Y(425,f|0,v[g+32>>2],b|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break l}yb(b);if(e){break n}v[22452]=0;W(428,f|0,g+32|0,a|0,d|0);b=v[22452];v[22452]=0;if((b|0)==1){break i}}In(g+32|0);b=v[g+32>>2];continue}break}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b);break h}a=P()|0;O()|0}Sg(f);S(a|0);L()}ab=g+176|0;return f|0}function xb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[114941]){break a}a=a+b|0;if(v[114942]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=459748,j=v[114937]&sia(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+460052|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=459752,j=v[114938]&sia(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[114939]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[114943]==(f|0)){v[114943]=d;a=v[114940]+a|0;v[114940]=a;v[d+4>>2]=a|1;if(v[114942]!=(d|0)){break a}v[114939]=0;v[114942]=0;return}if(v[114942]==(f|0)){v[114942]=d;a=v[114939]+a|0;v[114939]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=459748,j=v[114937]&sia(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+460052|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=459752,j=v[114938]&sia(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[114942]!=(d|0)){break f}v[114939]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+459788|0;c=v[114937];a=1<<a;k:{if(!(c&a)){v[114937]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;v[d+16>>2]=0;v[d+20>>2]=0;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;g=(e<<2)+460052|0;l:{m:{c=v[114938];b=1<<e;n:{if(!(c&b)){v[114938]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[114945]-1|0;v[114945]=a?a:-1}}function Ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=ab-288|0;ab=e;g=ab-32|0;ab=g;d=g+8|0;xA(d,b);pu(g,d);v[22452]=0;U(422,e+128|0,v[g>>2],v[g+4>>2]);b=v[22452];v[22452]=0;a:{if((b|0)!=1){rc(g+8|0);ab=g+32|0;break a}a=P()|0;O()|0;rc(g+8|0);S(a|0);L()}v[22452]=0;U(405,e+24|0,v[e+128>>2],v[e+132>>2]);b=v[22452];v[22452]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){v[22452]=0;g=Q(80,e+144|0,e+24|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break z}pb(e+24|0);Xb(e+128|0);if(c>>>0<2189){break g}b=yl(e+24|0,g);v[22452]=0;c=Q(408,e+8|0,10085)|0;d=v[22452];v[22452]=0;if((d|0)==1){break x}v[22452]=0;v[e>>2]=19923456;v[e+4>>2]=0;U(409,b|0,c|0,e|0);d=v[22452];v[22452]=0;if((d|0)==1){break w}yb(c);t[e|0]=0;v[22452]=0;c=Q(408,e+8|0,10954)|0;d=v[22452];v[22452]=0;if((d|0)==1){break i}v[22452]=0;U(410,b|0,e|0,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break v}yb(c);c=0;c=w[e|0]?c:v[a+1298404>>2];f=v[a+4>>2];v[22452]=0;d=Q(408,e+8|0,15750)|0;h=v[22452];v[22452]=0;if((h|0)==1){break u}v[22452]=0;W(411,b|0,f|0,d|0,c|0);f=v[22452];v[22452]=0;if((f|0)==1){break t}yb(d);v[22452]=0;d=Q(408,e+8|0,15420)|0;f=v[22452];v[22452]=0;if((f|0)==1){break s}v[22452]=0;W(412,b|0,a|0,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break r}yb(d);v[22452]=0;c=Q(408,e+8|0,15258)|0;d=v[22452];v[22452]=0;if((d|0)==1){break q}v[22452]=0;d=a+484360|0;U(413,b|0,d|0,c|0);f=v[22452];v[22452]=0;if((f|0)==1){break p}yb(c);v[22452]=0;c=Q(408,e+8|0,26646)|0;f=v[22452];v[22452]=0;if((f|0)==1){break o}v[22452]=0;U(414,b|0,a+484344|0,c|0);f=v[22452];v[22452]=0;if((f|0)==1){break n}yb(c);f=v[a+1298404>>2];v[22452]=0;c=Q(408,e+8|0,26652)|0;h=v[22452];v[22452]=0;if((h|0)==1){break m}v[22452]=0;W(415,b|0,d|0,c|0,f|0);d=v[22452];v[22452]=0;if((d|0)==1){break l}yb(c);if(w[b+3|0]&64){v[22452]=0;c=Q(1,e+8|0,16229)|0;d=v[22452];v[22452]=0;if((d|0)==1){break k}a=v[a+1298464>>2];v[22452]=0;U(364,a|0,1,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break j}pb(c)}Sg(b);break f}a=P()|0;O()|0;break y}a=P()|0;O()|0;pb(e+24|0)}Xb(e+128|0);break b}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(c);break h}a=P()|0;O()|0;yb(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;pb(c);break h}a=P()|0;O()|0}Sg(b);break c}b=Bb(e+24|0);d=v[a+1298404>>2];f=v[a+4>>2];v[22452]=0;d=da(416,f|0,g|0,b|0,d|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break e}A:{if((d|0)!=1){v[22452]=0;c=Q(1,e+8|0,16535)|0;d=v[22452];v[22452]=0;B:{if((d|0)!=1){a=v[a+1298464>>2];v[22452]=0;U(364,a|0,1,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break B}pb(c);break A}a=P()|0;O()|0;break d}a=P()|0;O()|0;pb(c);break d}d=v[a+1298404>>2];v[22452]=0;W(417,g|0,a|0,d|0,c>>>0<2188|0);a=v[22452];v[22452]=0;if((a|0)==1){break e}}pb(b)}ef(g);ab=e+288|0;return}a=P()|0;O()|0}pb(b)}ef(g)}S(a|0);L()}function og(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;j=ab-112|0;ab=j;k=i&2147483647;l=e&2147483647;m=l;a:{b:{n=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:n)){p=k-2147418112|0;if(!h&(p|0)==-2147418112?f|g:(p|0)==-2147418112&(h|0)!=0|p>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?n:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){m=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:m;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|m))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}l=(k|0)==(m|0);q=l&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:l&d>>>0<h>>>0|k>>>0>m>>>0;k=q;n=k?f:b;l=k?g:c;m=k?i:e;p=m;o=k?h:d;m=m&65535;e=k?e:i;r=e;h=k?d:h;d=e>>>16&32767;k=p>>>16&32767;if(!k){e=!(m|o);i=e<<6;k=E(e?n:o)+32|0;e=E(e?l:m);e=i+((e|0)==32?k:e)|0;zf(j+96|0,n,l,o,m,e-15|0);o=v[j+104>>2];m=v[j+108>>2];n=v[j+96>>2];k=16-e|0;l=v[j+100>>2]}f=q?b:f;g=q?c:g;i=r&65535;if(!d){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;zf(j+80|0,f,g,h,i,b-15|0);h=v[j+88>>2];i=v[j+92>>2];f=v[j+80>>2];g=v[j+84>>2];d=16-b|0}c=h;b=i<<3|c>>>29;h=c<<3|g>>>29;i=b|524288;c=o;b=m<<3|c>>>29;e=c<<3|l>>>29;m=b;o=p^r;c=f;b=g<<3|c>>>29;c=c<<3;d=k-d|0;c:{if(!d){break c}if(d>>>0>127){h=0;i=0;b=0;c=1;break c}zf(j- -64|0,c,b,h,i,128-d|0);Yl(j+48|0,c,b,h,i,d);h=v[j+56>>2];i=v[j+60>>2];b=v[j+52>>2];c=v[j+48>>2]|(v[j+64>>2]|v[j+72>>2]|(v[j+68>>2]|v[j+76>>2]))!=0}f=b;m=m|524288;d=n;b=l<<3|d>>>29;d=d<<3;d:{if((o|0)<0){n=d-c|0;g=h;o=e-h|0;q=(b|0)==(f|0)&c>>>0>d>>>0|b>>>0<f>>>0;h=o-q|0;l=b-((c>>>0>d>>>0)+f|0)|0;i=(m-((e>>>0<g>>>0)+i|0)|0)-(o>>>0<q>>>0)|0;if(!(n|h|(l|i))){f=0;g=0;h=0;i=0;break a}if(i>>>0>524287){break d}b=!(h|i);c=b<<6;d=E(b?n:h)+32|0;b=E(b?l:i);b=c+((b|0)==32?d:b)|0;b=b-12|0;zf(j+32|0,n,l,h,i,b);k=k-b|0;h=v[j+40>>2];i=v[j+44>>2];n=v[j+32>>2];l=v[j+36>>2];break d}b=b+f|0;g=c+d|0;b=g>>>0<d>>>0?b+1|0:b;n=g;d=g;l=b;f=(f|0)==(b|0)&c>>>0>d>>>0|b>>>0<f>>>0;b=i+m|0;c=e+h|0;b=c>>>0<h>>>0?b+1|0:b;d=c;c=f+c|0;h=c;i=c>>>0<d>>>0?b+1|0:b;if(!(i&1048576)){break d}n=n&1|((l&1)<<31|n>>>1);c=h;l=c<<31|l>>>1;k=k+1|0;h=(i&1)<<31|c>>>1;i=i>>>1|0}d=0;m=p&-2147483648;if((k|0)>=32767){h=d;i=m|2147418112;f=0;g=0;break a}c=0;e:{if((k|0)>0){c=k;break e}zf(j+16|0,n,l,h,i,k+127|0);Yl(j,n,l,h,i,1-k|0);n=v[j>>2]|(v[j+16>>2]|v[j+24>>2]|(v[j+20>>2]|v[j+28>>2]))!=0;l=v[j+4>>2];h=v[j+8>>2];i=v[j+12>>2]}e=h<<29;b=l>>>3|0;k=(l&7)<<29|n>>>3;l=n&7;g=l>>>0>4;f=k+g|0;e=b|e;b=e;b=f>>>0<g>>>0?b+1|0:b;g=b;e=(e|0)==(b|0)&f>>>0<k>>>0|b>>>0<e>>>0;b=i>>>3&65535;h=(i&7)<<29|h>>>3;i=c<<16;d=d|h;c=d+e|0;b=m|(b|i);h=c;i=c>>>0<d>>>0?b+1|0:b;f:{if((l|0)==4){d=0;b=g+d|0;e=f&1;c=f+e|0;b=c>>>0<f>>>0?b+1|0:b;f=c;g=b;c=(d|0)==(b|0)&c>>>0<e>>>0|b>>>0<d>>>0;b=c+h|0;i=b>>>0<c>>>0?i+1|0:i;h=b;break f}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;ab=j+112|0}function UI(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=ab-128|0;ab=e;A[e+120>>3]=c;f=v[b+4>>2];a:{if(!f){break a}g=v[b>>2];h=w[Gk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Pk(e+96|0,g,f,f-1|0);f=v[e+100>>2];v[b>>2]=v[e+96>>2];v[b+4>>2]=f}f=e+96|0;Dd(f);g=v[e+96>>2];Dd(e+80|0);h=Fk(g,v[e+84>>2],b);Dd(f);f=v[b+4>>2];g=v[b>>2];b:{c:{d:{e:{if((h|0)==v[e+100>>2]){a=kc(e+112|0,21598);if(yc(g,f,v[a>>2],v[a+4>>2])){d=aa(8)|0;v[22452]=0;R(936,e+80|0,e+120|0);a=v[22452];v[22452]=0;f:{g:{h:{if((a|0)!=1){v[22452]=0;U(939,e+96|0,17577,e+80|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}lc(d,e+96|0);a=0;v[22452]=0;U(110,d|0,58760,928);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;pb(e+96|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}pb(e+80|0);if(!a){break c}}ba(d|0);break c}if(!d){break e}d=aa(8)|0;v[22452]=0;f=Q(938,e+48|0,b|0)|0;a=v[22452];v[22452]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[22452]=0;U(939,e- -64|0,17613,f|0);a=v[22452];v[22452]=0;if((a|0)==1){break q}v[22452]=0;R(941,e+80|0,e- -64|0);b=v[22452];v[22452]=0;a=1;if((b|0)==1){break p}v[22452]=0;R(936,e+32|0,e+120|0);a=v[22452];v[22452]=0;if((a|0)==1){break o}v[22452]=0;U(943,e+96|0,e+80|0,e+32|0);b=v[22452];v[22452]=0;a=1;if((b|0)==1){break n}lc(d,e+96|0);v[22452]=0;U(110,d|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(e+96|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}pb(e+32|0)}pb(e+80|0)}pb(e- -64|0)}pb(f);if(!a){break c}}ba(d|0);break c}d=kc(e+24|0,21598);if(yc(g,f,v[d>>2],v[d+4>>2])){d=aa(8)|0;v[22452]=0;R(936,e+80|0,e+120|0);a=v[22452];v[22452]=0;r:{s:{t:{if((a|0)!=1){v[22452]=0;U(939,e+96|0,17577,e+80|0);a=v[22452];v[22452]=0;if((a|0)==1){break t}lc(d,e+96|0);a=0;v[22452]=0;U(110,d|0,58760,928);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;pb(e+96|0);break s}b=P()|0;O()|0;break r}b=P()|0;a=1;O()|0}pb(e+80|0);if(!a){break c}}ba(d|0);break c}f=v[b>>2];g=v[b+4>>2];d=kc(e+16|0,7677);if(yc(f,g,v[d>>2],v[d+4>>2])){if(!zd(w[a+28|0])){break e}if(c<=0|c>4){a=aa(8)|0;v[22452]=0;d=Q(55,e+96|0,7772)|0;b=v[22452];v[22452]=0;if((b|0)==1){break d}lc(a,d);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(d);break c}b=xe(65536/c);a=a+24|0;v[v[a>>2]+480244>>2]=b;bp(v[a>>2]);break e}f=v[b>>2];g=v[b+4>>2];d=kc(e+8|0,7729);if(yc(f,g,v[d>>2],v[d+4>>2])){if(!zd(w[a+28|0])){break e}if(c<=0|c>4){a=aa(8)|0;v[22452]=0;d=Q(55,e+96|0,7793)|0;b=v[22452];v[22452]=0;if((b|0)!=1){lc(a,d);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(d);break c}b=P()|0;O()|0;ba(a|0);break c}b=xe(c*65536);a=a+24|0;v[v[a>>2]+480240>>2]=b;bp(v[a>>2]);break e}d=v[b>>2];f=v[b+4>>2];b=kc(e,7747);if(!yc(d,f,v[b>>2],v[b+4>>2])){break e}b=Tl(c*65536);v[v[a+24>>2]+480236>>2]=b}ab=e+128|0;return}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function VI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=ab-176|0;ab=e;t[e+175|0]=c;f=v[b+4>>2];a:{if(!f){break a}g=v[b>>2];h=w[Gk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Pk(e,g,f,f-1|0);f=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=f}Dd(e);f=v[e>>2];Dd(e+144|0);h=Fk(f,v[e+148>>2],b);Dd(e);f=v[b+4>>2];g=v[b>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==v[e+4>>2]){a=kc(e+160|0,21598);if(yc(g,f,v[a>>2],v[a+4>>2])){c=aa(8)|0;v[22452]=0;R(932,e+144|0,e+175|0);a=v[22452];v[22452]=0;if((a|0)==1){break g}v[22452]=0;U(939,e|0,17577,e+144|0);a=v[22452];v[22452]=0;if((a|0)==1){break f}lc(c,e);a=0;v[22452]=0;U(110,c|0,58760,928);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;pb(e);break e}if(!d){break h}c=aa(8)|0;v[22452]=0;d=Q(938,e+112|0,b|0)|0;a=v[22452];v[22452]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[22452]=0;U(939,e+128|0,17613,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break p}v[22452]=0;R(941,e+144|0,e+128|0);b=v[22452];v[22452]=0;a=1;if((b|0)==1){break o}v[22452]=0;R(932,e+96|0,e+175|0);a=v[22452];v[22452]=0;if((a|0)==1){break n}v[22452]=0;U(943,e|0,e+144|0,e+96|0);b=v[22452];v[22452]=0;a=1;if((b|0)==1){break m}lc(c,e);v[22452]=0;U(110,c|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(e);a=0;break l}b=P()|0;O()|0;break d}b=P()|0;a=1;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;a=1;O()|0;break k}b=P()|0;O()|0}pb(e+96|0)}pb(e+144|0)}pb(e+128|0)}pb(d);if(a){break d}break c}d=kc(e+88|0,21598);if(yc(g,f,v[d>>2],v[d+4>>2])){c=aa(8)|0;v[22452]=0;R(932,e+144|0,e+175|0);a=v[22452];v[22452]=0;q:{r:{if((a|0)!=1){v[22452]=0;U(939,e|0,17577,e+144|0);a=v[22452];v[22452]=0;if((a|0)==1){break r}lc(c,e);a=0;v[22452]=0;U(110,c|0,58760,928);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;pb(e);break q}b=P()|0;O()|0;break d}b=P()|0;a=1;O()|0}pb(e+144|0);if(a){break d}break c}s:{f=v[b>>2];g=v[b+4>>2];d=kc(e+80|0,7380);if(!yc(f,g,v[d>>2],v[d+4>>2])){f=v[b>>2];g=v[b+4>>2];d=kc(e+72|0,7362);if(!yc(f,g,v[d>>2],v[d+4>>2])){break s}}t[a+60|0]=c;break h}t:{f=v[b>>2];g=v[b+4>>2];d=kc(e- -64|0,6895);if(!yc(f,g,v[d>>2],v[d+4>>2])){f=v[b>>2];g=v[b+4>>2];d=kc(e+56|0,6876);if(!yc(f,g,v[d>>2],v[d+4>>2])){break t}}t[a+61|0]=c;break h}f=v[b>>2];g=v[b+4>>2];d=kc(e+48|0,6979);if(yc(f,g,v[d>>2],v[d+4>>2])){t[a+62|0]=c;break h}f=v[b>>2];g=v[b+4>>2];d=kc(e+40|0,6025);if(yc(f,g,v[d>>2],v[d+4>>2])){t[a+63|0]=c;break h}f=v[b>>2];g=v[b+4>>2];d=kc(e+32|0,7429);if(yc(f,g,v[d>>2],v[d+4>>2])){t[a+64|0]=c;break h}d=v[b>>2];f=v[b+4>>2];b=kc(e+24|0,13359);if(!yc(d,f,v[b>>2],v[b+4>>2])){break h}d=a+24|0;b=v[d>>2];f=b+24664|0;g=v[f+4>>2];v[e+16>>2]=v[f>>2];v[e+20>>2]=g;f=b+24656|0;g=v[f+4>>2];v[e+8>>2]=v[f>>2];v[e+12>>2]=g;f=v[b+24652>>2];v[e>>2]=v[b+24648>>2];v[e+4>>2]=f;if(c){a=yI(v[a+56>>2])}else{a=0}v[e+20>>2]=a;a=v[d>>2];if(!Rw(e,a+24648|0)){break h}Sx(a,e)}ab=e+176|0;return}b=P()|0;O()|0;break d}b=P()|0;a=1;O()|0}pb(e+144|0);if(!a){break c}}ba(c|0)}S(b|0)}L()}function hS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=ab-128|0;ab=f;i=Rg(f+112|0);a:{b:{c:{if(d){v[22452]=0;U(429,a|0,i|0,c|0);c=v[22452];v[22452]=0;if((c|0)!=1){break c}break b}v[22452]=0;U(430,a|0,i|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}}k=Pb(f+96|0);n=b+480192|0;o=b+1298464|0;d=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{l=d&65535;if(l>>>0<=x[n>>1]){v[22452]=0;u[f+94>>1]=0;R(431,a|0,f+94|0);c=v[22452];v[22452]=0;t:{u:{v:{w:{if((c|0)!=1){g=ab-16|0;ab=g;e=ab-16|0;ab=e;p=x[f+94>>1];c=Kd(i);j=ac(i);h=ab-16|0;ab=h;while(1){if(c){m=tA(c+16|0,p);j=m?j:c;c=v[(m?4:0)+c>>2];continue}break}c=v[$b(h+8|0,j)>>2];ab=h+16|0;v[e+8>>2]=c;x:{if(Tb(c,Jf(i))){if(!uA(x[f+94>>1],id(e+8|0))){break x}}c=Jf(i)}ab=e+16|0;c=v[$b(g+8|0,c)>>2];ab=g+16|0;v[f+88>>2]=c;j=((l<<2)+b|0)+900380|0;if(!v[j>>2]){break d}q=f,r=Af(i),v[q+72>>2]=r;if(!Qg(f+88|0,f+72|0)){break u}c=id(f+88|0);v[22452]=0;c=Q(3,f+72|0,c+4|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break t}v[22452]=0;e=Q(1,f+56|0,16725)|0;g=v[22452];v[22452]=0;if((g|0)==1){break v}g=Mp(c,e);pb(e);if(g){break p}e=v[b+4>>2];v[22452]=0;e=Q(432,e|0,c|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break r}v[v[j>>2]+44>>2]=e;if(!v[v[j>>2]+44>>2]){break w}break e}d=P()|0;O()|0;break f}v[22452]=0;e=Q(1,f+56|0,13390)|0;g=v[22452];v[22452]=0;y:{z:{A:{if((g|0)!=1){B:{if(!Mp(c,e)){v[22452]=0;g=Q(1,f+40|0,13602)|0;h=v[22452];v[22452]=0;if((h|0)==1){break A}h=Mp(c,g);pb(g);pb(e);if(h){break B}break s}pb(e)}v[22452]=0;e=T(433,c|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break z}v[f+56>>2]=e;e=v[b+4>>2];Oh(f+32|0,f+56|0);v[22452]=0;e=Q(434,e|0,v[f+32>>2])|0;g=v[22452];v[22452]=0;if((g|0)==1){break y}bg(f+56|0);if(e){break e}break s}d=P()|0;O()|0;break g}d=P()|0;O()|0;pb(e);break g}d=P()|0;O()|0;break g}d=P()|0;O()|0;bg(f+56|0);break g}d=P()|0;O()|0;break g}c=v[j>>2];if(!c){break d}v[c+44>>2]=0;break d}d=P()|0;O()|0;break f}Uc(k);gS(i);ab=f+128|0;return}e=wb(v[k>>2]);h=wb(v[k+4>>2]);g=ab-16|0;ab=g;v[g+8>>2]=e;while(1){C:{if(!Tb(e,h)){break C}if(Mp(e,c)){break C}Sn(g+8|0);e=v[g+8>>2];continue}break}ab=g+16|0;if(Tb(e,wb(v[k+4>>2]))){break p}v[22452]=0;R(435,k|0,c|0);e=v[22452];v[22452]=0;if((e|0)!=1){break q}}d=P()|0;O()|0;break g}v[22452]=0;e=Q(1,f+16|0,17426)|0;g=v[22452];v[22452]=0;if((g|0)==1){break o}v[22452]=0;U(436,f+40|0,e|0,c|0);g=v[22452];v[22452]=0;if((g|0)==1){break n}v[22452]=0;g=Q(1,f|0,16278)|0;h=v[22452];v[22452]=0;if((h|0)==1){break m}v[22452]=0;U(2,f+56|0,f+40|0,g|0);h=v[22452];v[22452]=0;if((h|0)==1){break l}h=v[o>>2];v[22452]=0;U(364,h|0,2,f+56|0);h=v[22452];v[22452]=0;if((h|0)==1){break k}pb(f+56|0);pb(g);pb(f+40|0);pb(e)}v[v[j>>2]+44>>2]=0;break e}d=P()|0;O()|0;break g}d=P()|0;O()|0;break h}d=P()|0;O()|0;break i}d=P()|0;O()|0;break j}d=P()|0;O()|0;pb(f+56|0)}pb(g)}pb(f+40|0)}pb(e)}pb(c)}Uc(k);break a}pb(c)}d=d+1|0;continue}}d=P()|0;O()|0}gS(i);S(d|0);L()}function xG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[114942]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=459748,j=v[114937]&sia(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+460052|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=459752,j=v[114938]&sia(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[114939]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[114943]==(f|0)){v[114943]=a;b=v[114940]+b|0;v[114940]=b;v[a+4>>2]=b|1;if(v[114942]!=(a|0)){break a}v[114939]=0;v[114942]=0;return}if(v[114942]==(f|0)){v[114942]=a;b=v[114939]+b|0;v[114939]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=459748,j=v[114937]&sia(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+460052|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=459752,j=v[114938]&sia(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[114942]!=(a|0)){break g}v[114939]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){b=b>>>3|0;c=(b<<3)+459788|0;d=v[114937];b=1<<b;l:{if(!(d&b)){v[114937]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;v[a+16>>2]=0;v[a+20>>2]=0;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;g=(e<<2)+460052|0;m:{d=v[114938];c=1<<e;n:{if(!(d&c)){v[114938]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function ZK(a,b){var c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=0,s=C(0),t=0;if(b){$o(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;cL(a)}YK(a+24648|0);p=v[a+24620>>2];f=ab-144|0;ab=f;e=a+397456|0;c=v[e+4>>2];if(c>>>0>=29){v[e+4>>2]=0;c=0}h=B(c,44)+47632|0;if(!(b?0:(h|0)==v[e+8>>2])){v[e+8>>2]=h;c=f+8|0;d=v[h+24>>2];v[c>>2]=d;i=v[h+16>>2];v[c+4>>2]=i;v[c+8>>2]=v[h+4>>2];k=(d|0)>(i|0)?d:i;if((k|0)<=-601){j=i;i=k+600|0;v[c+4>>2]=j-i;v[c>>2]=d-i}o=C(p>>>0);g=C(z[h+36>>2]*C(79.30999755859375));a:{if(C(D(g))<C(2147483648)){d=~~g;break a}d=-2147483648}v[c+16>>2]=d- -8192;g=C(C(C(z[h+32>>2]*C(.0036000001709908247))+C(.15000000596046448))*C(32767));b:{if(C(D(g))<C(2147483648)){d=~~g;break b}d=-2147483648}v[c+20>>2]=(d|0)<32512?d:32512;i=0;g=z[h+8>>2];n=C(C(F(z[h+20>>2],C(.10000000149011612)))*o);c:{if(C(D(n))<C(2147483648)){d=~~n;break c}d=-2147483648}j=(d|0)<96;k=j?96:d;l=k-7500|0;m=k>>>0<l>>>0?0:l;n=C(z[h+28>>2]*o);d:{if(C(D(n))<C(2147483648)){l=~~n;break d}l=-2147483648}j=m+(l+(j?d-96|0:0)|0)|0;l=(j|0)<128;d=l?128:j;q=d>>>0<3800?d:3800;v[c+24>>2]=q;l=l?j-128|0:0;g=C(g*o);e:{if(C(D(g))<C(2147483648)){m=~~g;break e}m=-2147483648}j=d-3800|0;j=(m+l|0)+(d>>>0<j>>>0?0:j)|0;v[c+32>>2]=j;l=k>>>0<7500?k:7500;while(1){if((i|0)==8){g=C(j|0);n=C(fe(C(.0010000000474974513),(j|0)<4721?C(1):C(C(4720)/g))*C(32768));f:{if(C(D(n))<C(2147483648)){d=~~n;break f}d=-2147483648}v[c+12>>2]=d;g=C(z[h+12>>2]*g);r=c,s=fe(C(.0010000000474974513),g<=C(4720)?C(1):C(C(4720)/g)),z[r+28>>2]=s}else{d=B(i,12);k=d+c|0;u[k+42>>1]=x[d+48922>>1];u[k+36>>1]=x[d+48916>>1];m=d+48918|0;m=x[m>>1]|x[m+2>>1]<<16;u[k+38>>1]=m;u[k+40>>1]=m>>>16;v[k+44>>2]=l+((B(v[d+48912>>2],q)+50|0)/100|0);i=i+1|0;continue}break}v[e+20>>2]=v[f+40>>2];c=eJ(fJ(v[f+16>>2]),o);u[e+86>>1]=c;u[e+84>>1]=c;c=x[f+24>>1]<<1;u[e+94>>1]=c;u[e+92>>1]=c;c=0;while(1){if((c|0)==8){v[e+49892>>2]=v[f+32>>2];c=v[f+12>>2];if((c|0)>-9e3){c=dJ(c)}else{c=0}v[e+80>>2]=c;d=e+49948|0;c=v[f+8>>2];if((c|0)>=-8999){c=dJ(c)}else{c=0}v[d>>2]=c;c=v[f+28>>2];d=e+49932|0;v[d>>2]=268464128;v[d+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[e+49906>>1]=c;u[e+49904>>1]=c;u[e+49902>>1]=c;u[e+49900>>1]=c;v[f+4>>2]=v[f+20>>2];ce(f+4|0,0,32752);c=x[f+4>>1];u[e+49914>>1]=c;d=e+49910|0;u[d>>1]=0;u[d+2>>1]=0;u[e+49908>>1]=c;g=z[f+36>>2];r=f,t=eJ(C(g*g),o),v[r>>2]=t;ce(f,256,32512);c=x[f>>1];u[e+49922>>1]=c;d=e+49918|0;u[d>>1]=0;u[d+2>>1]=0;u[e+49916>>1]=c}else{d=(c<<4)+e|0;h=(f+8|0)+B(c,12)|0;i=v[h+44>>2];v[d+100>>2]=i;v[d+104>>2]=i;u[d+108>>1]=x[h+36>>1];u[d+110>>1]=x[h+42>>1];u[d+112>>1]=x[h+40>>1];u[d+114>>1]=x[h+38>>1];c=c+1|0;continue}break}}c=a+397448|0;d=a+397452|0;if(b){v[e+16>>2]=0;hJ(e,c,d)}b=B(p,5);if(b>>>0>y[e+20>>2]){v[e+20>>2]=b}ab=f+144|0;b=a+1298300|0;if(td(b)){NN(v[b>>2],v[a+24620>>2])}}function hia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=ab-736|0;ab=d;qc(b);e=ab-16|0;ab=e;g=d+120|0;AT(e+8|0,g);i=b;b=v[e+12>>2];_b(e,i,v[e+8>>2],b);h=v[e+4>>2];if((h|0)==(b|0)){Ob(i,v[e+12>>2])}ab=e+16|0;b=(b|0)==(h|0);if(!b){zT(g)}a:{if(!b){break a}if(!BT(d+120|0)){break a}b:{if(!c){break b}vd(a,67108864);wg(a);b=w[d+145|0];u[a+480190>>1]=31;u[a+480188>>1]=b;v[a+480228>>2]=256/(b>>>0);b=Mb(d,8166);tb(a+1298344|0,b);pb(b);b=Mb(d,10732);tb(a+1298356|0,b);pb(b);f=d+96|0;af(f,4135);e=w[d+144|0];v[d+72>>2]=e>>>4;b=0;v[22452]=0;v[d+116>>2]=e&15;W(295,d|0,f|0,d+72|0,d+116|0);f=v[22452];v[22452]=0;c:{d:{if((f|0)!=1){tb(a+1298368|0,d);pb(d);yb(d+96|0);v[a+1298404>>2]=2;cq(Kb(a+484360|0),d+168|0,w[d+167|0]+1|0);while(1){e:{if((b|0)==31){du(i,a+1298308|0,32);f=1;break e}f=b+1|0;g=B(f,104)+a|0;h=g+484380|0;ed(h,1);e=(d+120|0)+(b<<2)|0;p=h,q=Wb(w[e+176|0]|w[e+177|0]<<8|(w[e+178|0]<<16|w[e+179|0]<<24)),v[p>>2]=q;j=Wb(w[e+300|0]|w[e+301|0]<<8|(w[e+302|0]<<16|w[e+303|0]<<24));v[g+484384>>2]=j;p=g+484388|0,q=Wb(w[e+424|0]|w[e+425|0]<<8|(w[e+426|0]<<16|w[e+427|0]<<24))+j|0,v[p>>2]=q;if(Wb(w[e+424|0]|w[e+425|0]<<8|(w[e+426|0]<<16|w[e+427|0]<<24))){e=g+484414|0;u[e>>1]=x[e>>1]|2}ek(h);b=(d+120|0)+b|0;t[d|0]=w[b+548|0];t[d+96|0]=64;p=g+484410|0,q=w[Qb(d,d+96|0)|0]<<2,u[p>>1]=q;t[g+484417|0]=w[b+579|0]<<4;b=f;continue}break}while(1){if((f|0)!=32){yT(i,((f<<5)+a|0)+946304|0,30);f=f+1|0;continue}break}m=c&1;if(m){fg(a+484344|0,w[d+166|0]+1|0)}j=a+484344|0;l=a+480188|0;e=0;while(1){if(w[d+166|0]<e>>>0){f=1;if(!(c&2)){break a}b=Gc(d,8,1,1,0);while(1){if((f|0)==32){break b}eg(b,(B(f,104)+a|0)+484380|0,i);f=f+1|0;continue}}h=Nh(d+96|0);f:{g:{if(w[d+146|0]){v[22452]=0;b=T(265,i|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break f}v[22452]=0;U(181,d+72|0,i|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break f}break g}b=x[l>>1];v[22452]=0;U(181,d+72|0,i|0,b<<8);b=v[22452];v[22452]=0;if((b|0)==1){break d}}b=d+72|0;Mc(h,bc(d,b));qb(d);qb(b);h:{if(!m){break h}v[22452]=0;b=Y(217,j|0,e&65535,64)|0;f=v[22452];v[22452]=0;if((f|0)==1){break d}if(!b){break h}b=0;if(w[d+146|0]){g=0;v[22452]=0;R(296,h|0,d|0);b=v[22452];v[22452]=0;if((b|0)==1){break d}i:while(1){if((g|0)==64){break h}k=d+g|0;b=128;f=0;n=Of(Rb(j,e),g);while(1){if(x[l>>1]<=f>>>0){g=g+1|0;continue i}j:{if(!(w[k|0]&b)){break j}v[22452]=0;R(297,h|0,B(f,6)+n|0);o=v[22452];v[22452]=0;if((o|0)!=1){break j}break d}b=b>>>1|0;f=f+1|0;continue}}}k:while(1){f=0;g=b&65535;if(g>>>0>=x[l>>1]){break h}while(1){if((f|0)==64){b=b+1|0;continue k}k=Qc(Rb(j,e),f,g);v[22452]=0;R(297,h|0,k|0);k=v[22452];v[22452]=0;if((k|0)!=1){f=f+1|0;continue}break}break}break d}e=e+1|0;qb(d+96|0);continue}break}break d}f=P()|0;O()|0;yb(d+96|0);break c}f=P()|0;O()|0;qb(d+96|0)}S(f|0);L()}f=1}ab=d+736|0;return f|0}function bV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0;e=ab-32|0;ab=e;v[e+28>>2]=b;a:{if((d|0)<=0){break a}v[e+8>>2]=d;v[e+16>>2]=214748364;u=e,x=B(v[zb(e+28|0,e+16|0)>>2],20),v[u+20>>2]=x;Wm(c,v[zb(e+8|0,e+20|0)>>2]);v[e+12>>2]=b;v[e+8>>2]=a;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}g=Xg(a,b,h);i=Xg(a,b,h+4|0);f=Xg(a,b,h+5|0);u=e,x=Xg(a,b,h+6|0)<<8|Xg(a,b,h+7|0),v[u+24>>2]=x;n=f|i<<8;s=h+8|0;f:{g:{switch(g|0){case 0:h=0;if((d|0)<(n|0)){h=aa(8)|0;v[22452]=0;T(184,h|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break f}break d}while(1){if((h|0)!=(n|0)){u=e,x=Xg(a,b,h+s|0),t[u+20|0]=x;Um(c,e+20|0);h=h+1|0;continue}break};r=n;break b;case 1:break g;default:break e}}Jh(e+24|0,d);r=v[e+24>>2];o=Xg(a,b,h+10|0);t[e+20|0]=o;Um(c,e+20|0);j=h+11|0;n=n+3&65532;h=r-1|0;i=0;l=0;p=0;m=0;while(1){if((h|0)<=0){break c}f=ig(j,i,1,e+8|0);h:{i:{j:{k:{l:{if((l|0)<=7){if(f){g=i;break i}g=i+1|0;m=8;break l}g=i+1|0;m:{if(!f){if(!ig(j,g,1,e+8|0)){break i}k=2;n:{o:{f=i+2|0;if(!ig(j,f,1,e+8|0)){break o}k=3;f=i+3|0;if(!ig(j,f,1,e+8|0)){break o}k=ig(j,f,3,e+8|0);g=i+6|0;break n}g=f+1|0}f=4;p:{q:{r:{i=((m<<3)+k|0)-17|0;s:{if((i|0)<0){a=aa(8)|0;v[22452]=0;T(184,a|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break r}break s}if(i>>>0<56){break p}a=aa(8)|0;v[22452]=0;T(184,a|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break q}}b=P()|0;O()|0;ba(a|0);S(b|0);L()}ia(a|0,26072,159);L()}ia(a|0,26072,159);L()}m=w[i+26112|0];if((m|0)!=8){break k}break m}f=4;if((m|0)!=8){break k}}m=8;f=1;if((p|0)>19){break k}}f=0;break j}p=p+8|0}while(1){if(!((f|0)<0|(h|0)<=0)){k=(g|0)/8|0;i=k+j|0;q=Xg(v[e+8>>2],v[e+12>>2],i);o=o-Wc((Xg(v[e+8>>2],v[e+12>>2],i+1|0)<<8|q<<16|Xg(v[e+8>>2],v[e+12>>2],i+2|0))<<(g-(k<<3)|0)+8,32-m|0)|0;t[e+20|0]=o;Um(c,e+20|0);f=f-1|0;h=h-1|0;g=g+m|0;continue}break}l=(l|0)==31?31:l+1|0;i=g;break h}t:{u:{v:{f=g+1|0;if(!ig(j,f,1,e+8|0)){i=2;break v}f=g+2|0;if(!ig(j,f,1,e+8|0)){i=4;break v}f=g+3|0;if(!ig(j,f,1,e+8|0)){i=6;break v}f=g+5|0;if(!ig(j,g+4|0,1,e+8|0)){g=g+8|0;f=ig(j,f,3,e+8|0)+8|0;break t}g=g+10|0;i=16;f=ig(j,f,5,e+8|0);break u}g=f+2|0;f=ig(j,f+1|0,1,e+8|0)}f=f+i|0}w:{if(ig(j,g,1,e+8|0)){k=-256;i=12;break w}g=g+1|0;i=ig(j,g,1,e+8|0);k=i?-4352:0;i=i?14:8}q=g+1|0;g=ig(j,q,i,e+8|0);if(f>>>0>=3){l=l-((f|0)!=3)|0;l=((l|0)>1?l:1)-1|0}k=(g^-1)+k|0;g=Ic(v[c>>2],v[c+4>>2])+k|0;if(g>>>0<k>>>0){i=i+q|0;while(1){if((f|0)<=0|(h|0)<=0){break h}o=w[Cb(v[c>>2],g)|0];t[e+20|0]=o;Um(c,e+20|0);h=h-1|0;g=g+1|0;f=f-1|0;continue}}h=aa(8)|0;v[22452]=0;T(184,h|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break d}ia(h|0,26072,159);L()}p=p-(p>>3)|0;continue}}ia(h|0,26072,159);L()}h=jc(v[c>>2],v[c+4>>2])^1;break a}a=P()|0;O()|0;ba(h|0);S(a|0);L()}v[e+24>>2]=h}d=d-r|0;h=n+s|0;continue}}ab=e+32|0;return h|0}function Dca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=ab-32|0;ab=j;a:{if(at(a)>>>0<b>>>0){m=Fn(j+16|0);v[22452]=0;R(702,m|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}Rj(j+8|0,v[a>>2]);Yk(j,v[a>>2],v[a+4>>2]);n=ab-48|0;ab=n;f=v[m+4>>2];c=Zb(n+40|0,v[j+8>>2],v[j+12>>2]);e=Zb(n+32|0,v[j>>2],v[j+4>>2]);b=ab-16|0;ab=b;c=Zb(b+8|0,v[c>>2],v[c+4>>2]);e=Zb(b,v[e>>2],v[e+4>>2]);c=ZP(v[c>>2],v[c+4>>2],v[e>>2],v[e+4>>2]);ab=b+16|0;c=c+v[m+4>>2]|0;v[m+4>>2]=c;b:{c:{if(!f){b=c-1|0;break c}b=c-1|0;if((b^f-1)>>>0<32){break b}}v[v[m>>2]+((c>>>0<33?0:b>>>5|0)<<2)>>2]=0}e=Zb(n+24|0,v[j+8>>2],v[j+12>>2]);c=Zb(n+16|0,v[j>>2],v[j+4>>2]);b=n+8|0;go(b,v[m>>2],f);f=v[e>>2];o=ab-48|0;ab=o;e=v[e+4>>2];d:{if((e|0)==v[b+4>>2]){e=Zb(o+40|0,f,e);c=Zb(o+32|0,v[c>>2],v[c+4>>2]);b=Zb(o+24|0,v[b>>2],v[b+4>>2]);f=ab-16|0;ab=f;g=v[e>>2];d=v[e+4>>2];c=Xk(v[c>>2],v[c+4>>2],g,d);v[f+12>>2]=c;e:{if((c|0)<=0){c=v[b>>2];break e}if(d){i=32-d|0;v[f+8>>2]=i;k=c;c=v[jd(f+8|0,f+12|0)>>2];v[f+12>>2]=k-c;h=v[b>>2];d=-1<<d&-1>>>i-c;v[h>>2]=v[h>>2]&(d^-1)|d&v[g>>2];c=c+v[b+4>>2]|0;v[b+4>>2]=c&31;v[b>>2]=h+(c>>>3&536870908);g=v[e>>2]+4|0;v[e>>2]=g;c=v[f+12>>2]}k=g;d=(c|0)/32|0;g=d<<2;Wi(v[b>>2],k,g);d=c-(d<<5)|0;v[f+12>>2]=d;c=g+v[b>>2]|0;v[b>>2]=c;if((d|0)<=0){break e}c=e;e=g+v[e>>2]|0;v[c>>2]=e;c=v[b>>2];g=-1>>>32-d|0;v[c>>2]=v[c>>2]&(g^-1)|g&v[e>>2];v[b+4>>2]=v[f+12>>2]}Zb(n,c,v[b+4>>2]);break d}g=Zb(o+16|0,f,e);c=Zb(o+8|0,v[c>>2],v[c+4>>2]);e=Zb(o,v[b>>2],v[b+4>>2]);f=ab-16|0;ab=f;k=v[c>>2];d=v[c+4>>2];b=v[g>>2];c=v[g+4>>2];d=Xk(k,d,b,c);v[f+12>>2]=d;f:{if((d|0)<=0){c=v[e+4>>2];break f}g:{if(!c){c=v[e+4>>2];break g}l=32-c|0;v[f+8>>2]=l;i=f+8|0;h=v[jd(i,f+12|0)>>2];v[f+12>>2]=d-h;d=v[e+4>>2];p=v[b>>2];v[f+8>>2]=h;k=32-d|0;v[f+4>>2]=k;b=v[e>>2];q=v[b>>2];i=v[zb(i,f+4|0)>>2];l=p&(-1<<c&-1>>>l-h);v[b>>2]=(-1<<d&-1>>>k-i^-1)&q|(c>>>0<d>>>0?l<<d-c:l>>>c-d|0);d=d+i|0;c=d&31;v[e+4>>2]=c;d=b+(d>>>3&536870908)|0;v[e>>2]=d;b=h-i|0;if((b|0)>0){v[d>>2]=v[d>>2]&(-1>>>32-b^-1)|l>>>i+v[g+4>>2];v[e+4>>2]=b;c=b}b=v[g>>2]+4|0;v[g>>2]=b;d=v[f+12>>2]}h=32-c|0;i=-1<<c;l=i^-1;while(1){if((d|0)>=32){d=v[e>>2];b=v[b>>2];v[d>>2]=l&v[d>>2]|b<<c;v[e>>2]=d+4;v[d+4>>2]=i&v[d+4>>2]|b>>>h;d=v[f+12>>2]-32|0;v[f+12>>2]=d;b=v[g>>2]+4|0;v[g>>2]=b;continue}break}if((d|0)<=0){break f}l=v[b>>2];v[f+8>>2]=h;g=v[e>>2];b=v[g>>2];k=b;b=v[jd(f+12|0,f+8|0)>>2];k=k&(i&-1>>>h-b^-1);h=l&-1>>>32-d;v[g>>2]=k|h<<c;d=b+c|0;c=d&31;v[e+4>>2]=c;g=g+(d>>>3&536870908)|0;v[e>>2]=g;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<=0){break f}v[g>>2]=v[g>>2]&(-1>>>32-d^-1)|h>>>b;c=v[f+12>>2];v[e+4>>2]=c}Zb(n,v[e>>2],c)}ab=f+16|0;ab=o+48|0;ab=n+48|0;gt(a,m);Be(m)}ab=j+32|0;return}a=P()|0;O()|0;Be(m);S(a|0);L()}function hV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=ab-160|0;ab=d;qc(b);ro(a);a:{if(!Vu(b,d+120|0)){break a}if(!$C(d+120|0)){break a}j=v[b+8>>2];b:{if(!Nc(b,w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){break b}while(1){c:{if((w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))>>>0>k>>>0){if(Hb(b,5)){break c}}e=h&1;break b}g=0;e=1;d:{if((w[d+124|0]|w[d+125|0]<<8)>>>0>=64){if((di(b)|0)<=0){break d}}while(1){l=ue(b);if(l){m=g>>>0>4;f=m&e;if(!((e^1)&1|m)){f=(gp(l<<24>>24)&255)==w[g+13071|0]}e=f;g=g+1|0;continue}break}Ob(b,4);h=(g|0)==5?e&1?1:h:h}k=k+1|0;continue}}Nc(b,j);if(!e){break a}if(!Hb(b,_C(d+120|0))){break a}if(!c){i=1;break a}e=ab-16|0;ab=e;h=d+120|0;g=h;c=g+16|0;Nc(b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));k=d+104|0;i=Pb(k);f=g+12|0;c=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[22452]=0;R(172,i|0,c|0);c=v[22452];v[22452]=0;e:{f:{g:{if((c|0)!=1){g=g+4|0;c=0;h:{i:{while(1){if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<=c>>>0){break h}v[22452]=0;j=Q(147,b|0,5)|0;l=v[22452];v[22452]=0;if((l|0)==1){break g}if(!j){break h}j=w[g|0]|w[g+1|0]<<8;v[22452]=0;U(173,e|0,b|0,j|0);j=v[22452];v[22452]=0;if((j|0)!=1){v[22452]=0;R(174,i|0,e|0);j=v[22452];v[22452]=0;if((j|0)==1){break i}c=c+1|0;pb(e);continue}break}c=P()|0;O()|0;break f}c=P()|0;O()|0;pb(e);break f}ab=e+16|0;break e}c=P()|0;O()|0;break f}c=P()|0;O()|0}Uc(i);S(c|0);L()}v[22452]=0;W(167,d+88|0,b|0,h|0,k|0);c=v[22452];v[22452]=0;j:{if((c|0)!=1){c=w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24);v[22452]=0;Q(146,b|0,c|0)|0;c=v[22452];v[22452]=0;k:{if((c|0)!=1){g=d+36|0;i=0;l:{m:{n:{o:{while(1){p:{q:{if((w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))>>>0>i>>>0){v[22452]=0;c=Q(147,b|0,8)|0;f=v[22452];v[22452]=0;if((f|0)==1){break q}if(c){break p}}i=jc(v[a>>2],v[a+4>>2])^1;ec(d+88|0);Uc(d+104|0);break a}b=P()|0;O()|0;break k}v[22452]=0;ga(168,d- -64|0,b|0,d+120|0,d+88|0,d+104|0);c=v[22452];v[22452]=0;if((c|0)!=1){c=d- -64|0;e=so(c);v[22452]=0;f=T(169,c|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break o}if(f){v[22452]=0;f=T(170,d+24|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break n}e=v[e>>2];r:{if((e|0)<0){break r}h=v[d+104>>2];if(ad(h,v[d+108>>2])>>>0<=e>>>0){break r}v[22452]=0;U(11,d+8|0,2,ld(h,e)|0);e=v[22452];v[22452]=0;if((e|0)==1){break m}e=d+8|0;tb(d+24|0,e);pb(e)}Uu(g,c);v[22452]=0;R(171,a|0,f|0);c=v[22452];v[22452]=0;if((c|0)==1){break m}Fq(f)}i=i+1|0;qb(d- -64|0);continue}break}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;Fq(f)}qb(d- -64|0);break k}b=P()|0;O()|0}ec(d+88|0);break j}b=P()|0;O()|0}Uc(d+104|0);S(b|0);L()}ab=d+160|0;return i|0}function aE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=ab-144|0;ab=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((c|0)<=5){nv(a+96|0,c);v[22452]=0;c=Q(1,a+80|0,17713)|0;d=v[22452];v[22452]=0;if((d|0)==1){break E}v[22452]=0;U(2,a+112|0,a+96|0,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break D}v[22452]=0;d=Q(3,a+48|0,e|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break C}v[22452]=0;e=Q(1,a+32|0,19541)|0;f=v[22452];v[22452]=0;if((f|0)==1){break B}v[22452]=0;U(4,a- -64|0,d|0,e|0);f=v[22452];v[22452]=0;if((f|0)==1){break A}v[22452]=0;U(2,a+128|0,a+112|0,a- -64|0);f=v[22452];v[22452]=0;if((f|0)==1){break z}pb(a- -64|0);pb(e);pb(d);d=a+112|0;pb(d);pb(c);pb(a+96|0);c=v[b>>2];v[22452]=0;U(5,d|0,1,(c?c:21598)|0);c=v[22452];v[22452]=0;if((c|0)==1){break t}c=v[b+4>>2];v[22452]=0;U(5,a+96|0,1,(c?c:21598)|0);c=v[22452];v[22452]=0;if((c|0)==1){break s}b=v[b+8>>2];v[22452]=0;v[a+64>>2]=b;R(6,a+80|0,a- -64|0);b=v[22452];v[22452]=0;if((b|0)==1){break r}v[22452]=0;Z(7,17592);b=v[22452];v[22452]=0;if((b|0)==1){break q}v[22452]=0;U(8,a- -64|0,0,a+112|0);b=v[22452];v[22452]=0;if((b|0)==1){break p}v[22452]=0;Z(9,a- -64|0);b=v[22452];v[22452]=0;if((b|0)==1){break o}v[22452]=0;Z(7,17386);b=v[22452];v[22452]=0;if((b|0)==1){break o}v[22452]=0;U(8,a+32|0,0,a+80|0);b=v[22452];v[22452]=0;if((b|0)==1){break n}v[22452]=0;Z(9,a+32|0);b=v[22452];v[22452]=0;if((b|0)==1){break m}v[22452]=0;Z(7,17384);b=v[22452];v[22452]=0;if((b|0)==1){break m}v[22452]=0;Z(7,17713);b=v[22452];v[22452]=0;if((b|0)==1){break m}v[22452]=0;U(8,a+16|0,0,a+128|0);b=v[22452];v[22452]=0;if((b|0)==1){break l}v[22452]=0;Z(9,a+16|0);b=v[22452];v[22452]=0;if((b|0)==1){break k}v[22452]=0;Z(7,13416);b=v[22452];v[22452]=0;if((b|0)==1){break k}v[22452]=0;U(8,a|0,0,a+96|0);b=v[22452];v[22452]=0;if((b|0)==1){break j}v[22452]=0;Z(9,a|0);b=v[22452];v[22452]=0;if((b|0)==1){break i}v[22452]=0;Z(7,13414);b=v[22452];v[22452]=0;if((b|0)==1){break i}v[22452]=0;X(10);b=v[22452];v[22452]=0;if((b|0)==1){break i}pb(a);pb(a+16|0);pb(a+32|0);pb(a- -64|0);pb(a+80|0);pb(a+96|0);pb(a+112|0);pb(a+128|0)}ab=a+144|0;return}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;break y}b=P()|0;O()|0;pb(a- -64|0)}pb(e)}pb(d)}pb(a+112|0)}pb(c)}pb(a+96|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;pb(a)}pb(a+16|0)}pb(a+32|0)}pb(a- -64|0)}pb(a+80|0)}pb(a+96|0)}pb(a+112|0)}pb(a+128|0)}S(b|0);L()}function dda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,B=0,C=0;f=ab-4144|0;ab=f;a:{h=a+14|0;h=Ab(w[h|0]|w[h+1|0]<<8);b:{if(!h|h>>>0>20){break b}k=b+480190|0;h=a;if(x[k>>1]<=w[a+23|0]){break b}ed(d,32);u[d+34>>1]=1;a=f+24|0;j=h+20|0;v[a>>2]=j;v[a+4>>2]=(j+80|0)-j>>2;fP(f+4136|0,v[f+24>>2],v[f+28>>2],Ab(w[h+14|0]|w[h+15|0]<<8));j=v[f+4136>>2];g=w[Fb(j,0)+3|0];v[f+24>>2]=1;g=v[Pc(Tj(b,g+1|0)+24|0,a)>>2];i=a;a=v[f+4140>>2];fP(i,j,a,c?a:1);q=1/+(g>>>0);a=v[f+24>>2];j=Fb(a,v[f+28>>2]);g=v[f+4136>>2];k=x[k>>1];while(1){if((a|0)==(j|0)){c:{r=sg(d);if(!r){break c}k=(e<<12>>>0)/1e4|0;e=v[f+4140>>2];a=f+4120|0;j=sd(a);d:{if(!e){break d}v[22452]=0;R(694,a|0,e|0);g=v[22452];v[22452]=0;if((g|0)!=1){v[22452]=0;WO(a,e);e=v[22452];v[22452]=0;if((e|0)!=1){break d}}break a}j=a;s=v[a>>2];n=v[f+4136>>2];z=v[f+4140>>2];A=b+480190|0;a=0;i=0;while(1){if((a|0)==(z|0)){k=b+24648|0}else{g=Fb(n,a);e=eP(s,a);l=w[g+3|0];e:{if(l>>>0>=x[A>>1]){break e}o=t[g+1|0];if((o|0)<0){break e}m=0;g=w[g+2|0];if((g+14&255)>>>0<=5){m=t[g+26798|0]}g=Tj(b,l+1|0);l=v[g+24>>2];p=q*(Ej(+(m<<24>>24)/96+ +(o-t[Fb(n,0)+1|0]|0)/12)*+(l>>>0));if(p<=0){break e}m=dP(p);v[e+8>>2]=m;l=db;v[e+12>>2]=l;v[e+16>>2]=v[g+20>>2];o=v[g>>2];v[e+76>>2]=o;v[e+88>>2]=x[g+34>>1]&1023;f:{if(c){v[e+664>>2]=i;i=xe(+(o>>>0)/tz(m,l))+i|0;g=k;break f}g=(k>>>0)/(Ab(w[h+14|0]|w[h+15|0]<<8)>>>0)|0}v[e+20>>2]=g;v[e+24>>2]=g}a=a+1|0;continue}break}b=0;while(1){g:{a=v[d>>2];if(a>>>0>b>>>0){Jb(f+24|0,0,4096);v[f+16>>2]=512;v[f+12>>2]=a-b;c=v[zb(f+16|0,f+12|0)>>2];B=f,C=wb(v[j>>2]),v[B+16>>2]=C;g=wb(v[j+4>>2]);while(1){a=v[f+16>>2];if(!Tb(a,g)){break g}h:{i:{if(!v[a+16>>2]){break i}e=v[a+664>>2];if(e>>>0>=c>>>0){v[a+664>>2]=e-c;break i}h=v[a+88>>2];v[f+12>>2]=c-e;B=f,C=xe((+y[a+76>>2]-tz(v[a>>2],v[a+4>>2]))/tz(v[a+8>>2],v[a+12>>2])),v[B+8>>2]=C;i=v[zb(f+12|0,f+8|0)>>2];v[22452]=0;W(v[((h&1|(h&64?18:16))<<2)+27392>>2],a|0,k|0,(f+24|0)+(e<<3)|0,i|0);e=v[22452];v[22452]=0;if((e|0)==1){break h}v[a+664>>2]=0;if(y[a+76>>2]>y[a+4>>2]){break i}v[a+16>>2]=0}v[f+16>>2]=v[f+16>>2]+872;continue}break}break a}Cp(j);break c}e=v[d+20>>2]+(b<<1)|0;i=f+24|0;a=ab-16|0;ab=a;v[a+12>>2]=c;mc(a+12|0,512);g=v[a+12>>2];while(1){if(g){h=Wc(v[i>>2]+2048|0,12);h=(h|0)<32767?h:32767;u[e>>1]=(h|0)>-32768?h:-32768;i=i+8|0;e=e+2|0;g=g-1|0;continue}break}ab=a+16|0;b=b+c|0;continue}}g=(r|0)!=0}else{i=w[a+3|0];j:{if(i>>>0>=k>>>0){break j}n=t[a+1|0];if((n|0)<0){break j}i=Tj(b,i+1|0);m=v[i>>2];p=Ej(+(n-t[Fb(g,0)+1|0]|0)/-12);B=d,C=v[d>>2]+xe(q*(p*+(m>>>0)*+y[i+24>>2]))|0,v[B>>2]=C}a=a+4|0;continue}break}}ab=f+4144|0;return g|0}a=P()|0;O()|0;Cp(j);S(a|0);L()}function nJ(a){var b=C(0),c=C(0),d=0,e=C(0),f=C(0),g=0,h=0,i=C(0),k=0,m=C(0),r=C(0),s=0,t=C(0),u=0,w=C(0),x=C(0);d=a+4208|0;KM(d,z[a+4272>>2]);b=C(C(z[d>>2]*C(15920))+C(80));t=fe(C(10),C(C(C(z[a+4216>>2]+C(-.5))*C(30))/C(40)));c=C(C(b/C(y[v[a+16>>2]+24620>>2]))*C(6.2831854820251465));b=FJ(c);w=Po(c);x=b;f=C(C(c*C(C(C(z[a+4212>>2]*C(35))+C(1))*C(.02888113260269165)))/b);m=(l(2,(p(f),j(2))&-2147483648|1056964608),q());g=(p(f),j(2))&2147483647;c=(l(2,g),q());a:{if(g>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(p(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((h|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(1.7014118346046923e38));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=C(b-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=C(c*C(.5));i=C(c*b);r=C(C(i*C(C(i*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));b=C(C(3)-C(r*b));r=C(i*C(C(r-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*r)-i));if(!d){break b}e=C(C(C(c*C(r-e))-e)-i);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}b=C(c-e);b=C(C(b+b)+C(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(1.7014118346046923e38)):C(c*b))+C(-1));break b}i=(l(2,1065353216-h|0),q());c=C((d>>>0<=22?C(C(C(1)-i)+C(c-e)):C(C(c-C(e+i))+C(1)))*b)}b=c}if(g>>>0<=1065353215){if(g>>>0<964689920){break a}f=C(m*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}f=C(m*C(b+C(b/C(b+C(1)))));break a}m=C(C(m+m)*C(1.661534994731145e35));b=C(c+C(-162.88958740234375));d=rw(b)&2047;j:{k:{if(rw(C(88))>>>0>d>>>0){break k}c=C(0);if(((p(b),j(2))|0)==-8388608){break j}c=C(b+b);if(rw(C(N))>>>0<=d>>>0){break j}if(b>C(88.72283172607422)){c=JD(0);break j}if(!(b<C(-103.97207641601562))){break k}c=eD(0);break j}k=A[165]*+b;s=A[164];u=k+s;k=k-(u-s);s=(A[166]*k+A[167])*(k*k)+(A[168]*k+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;g=v[d>>2];d=v[d+4>>2]+h|0;l(0,g|0);l(1,(g>>>0<g>>>0?d+1|0:d)|0);c=C(s*+n())}f=C(C(m*c)*C(1.661534994731145e35))}c=C(x*f);f=C(c/t);b=C(f+C(1));z[a+4236>>2]=C(C(1)-f)/b;f=C(C(w*C(-2))/b);z[a+4232>>2]=f;c=C(c*t);z[a+4228>>2]=C(C(1)-c)/b;z[a+4224>>2]=f;z[a+4220>>2]=C(c+C(1))/b}function S0(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=ab-192|0;ab=d;v[d+184>>2]=c;a:{b:{c:{if(b>=.8){v[22452]=0;c=ha(1054)|0;e=v[22452];v[22452]=0;d:{e:{f:{if((e|0)!=1){v[d+80>>2]=c;c=v[d+184>>2];v[22452]=0;c=T(1055,c|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break e}v[d+176>>2]=c;dn(v[d+80>>2],v[d+176>>2]);c=v[d+80>>2];a=_d(d+152|0,a);v[22452]=0;g=v[a+12>>2];e=d- -64|0;v[e>>2]=v[a+8>>2];v[e+4>>2]=g;v[d+72>>2]=v[a+16>>2];e=v[a+4>>2];v[d+56>>2]=v[a>>2];v[d+60>>2]=e;a=Y(1047,c|0,d+56|0,15)|0;c=v[22452];v[22452]=0;if((c|0)==1){break f}if(a){a=v[d+80>>2];v[22452]=0;Z(789,a|0);a=v[22452];v[22452]=0;f=1;if((a|0)==1){break f}}Yh(d+176|0);Zh(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;Yh(d+176|0);break d}c=V(0)|0;O()|0}Zh(d+80|0);break c}if(b>=.6){v[22452]=0;c=ha(1054)|0;e=v[22452];v[22452]=0;g:{h:{i:{if((e|0)!=1){v[d+80>>2]=c;c=v[d+184>>2];v[22452]=0;c=T(1055,c|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break h}v[d+176>>2]=c;dn(v[d+80>>2],v[d+176>>2]);c=v[d+80>>2];a=_d(d+128|0,a);v[22452]=0;e=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=e;v[d+48>>2]=v[a+16>>2];e=v[a+4>>2];v[d+32>>2]=v[a>>2];v[d+36>>2]=e;a=Y(1047,c|0,d+32|0,2)|0;c=v[22452];v[22452]=0;if((c|0)==1){break i}if(a){a=v[d+80>>2];v[22452]=0;Z(789,a|0);a=v[22452];v[22452]=0;f=.8;if((a|0)==1){break i}}Yh(d+176|0);Zh(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;Yh(d+176|0);break g}c=V(0)|0;O()|0}Zh(d+80|0);break c}f=.2;if(b>=.2){v[22452]=0;c=ha(1054)|0;e=v[22452];v[22452]=0;j:{k:{l:{if((e|0)!=1){v[d+80>>2]=c;c=v[d+184>>2];v[22452]=0;c=T(1055,c|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break k}v[d+176>>2]=c;dn(v[d+80>>2],v[d+176>>2]);c=v[d+80>>2];a=_d(d+104|0,a);v[22452]=0;e=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=e;v[d+24>>2]=v[a+16>>2];e=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=e;a=Y(1047,c|0,d+8|0,0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break l}f=0;if(a){a=v[d+80>>2];v[22452]=0;Z(789,a|0);a=v[22452];v[22452]=0;f=.6;if((a|0)==1){break l}}Yh(d+176|0);Zh(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;Yh(d+176|0);break j}c=V(0)|0;O()|0}Zh(d+80|0);break c}if(!(b>=.1)){break b}v[22452]=0;U(194,d+80|0,a|0,2048);c=v[22452];v[22452]=0;if((c|0)!=1){c=Sd(d+80|0);v[22452]=0;e=v[d+80>>2];a=T(151,a|0)|0;g=v[22452];v[22452]=0;m:{if((g|0)==1){break m}v[22452]=0;a=Ha(1056,c|0,e|0,a|0,0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break m}f=A[(a<<3)+58488>>3];rc(d+80|0);break b}c=V(0)|0;O()|0;rc(d+80|0);break c}c=V(0)|0;O()|0}_(c|0)|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;f=0;if((a|0)==1){break a}}oe(d+184|0);ab=d+192|0;return+f}a=P()|0;O()|0;oe(d+184|0);S(a|0);L()}function iE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=ab-48|0;ab=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e;k=e&2147483647;c:{if(k>>>0<=1074752122){if((h&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+-6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6.077100506506192e-11;p=c-g;e=p<-.7853981633974483;if(D(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6.077100506506192e-11;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6.077100506506192e-11;c=a+f*-1.5707963267341256}a=c-g;A[b>>3]=a;o(+a);h=j(1)|0;j(0)|0;e=k>>>20|0;e:{if((e-(h>>>20&2047)|0)<17){break e}g=c;a=f*6.077100506303966e-11;c=c-a;g=f*2.0222662487959506e-21-(g-c-a);a=c-g;A[b>>3]=a;h=e;o(+a);e=j(1)|0;j(0)|0;if((h-(e>>>20&2047)|0)<50){break e}g=c;a=f*2.0222662487111665e-21;c=c-a;g=f*8.4784276603689e-32-(g-c-a);a=c-g;A[b>>3]=a}A[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;h=1;while(1){m=(i+16|0)+(d<<3)|0;if(D(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);A[m>>3]=c;a=(a-c)*16777216;d=1;m=h&1;h=0;if(m){continue}break}A[i+32>>3]=a;f:{if(a!=0){d=2;break f}h=1;while(1){d=h;h=d-1|0;if(A[(i+16|0)+(d<<3)>>3]==0){continue}break}}d=EG(i+16|0,i,(k>>>20|0)-1046|0,d+1|0,1);a=A[i>>3];if((e|0)<0){A[b>>3]=-a;A[b+8>>3]=-A[i+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[i+8>>3]}ab=i+48|0;return d}function Hv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ab-96|0;ab=e;a:{b:{if(i=1,j=Vc(a,11),k=v[a+4>>2],k?i:j){d=v[a+28>>2];b=v[a+12>>2];f=v[a+64>>2];c=f+v[a+8>>2]|0;b=Zg(e+80|0,c,c>>>0<f>>>0?b+1|0:b);c=v[b+12>>2];v[e+32>>2]=v[b+8>>2];v[e+36>>2]=c;c=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=c;yj(d,e+24|0);b=v[a+28>>2];if(Fj(v[v[b>>2]-12>>2]+b|0)){$g(a,1073741826);break a}c=v[a+92>>2];b=a+44|0;f=v[b>>2];d=Cg(f,v[b+4>>2]);c:{if(c>>>0>d>>>0){g=ab-32|0;ab=g;c=c-d|0;d=v[vb(b)>>2];f=v[b+4>>2];d:{if(c>>>0<=d-f>>4>>>0){d=ab-16|0;ab=d;c=xo(d,b,c);b=v[c+4>>2];f=v[c+8>>2];while(1){if((b|0)==(f|0)){dc(c);ab=d+16|0}else{sE(b);b=b+16|0;v[c+4>>2]=b;continue}break}break d}d=vb(b);d=yv(g+8|0,Av(b,Cg(v[b>>2],f)+c|0),Cg(v[b>>2],v[b+4>>2]),d);h=ab-16|0;ab=h;c=nE(h,d+8|0,c);f=v[c>>2];while(1){if(v[c+4>>2]!=(f|0)){sE(f);f=v[c>>2]+16|0;v[c>>2]=f;continue}break}xd(c);ab=h+16|0;rd(b,d);yE(d)}ab=g+32|0;break c}if(c>>>0<d>>>0){Hd(b,f+(c<<4)|0)}}g=a+32|0;Wm(g,v[a+92>>2]<<2);b=0;e:{while(1){if(y[a+92>>2]<=b>>>0){break e}d=v[a+28>>2];if(Fj(v[v[d>>2]-12>>2]+d|0)){$g(a,1073741828);break a}c=x[a+16>>1];u[e+78>>1]=c;if((c|0)==65535){Iv(d,e+78|0);c=x[e+78>>1]}d=Ic(v[a+32>>2],v[a+36>>2]);f=c&65535;f:{if(!f){c=0;break f}if(f>>>0>(d^-1)>>>0){break f}Ei(g,d+f|0);Ck(v[a+28>>2],Cb(v[a+32>>2],d),f)}f=Hc(v[a+44>>2],b);v[f>>2]=d;u[f+12>>1]=c;if(Vc(a,6)){qk(v[a+28>>2],e+56|0);c=v[e+56>>2];if(v[e+60>>2]<0){break b}i=Hc(v[a+44>>2],b),j=c,v[i+4>>2]=j}g:{d=v[a+4>>2];h:{if(d){c=Hc(v[a+44>>2],b);v[c+8>>2]=d;break h}if(!Vc(a,7)){c=Hc(v[a+44>>2],b);break h}qk(v[a+28>>2],e+56|0);d=v[e+56>>2];if(v[e+60>>2]<0){break g}c=Hc(v[a+44>>2],b);v[c+8>>2]=d}i:{if(v[c+8>>2]==-1){break i}if(Vc(a,6)){break i}j:{if(!b){c=0;d=Hc(v[a+44>>2],0);break j}d=v[a+44>>2];c=Hc(d,b-1|0);c=v[c+8>>2]+v[c+4>>2]|0;d=Hc(d,b)}v[d+4>>2]=c}if(Vc(a,8)){u[e+56>>1]=0;Iv(v[a+28>>2],e+56|0);c=Vc(a,9);Cl(v[a+28>>2],x[e+56>>1]<<c)}b=b+1|0;continue}break}$g(a,1073741829);break a}Xd(e+56|0,v[a+28>>2]);b=v[e+68>>2];v[a+72>>2]=v[e+64>>2];v[a+76>>2]=b}tk(a,4,1);b=v[a+88>>2];k:{if((b|0)==v[a+64>>2]){b=v[a+76>>2];c=v[a+72>>2];break k}c=b;d=b+v[a+8>>2]|0;b=v[a+12>>2];b=c>>>0>d>>>0?b+1|0:b;c=d}v[a+80>>2]=c;v[a+84>>2]=b;d=v[a+28>>2];b=Zg(e+40|0,c,b);c=v[b+12>>2];v[e+16>>2]=v[b+8>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;yj(d,e+8|0);if(Vc(a,6)){break a}if(!(i=1,j=Vc(a,7),k=v[a+4>>2],k?i:j)){break a}b=v[a+80>>2];c=v[a+8>>2];c=b-c|0;d=v[a+92>>2];b=0;while(1){if((b|0)==(d|0)){break a}f=Hc(v[a+44>>2],b);v[f+4>>2]=c+v[f+4>>2];b=b+1|0;continue}}$g(a,1073741829)}ab=e+96|0}function i9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+8>>2]=43728;v[a+4>>2]=0;v[a>>2]=32160;b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;yp(a+24604|0);DL(a+24648|0,0);v[a+397448>>2]=0;v[a+397452>>2]=0;b=a+397456|0;v[b>>2]=8;v[b+4>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;t[b+12|0]=0;v[b+8>>2]=0;u[b+24>>1]=0;Jb(b+28|0,0,40);Jb(b+68|0,0,49824);Jb(b+49892|0,0,32832);t[a+480224|0]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;k=Ye(a+480248|0);v[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;sC(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=a+484344|0;Pb(f);v[f+12>>2]=a;v[22452]=0;h=a+484360|0;Q(784,h|0,a|0)|0;b=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){c=a+900380|0;b=a+484380|0;while(1){v[22452]=0;b=T(649,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break i}b=b+104|0;if((c|0)!=(b|0)){continue}break}v[22452]=0;T(785,a+901404|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break h}c=a+946300|0;d=a+906300|0;b=d;while(1){b=CL(b)+160|0;if((c|0)!=(b|0)){continue}break}v[a+946300>>2]=0;g=a+1074304|0;e=a+946304|0;b=e;while(1){b=Xs(b)+32|0;if((g|0)!=(b|0)){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;by(a+1074312|0);v[22452]=0;X(786);b=v[22452];v[22452]=0;if((b|0)==1){break g}r=a,s=yL(),v[r+1074328>>2]=s;b=a+1074332|0;v[b+12>>2]=1065353216;oL(b,4);v[22452]=0;g=T(787,a+1074376|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break g}v[22452]=0;i=a+1298264|0;Y(547,i|0,a|0,255)|0;b=v[22452];v[22452]=0;if((b|0)==1){break f}l=of(a+1298300|0);m=of(a+1298304|0);n=Bb(a+1298308|0);o=Bb(a+1298320|0);j=a+1298332|0;Bb(j);p=BL(a+1298344|0);q=Pb(a+1298408|0);t[a+1298420|0]=0;b=a+1298424|0;v[b>>2]=0;v[b+4>>2]=0;v[b+32>>2]=0;v[b+36>>2]=1072693248;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[a+1298464>>2]=0;dp(a+12|0);ay(a+8204|0);ay(a+12300|0);b=a+1074408|0;v[b>>2]=4;v[b+4>>2]=16;v[a+480216>>2]=4;v[a+480220>>2]=16;Jb(a+900380|0,0,1024);xL(e);v[22452]=0;b=T(788,12)|0;e=v[22452];v[22452]=0;if((e|0)==1){break e}v[b>>2]=0;v[b+4>>2]=0;v[b+8>>2]=0;Ye(b);v[a+4>>2]=b;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;$x(q);zs(p);pb(j);pb(o);pb(n);ys(m);xs(l);ip(i)}Es(g)}while(1){c=ep(c-160|0);if((d|0)!=(c|0)){continue}break}}ZN(h)}_x(f);ec(k);S(b|0);L()}function Vl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=ab-80|0;ab=c;h=Pb(a);v[22452]=0;a=T(273,b|0)|0;d=v[22452];v[22452]=0;a:{b:{c:{d:{e:{if((d|0)==1){break e}v[22452]=0;d=Q(147,b|0,a|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break e}if(d){break d}v[22452]=0;a=T(193,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break e}v[22452]=0;Q(179,b|0,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break c}}a=P()|0;O()|0;break a}v[22452]=0;U(181,c+32|0,b|0,a|0);b=v[22452];v[22452]=0;f:{g:{h:{if((b|0)!=1){b=c+32|0;d=bc(c+56|0,b);qb(b);if(a>>>0<10){break g}v[22452]=0;b=T(676,d|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break b}if(!b){break g}v[22452]=0;b=T(273,d|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break b}v[c+28>>2]=b;a=a-10|0;mc(c+28|0,a>>>0>25264513?-1:B(a,170));v[22452]=0;e=v[c+28>>2];R(279,h|0,e|0);a=v[22452];v[22452]=0;if((a|0)!=1){break h}break b}a=P()|0;O()|0;break a}b=0;i:while(1){g=0;j:{k:{while(1){if(g){break j}v[22452]=0;a=T(677,d|0)|0;g=v[22452];v[22452]=0;l:{m:{n:{o:{if((g|0)!=1){if(a){break j}v[22452]=0;a=T(481,d|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break b}g=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}v[22452]=0;a=T(197,d|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break b}if(a>>>0>e>>>0){continue}v[22452]=0;f=Q(147,d|0,a|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}if(!f){continue}de(c+32|0,v[h>>2],v[h+4>>2]);Xp(c+16|0,v[c+32>>2],v[c+36>>2],b,a);v[22452]=0;W(418,c+8|0,d|0,v[c+16>>2],v[c+20>>2]);g=v[22452];v[22452]=0;if((g|0)!=1){e=e-a|0;b=a+b|0;continue i}break b}v[22452]=0;a=T(197,d|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break b}f=a<<2;if(f>>>0>e>>>0){continue}v[22452]=0;i=Q(678,d|0,c+24|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}g=c+24|0;i=ac(g);k=c,l=wb(v[h>>2]),v[k+32>>2]=l;it(g,i,le(c+32|0,b));b=b+4|0;a=a-1|0;continue}}if(e>>>0<8){continue}v[22452]=0;a=Q(678,d|0,c+24|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break b}if(!a){continue}a=c+24|0;g=ac(a);k=c,l=wb(v[h>>2]),v[k+32>>2]=l;f=c+32|0;it(a,g,le(f,b));k=c,l=wb(v[h>>2]),v[k+8>>2]=l;k=c,l=le(c+8|0,b),v[k+32>>2]=l;it(a,g,le(f,4));e=e-8|0;b=b+8|0;continue i}v[22452]=0;a=T(197,d|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break b}if(a>>>0>e>>>0){continue}break}e=e-a|0;b=a+b|0;continue}e=e-f|0;continue}break}if(!e){break f}a=Pb(c+32|0);gt(a,h);Xb(a);break f}v[22452]=0;U(322,d|0,h|0,a|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}}qb(d)}ab=c+80|0;return}a=P()|0;O()|0;qb(d)}Xb(h);S(a|0);L()}function TI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=ab-128|0;ab=f;v[f+120>>2]=c;v[f+124>>2]=d;g=v[b+4>>2];a:{if(!g){break a}h=v[b>>2];i=w[Gk(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}Pk(f+96|0,h,g,g-1|0);g=v[f+100>>2];v[b>>2]=v[f+96>>2];v[b+4>>2]=g}g=f+96|0;Dd(g);h=v[f+96>>2];Dd(f+80|0);i=Fk(h,v[f+84>>2],b);Dd(g);g=v[b+4>>2];h=v[b>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==v[f+100>>2]){a=kc(f+112|0,21598);if(yc(h,g,v[a>>2],v[a+4>>2])){a=aa(8)|0;v[22452]=0;R(934,f+80|0,f+120|0);b=v[22452];v[22452]=0;if((b|0)==1){break g}v[22452]=0;U(939,f+96|0,17577,f+80|0);b=v[22452];v[22452]=0;if((b|0)==1){break f}lc(a,f+96|0);e=0;v[22452]=0;U(110,a|0,58760,928);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;pb(f+96|0);break e}if(!e){break h}a=aa(8)|0;v[22452]=0;c=Q(938,f+48|0,b|0)|0;b=v[22452];v[22452]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){v[22452]=0;U(939,f- -64|0,17613,c|0);b=v[22452];v[22452]=0;if((b|0)==1){break p}v[22452]=0;R(941,f+80|0,f- -64|0);b=v[22452];v[22452]=0;e=1;if((b|0)==1){break o}v[22452]=0;R(934,f+32|0,f+120|0);b=v[22452];v[22452]=0;if((b|0)==1){break n}v[22452]=0;U(943,f+96|0,f+80|0,f+32|0);b=v[22452];v[22452]=0;if((b|0)==1){break m}lc(a,f+96|0);v[22452]=0;U(110,a|0,58760,928);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;pb(f+96|0);e=0;break l}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0}pb(f+32|0)}pb(f+80|0)}pb(f- -64|0)}pb(c);if(e){break d}break c}e=kc(f+24|0,21598);if(yc(h,g,v[e>>2],v[e+4>>2])){a=aa(8)|0;v[22452]=0;R(934,f+80|0,f+120|0);b=v[22452];v[22452]=0;q:{r:{if((b|0)!=1){v[22452]=0;U(939,f+96|0,17577,f+80|0);b=v[22452];v[22452]=0;if((b|0)==1){break r}lc(a,f+96|0);e=0;v[22452]=0;U(110,a|0,58760,928);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;pb(f+96|0);break q}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0}pb(f+80|0);if(e){break d}break c}g=v[b>>2];h=v[b+4>>2];e=kc(f+16|0,10881);if(yc(g,h,v[e>>2],v[e+4>>2])){LI(a,vc(c,d));break h}e=v[b>>2];g=v[b+4>>2];b=kc(f+8|0,8598);if(!yc(e,g,v[b>>2],v[b+4>>2])){break h}b=Dy(c,d);c=ab-16|0;ab=c;a=v[a+32>>2];b=b>>>0<4?b:1;s:{if((Qw(a)|0)==(b|0)){d=a+120|0;Xh(d);b=ab-16|0;ab=b;v[b+8>>2]=c+8;a=ab-16|0;ab=a;e=v[14618];v[a+8>>2]=v[14617];v[a+12>>2]=e;e=v[14616];v[a>>2]=v[14615];v[a+4>>2]=e;eb[v[yh(a,Ig(w[d+20|0]))>>2]](b+8|0,d);ab=a+16|0;ab=b+16|0;break s}wI(a,b,xI(a))}ab=c+16|0}ab=f+128|0;return}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0}pb(f+80|0);if(!e){break c}}ba(a|0)}S(b|0)}L()}function u9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;j=ab-32|0;ab=j;r=a+4|0;s=v[r>>2];i=He(v[a+8>>2],b);y=v[i>>2];a:{if(y+1>>>0<2){break a}e=B(b,872)+s|0;if(!(I=1,J=gi(v[e+624>>2],v[e+628>>2]),K=w[i+4|0],K?I:J)){break a}g=B(b,872)+s|0;if(!v[g+720>>2]){break a}i=e+616|0;h=v[g+704>>2]&2;e=v[(h?g+700|0:g+692|0)>>2];n=v[g+700>>2];f=v[g+696>>2];rb(j+8|0,v[a>>2]+1074312|0,31);z=sb(v[v[j+8>>2]>>2],v[j+12>>2]);m=Tu(v[g+624>>2],v[g+628>>2],c);p=m;l=w[g+704|0]&128;m=l?0-m|0:m;k=db;l=l?0-(k+((p|0)!=0)|0)|0:k;k=0;E=k;p=e;A=h?k:0;e=f;q=h?e:0;k=n-e|0;F=k<<1;G=g+1316|0;o=g+1467|0;D=g+1362|0;H=(w[D|0]&17)!=1;b:{while(1){if((u|0)==(y|0)){break b}c:{if(d>>>0>u>>>0){f=(w[D|0]&17)==1;break c}t[o|0]=w[o|0]&254;h=v[a>>2];e=Qc(Rb(h+484344|0,x[v[r>>2]+70>>1]),v[v[r>>2]+48>>2],b);n=w[e+3|0];if(w[e+2|0]==11){f=j+8|0;vy(f,h,e,0);h=Me(f);rn(v[a>>2],i,x[f>>1]);f=1;if(w[h|0]){break c}}f=1;d:{switch(n-4|0){case 0:rn(v[a>>2],i,w[e+5|0]);break c;case 2:break d;default:break c}}rn(v[a>>2],i,0)}v[j+28>>2]=v[G>>2];if(z){Fs(v[a>>2],i)}if(!H){iM(v[a>>2],i,j+28|0);f=1}if(!z){Fs(v[a>>2],i)}v[j+24>>2]=0;hM(i,j+24|0);e:{f:{if(w[g+705|0]&2){break f}g:{if(!f){if(!w[He(v[a+8>>2],b)+4|0]){break g}}if(w[o|0]&96){oO(i,C(1),0,v[a>>2]);e=w[o|0];t[o|0]=(e&64?-65:-33)&e}xy(j+8|0,v[a>>2],i,v[j+28>>2],0);e=v[j+12>>2];v[g+624>>2]=v[j+8>>2];v[g+628>>2]=e;I=He(v[a+8>>2],b),J=0,t[I+4|0]=J;e=Tu(v[g+624>>2],v[g+628>>2],c);f=w[g+704|0]&128;m=f?0-e|0:e;h=db;l=f?0-(h+((e|0)!=0)|0)|0:h}Lb(i,m,l);n=v[i>>2];e=v[i+4>>2];if((n>>>0<E>>>0&(e|0)<=(p|0)|(e|0)<(p|0))&((e|0)>=(q|0)&n>>>0>=A>>>0|(e|0)>(q|0)|((l|0)>0|(l|0)>=0))){break f}h=v[g+704>>2];if(!(h&2)){break e}if(h&4){f=v[g+696>>2];if(n>>>0<A>>>0&(e|0)<=(q|0)|(e|0)<(q|0)){I=i,J=yg(0,f<<1,n,e),v[I>>2]=J;e=db;v[i+4>>2]=e;v[g+704>>2]=h^128;h=m;m=0-h|0;l=0-(((h|0)!=0)+l|0)|0}rb(j+8|0,v[a>>2]+1074312|0,33);e=(e-f>>>0)%(F-sb(v[v[j+8>>2]>>2],v[j+12>>2])>>>0)|0;h:{if(e>>>0<k>>>0){f=e+v[g+696>>2]|0;break h}f=v[g+700>>2]+(k-e|0)|0}v[i+4>>2]=f;f=v[g+704>>2];if((f&128)>>>7^e>>>0<k>>>0){break f}v[g+704>>2]=f^128;e=m;m=0-e|0;l=0-(((e|0)!=0)+l|0)|0;break f}f=e;h=v[g+700>>2];if(e>>>0>=h+k>>>0){f=h+((f-h>>>0)%(k>>>0)|0)|0}while(1){e=f;f=e-k|0;if(e>>>0>=h>>>0){continue}break}v[i>>2]=n;v[i+4>>2]=e}u=u+1|0;continue}break}qO(i);v[(B(b,872)+s|0)+1324>>2]=0}I=He(v[a+8>>2],b),J=0,v[I>>2]=J}ab=j+32|0}function vca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=ab+-64|0;ab=d;u[d+62>>1]=c;lg(d+62|0,32);j=Pb(a);v[22452]=0;o=x[d+62>>1];R(485,j|0,o|0);a=v[22452];v[22452]=0;a:{b:{if((a|0)!=1){k=b+480190|0;p=b+480192|0;c:{d:{while(1){if((q&65535)>>>0>=o>>>0){break d}a=x[k>>1];e=a+1|0;u[d+60>>1]=e;e:{f:{g:{if((e&65535)>>>0<4e3){break g}c=1;h:{while(1){u[d+48>>1]=c;f=c&65535;if(f>>>0>(a&65535)>>>0){break h}i:{if(!Fd(Tj(b,f))){if(!Tb(Hz(wb(v[j>>2]),wb(v[j+4>>2]),d+48|0),wb(v[j+4>>2]))){break i}a=x[k>>1]}c=c+1|0;continue}break}u[d+60>>1]=c;e=1;while(1){a=e&65535;if(a>>>0>x[p>>1]){e=c;break h}j:{a=v[((a<<2)+b|0)+900380>>2];if(!a){break j}a=a+236|0;i=$s(a);while(1){if((a|0)==(i|0)){break j}if((f|0)==x[a>>1]){u[a>>1]=0}a=a+2|0;continue}}e=e+1|0;continue}}if((e&65535)>>>0<4e3){break g}i=Fn(d+48|0);v[22452]=0;a=Q(719,b|0,i|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break b}if(!a){break e}v[22452]=0;Q(720,b|0,i|0)|0;a=v[22452];v[22452]=0;c=1;if((a|0)==1){break b}while(1){a=c&65535;if(a>>>0<=x[p>>1]){k:{a=v[((a<<2)+b|0)+900380>>2];if(!a){break k}a=a+236|0;e=$s(a);while(1){if((a|0)==(e|0)){break k}f=x[a>>1];l:{if(f>>>0>=y[d+52>>2]){break l}rb(d+40|0,v[d+48>>2],f);if(sb(v[v[d+40>>2]>>2],v[d+44>>2])){break l}u[a>>1]=0}a=a+2|0;continue}}c=c+1|0;continue}break}Rj(d+24|0,v[d+48>>2]);GO(d+32|0,v[d+24>>2],v[d+28>>2],1);Yk(d+16|0,v[d+48>>2],v[d+52>>2]);m=ab-16|0;ab=m;f=d+40|0;c=Zb(m,v[d+32>>2],v[d+36>>2]);a=Xk(v[d+16>>2],v[d+20>>2],v[d+32>>2],v[d+36>>2]);e=ab-16|0;ab=e;v[e+12>>2]=a;g=v[c+4>>2];m:{if(g){h=32-g|0;v[e+8>>2]=h;n=v[zb(e+8|0,e+12|0)>>2];l=-1<<g&-1>>>h-n;h=v[c>>2];l=l&(v[h>>2]^-1);if(l){Zb(f,h,nia(l));break m}if((a|0)==(n|0)){GO(f,h,g,a);break m}a=a-n|0;v[e+12>>2]=a;v[c>>2]=h+4}while(1){if(a>>>0>=32){g=v[c>>2];h=v[g>>2];if((h|0)!=-1){Zb(f,g,nia(h^-1));break m}else{v[c>>2]=g+4;a=a-32|0;v[e+12>>2]=a;continue}}break}if(!a){Zb(f,v[c>>2],0);break m}c=v[c>>2];g=(v[c>>2]^-1)&-1>>>32-a;if(!g){Zb(f,c,a);break m}Zb(f,c,nia(g))}ab=e+16|0;ab=m+16|0;Rj(d+8|0,v[d+48>>2]);e=Xk(v[d+40>>2],v[d+44>>2],v[d+8>>2],v[d+12>>2]);u[d+60>>1]=e;Be(i);if((e&65535)>>>0>3999){break f}}v[22452]=0;R(251,j|0,d+60|0);a=v[22452];v[22452]=0;if((a|0)==1){break c}if(x[k>>1]>=(e&65535)>>>0){break f}u[k>>1]=e}q=q+1|0;continue}break}Be(i)}ab=d- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Be(i)}_c(j);S(a|0);L()}function Lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=ab-560|0;ab=f;a:{if(!Nc(b,1464)){break a}if(!Tn(b,f+556|0)){break a}vd(a,1);Db(Db(Cf(a+1074312|0,83),84,1),85,1);b:{if(ae(f+556|0,26889)){d=f+32|0;e=Mb(d,8417);tb(a+1298344|0,e);pb(e);e=Mb(d,14795);tb(a+1298356|0,e);pb(e);d=Mb(d,14860);tb(a+1298368|0,d);break b}if(!ae(f+556|0,15476)){break a}d=f+32|0;e=Mb(d,8575);tb(a+1298344|0,e);pb(e);e=Mb(d,12246);tb(a+1298356|0,e);pb(e);d=Mb(d,15383);tb(a+1298368|0,d)}pb(d);v[a+1298404>>2]=2;Nc(b,0);zA(b,a+1298308|0,20);u[a+480190>>1]=31;d=1;while(1){if((d|0)==32){c:{d=0;if(g>>>0>40){break a}k=f+552|0;Bu(k,b);n=Zc(k);if(w[k|0]>128){break a}d=f+32|0;e=ab-16|0;ab=e;d:{if(!Hb(b,512)){HQ(d);break d}eu(e+8|0,d);fd(e,b,v[e+8>>2],v[e+12>>2])}ab=e+16|0;e=f+544|0;i=w[n|0];e:{while(1){if((d|0)==(e|0)){break e}g=w[d|0];d=d+1|0;if(g>>>0<=i>>>0){continue}break}d=0;break a}if(!c){break c}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;lh(a,0);o=a+484360|0;mf(Kb(o),w[k|0]);l=a+484344|0;fg(l,w[k|0]);e=0;while(1){if(w[k|0]<=e>>>0){if(!(c&2)){break c}Nc(b,(w[n|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break c}c=(B(d,104)+a|0)+484380|0;if(v[c>>2]){eg(Gc(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}r=Yb(v[Kb(o)>>2],e),s=e,u[r>>1]=s;f:{if(!Vg(l,e&65535,64)){break f}m=e<<2;i=0;g:while(1){if((i|0)==4){r=f,s=vg(Rb(l,e)),v[r+24>>2]=s;i=0;while(1){if((i|0)==64){break f}d=0;h:{while(1){if((d&65535)>>>0>=4){i:{t[f+31|0]=p;t[f+30|0]=q;d=h&255;if(d){break i}h=0;break h}}else{g=v[f+24>>2];j:{if((w[g+3|0]&254)!=16){break j}t[g+3|0]=16;h=0;j=w[g+5|0];if(j>>>0<16){break j}h=j>>>4|0;t[g+5|0]=h;m=h;h=j&15;g=(m|0)==(h|0)|!h;q=g?q:m;p=g?p:h;h=!g}d=d+1|0;ui(f+24|0);continue}break}je(Rb(l,e),Ae(ve(f+8|0,16,w[(d+f|0)+29|0]),i));h=h+1|0;h=(h&255)==3?1:h}i=i+1|0;continue}}Nc(b,(w[f+32+(i+m)|0]<<8)+1468|0);g=0;d=Qc(Rb(l,e),0,i&65535);while(1)if((g|0)==64){i=i+1|0;continue g}else{_t(b,d);k:{l:{j=w[d+3|0];m:{if((j|0)!=14){if(!j){if(w[d+5|0]){break l}break m}if((j-5&255)>>>0<5){break m}break l}if(w[d+5|0]<=15){break l}}t[d+3|0]=0;break k}Mf(d)}d=d+24|0;g=g+1|0;continue}}}e=e+1|0;continue}}}else{g=Oz(b,f+32|0,(B(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+g|0;d=d+1|0;continue}break}d=1}ab=f+560|0;return d|0}function ufa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=ab-32|0;ab=e;a:{b:{if(!c){break b}s=e,u=ue(a),t[s+16|0]=u;Um(b,e+16|0);k=c-1|0;c=0;while(1){g=1;if(!k){break a}c:{d:{d=c<<1;c=d&254;if(!c){if(!We(a,e+16|0)){break b}f=1;d=w[e+16|0]<<1|1;c=d&255;if(d>>>0<=255){break d}break c}if((d&65535)>>>0<=255){break d}f=1;break c}if(!We(a,e+16|0)){break b}SS(b,e+16|0);k=k-1|0;continue}while(1){e:{f:{g:{d=c<<1&254;h:{if(d){c=(c&65535)>>>0>127}else{if(!We(a,e+16|0)){break h}c=w[e+16|0]<<1|1;d=c&255;c=c>>>0>255}f=Hp(f,1)+c|0;c=d<<1&254;if(c){break f}if(We(a,e+16|0)){break g}}c=0;break e}d=w[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break e}if(d>>>0>127){continue}}break}i:{if((f|0)<=2){h=0;f=f-2|0;break i}if(!We(a,e+16|0)){break b}d=Hp(f-3|0,8)|w[e+16|0];h=((d|0)>1279?2:1)+((d|0)>31999)|0;m=d^-1;f=0}d=c<<1&254;if(d){g=c>>>0>127}else{if(!We(a,e+16|0)){break b}c=w[e+16|0]<<1|1;d=c&255;g=c>>>0>255}i=Hp(f,1);c=d<<1&254;if(c){d=d>>>0>127}else{if(!We(a,e+16|0)){break b}d=w[e+16|0]<<1|1;c=d&255;d=d>>>0>255}f=1;d=Hp(g+i|0,1)+d|0;if(!d){while(1){j:{k:{l:{d=c<<1&254;m:{if(d){c=(c&65535)>>>0>127}else{if(!We(a,e+16|0)){break m}c=w[e+16|0]<<1|1;d=c&255;c=c>>>0>255}f=Hp(f,1)+c|0;c=d<<1&254;if(c){break k}if(We(a,e+16|0)){break l}}c=0;break j}d=w[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break j}if(d>>>0>127){continue}}break}d=f+2|0}f=d+h|0;g=0;if(f>>>0>k>>>0|(f|0)<=0|(m|0)>=0){break a}d=v[b+4>>2];g=0;if((0-Ic(v[b>>2],d)|0)>(m|0)){break a}$b(e+24|0,wb(d));t[e+16|0]=0;g=e+16|0;n=ab-32|0;ab=n;d=v[b>>2];h=TA(v[e+24>>2],wb(d))+d|0;d=v[vb(b)>>2];i=v[b+4>>2];n:{if(f>>>0<=d-i>>>0){d=f;j=i-h|0;if(d>>>0>j>>>0){tm(b,f-j|0,g);d=j;if(!d){break n}}o=ab-16|0;ab=o;r=i;q=v[b+4>>2];j=(q-(f+h|0)|0)+h|0;p=zk(o,b,i-j|0);l=v[p+4>>2];i=j;while(1){if(i>>>0>=r>>>0){dc(p);Wp(h,j,q);ab=o+16|0}else{Bj(l,w[i|0]);l=l+1|0;v[p+4>>2]=l;i=i+1|0;continue}break}if(h>>>0<=g>>>0){g=(y[b+4>>2]>g>>>0?f:0)+g|0}Lh(h,d,g);break n}d=vb(b);d=xl(n+8|0,ul(b,Ic(v[b>>2],i)+f|0),h-v[b>>2]|0,d);TR(d,f,g);h=TS(b,d,h);wl(d)}wb(h);ab=n+32|0;s=e,u=wb(v[b+4>>2]),v[s>>2]=u;s=e,u=Uz(e,f),v[s+8>>2]=u;s=e,u=le(e+8|0,m),v[s+16>>2]=u;s=e,u=wb(v[b+4>>2]),v[s>>2]=u;s=e,u=Uz(e,f),v[s+8>>2]=u;d=f;while(1){h=w[fR(e+16|0)|0];s=fR(e+8|0),u=h,t[s|0]=u;h=d>>>0>1;d=d-1|0;if(h){continue}break}k=k-f|0;continue}}g=0}ab=e+32|0;return g|0}function F4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=ab-112|0;ab=e;d=v[b+4>>2];a:{if(!d){break a}f=v[b>>2];g=w[Gk(f,d)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}Pk(e+88|0,f,d,d-1|0);d=v[e+92>>2];v[b>>2]=v[e+88>>2];v[b+4>>2]=d}f=e+88|0;Dd(f);d=v[e+88>>2];Dd(e+72|0);d=Fk(d,v[e+76>>2],b);Dd(f);b:{c:{d:{e:{if((d|0)==v[e+92>>2]){d=v[b>>2];f=v[b+4>>2];a=kc(e+104|0,21598);if(yc(d,f,v[a>>2],v[a+4>>2])){a=aa(8)|0;v[22452]=0;c=Q(55,e+88|0,10443)|0;b=v[22452];v[22452]=0;if((b|0)==1){break d}lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(c);break c}d=0;if(!c){break e}c=aa(8)|0;v[22452]=0;d=Q(938,e+72|0,b|0)|0;a=v[22452];v[22452]=0;f:{g:{h:{if((a|0)!=1){v[22452]=0;U(939,e+88|0,17613,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}lc(c,e+88|0);a=0;v[22452]=0;U(110,c|0,58760,928);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;pb(e+88|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}pb(d);if(!a){break c}}ba(c|0);break c}if(v[d+4>>2]){a=aa(8)|0;v[22452]=0;c=Q(55,e+88|0,11558)|0;b=v[22452];v[22452]=0;if((b|0)!=1){lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(c);break c}b=P()|0;O()|0;ba(a|0);break c}d=v[b>>2];f=v[b+4>>2];c=kc(e- -64|0,21598);if(yc(d,f,v[c>>2],v[c+4>>2])){a=aa(8)|0;v[22452]=0;c=Q(55,e+88|0,10443)|0;b=v[22452];v[22452]=0;if((b|0)!=1){lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(c);break c}b=P()|0;O()|0;ba(a|0);break c}i:{d=v[b>>2];f=v[b+4>>2];c=kc(e+56|0,7380);if(!yc(d,f,v[c>>2],v[c+4>>2])){d=v[b>>2];f=v[b+4>>2];c=kc(e+48|0,7362);if(!yc(d,f,v[c>>2],v[c+4>>2])){break i}}d=w[a+60|0]!=0;break e}j:{d=v[b>>2];f=v[b+4>>2];c=kc(e+40|0,6895);if(!yc(d,f,v[c>>2],v[c+4>>2])){d=v[b>>2];f=v[b+4>>2];c=kc(e+32|0,6876);if(!yc(d,f,v[c>>2],v[c+4>>2])){break j}}d=w[a+61|0]!=0;break e}d=v[b>>2];f=v[b+4>>2];c=kc(e+24|0,6979);if(yc(d,f,v[c>>2],v[c+4>>2])){d=w[a+62|0]!=0;break e}d=v[b>>2];f=v[b+4>>2];c=kc(e+16|0,6025);if(yc(d,f,v[c>>2],v[c+4>>2])){d=w[a+63|0]!=0;break e}d=v[b>>2];f=v[b+4>>2];c=kc(e+8|0,7429);if(yc(d,f,v[c>>2],v[c+4>>2])){d=w[a+64|0]!=0;break e}c=v[b>>2];f=v[b+4>>2];b=kc(e,13359);d=0;if(!yc(c,f,v[b>>2],v[b+4>>2])){break e}d=v[v[a+24>>2]+24668>>2]!=0}ab=e+112|0;return d|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function r1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=ab-192|0;ab=d;g=d+176|0;nI(g);v[g>>2]=49444;Pb(g+4|0);h=a+24|0;dn(v[h>>2],g);i=w[a+62|0];e=w[a+61|0];f=w[a+60|0];k=v[h>>2];b=_d(d+152|0,b);v[22452]=0;j=v[b+12>>2];v[d+16>>2]=v[b+8>>2];v[d+20>>2]=j;v[d+24>>2]=v[b+16>>2];j=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=j;b=f?13:15;b=e?b&14:b;b=Y(1047,k|0,d+8|0,(i?b&3:b)|0)|0;i=v[22452];v[22452]=0;a:{b:{c:{d:{e:{if((i|0)==1){break e}if(!b){b=aa(8)|0;v[22452]=0;c=Q(55,d+136|0,11984)|0;a=v[22452];v[22452]=0;if((a|0)!=1){lc(b,c);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(c);break b}a=P()|0;O()|0;ba(b|0);break b}if(!w[a+63|0]){v[22452]=0;R(1048,a|0,a+36|0);b=v[22452];v[22452]=0;if((b|0)==1){break e}}t[a+28|0]=1;dn(v[h>>2],v[a+4>>2]);v[22452]=0;R(1049,d+136|0,g|0);b=v[22452];v[22452]=0;if((b|0)==1){break c}l=d,m=wb(v[d+136>>2]),v[l+128>>2]=m;h=a+68|0;i=wb(v[d+140>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=v[d+128>>2];if(!Tb(b,i)){l=d,m=al(c),v[l+112>>2]=m;l=d,m=Af(c),v[l+96>>2]=m;while(1){if(!Qg(d+112|0,d+96|0)){break d}c=id(d+112|0);v[22452]=0;b=Q(54,d+32|0,c|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break h}v[22452]=0;W(940,a|0,b|0,c+12|0,0);c=v[22452];v[22452]=0;if((c|0)==1){break g}pb(b);Uj(d+112|0);continue}}e=v[b>>2];v[22452]=0;f=e;e=b+4|0;U(1050,a|0,f|0,e|0);f=v[22452];v[22452]=0;if((f|0)!=1){b=v[b>>2];v[22452]=0;R(1051,d- -64|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break r}v[22452]=0;R(986,d+80|0,d- -64|0);b=v[22452];v[22452]=0;if((b|0)==1){break q}v[22452]=0;b=Q(55,d+48|0,17713)|0;f=v[22452];v[22452]=0;if((f|0)==1){break p}v[22452]=0;U(943,d+96|0,d+80|0,b|0);f=v[22452];v[22452]=0;if((f|0)==1){break o}v[22452]=0;U(491,d+112|0,d+96|0,e|0);e=v[22452];v[22452]=0;if((e|0)==1){break n}v[22452]=0;R(174,h|0,d+112|0);e=v[22452];v[22452]=0;if((e|0)==1){break m}pb(d+112|0);pb(d+96|0);pb(b);pb(d+80|0);pb(d- -64|0);In(d+128|0);continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;break l}a=P()|0;O()|0;pb(d+112|0)}pb(d+96|0)}pb(b)}pb(d+80|0)}pb(d- -64|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;pb(b)}Wr(d+136|0);break b}a=P()|0;O()|0;break b}Wr(d+136|0);Tr(g);ab=d+192|0;return}a=P()|0;O()|0}Tr(g);S(a|0)}L()}function l8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=ab-48|0;ab=c;a:{b:{if(!Gh(b)){break b}l=v[b+12>>2];k=oj(v[v[b+48>>2]+12>>2]);e=k;d=c+32|0;f=sd(d);c:{if(e){v[22452]=0;R(407,d|0,e|0);g=v[22452];v[22452]=0;if((g|0)==1){break a}g=ab-16|0;ab=g;f=_p(g,d,e);e=v[f+4>>2];h=v[f+8>>2];while(1){if((e|0)==(h|0)){dc(f);ab=g+16|0}else{kh(e);e=e+6|0;v[f+4>>2]=e;continue}break}}f=d;break c}while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(j>>>0>=l>>>0){break s}if(!uh(v[v[a>>2]-12>>2]+a|0)){break s}v[22452]=0;t[c+31|0]=0;Q(852,a|0,c+31|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}d=t[c+31|0];if(!d){j=j+1|0;continue}t[c+30|0]=0;t:{if((d|0)>=0){break t}v[22452]=0;Q(852,a|0,c+30|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){break t}break a}t[c+29|0]=0;kh(c+16|0);u:{d=d&127;g=(d?d-1|0:0)&65535;i=g>>>0>=k>>>0;v:{w:{if(!i){h=Qc(b,j,g);e=w[c+30|0];if(e&1){break w}d=ud(v[f>>2],g);break v}h=c+16|0;e=w[c+30|0];if(!(e&1)){break u}}v[22452]=0;Q(852,a|0,c+29|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}if(i){break u}d=ud(v[f>>2],g);t[d|0]=w[c+29|0]}t[h|0]=w[d|0];e=w[c+30|0];if(!(e&2)){break q}break r}if(e&2){break r}break p}Eh(f);break b}v[22452]=0;Q(852,a|0,c+29|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}if(i){break p}d=ud(v[f>>2],g);t[d+1|0]=w[c+29|0]}t[h+1|0]=w[d+1|0];if(e&4){break o}break n}if(!(e&4)){break m}}v[22452]=0;Q(852,a|0,c+29|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}if(i){break m}d=ud(v[f>>2],g);t[d+2|0]=w[c+29|0]}t[h+2|0]=w[d+2|0];if(!(e&8)){break k}break l}if(!(e&8)){break j}}v[22452]=0;Q(852,a|0,c+29|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}if(i){break j}d=ud(v[f>>2],g);t[d+4|0]=w[c+29|0]}t[h+4|0]=w[d+4|0];if(e&16){break i}break h}if(!(e&16)){break g}}v[22452]=0;Q(852,a|0,c+29|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}if(i){break g}d=ud(v[f>>2],g);t[d+3|0]=w[c+29|0]}t[h+3|0]=w[d+3|0];if(!(e&32)){break e}break f}if(!(e&32)){break d}}v[22452]=0;Q(852,a|0,c+29|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}if(i){break d}d=ud(v[f>>2],g);t[d+5|0]=w[c+29|0]}t[h+5|0]=w[d+5|0]}if(!(e&64)){continue}v[22452]=0;Q(852,a|0,c+15|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){v[22452]=0;Q(853,a|0,w[c+15|0])|0;d=v[22452];v[22452]=0;if((d|0)!=1){continue}}break}break a}ab=c+48|0;return}a=P()|0;O()|0;Eh(f);S(a|0);L()}function eea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;h=ab-16|0;ab=h;a:{if(!Hb(a,2)){Vg(c+484344|0,b,64);break a}l=c+484344|0;m=Ld(hq(a),1,1024);if(!Vg(l,b,m)){break a}p=x[c+480188>>1];q=c+480190|0;b:while(1){if((k|0)==(m|0)){break a}i=0;n=Of(Rb(l,b),k);while(1)if((i|0)==(p|0)){k=k+1|0;continue b}else{g=h+8|0;nm(g,a);e=B(i,6)+n|0;r=Me(g);f=vi(g);g=w[g|0];c:{if((g-1&255)>>>0>35){break c}t[e|0]=g+48;o=w[Zc(h+8|0)|0];g=o+1|0;t[e+1|0]=g;j=g;g=g&255;if((j|0)!=(g|0)|g>>>0>x[q>>1]){break c}g=Tj(c,g);j=Cb(d,i);if(!(!w[j|0]|x[g+30>>1]>255)){t[e+4|0]=64;t[e+2|0]=1}g=v[Fb(g+68|0,0)>>2];if(!(w[j|0]|g?w[j|0]?(g|0)==1:0:1)){break c}t[e+1|0]=o+101}d:{e:{switch(w[r|0]){case 1:if(!w[f|0]){break d}t[e+3|0]=2;t[e+5|0]=w[f|0];break d;case 2:if(!w[f|0]){break d}t[e+3|0]=3;t[e+5|0]=w[f|0];break d;case 12:if(!w[f|0]){break d}t[e+3|0]=1;t[e+5|0]=w[f|0];break d;case 13:if(!w[f|0]){break d}t[e+3|0]=39;t[h+7|0]=15;s=e,u=w[Qb(h+7|0,f)|0]|16,t[s+5|0]=u;break d;case 30:if(!w[f|0]){break d}t[e+3|0]=38;t[h+6|0]=15;s=e,u=w[Qb(h+6|0,f)|0]|16,t[s+5|0]=u;break d;case 21:if(!w[f|0]){break d}t[e+3|0]=39;t[h+5|0]=15;s=e,u=w[Qb(h+5|0,f)|0]|80,t[s+5|0]=u;break d;case 17:if(!w[f|0]){break d}t[e+3|0]=38;t[h+4|0]=15;s=e,u=w[Qb(h+4|0,f)|0]|80,t[s+5|0]=u;break d;case 15:t[e+3|0]=19;t[e+5|0]=w[f|0]!=0;break d;case 25:t[e+3|0]=12;t[e+5|0]=w[f|0];break d;case 27:Kn(e);t[e|0]=255;break d;case 28:if(w[f|0]>31){break d}t[e+3|0]=16;t[e+5|0]=w[f|0];break d;case 31:g=w[f|0];if(g&15){s=e,u=w[Cb(d,i)|0]?22:11,t[s+3|0]=u;t[e+5|0]=w[f|0]&15;g=w[f|0]}f:{g:{switch(g>>>4|0){case 4:if((g|0)!=64){break f}case 0:case 1:case 2:case 3:if(w[Cb(d,i)|0]){t[e+3|0]=21;t[e+5|0]=w[f|0];break f}t[e+2|0]=1;f=w[f|0];t[e+3|0]=0;t[e+4|0]=f;break f;case 5:t[e+5|0]=w[e+5|0]<<4;break f;case 6:t[h+3|0]=w[e+5|0];t[h+2|0]=14;s=e,u=w[Qb(h+3|0,h+2|0)|0]|240,t[s+5|0]=u;break f;case 7:t[h+1|0]=w[e+5|0];t[h|0]=14;s=e,u=w[Qb(h+1|0,h)|0]<<4|15,t[s+5|0]=u;break f;default:break g}}t[e+3|0]=0}if((w[e+3|0]-21&255)>>>0>1){break d}f=B(t[Cb(d,i)|0]+i|0,6)+n|0;if(lq(f+3|0,f+5|0,1)){t[f+2|0]=w[f+3|0];t[f+4|0]=w[f+5|0]}t[f+3|0]=w[e+3|0];t[f+5|0]=w[e+5|0];break d;case 0:break d;default:break e}}t[e+3|0]=0}i=i+1|0;continue}}}ab=h+16|0}function uaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0;g=ab+-64|0;ab=g;r=v[a+16>>2];h=Vd(g+32|0);v[h+8>>2]=a+112;e=v[a+128>>2];v[h+16>>2]=e;D=h,E=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[D+12>>2]=E;b=0;if(e){D=h,E=Wf(v[a+8>>2],v[a+12>>2],e),v[D>>2]=E;v[h+4>>2]=db}while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}k=v[a+40>>2];l=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;s=v[a+8>>2];u=v[a+12>>2];while(1){if(d){b=v[g+12>>2];e=v[g+8>>2];v[g+56>>2]=e;v[g+60>>2]=0;m=(((b&2147483647)<<1|e>>>31)&-2)+r|0;e=v[h+16>>2];a:{b:while(1){c:{if((e|0)<=0){b=v[h+8>>2];e=v[b+8>>2];Lb(b,e,v[b+12>>2]);e=v[h+8>>2];j=v[e+4>>2];if(!j){break a}o=((v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31)&-2;f=0;b=0;break c}j=((v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31)&-2;b=0;f=0;while(1)if((b|0)==2){Bd(v[h+8>>2],(f|0)/8<<16>>16);Ad(v[h+8>>2],4);Lb(g+56|0,v[h>>2],v[h+4>>2]);e=e-1|0;continue b}else{f=(t[m+(b+j|0)|0]<<8)+f|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){f=(t[m+(b+o|0)|0]<<8)+f|0;b=b+1|0;continue}break}Bd(e,(f|0)/8<<16>>16);Ad(v[h+8>>2],j);e=v[h+8>>2];b=e;f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}d=d-1|0;b=Uf(e,v[h+12>>2]);v[g+4>>2]=b;v[g>>2]=b;m=v[a+72>>2];b=v[a+68>>2];j=b;o=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+g|0;f=v[p>>2];e=(g+16|0)+(b<<3)|0;n=v[e+4>>2];i=v[e>>2];v[e+4>>2]=i;q=f<<8;f=q;f=oia(y,z,f,f>>31);A=db;C=e;e=Sb(i,-16777216,16776704);i=oia(w,x,e,e>>31);f=i+f|0;e=db+A|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=Sb(n,-16777216,16776704);n=oia(j,o,f,f>>31);f=i+n|0;e=db+e|0;e=f>>>0<n>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[C>>2]=e-(m&q);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];l=v[a+28>>2]+l|0;v[c>>2]=v[c>>2]+B(v[g>>2],l>>12);k=b+k|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],k>>12);Lb(g+8|0,s,u);c=c+8|0;continue}break}v[a+40>>2]=k;v[a+36>>2]=l;v[a+20>>2]=l>>12;v[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g- -64|0}function _1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Bb(a);v[22452]=0;X(95);c=v[22452];v[22452]=0;a:{b:{if((c|0)==1){c=Qa(58760,88408,88980,0)|0;d=O()|0;c:{d:{e:{if((fa(58760)|0)==(d|0)){c=_(c|0)|0;v[22452]=0;b=Q(913,a|0,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break e}v[22452]=0;b=Q(913,b|0,17713)|0;d=v[22452];v[22452]=0;if((d|0)==1){break e}v[22452]=0;d=Q(913,b|0,17689)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}b=eb[v[v[c>>2]+8>>2]](c)|0;v[22452]=0;Q(913,d|0,(b?b:21598)|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((fa(88408)|0)==(d|0)){c=_(c|0)|0;v[22452]=0;b=Q(913,a|0,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break f}v[22452]=0;b=Q(913,b|0,17713)|0;d=v[22452];v[22452]=0;if((d|0)==1){break f}v[22452]=0;d=Q(913,b|0,17664)|0;b=v[22452];v[22452]=0;if((b|0)==1){break f}b=eb[v[v[c>>2]+8>>2]](c)|0;v[22452]=0;Q(913,d|0,(b?b:21598)|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break f}v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=fa(88980)|0;c=_(c|0)|0;g:{if((d|0)==(e|0)){v[22452]=0;b=Q(913,a|0,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break g}v[22452]=0;b=Q(913,b|0,17713)|0;d=v[22452];v[22452]=0;if((d|0)==1){break g}v[22452]=0;d=Q(913,b|0,17680)|0;b=v[22452];v[22452]=0;if((b|0)==1){break g}b=eb[v[v[c>>2]+8>>2]](c)|0;v[22452]=0;Q(913,d|0,(b?b:21598)|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break g}v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[22452]=0;b=Q(913,a|0,b|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}v[22452]=0;b=Q(913,b|0,17713)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}v[22452]=0;Q(913,b|0,13689)|0;b=v[22452];v[22452]=0;if((b|0)==1){break d}v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[22452]=0;X(17);c=v[22452];v[22452]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[22452]=0;X(17);c=v[22452];v[22452]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[22452]=0;X(17);c=v[22452];v[22452]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[22452]=0;X(17);c=v[22452];v[22452]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Gb()}L()}return}pb(a);S(b|0);L()}function Ms(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=ab-32|0;ab=h;g=v[a+24>>2];i=Ny(g,w[a+32|0]);j=v[i>>2];a:{if(wc(j,v[i+4>>2])>>>0<=b>>>0){break a}if(rN(a,x[Yb(j,b)>>1])>>>0<=c>>>0){break a}i=v[a>>2];b:{if(ad(i,v[a+4>>2])>>>0>b>>>0){if(y[ld(i,b)+4>>2]>c>>>0){break b}}An(a,0);if(ad(v[a>>2],v[a+4>>2])>>>0<=b>>>0){break a}g=v[a+24>>2]}m=h+16|0;Ub(m,v[d>>2],x[g+480188>>1]);d=h+24|0;i=v[h+16>>2];g=e?-2046629010:-2078137563;e=e?-1352371636:-873292572;j=v[h+20>>2];while(1){if(!f&(k|0)==(j|0)){v[d>>2]=g;v[d+4>>2]=e}else{l=w[eP(i,k)+841|0];n=l^oia(g^k,e^f,435,256);l=!l;g=(o=g,p=oia(n,db,435,256),q=l,q?o:p);e=l?e:db;k=k+1|0;f=k?f:f+1|0;continue}break}e=d;d=Ql(m,b,c);j=ab-16|0;ab=j;f=ab-16|0;ab=f;k=a+12|0;g=k;i=gN(x[d>>1],v[d+4>>2],Kd(g),ac(g));v[f+8>>2]=i;c:{if(Tb(i,Jf(g))){if(!Os(x[d>>1],v[d+4>>2],id(f+8|0))){break c}}i=Jf(g)}ab=f+16|0;d=v[$b(j+8|0,i)>>2];ab=j+16|0;v[h+8>>2]=d;o=h,p=Af(k),v[o+16>>2]=p;d=0;if(Qg(h+8|0,m)){d=id(h+8|0);d=jc(v[d+8>>2],v[d+12>>2])^1}i=v[e>>2]!=-2078137563|v[e+4>>2]!=-873292572;rb(h+16|0,v[ld(v[a>>2],b)>>2],c);m=1;f=d|i;l=sb(v[v[h+16>>2]>>2],v[h+20>>2])^1;if(!(l?1:f)){break a}d:{e:{f:{g:{if(d){j=id(h+8|0);g=wb(v[j+8>>2]);n=wb(v[j+12>>2]);f=ab-16|0;ab=f;v[f+8>>2]=g;while(1){if(!(!Tb(g,n)|v[g>>2]==v[e>>2]&v[g+4>>2]==v[e+4>>2])){Qs(f+8|0);g=v[f+8>>2];continue}break}ab=f+16|0;if(Tb(g,wb(v[j+12>>2]))){break a}if(!i){break e}break g}if(i){break g}if(!f){break d}break f}v[a+28>>2]=v[a+28>>2]+1}if(d|l){break e}d=eN(k,Ql(h+16|0,b,c));h:{if(y[d+4>>2]<y[vb(d)>>2]){f=ab-16|0;ab=f;d=dN(f,d);bN(v[d+4>>2]);v[d+4>>2]=v[d+4>>2]+8;dc(d);ab=f+16|0;break h}g=ab-32|0;ab=g;f=vb(d);f=Jq(g+8|0,Kq(d,Ag(v[d>>2],v[d+4>>2])+1|0),Ag(v[d>>2],v[d+4>>2]),f);bN(v[f+8>>2]);v[f+8>>2]=v[f+8>>2]+8;rd(d,f);Iq(f);ab=g+32|0}}d=eN(k,Ql(h+16|0,b,c));i:{if(y[d+4>>2]<y[vb(d)>>2]){f=ab-16|0;ab=f;d=dN(f,d);cN(v[d+4>>2],v[e>>2],v[e+4>>2]);v[d+4>>2]=v[d+4>>2]+8;dc(d);ab=f+16|0;break i}g=ab-32|0;ab=g;f=vb(d);f=Jq(g+8|0,Kq(d,Ag(v[d>>2],v[d+4>>2])+1|0),Ag(v[d>>2],v[d+4>>2]),f);cN(v[f+8>>2],v[e>>2],v[e+4>>2]);v[f+8>>2]=v[f+8>>2]+8;rd(d,f);Iq(f);ab=g+32|0}}d=h+16|0;rb(d,v[ld(v[a>>2],b)>>2],c);mg(d,1);m=0}ab=h+32|0;return m|0}function j_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=ab-320|0;ab=d;e=ab-16|0;ab=e;v[a>>2]=0;f=a+32|0;Wm(f,32);t[e+15|0]=0;Um(f,e+15|0);ab=e+16|0;f=v[a+28>>2];a:{if(!uh(v[v[f>>2]-12>>2]+f|0)){$g(a,1073741825);break a}e=d+56|0;Xd(e,f);f=v[e+12>>2];v[a+8>>2]=v[e+8>>2];v[a+12>>2]=f;v[e>>2]=3;h=v[a+28>>2];g=d+16|0;f=0;while(1){if(y[e>>2]>f>>>0){Wh(h,f+g|0);f=f+1|0;continue}break}if(Ib(g,25968,3)){$g(a,1073741827);break a}t[d+319|0]=0;Wh(v[a+28>>2],d+319|0);Jb(d+56|0,0,256);e=w[d+319|0];b:{if(!e){f=d+56|0;break b}f=d+56|0;Ck(v[a+28>>2],f,e)}g=b;b=Mm(d+16|0,f,e);e=Jv(g,b);yb(b);if(!e){$g(a,1073741830)}if(w[a+3|0]&64){break a}Wh(v[a+28>>2],d+55|0);b=w[d+55|0];e=b&3;u[a+16>>1]=(e|0)==3?4:e;if(Ii(b,6)){tk(a,9,1)}v[d+48>>2]=0;aF(v[a+28>>2],d+48|0);e=v[d+48>>2];t[d+47|0]=0;if(e>>>0>=2){Wh(v[a+28>>2],d+55|0);f=-1;if(!w[d+55|0]){Wh(v[a+28>>2],d+47|0);f=-2}Cl(v[a+28>>2],e+f|0)}v[d+32>>2]=0;v[d+36>>2]=0;c:{if(!Ii(b,4)){break c}qk(v[a+28>>2],d+32|0);e=v[d+36>>2];f=v[d+32>>2];v[a+56>>2]=f;v[a+60>>2]=e;g=v[c+4>>2];if((g|0)==(e|0)&y[c>>2]>=f>>>0|e>>>0<g>>>0){break c}$g(a,536871424)}if(Ii(b,5)){Wh(v[a+28>>2],d+55|0);Cl(v[a+28>>2],w[d+55|0])}e=w[d+47|0];d:{if(!Ii(e,0)){break d}Wh(v[a+28>>2],d+55|0);c=w[d+55|0];c=c&1?-1:c>>>1|0;u[a+16>>1]=c;if(c){break d}$g(a,536871168)}v[a+4>>2]=0;c=1;if(Ii(e,1)){aF(v[a+28>>2],a+4|0)}tk(a,6,Ii(b,2));tk(a,7,Ii(b,3));tk(a,5,x[a+16>>1]!=0);tk(a,8,Ii(b,7));e:{if(Vc(a,5)){break e}if(Vc(a,6)){break e}if(Vc(a,7)){break e}c=Vc(a,8)}tk(a,11,c);Vc(a,11);if(Ii(e,2)){u[d+16>>1]=0;Iv(v[a+28>>2],d+16|0);Cl(v[a+28>>2],B(x[d+16>>1],Vc(a,9)?2:1))}if(Ii(e,3)){Cl(v[a+28>>2],5)}qk(v[a+28>>2],d+32|0);c=v[d+36>>2];b=v[d+32>>2];if(!c&b>>>0>=16001|c){$g(a,1073741831);break a}v[a+92>>2]=b;if(!b){$g(a,536871040)}f:{if(!Vc(a,11)){break f}qk(v[a+28>>2],d+32|0);b=v[d+32>>2];c=v[d+36>>2];if((c|0)>0|(c|0)>=0){break f}$g(a,1073741829);break a}Xd(d,v[a+28>>2]);c=d+16|0;KF(c,d,v[a+8>>2],v[a+12>>2]);e=v[c+8>>2];c=v[c+12>>2];if((c|0)==1|c>>>0>1){$g(a,1073741832);break a}v[a+88>>2]=e;if(!Vc(a,11)){b=v[a+88>>2]}v[a+64>>2]=b;if(!Vc(a,11)){b=v[a+12>>2];c=v[a+88>>2];e=c+v[a+8>>2]|0;b=e>>>0<c>>>0?b+1|0:b;v[a+72>>2]=e;v[a+76>>2]=b}tk(a,10,1)}ab=d+320|0}function OU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=ab-384|0;ab=f;qc(b);d=ab-16|0;ab=d;h=f+344|0;oC(d+8|0,h);e=v[d+12>>2];_b(d,b,v[d+8>>2],e);i=v[d+4>>2];if((i|0)==(e|0)){Ob(b,v[d+12>>2])}ab=d+16|0;d=(e|0)==(i|0);if(!d){nC(h)}a:{if(!d){break a}if(!qC(f+344|0)){break a}if(!Hb(b,Fc(pC(w[f+379|0]),db))){break a}b:{if(!c){break b}vd(a,2097152);wg(a);lh(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[f+376|0];v[a+480204>>2]=B(w[f+377|0],1e4);l=a+480190|0;u[l>>1]=w[f+378|0];d=w[f+381|0];if(d>>>0<w[f+380|0]){Re(Kb(a+484360|0),d)}d=f+80|0;g=Mb(d,6480);tb(a+1298344|0,g);pb(g);g=Mb(d,11056);tb(a+1298356|0,g);pb(g);v[a+1298404>>2]=5;Cu(b,d);rq(Kb(a+484360|0),d,w[f+380|0],65535,65535);g=1;while(1){k=g&65535;if(k>>>0>x[l>>1]){Ob(b,B(64-w[f+378|0]|0,37));h=a+484344|0;fg(h,w[f+379|0]);i=c&1;g=0;while(1){if(w[f+379|0]<=g>>>0){if(!(c&2)){break b}c=Gc(f+40|0,8,1,0,0);d=a+480190|0;g=1;while(1){e=g&65535;if(e>>>0>x[d>>1]){break b}eg(c,(B(e,104)+a|0)+484380|0,b);g=g+1|0;continue}}c:{d:{if(i){if(Vg(h,g&65535,64)){break d}}Ob(b,2048);break c}d=Rb(h,g);o=f,p=vg(d),v[o+40>>2]=p;j=ug(d);while(1){d=v[f+40>>2];if(!Tb(d,j)){break c}e=f+24|0;nm(e,b);k=Zc(e);l=Me(e);m=vi(e);e=w[e|0];if((e-1&255)>>>0<=106){t[d|0]=e+13}t[d+1|0]=w[k|0];t[d+3|0]=w[l|0];t[d+5|0]=w[m|0];Mf(d);ui(f+40|0);continue}}g=g+1|0;continue}}else{i=f+40|0;lC(b,i);j=ab-16|0;ab=j;h=(B(k,104)+a|0)+484380|0;ed(h,0);t[h+37|0]=w[i+22|0]<<4;t[j+15|0]=w[i+23|0];t[j+14|0]=64;o=h,p=w[Qb(j+15|0,j+14|0)|0]<<2,u[o+30>>1]=p;t[h+36|0]=w[i+24|0];e=i+25|0;v[h>>2]=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);d=i+33|0;m=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);e:{if(m>>>0<3){break e}n=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=i+29|0;if(n>>>0<m+(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0){break e}u[h+34>>1]=x[h+34>>1]|2;v[h+4>>2]=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[h+8>>2]=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))}ab=j+16|0;gl(f+8|0,2,i);d=f+24|0;tc(d,v[f+8>>2],v[f+12>>2],w[f+16|0]);sc(((k<<5)+a|0)+946304|0,d);g=g+1|0;pb(d);continue}}}g=1}ab=f+384|0;return g|0}function rU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0;f=ab-32|0;ab=f;j=Fh(f+24|0);q=j+3|0;r=j+5|0;s=j+4|0;x=j+2|0;z=j+1|0;g=f+16|0;A=g|5;C=g|3;while(1){a:{if(y[a+12>>2]>m>>>0){D=Of(a,m);b:while(1){if(!Hb(c,1)){break a}k=ue(c);if((k|0)==255){break a}d=k&31;g=oj(v[v[a+48>>2]+12>>2])>>>0>d>>>0;e=B(d,6)+D|0;h=1;if(!(k&64)){d=ue(c);i=d<<24>>24;h=255;d=d&127;c:{d:{if((d|0)==1){break d}h=d-1|0;if(b?h>>>0<=120:0){break d}if((d-109&255)>>>0<159|b){break c}h=d+13|0}t[(g?e:f+24|0)|0]=h}E=g?e+1|0:z,F=ue(c),t[E|0]=F;h=(i|0)<0}p=g?e:j;i=g?e+3|0:q;d=g?e+5|0:r;n=g?e+4|0:s;l=g?e+2|0:x;g=g?e:f+24|0;while(1){e:{f:{g:{if(h&1){v[f+16>>2]=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);u[f+20>>1]=w[g+4|0]|w[g+5|0]<<8;o=ue(c);h=o&63;if(o&64){t[l|0]=1;t[n|0]=h;break e}e=ue(c);t[d|0]=e;if(h>>>0<=15){t[i|0]=h;Mf(p);h:{i:{j:{e=w[i|0];switch(e-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}t[i|0]=9;t[d|0]=B(w[d|0]&15,17);break f}t[i|0]=0;t[l|0]=1;v[f+12>>2]=w[d|0]+1>>>1;v[f+8>>2]=64;E=n,F=v[jd(f+12|0,f+8|0)>>2],t[E|0]=F;break f}if((e|0)!=19){break f}if(w[d|0]==128){break g}ru(p);break f}if(h>>>0>44){break f}t[i|0]=w[h+26224|0];k:{switch(h-16|0){case 0:if(e>>>0>1){break g}t[d|0]=e|158;break f;case 1:case 2:t[f+12|0]=15;E=d,F=w[Qb(f+12|0,d)|0]|224,t[E|0]=F;break f;case 5:case 6:v[f+12>>2]=16;v[f+8>>2]=e+1;E=d,F=v[jd(f+12|0,f+8|0)>>2]/2|240,t[E|0]=F;break f;case 14:l:{m:{n:{o:{p:{h=e>>>4|0;switch(h-1|0){case 1:break n;case 0:break o;default:break p}}switch(h-10|0){case 1:break l;case 0:break m;default:break g}}t[i|0]=2;t[d|0]=e|240;break f}t[i|0]=3;t[d|0]=e|240;break f}t[i|0]=11;t[d|0]=(e<<3&120)+8|15;break f}t[i|0]=11;t[d|0]=(e&15)+1>>>1|240;break f;case 12:break k;default:break f}}v[f+12>>2]=e+1>>>1;v[f+8>>2]=64;E=d,F=v[jd(f+12|0,f+8|0)>>2],t[E|0]=F;break f}if(!(k&128)){continue b}break a}t[i|0]=0}qu(i,d,C,A);e=w[f+19|0];if(ti(e)>>>0<=ti(w[i|0])>>>0){break e}q:{if(w[l|0]){break q}if(!lq(i,d,1)){break q}t[l|0]=w[i|0];t[n|0]=w[d|0]}t[i|0]=e;t[d|0]=w[f+21|0]}h=o>>>7|0;continue}}}ab=f+32|0;return}m=m+1|0;continue}}function Mfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=ab-48|0;ab=d;a:{b:{c:{d:{e:{h=a+24|0;f:{if(td(h)){break f}g=a+4|0;i=ub(g);a=ab-32|0;ab=a;f=a+24|0;c=f;v[c>>2]=-1;v[c+4>>2]=-1;v[22452]=0;c=dE(37);b=v[22452];v[22452]=0;if((b|0)==1){break a}v[a>>2]=c;v[a+4>>2]=db;c=ab-16|0;ab=c;k=c,l=oia(v[a>>2],v[a+4>>2],1e3,0),v[k>>2]=l;v[c+4>>2]=db;b=Zs(c+8|0,c);e=v[b+4>>2];ab=c+16|0;v[a+8>>2]=v[b>>2];v[a+12>>2]=e;c=a+8|0;b=Sz(v[c>>2],v[c+4>>2]);t[a+16|0]=b;t[a+17|0]=b>>>8;t[a+18|0]=b>>>16;t[a+19|0]=b>>>24;b=db;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[a+20>>2];v[a+8>>2]=v[a+16>>2];v[a+12>>2]=b;f=WQ(f,c,vb(c));v[22452]=0;b=dE(38);e=v[22452];v[22452]=0;if((e|0)==1){break a}v[a>>2]=b;v[a+4>>2]=db;b=ab-16|0;ab=b;e=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=e;e=Zs(b+8|0,b);j=v[e+4>>2];ab=b+16|0;v[a+8>>2]=v[e>>2];v[a+12>>2]=j;b=Sz(v[c>>2],v[c+4>>2]);t[a+16|0]=b;t[a+17|0]=b>>>8;t[a+18|0]=b>>>16;t[a+19|0]=b>>>24;b=db;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[a+20>>2];v[a+8>>2]=v[a+16>>2];v[a+12>>2]=b;c=WQ(f,c,vb(c));b=v[c>>2];f=v[c+4>>2];ab=a+32|0;if(i){c=Pb(d+32|0);v[22452]=0;v[d+16>>2]=f;R(31,c|0,d+16|0);a=v[22452];v[22452]=0;if((a|0)==1){break c}v[22452]=0;v[d+16>>2]=b;R(31,c|0,d+16|0);a=v[22452];v[22452]=0;if((a|0)==1){break d}a=0;g:{while(1){if(ub(g)>>>0<=a>>>0){a=wb(v[c>>2]);b=wb(v[c+4>>2]);v[22452]=0;b=Y(32,d+16|0,a|0,b|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break g}a=P()|0;O()|0;break b}b=w[oc(g,a)|0];v[22452]=0;v[d+16>>2]=b;R(31,c|0,d+16|0);b=v[22452];v[22452]=0;if((b|0)!=1){a=a+1|0;continue}break}a=P()|0;O()|0;break b}v[22452]=0;a=T(33,b|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){v[d+8>>2]=a;a=d+8|0;Vz(h,a);bl(a);ec(b);ec(c);break f}a=P()|0;O()|0;ec(b);break b}db=b;v[d+16>>2]=f;v[d+20>>2]=db;c=d+32|0;a=Pb(c);v[22452]=0;U(36,c|0,d+16|0,d+24|0);b=v[22452];v[22452]=0;if((b|0)==1){c=P()|0;O()|0;ec(a);S(c|0);L()}v[22452]=0;a=T(33,c|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}v[d+8>>2]=a;a=d+8|0;Vz(h,a);bl(a);ec(c)}ab=d+48|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}ec(c);S(a|0);L()}V(0)|0;O()|0;Gb();L()}function taa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0;g=ab+-64|0;ab=g;p=v[a+16>>2];h=Vd(g+32|0);v[h+8>>2]=a+112;e=v[a+128>>2];v[h+16>>2]=e;D=h,E=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[D+12>>2]=E;b=0;if(e){D=h,E=Wf(v[a+8>>2],v[a+12>>2],e),v[D>>2]=E;v[h+4>>2]=db}while(1){if((b|0)!=2){e=b<<3;i=e+(g+16|0)|0;e=a+e|0;v[i>>2]=v[e+44>>2];v[i+4>>2]=v[e+48>>2];b=b+1|0;continue}break}i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+8>>2];r=v[a+12>>2];a:while(1){if(d){b=v[g+12>>2];e=v[g+8>>2];v[g+56>>2]=e;v[g+60>>2]=0;e=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+p|0;b=v[h+16>>2];while(1)if((b|0)<=0){b=v[h+8>>2];f=v[b+8>>2];Lb(b,f,v[b+12>>2]);b=v[h+8>>2];f=v[b+4>>2];if(f){k=b;b=(v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31;Bd(k,(u[(b<<1|2)+e>>1]+u[e+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Ad(v[h+8>>2],f);b=v[h+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}d=d-1|0;b=Uf(b,v[h+12>>2]);v[g+4>>2]=b;v[g>>2]=b;s=v[a+72>>2];b=v[a+68>>2];t=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;b=0;while(1){if((b|0)!=2){n=(b<<2)+g|0;f=v[n>>2];e=(g+16|0)+(b<<3)|0;m=v[e+4>>2];l=v[e>>2];v[e+4>>2]=l;o=f<<8;f=o;f=oia(z,A,f,f>>31);k=db;C=e;e=Sb(l,-16777216,16776704);l=oia(x,y,e,e>>31);f=l+f|0;e=db+k|0;e=f>>>0<l>>>0?e+1|0:e;k=f;f=Sb(m,-16777216,16776704);m=oia(t,w,f,f>>31);f=k+m|0;e=db+e|0;e=f>>>0<m>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[C>>2]=e-(s&o);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];j=v[a+28>>2]+j|0;v[c>>2]=v[c>>2]+B(v[g>>2],j>>12);i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],i>>12);Lb(g+8|0,q,r);c=c+8|0;continue a}else{f=(v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31;Bd(v[h+8>>2],(u[(f<<1|2)+e>>1]+u[e+((f&2147483646)<<1)>>1]|0)/8<<16>>16);Ad(v[h+8>>2],4);Lb(g+56|0,v[h>>2],v[h+4>>2]);b=b-1|0;continue}}break}v[a+40>>2]=i;v[a+36>>2]=j;v[a+20>>2]=j>>12;v[a+24>>2]=i>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g- -64|0}function yaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;g=ab+-64|0;ab=g;q=v[a+16>>2];h=Vd(g+32|0);v[h+8>>2]=a+112;e=v[a+128>>2];v[h+16>>2]=e;E=h,F=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[E+12>>2]=F;b=0;if(e){E=h,F=Wf(v[a+8>>2],v[a+12>>2],e),v[E>>2]=F;v[h+4>>2]=db}while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}r=v[a+24>>2];s=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;u=v[a+8>>2];w=v[a+12>>2];while(1){a:{if(!d){while(1){if((m|0)==2){break a}b=m<<3;c=b+a|0;b=b+(g+16|0)|0;v[c+44>>2]=v[b>>2];v[c+48>>2]=v[b+4>>2];m=m+1|0;continue}}b=v[g+12>>2];e=v[g+8>>2];v[g+56>>2]=e;v[g+60>>2]=0;k=(((b&2147483647)<<1|e>>>31)&-2)+q|0;e=v[h+16>>2];b:{c:while(1){d:{if((e|0)<=0){b=v[h+8>>2];e=v[b+8>>2];Lb(b,e,v[b+12>>2]);e=v[h+8>>2];j=v[e+4>>2];if(!j){break b}n=((v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31)&-2;f=0;b=0;break d}j=((v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31)&-2;b=0;f=0;while(1)if((b|0)==2){Bd(v[h+8>>2],(f|0)/8<<16>>16);Ad(v[h+8>>2],4);Lb(g+56|0,v[h>>2],v[h+4>>2]);e=e-1|0;continue c}else{f=(t[k+(b+j|0)|0]<<8)+f|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){f=(t[k+(b+n|0)|0]<<8)+f|0;b=b+1|0;continue}break}Bd(e,(f|0)/8<<16>>16);Ad(v[h+8>>2],j);e=v[h+8>>2];b=e;f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}d=d-1|0;b=Uf(e,v[h+12>>2]);v[g+4>>2]=b;v[g>>2]=b;k=v[a+72>>2];b=v[a+68>>2];j=b;n=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;b=0;while(1){if((b|0)!=2){o=(b<<2)+g|0;f=v[o>>2];e=(g+16|0)+(b<<3)|0;l=v[e+4>>2];i=v[e>>2];v[e+4>>2]=i;p=f<<8;f=p;f=oia(z,A,f,f>>31);C=db;D=e;e=Sb(i,-16777216,16776704);i=oia(x,y,e,e>>31);f=i+f|0;e=db+C|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=Sb(l,-16777216,16776704);l=oia(j,n,f,f>>31);f=i+l|0;e=db+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[D>>2]=e-(k&p);v[o>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],r);Lb(g+8|0,u,w);c=c+8|0;continue}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g- -64|0}function A8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=ab-16|0;ab=h;v[22452]=0;e=T(566,a|0)|0;f=v[22452];v[22452]=0;a:{b:{if((f|0)!=1){if(e){break b}v[22452]=0;e=T(197,a|0)|0;f=v[22452];v[22452]=0;c:{if((f|0)==1){break c}v[22452]=0;j=d+484344|0;k=Ld(e+1|0,1,1024);e=Y(217,j|0,b|0,k|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break c}if(!e){break b}d=x[d+480188>>1];if(!d){break b}l=d-1|0;d=0;while(1){if(d>>>0>=k>>>0){break b}v[22452]=0;e=Q(147,a|0,1)|0;f=v[22452];v[22452]=0;d:{if((f|0)!=1){if(!e){break b}v[22452]=0;i=T(197,a|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break a}if(i){break d}d=d+1|0;continue}break a}f=Rb(j,b);u[h+14>>1]=i&31;u[h+12>>1]=l;f=Qc(f,d,x[Lc(h+14|0,h+12|0)>>1]);if(!(i&224)){continue}e:{if(!(i&128)){break e}v[22452]=0;g=T(197,a|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break a}t[f+5|0]=g;v[22452]=0;g=T(197,a|0)|0;e=v[22452];v[22452]=0;f:{g:{if((e|0)!=1){if(g>>>0<26){break g}break f}break a}e=w[g+42848|0];t[f+3|0]=e;h:{switch(e-1|0){case 0:if(!w[f+5|0]){break f}break e;case 12:if(w[f+2|0]){break e}t[f+2|0]=1;e=w[f+5|0];t[f+5|0]=0;t[f+3|0]=0;m=f,n=Ld(e,0,64),t[m+4|0]=n;break e;case 5:case 6:case 10:case 23:case 28:e=w[f+5|0]&240;if(!e){break e}t[f+5|0]=e;break e;case 8:e=w[f+5|0];if(e>>>0<=128){m=f,n=pi(e<<1),t[m+5|0]=n;break e}if((e|0)!=164){break e}t[f+5|0]=145;t[f+3|0]=20;break e;case 13:e=w[f+5|0];t[f+5|0]=B(e>>>4|0,10)+(e&15);break e;case 18:ru(f);break e;case 16:if(w[f+5|0]>31){break e}t[f+3|0]=16;break e;case 27:break h;default:break e}}g=w[f+5|0];e=g&240;i:{if((e|0)==16){e=2}else{if((e|0)!=32){break i}e=3}t[f+3|0]=e}t[f+5|0]=g&15|224;break e}t[f+3|0]=0}j:{k:{if(!(i&64)){break k}v[22452]=0;R(254,h+8|0,a|0);e=v[22452];v[22452]=0;if((e|0)==1){break j}e=h+8|0;t[f+1|0]=w[e|0];g=w[Zc(e)|0];t[f|0]=g;e=255;if((g|0)!=128){e=253;if(g>>>0<129){break k}}t[f|0]=e}if(!(i&32)){continue}t[f+2|0]=1;v[22452]=0;g=T(197,a|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break a}t[f+4|0]=g;if(!c){continue}t[f+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}qb(a);ab=h+16|0;return}b=P()|0;O()|0;qb(a);S(b|0);L()}function ax(a){a=a|0;var b=0,c=0,d=C(0),e=0;Jb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[22452]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}ga(901,e|0,67,5,c|0,b|0);b=v[22452];v[22452]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[22452]=0;ga(901,a+4528|0,62,5,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[22452]=0;ga(901,a+4552|0,53,5,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[22452]=0;ga(901,a+4576|0,43,5,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[22452]=0;ga(901,a+4600|0,32,5,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[22452]=0;ga(901,a+4624|0,22,5,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[22452]=0;ga(901,a+4648|0,75,5,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[22452]=0;ga(901,a+4672|0,69,5,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[22452]=0;ga(901,a+4696|0,60,5,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[22452]=0;ga(901,a+4720|0,48,5,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[22452]=0;ga(901,a+4744|0,36,5,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[22452]=0;ga(901,a+4768|0,25,5,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}v[22452]=0;ga(901,a+4792|0,0,0,0,0);b=v[22452];v[22452]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[22452]=0;ga(901,a+4816|0,3,0,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[22452]=0;ga(901,a+4840|0,3,0,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}v[22452]=0;ga(901,a+4864|0,407,1,c|0,0);b=v[22452];v[22452]=0;if((b|0)==1){break a}v[22452]=0;ga(901,a+4888|0,400,1,c|0,0);b=v[22452];v[22452]=0;if((b|0)==1){break a}v[22452]=0;ga(901,a+4912|0,10,0,c|0,-1);b=v[22452];v[22452]=0;if((b|0)==1){break a}v[22452]=0;ga(901,a+4936|0,10,0,c|0,-1);c=v[22452];v[22452]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(88408)|0;if((O()|0)==(fa(88408)|0)){_(c|0)|0;t[a+5045|0]=0;$();return}S(c|0);L()}function Zca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ab-128|0;ab=d;a:{b:{c:{d:{switch(w[a|0]-23|0){case 0:e=t[a+1|0];f=d,g=yQ(v[c+480208>>2],+w[a+2|0]*1e4/240),t[f|0]=g;v[d+96>>2]=127;v[d+80>>2]=(B(w[a+3|0],127)>>>0)/185;f=d,g=v[jd(d+96|0,d+80|0)>>2],t[f+127|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:af(d+80|0,15551);v[22452]=0;R(507,d- -64|0,d|0);a=v[22452];v[22452]=0;f:{g:{h:{i:{if((a|0)!=1){v[22452]=0;R(507,d+48|0,d+127|0);a=v[22452];v[22452]=0;if((a|0)==1){break i}v[22452]=0;W(508,d+96|0,d+80|0,d- -64|0,d+48|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}a=d+96|0;qe(d+112|0,a);Ie(b,v[d+112>>2],v[d+116>>2]);pb(a);pb(d+48|0);pb(d- -64|0);yb(d+80|0);break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;pb(d+48|0)}pb(d- -64|0)}break c;case 1:af(d+80|0,15491);v[22452]=0;R(507,d- -64|0,d|0);a=v[22452];v[22452]=0;j:{k:{l:{m:{if((a|0)!=1){v[22452]=0;R(507,d+48|0,d+127|0);a=v[22452];v[22452]=0;if((a|0)==1){break m}v[22452]=0;W(508,d+96|0,d+80|0,d- -64|0,d+48|0);a=v[22452];v[22452]=0;if((a|0)==1){break l}a=d+96|0;qe(d+40|0,a);Ie(b,v[d+40>>2],v[d+44>>2]);pb(a);pb(d+48|0);pb(d- -64|0);yb(d+80|0);break b}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;pb(d+48|0)}pb(d- -64|0)}break c;default:break e}}a=kc(d+32|0,15578);Ie(b,v[a>>2],v[a+4>>2]);break b;case 1:break d;default:break a}}c=t[a+1|0];t[d+127|0]=(c|0)<5?c:0;c=t[a+2|0];t[d+31|0]=(c|0)>=0?c:127;a=t[a+3|0];t[d+30|0]=(a|0)>=0?a:127;a=ab-16|0;ab=a;c=Mb(a,4009);Ac(d+80|0,c);pb(c);ab=a+16|0;v[22452]=0;R(507,d- -64|0,d+127|0);a=v[22452];v[22452]=0;n:{o:{p:{q:{r:{s:{if((a|0)!=1){v[22452]=0;R(507,d+48|0,d+31|0);a=v[22452];v[22452]=0;if((a|0)==1){break s}v[22452]=0;R(507,d|0,d+30|0);a=v[22452];v[22452]=0;if((a|0)==1){break r}v[22452]=0;ga(680,d+96|0,d+80|0,d- -64|0,d+48|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break q}a=d+96|0;qe(d+16|0,a);Ie(b,v[d+16>>2],v[d+20>>2]);pb(a);pb(d);pb(d+48|0);pb(d- -64|0);yb(d+80|0);break b}a=P()|0;O()|0;break n}a=P()|0;O()|0;break o}a=P()|0;O()|0;break p}a=P()|0;O()|0;pb(d)}pb(d+48|0)}pb(d- -64|0)}}yb(d+80|0);S(a|0);L()}e=1}ab=d+128|0;return e|0}function caa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=ab-32|0;ab=h;c=cf(a,c);Xd(h+8|0,v[a+28>>2]);e=v[h+20>>2];v[h+24>>2]=v[h+16>>2];v[h+28>>2]=e;j=a;a:{if(!c){e=0;if(Vc(a,5)){break a}}e=ab-160|0;ab=e;g=yl(e+56|0,v[a+28>>2]);v[22452]=0;f=Q(408,e+40|0,27800)|0;a=v[22452];v[22452]=0;b:{c:{d:{e:{if((a|0)!=1){v[22452]=0;v[e+24>>2]=19923456;v[e+28>>2]=0;U(409,g|0,f|0,e+24|0);a=v[22452];v[22452]=0;if((a|0)==1){break e}yb(f);if(!(w[g+3|0]&64)){break d}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(f);break c}t[e+39|0]=0;v[22452]=0;f=Q(408,e+40|0,5466)|0;a=v[22452];v[22452]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[22452]=0;U(410,g|0,e+39|0,f|0);a=v[22452];v[22452]=0;if((a|0)==1){break q}yb(f);f=Bb(e+40|0);v[22452]=0;a=Q(408,e+24|0,10055)|0;i=v[22452];v[22452]=0;if((i|0)==1){break p}v[22452]=0;U(728,g|0,f|0,a|0);i=v[22452];v[22452]=0;if((i|0)==1){break o}yb(a);v[22452]=0;U(11,e+24|0,(w[e+39|0]?0:d)|0,f|0);d=v[22452];v[22452]=0;if((d|0)==1){break n}v[22452]=0;R(267,b|0,e+24|0);d=v[22452];v[22452]=0;if((d|0)==1){break m}d=e+24|0;pb(d);u[e+22>>1]=0;v[22452]=0;d=Q(408,d|0,10715)|0;a=v[22452];v[22452]=0;if((a|0)==1){break g}v[22452]=0;Y(438,g|0,e+22|0,d|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break l}yb(d);lg(e+22|0,4e3);v[22452]=0;d=Q(408,e+24|0,13388)|0;a=v[22452];v[22452]=0;if((a|0)==1){break k}i=x[e+22>>1];a=v[$b(e+16|0,i)>>2];v[22452]=0;W(729,g|0,b|0,d|0,a|0);a=v[22452];v[22452]=0;if((a|0)==1){break j}yb(d);u[e+14>>1]=65535;v[22452]=0;d=Q(408,e+24|0,8935)|0;a=v[22452];v[22452]=0;if((a|0)==1){break i}v[22452]=0;k=Y(438,g|0,e+14|0,d|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break h}a=x[e+14>>1];yb(d);if(!((k|0)==1|a>>>0>=i>>>0)){Re(b,a)}pb(f);break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(f);break c}b=P()|0;O()|0;break f}b=P()|0;O()|0;yb(a);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;pb(e+24|0);break f}b=P()|0;O()|0;yb(d);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;yb(d);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;yb(d);break f}b=P()|0;O()|0}pb(f)}Sg(g);S(b|0);L()}Sg(g);ab=e+160|0;e=c}Te(j,e,h+24|0);ab=h+32|0}function yO(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=ab-128|0;ab=j;a:{b:{c:{if(!$l(f,g,h,i,0,0,0,0)){break c}m=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|m)?3:2;break d}l=!(f|h|(g|m))}}r=e>>>16|0;o=r&32767;if((o|0)==32767){break c}if(l){break b}}wd(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];YO(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}m=e&65535|o<<16;p=m;l=d;m=h;q=i>>>16&32767;k=i&65535|q<<16;if(($l(b,c,l,p,f,g,h,k)|0)<=0){if($l(b,c,l,p,f,g,m,k)){h=b;i=c;break a}wd(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{wd(j+96|0,b,c,l,p,0,0,0,1081540608);h=v[j+108>>2];p=h;l=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){wd(j+80|0,f,g,m,k,0,0,0,1081540608);f=v[j+92>>2];k=f;m=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){t=l-m|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=(p-((l>>>0<m>>>0)+s|0)|0)-(t>>>0<k>>>0)|0;k=t-k|0;f:{if((n|0)>0|(n|0)>=0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|k|(i|n))){wd(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}n=n<<1|k>>>31;l=k<<1|i>>>31;p=n;break f}n=p<<1|l>>>31;l=l<<1|i>>>31;p=n}n=i<<1|h>>>31;h=h<<1;i=n;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}q=l-m|0;n=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=(p-((l>>>0<m>>>0)+s|0)|0)-(q>>>0<n>>>0)|0;m=q-n|0;g:{if((k|0)<0){m=l;k=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|m|(i|k)){break g}wd(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m;k=k<<1|b>>>31;m=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){wd(j- -64|0,h,i,m,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=m;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;ab=j+128|0}function v6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=0,h=C(0),i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=0,u=0,x=0,y=0,A=0,B=C(0),E=0,F=0,G=C(0),H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=C(0),P=0,Q=C(0);a:{if(!v[a+4316>>2]){break a}m=a+44|0;if(!Ih(m)){break a}t=Gd(m,0);u=Gd(m,1);x=dd(m,0);y=dd(m,1);K=eb[v[v[a>>2]+192>>2]](a)|0;e=C(eb[v[v[a>>2]+200>>2]](a));G=C(eb[v[v[a>>2]+188>>2]](a));A=eb[v[v[a>>2]+212>>2]](a)|0;H=a+4264|0;r=w[a+4260|0];L=r?a+4276|0:H;I=a+4300|0;J=a+4288|0;B=C(e/C(100));M=A&1;N=a+4316|0;j=r;E=d;while(1){if(E){p=z[u>>2];l=z[t>>2];n=v[N>>2];o=v[a+4312>>2];F=v[a+4256>>2];k=kn(n,o+F|0);q=kn(n,o);i=j&255;b:{if(i){j=v[a+4328>>2];P=Fb(J,j),Q=l,z[P>>2]=Q;P=Fb(I,j),Q=p,z[P>>2]=Q;g=v[a+4264>>2];j=Fb(g,k);P=Fb(g,q),Q=C(C(z[j>>2]*B)+l),z[P>>2]=Q;j=v[a+4276>>2];h=C(C(z[Fb(j,k)>>2]*B)+p);break b}g=v[H>>2];h=C(C(z[Fb(g,k)>>2]*B)+C(C(l+p)*C(.5)));j=g}P=Fb(j,q),Q=h,z[P>>2]=Q;c:{if(K){e=z[a+4244>>2];h=C(e+z[a+4236>>2]);z[a+4236>>2]=h;f=C(e+z[a+4240>>2]);z[a+4240>>2]=f;if(h>C(1)){h=C(h+C(-2));z[a+4236>>2]=h}if(f>C(1)){f=C(f+C(-2));z[a+4240>>2]=f}e=C(D(h));h=C(C(e+e)+C(-1));e=C(D(f));f=C(C(e+e)+C(-1));break c}f=z[a+4240>>2];e=z[a+4244>>2];h=C(C(f*e)+z[a+4236>>2]);z[a+4236>>2]=h;f=C(f-C(h*e));z[a+4240>>2]=f}s=v[a+4328>>2];j=0;d:{if(!i){break d}i=(s+2|0)%3|0;l=z[Fb(J,i)>>2];if(!r){break d}p=z[Fb(I,i)>>2];j=r}k=v[a+4320>>2];i=Fb(g,kn(n,k+o|0));q=o+4096|0;O=z[Fb(g,kn(n,q+k|0))>>2];e=z[i>>2];z[x>>2]=C(C(C(C(C(O-e)*C(C(k&4095)*C(.000244140625)))+e)-l)*G)+l;i=v[L>>2];k=v[a+4324>>2];g=Fb(i,kn(n,k+o|0));l=z[Fb(i,kn(n,k+q|0))>>2];e=z[g>>2];z[y>>2]=C(C(C(C(C(l-e)*C(C(k&4095)*C(.000244140625)))+e)-p)*G)+p;v[a+4328>>2]=((s|0)<=0?s+3|0:s)-1;v[a+4312>>2]=(((o|0)>0?0:n<<12)+o|0)-4096;e=M?f:h;f=z[a+4248>>2];e=C(e*f);e:{if(C(D(e))<C(2147483648)){g=~~e;break e}g=-2147483648}v[a+4324>>2]=(A>>>0>1?g:0-g|0)+F;g=A>>>0<4;u=u+4|0;t=t+4|0;e=C(h*f);f:{if(C(D(e))<C(2147483648)){i=~~e;break f}i=-2147483648}v[a+4320>>2]=(g?i:0-i|0)+F;E=E-1|0;y=y+4|0;x=x+4|0;continue}else{ai(a,b,c,dd(m,0),dd(m,1),d)}break}}}function xaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;g=ab+-64|0;ab=g;o=v[a+16>>2];h=Vd(g+32|0);v[h+8>>2]=a+112;e=v[a+128>>2];v[h+16>>2]=e;E=h,F=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[E+12>>2]=F;b=0;if(e){E=h,F=Wf(v[a+8>>2],v[a+12>>2],e),v[E>>2]=F;v[h+4>>2]=db}while(1){if((b|0)!=2){e=b<<3;i=e+(g+16|0)|0;e=a+e|0;v[i>>2]=v[e+44>>2];v[i+4>>2]=v[e+48>>2];b=b+1|0;continue}break}p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;r=v[a+8>>2];s=v[a+12>>2];i=0;a:while(1){b:{if(!d){while(1){if((i|0)==2){break b}b=i<<3;c=b+a|0;b=b+(g+16|0)|0;v[c+44>>2]=v[b>>2];v[c+48>>2]=v[b+4>>2];i=i+1|0;continue}}b=v[g+12>>2];e=v[g+8>>2];v[g+56>>2]=e;v[g+60>>2]=0;e=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+o|0;b=v[h+16>>2];while(1)if((b|0)<=0){b=v[h+8>>2];f=v[b+8>>2];Lb(b,f,v[b+12>>2]);b=v[h+8>>2];f=v[b+4>>2];if(f){j=b;b=(v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31;Bd(j,(u[(b<<1|2)+e>>1]+u[e+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Ad(v[h+8>>2],f);b=v[h+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}d=d-1|0;b=Uf(b,v[h+12>>2]);v[g+4>>2]=b;v[g>>2]=b;t=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;b=0;while(1){if((b|0)!=2){m=(b<<2)+g|0;f=v[m>>2];e=(g+16|0)+(b<<3)|0;l=v[e+4>>2];k=v[e>>2];v[e+4>>2]=k;n=f<<8;f=n;f=oia(A,C,f,f>>31);j=db;D=e;e=Sb(k,-16777216,16776704);k=oia(y,z,e,e>>31);f=k+f|0;e=db+j|0;e=f>>>0<k>>>0?e+1|0:e;j=f;f=Sb(l,-16777216,16776704);l=oia(w,x,f,f>>31);f=j+l|0;e=db+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[D>>2]=e-(t&n);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],p);Lb(g+8|0,r,s);c=c+8|0;continue a}else{f=(v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31;Bd(v[h+8>>2],(u[(f<<1|2)+e>>1]+u[e+((f&2147483646)<<1)>>1]|0)/8<<16>>16);Ad(v[h+8>>2],4);Lb(g+56|0,v[h>>2],v[h+4>>2]);b=b-1|0;continue}}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g- -64|0}function n4(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=ab-80|0;ab=j;a:{b:{c:{k=No(1,32);d:{e:{if(!k){a=aa(4)|0;gn(a);v[22452]=0;U(110,a|0,88408,25);a=v[22452];v[22452]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:905;c=Rg(j- -64|0);f:{g:{h:{if(!i){break h}while(1){d=v[i>>2];if(!d){break h}e=v[i+4>>2];i:{if(e){v[22452]=0;d=Q(55,j+48|0,d|0)|0;f=v[22452];v[22452]=0;j:{if((f|0)!=1){v[22452]=0;f=Q(916,c|0,d|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break j}v[22452]=0;Q(264,f|0,e|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;pb(d);break f}v[22452]=0;d=Q(55,j+48|0,d|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break g}_r(c,d)}pb(d);i=i+8|0;continue}}d=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[22452]=0;a=T(788,96)|0;i=v[22452];v[22452]=0;k:{l:{m:{if((i|0)!=1){v[j+44>>2]=d;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=v[k+4>>2];d=v[k>>2];v[22452]=0;b=Q(917,d|0,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break m}v[j+48>>2]=b;b=v[Oo(j+24|0,j+48|0)>>2];d=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=d;v[22452]=0;d=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=d;da(947,a|0,j+8|0,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break l}v[k+28>>2]=a;oe(j+48|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;Qk(c);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;oe(j+48|0)}xb(a);break f}i=V(0)|0;O()|0}Qk(c);_(i|0)|0;v[22452]=0;W(911,11314,k|0,g|0,h|0);a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)!=1){a=v[k+28>>2];if(a){eb[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){xb(a);v[k+20>>2]=0}xb(k);k=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)==1){break b}}_(i|0)|0;k=0;v[22452]=0;W(911,11314,0,g|0,h|0);a=v[22452];v[22452]=0;if((a|0)==1){break c}$()}ab=j+80|0;return k|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Gb()}L()}function D4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=ab-80|0;ab=e;d=v[b+4>>2];a:{if(!d){break a}f=v[b>>2];h=w[Gk(f,d)|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}Pk(e+56|0,f,d,d-1|0);d=v[e+60>>2];v[b>>2]=v[e+56>>2];v[b+4>>2]=d}f=e+56|0;Dd(f);d=v[e+56>>2];Dd(e+40|0);d=Fk(d,v[e+44>>2],b);Dd(f);b:{c:{d:{e:{if((d|0)==v[e+60>>2]){d=v[b>>2];f=v[b+4>>2];a=kc(e+72|0,21598);if(yc(d,f,v[a>>2],v[a+4>>2])){a=aa(8)|0;v[22452]=0;c=Q(55,e+56|0,10443)|0;b=v[22452];v[22452]=0;if((b|0)==1){break d}lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(c);break c}g=0;if(!c){break e}a=aa(8)|0;v[22452]=0;d=Q(938,e+40|0,b|0)|0;b=v[22452];v[22452]=0;f:{g:{h:{if((b|0)!=1){v[22452]=0;U(939,e+56|0,17613,d|0);b=v[22452];v[22452]=0;if((b|0)==1){break h}lc(a,e+56|0);c=0;v[22452]=0;U(110,a|0,58760,928);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;pb(e+56|0);break g}b=P()|0;O()|0;break f}b=P()|0;c=1;O()|0}pb(d);if(!c){break c}}ba(a|0);break c}if(v[d+4>>2]!=2){a=aa(8)|0;v[22452]=0;c=Q(55,e+56|0,11558)|0;b=v[22452];v[22452]=0;if((b|0)!=1){lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(c);break c}b=P()|0;O()|0;ba(a|0);break c}d=v[b>>2];f=v[b+4>>2];c=kc(e+32|0,21598);if(yc(d,f,v[c>>2],v[c+4>>2])){a=aa(8)|0;v[22452]=0;c=Q(55,e+56|0,10443)|0;b=v[22452];v[22452]=0;if((b|0)!=1){lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(c);break c}b=P()|0;O()|0;ba(a|0);break c}d=v[b>>2];f=v[b+4>>2];c=kc(e+24|0,7677);if(yc(d,f,v[c>>2],v[c+4>>2])){g=1;if(!zd(w[a+28|0])){break e}g=65536/+y[v[a+24>>2]+480244>>2];break e}d=v[b>>2];f=v[b+4>>2];c=kc(e+16|0,7729);if(yc(d,f,v[c>>2],v[c+4>>2])){g=1;if(!zd(w[a+28|0])){break e}g=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break e}c=v[b>>2];d=v[b+4>>2];b=kc(e+8|0,7747);g=0;if(!yc(c,d,v[b>>2],v[b+4>>2])){break e}g=+y[v[a+24>>2]+480236>>2]*152587890625e-16}ab=e+80|0;return+g}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function AN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;c=ab-176|0;ab=c;h=1;k=2;d=v[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=k>>>0){m=m>>>2|0;w=B(h,3);x=h<<1;i=0;b:while(1){if((i|0)==(m|0)){k=k+2|0;h=h<<2;d=v[a+12>>2];continue a}d=Hc(v[a>>2],i<<1);KK(c+160|0,A[d>>3],A[d+8>>3]);d=Hc(v[a>>2],i);KK(c+144|0,A[d>>3],A[d+8>>3]);ei(c+128|0,A[c+144>>3],A[c+152>>3],A[c+160>>3],A[c+168>>3]);d=i<<k;f=h+d|0;y=d>>>0>f>>>0?d:f;while(1)if((d|0)==(y|0)){i=i+1|0;continue b}else{f=v[b>>2];e=Hc(f,d);j=v[e+12>>2];v[c+120>>2]=v[e+8>>2];v[c+124>>2]=j;j=v[e+4>>2];v[c+112>>2]=v[e>>2];v[c+116>>2]=j;l=d+h|0;e=Hc(f,l);n=A[e+8>>3];o=A[e>>3];r=d+x|0;e=Hc(f,r);j=v[e+12>>2];v[c+104>>2]=v[e+8>>2];v[c+108>>2]=j;j=v[e+4>>2];v[c+96>>2]=v[e>>2];v[c+100>>2]=j;s=d+w|0;f=Hc(f,s);t=A[f+8>>3];u=A[f>>3];e=c+80|0;f=c+112|0;Kk(e,f,o,n);j=c- -64|0;Yi(j,f,o,n);g=c+96|0;Kk(c+48|0,g,u,t);f=c+16|0;Yi(f,g,u,t);ei(c+32|0,0,1,A[c+16>>3],A[c+24>>3]);Kk(f,e,A[c+48>>3],A[c+56>>3]);g=Hc(v[b>>2],d);p=v[c+28>>2];v[g+8>>2]=v[c+24>>2];v[g+12>>2]=p;p=v[c+20>>2];v[g>>2]=v[c+16>>2];v[g+4>>2]=p;Kk(c,j,A[c+32>>3],A[c+40>>3]);ei(f,A[c+160>>3],A[c+168>>3],A[c>>3],A[c+8>>3]);g=Hc(v[b>>2],l);l=v[c+28>>2];v[g+8>>2]=v[c+24>>2];v[g+12>>2]=l;l=v[c+20>>2];v[g>>2]=v[c+16>>2];v[g+4>>2]=l;Yi(c,e,A[c+48>>3],A[c+56>>3]);ei(f,A[c+144>>3],A[c+152>>3],A[c>>3],A[c+8>>3]);e=Hc(v[b>>2],r);g=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=g;g=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=g;Yi(c,j,A[c+32>>3],A[c+40>>3]);ei(f,A[c+128>>3],A[c+136>>3],A[c>>3],A[c+8>>3]);f=Hc(v[b>>2],s);e=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=e;e=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=e;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}a=q>>>1|0;d=0;while(1){if((a|0)==(d|0)){break c}i=v[b>>2];k=a+d|0;h=Hc(i,k);m=Hc(i,d);n=A[h>>3];o=A[h+8>>3];Yi(c+160|0,m,n,o);h=Hc(v[b>>2],k);i=v[c+172>>2];v[h+8>>2]=v[c+168>>2];v[h+12>>2]=i;i=v[c+164>>2];v[h>>2]=v[c+160>>2];v[h+4>>2]=i;Fx(Hc(v[b>>2],d),n,o);d=d+1|0;continue}}ab=c+176|0}function Zaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;f=ab-32|0;ab=f;a:{b:{c:{k=v[a+12>>2];m=v[a+8>>2];d:{if((k|0)<=1&m>>>0<=805306368|(k|0)<=0){if((k|0)>=-2&m>>>0>=3489660928|(k|0)>-2){break c}if((k|0)==-2&m>>>0>2147483647|k>>>0>4294967294){break d}break b}if((k|0)==1&m>>>0>2147483648|k>>>0>1){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}x=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;g=e+(f+16|0)|0;e=a+e|0;v[g>>2]=v[e+44>>2];v[g+4>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+40>>2];o=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;e:while(1){if(d){b=v[f+8>>2];s=((((v[f+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+x|0;b=(b>>>16&65520)+r|0;t=u[b+14>>1];p=u[b+12>>1];w=u[b+10>>1];i=u[b+8>>1];q=u[b+6>>1];g=u[b+4>>1];e=u[b+2>>1];b=u[b>>1];l=0;while(1)if((l|0)==2){y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];j=b;l=b>>31;b=v[a+60>>2];s=b;t=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=v[p>>2];h=(f+16|0)+(b<<3)|0;w=v[h+4>>2];i=v[h>>2];v[h+4>>2]=i;q=e<<8;e=q;e=oia(s,t,e,e>>31);g=db;C=h;h=e;e=Sb(i,-16777216,16776704);e=oia(j,l,e,e>>31);i=h+e|0;h=db+g|0;h=e>>>0>i>>>0?h+1|0:h;e=Sb(w,-16777216,16776704);g=oia(z,A,e,e>>31);i=g+i|0;e=db+h|0;e=g>>>0>i>>>0?e+1|0:e;g=i+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Cc(g,e,24);v[C>>2]=e-(q&y);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;v[c>>2]=v[c>>2]+B(v[f>>2],o>>12);n=b+n|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],n>>12);Lb(f+8|0,m,k);c=c+8|0;d=d-1|0;continue e}else{j=s+(l<<1)|0;v[(l<<2)+f>>2]=(((((((B(u[j-8>>1],e)+B(u[j-12>>1],b)|0)+B(u[j-4>>1],g)|0)+B(u[j>>1],q)|0)+B(i,u[j+4>>1])|0)+B(w,u[j+8>>1])|0)+B(p,u[j+12>>1])|0)+B(t,u[j+16>>1])|0)/32768;l=l+1|0;continue}}break}v[a+40>>2]=n;v[a+36>>2]=o;v[a+20>>2]=o>>12;v[a+24>>2]=n>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+32|0}function aN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=ab-48|0;ab=i;m=Ny(v[a+24>>2],w[a+32|0]);o=ej(m);a:{while(1){b:{u[b>>1]=g;e=g&65535;if(e>>>0>=o>>>0){break b}c:{if(!aq(m,e)){break c}e=v[a>>2];f=ad(e,v[a+4>>2]);h=x[b>>1];if(f>>>0<=h>>>0){v[c>>2]=0;a=1;break a}l=ld(e,h);Rj(i+32|0,v[l>>2]);Yk(i+24|0,v[l>>2],v[l+4>>2]);k=i+40|0;h=v[i+32>>2];f=v[i+36>>2];g=Xk(v[i+24>>2],v[i+28>>2],h,f);d:{if(d&255){e=0;j=ab-16|0;ab=j;v[j+12>>2]=f;v[j+8>>2]=h;v[j+4>>2]=g;e:{if(f){e=32-f|0;v[j>>2]=e;n=-1<<f;f=v[zb(j,j+4|0)>>2];e=n&-1>>>e-f&v[h>>2];if(e){Zb(k,h,nia(e));break e}if((f|0)==(g|0)){_M(k,j+8|0,g);break e}e=h+4|0;g=g-f|0;f=1}else{f=0}while(1){f:{if(!f){e=h;break f}g:{if(g>>>0>=32){f=v[e>>2];if(f){v[j+8>>2]=h;Zb(k,e,nia(f));break e}g=g-32|0;v[j+4>>2]=g;h=e+4|0;break g}v[j+8>>2]=h;if(!g){Zb(k,e,0);break e}h=v[e>>2]&-1>>>32-g;if(!h){Zb(k,e,g);break e}Zb(k,e,nia(h));break e}f=0;continue}f=1;continue}}break d}e=0;j=ab-16|0;ab=j;v[j+12>>2]=f;v[j+8>>2]=h;v[j+4>>2]=g;h:{if(f){e=32-f|0;v[j>>2]=e;n=-1<<f;f=v[zb(j,j+4|0)>>2];e=n&-1>>>e-f&(v[h>>2]^-1);if(e){Zb(k,h,nia(e));break h}if((f|0)==(g|0)){_M(k,j+8|0,g);break h}e=h+4|0;g=g-f|0;f=1}else{f=0}while(1){i:{if(!f){e=h;break i}j:{if(g>>>0>=32){f=v[e>>2];if((f|0)!=-1){v[j+8>>2]=h;Zb(k,e,nia(f^-1));break h}g=g-32|0;v[j+4>>2]=g;h=e+4|0;break j}v[j+8>>2]=h;if(!g){Zb(k,e,0);break h}h=(v[e>>2]^-1)&-1>>>32-g;if(!h){Zb(k,e,g);break h}Zb(k,e,nia(h));break h}f=0;continue}f=1;continue}}}ab=j+16|0;if(d){Yk(i+16|0,v[l>>2],v[l+4>>2]);if(!$M(v[i+40>>2],v[i+44>>2],v[i+16>>2],v[i+20>>2])){break c}v[c>>2]=0;a=1;break a}Yk(i+16|0,v[l>>2],v[l+4>>2]);if($M(v[i+40>>2],v[i+44>>2],v[i+16>>2],v[i+20>>2])^1){Rj(i+8|0,v[l>>2]);p=c,q=$P(v[i+8>>2],v[i+12>>2],v[i+40>>2],v[i+44>>2]),v[p>>2]=q;a=1;break a}e=v[l+4>>2];if(e>>>0>=y[Rb(v[a+24>>2]+484344|0,x[Yb(v[m>>2],x[b>>1])>>1])+12>>2]){break c}v[c>>2]=e;a=1;break a}g=x[b>>1]+1|0;continue}break}u[b>>1]=65535;v[c>>2]=-1;a=0}ab=i+48|0;return a|0}function Dga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0),h=0,i=C(0);d=ab-112|0;ab=d;c=ab-16|0;ab=c;e=b+16|0;PR(c+8|0,e);f=v[c+12>>2];_b(c,a,v[c+8>>2],f);h=v[c+4>>2];if((f|0)==(h|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((f|0)!=(h|0)){Jb(e,0,128)}t[b+79|0]=0;t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;c=d- -64|0;Md(c,a,jg(a));f=bc(d+88|0,c);qb(c);v[22452]=0;c=T(193,f|0)|0;e=v[22452];v[22452]=0;a:{b:{if((e|0)==1){break b}v[22452]=0;R(279,b+4|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}de(d+56|0,v[b+4>>2],v[b+8>>2]);v[22452]=0;W(418,d- -64|0,f|0,v[d+56>>2],v[d+60>>2]);c=v[22452];v[22452]=0;if((c|0)!=1){v[22452]=0;c=T(148,a|0)|0;e=v[22452];v[22452]=0;c:{if((e|0)==1){break c}v[22452]=0;U(181,d+32|0,a|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break c}a=d+32|0;c=bc(d- -64|0,a);qb(a);v[22452]=0;a=T(169,c|0)|0;e=v[22452];v[22452]=0;d:{if((e|0)!=1){e:{f:{if(!a){break f}while(1){g:{v[22452]=0;a=Q(147,c|0,5)|0;e=v[22452];v[22452]=0;if((e|0)==1){break e}if(!a){break f}v[22452]=0;Q(419,c|0,d+28|0)|0;a=v[22452];v[22452]=0;h:{if((a|0)!=1){a=4;if(!Ib(d+28|0,13573,4)){break h}if(!Ib(d+28|0,14092,4)){break h}v[22452]=0;a=T(148,c|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[22452]=0;U(181,d+8|0,c|0,a|0);a=v[22452];v[22452]=0;i:{j:{k:{if((a|0)!=1){e=d+8|0;a=bc(d+32|0,e);qb(e);if(Ib(d+28|0,13573,4)){break k}v[22452]=0;g=C(Ba(420,a|0));a=v[22452];v[22452]=0;if((a|0)==1){break g}z[d+8>>2]=g;v[d+4>>2]=0;v[d>>2]=1065353216;g=z[oA(d+8|0,d+4|0,d)>>2];z[b+144>>2]=g;i=C(D(g));if((i<C(1.1754943508222875e-38)^-1)&(!(i>=C(N))&g==g)){break j}v[b+144>>2]=0;break j}a=P()|0;O()|0;break d}if(Ib(d+28|0,14092,4)){break j}v[22452]=0;a=T(148,a|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break i}v[b+148>>2]=a}qb(d+32|0);continue}}break}a=P()|0;O()|0;qb(d+32|0);break d}qb(c);qb(f);ab=d+112|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0}qb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}qb(f);S(a|0);L()}function _aa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;f=ab-32|0;ab=f;a:{b:{c:{k=v[a+12>>2];m=v[a+8>>2];d:{if((k|0)<=1&m>>>0<=805306368|(k|0)<=0){if((k|0)>=-2&m>>>0>=3489660928|(k|0)>-2){break c}if((k|0)==-2&m>>>0>2147483647|k>>>0>4294967294){break d}break b}if((k|0)==1&m>>>0>2147483648|k>>>0>1){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}y=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;g=e+(f+16|0)|0;e=a+e|0;v[g>>2]=v[e+44>>2];v[g+4>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+40>>2];o=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;e:while(1){if(d){b=v[f+8>>2];s=(((v[f+12>>2]&2147483647)<<1|b>>>31)&-2)+y|0;b=(b>>>16&65520)+r|0;w=u[b+14>>1];p=u[b+12>>1];x=u[b+10>>1];i=u[b+8>>1];q=u[b+6>>1];g=u[b+4>>1];e=u[b+2>>1];b=u[b>>1];l=0;while(1)if((l|0)==2){z=v[a+72>>2];b=v[a+68>>2];A=b;C=b>>31;b=v[a+64>>2];j=b;l=b>>31;b=v[a+60>>2];s=b;w=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=v[p>>2];h=(f+16|0)+(b<<3)|0;x=v[h+4>>2];i=v[h>>2];v[h+4>>2]=i;q=e<<8;e=q;e=oia(s,w,e,e>>31);g=db;D=h;h=e;e=Sb(i,-16777216,16776704);e=oia(j,l,e,e>>31);i=h+e|0;h=db+g|0;h=e>>>0>i>>>0?h+1|0:h;e=Sb(x,-16777216,16776704);g=oia(A,C,e,e>>31);i=g+i|0;e=db+h|0;e=g>>>0>i>>>0?e+1|0:e;g=i+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Cc(g,e,24);v[D>>2]=e-(q&z);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;v[c>>2]=v[c>>2]+B(v[f>>2],o>>12);n=b+n|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],n>>12);Lb(f+8|0,m,k);c=c+8|0;d=d-1|0;continue e}else{j=l+s|0;v[(l<<2)+f>>2]=(((((((B(t[j-4|0],e)+B(t[j-6|0],b)|0)+B(t[j-2|0],g)|0)+B(t[j|0],q)|0)+B(i,t[j+2|0])|0)+B(x,t[j+4|0])|0)+B(p,t[j+6|0])|0)+B(w,t[j+8|0])<<8)/32768;l=l+1|0;continue}}break}v[a+40>>2]=n;v[a+36>>2]=o;v[a+20>>2]=o>>12;v[a+24>>2]=n>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+32|0}function YI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=ab-80|0;ab=j;a:{b:{c:{d:{e:{f:{k=No(1,28);if(!k){a=aa(4)|0;gn(a);v[22452]=0;U(110,a|0,88408,25);a=v[22452];v[22452]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:905;c=Rg(j- -64|0);g:{h:{i:{if(!i){break i}while(1){d=v[i>>2];if(!d){break i}e=v[i+4>>2];j:{if(e){v[22452]=0;d=Q(55,j+48|0,d|0)|0;f=v[22452];v[22452]=0;k:{if((f|0)!=1){v[22452]=0;f=Q(916,c|0,d|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break k}v[22452]=0;Q(264,f|0,e|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;pb(d);break g}v[22452]=0;d=Q(55,j+48|0,d|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break h}_r(c,d)}pb(d);i=i+8|0;continue}}d=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[22452]=0;a=T(788,80)|0;i=v[22452];v[22452]=0;l:{m:{n:{if((i|0)!=1){v[j+44>>2]=d;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=v[k+4>>2];d=v[k>>2];v[22452]=0;b=Q(917,d|0,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break n}v[j+48>>2]=b;b=v[Oo(j+24|0,j+48|0)>>2];d=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=d;v[22452]=0;d=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=d;da(918,a|0,j+8|0,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break m}v[k+24>>2]=a;oe(j+48|0);Qk(c);i=k;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;oe(j+48|0)}xb(a);break g}i=V(0)|0;O()|0}Qk(c);_(i|0)|0;v[22452]=0;W(911,15114,k|0,g|0,h|0);a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Zr(a)}xb(a);i=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){xb(a);v[k+20>>2]=0}xb(k);break d}i=V(0)|0;O()|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;i=0;v[22452]=0;W(911,15114,0,g|0,h|0);a=v[22452];v[22452]=0;if((a|0)==1){break c}$()}ab=j+80|0;return i|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Gb()}L()}function xF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!d){break k}h=v[d>>2];if(!h){break k}if(!a){g=c;break j}v[d>>2]=0;g=c;break i}l:{if(!v[v[114936]>>2]){if(!a){break l}if(!c){break a}d=c;while(1){g=t[e|0];if(g){v[a>>2]=g&57343;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-d|0}if(!a){g=c;d=0;break g}g=c;d=0;break h}return Pf(e)}d=1;break g}d=1}while(1){if(!d){if(!g){break a}while(1){m:{f=w[e|0];h=f-1|0;n:{o:{if(h>>>0>126){d=f;break o}if(e&3|g>>>0<5){break n}p:{while(1){d=v[e>>2];if((d|d-16843009)&-2139062144){break p}v[a>>2]=d&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;g=g-4|0;if(g>>>0>4){continue}break}d=w[e|0]}f=d&255;h=f-1|0}if(h>>>0>126){break m}}v[a>>2]=f;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;h=v[(f<<2)+79536>>2];d=1;continue}d=w[e|0];f=d>>>3|0;if((f-16|f+(h>>26))>>>0>7){break f}q:{r:{f=e+1|0;d=d-128|h<<6;s:{if((d|0)>=0){break s}i=w[f|0]-128|0;if(i>>>0>63){break r}f=e+2|0;d=i|d<<6;if((d|0)>=0){break s}f=w[f|0]-128|0;if(f>>>0>63){break r}d=f|d<<6;f=e+3|0}e=f;v[a>>2]=d;g=g-1|0;a=a+4|0;break q}v[114934]=25;e=e-1|0;break c}d=0;continue}}while(1){t:{if(!d){u:{v:{d=w[e|0];if(!(e&3|d-1>>>0>126)){d=v[e>>2];if(!((d|d-16843009)&-2139062144)){break v}}f=e;break u}while(1){g=g-4|0;d=v[e+4>>2];f=e+4|0;e=f;if(!((d-16843009|d)&-2139062144)){continue}break}}e=d&255;if(e-1>>>0<=126){e=f+1|0;g=g-1|0;break t}h=e-194|0;if(h>>>0>50){e=f;break e}e=f+1|0;h=v[(h<<2)+79536>>2];d=1;continue}d=w[e|0]>>>3|0;if((d-16|d+(h>>26))>>>0>7){break f}d=e+1|0;w:{if(!(h&33554432)){break w}if((w[d|0]&192)!=128){e=e-1|0;break d}d=e+2|0;if(!(h&524288)){break w}if((w[d|0]&192)!=128){e=e-1|0;break d}d=e+3|0}e=d;g=g-1|0}d=0;continue}}e=e-1|0;if(h){break d}d=w[e|0]}if(d&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-g|0}v[114934]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c}function Sk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Bb(a);d=ub(c);v[22452]=0;R(46,a|0,d|0);d=v[22452];v[22452]=0;d:{if((d|0)!=1){e:{while(1){if(ub(c)>>>0>b>>>0){d=v[Mj(c,b)>>2];f:{if(d>>>0<=127){v[22452]=0;R(47,a|0,d<<24>>24);d=v[22452];v[22452]=0;if((d|0)!=1){break f}break e}v[22452]=0;R(47,a|0,63);d=v[22452];v[22452]=0;if((d|0)==1){break e}}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Bb(a);d=ub(c);v[22452]=0;R(46,a|0,d|0);d=v[22452];v[22452]=0;g:{if((d|0)!=1){h:{while(1){if(ub(c)>>>0>b>>>0){d=v[Mj(c,b)>>2];i:{if(d>>>0<=255){v[22452]=0;R(47,a|0,d<<24>>24);d=v[22452];v[22452]=0;if((d|0)!=1){break i}break h}v[22452]=0;R(47,a|0,63);d=v[22452];v[22452]=0;if((d|0)==1){break h}}b=b+1|0;continue}break}break g}}break a}return;case 3:up(a,c,49744);return;case 5:up(a,c,50768);return;case 4:up(a,c,51792);return;case 6:up(a,c,52816);return;default:a=aa(8)|0;v[22452]=0;Q(45,a|0,11013)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;ba(a|0);S(b|0);L();case 0:break c}}e=ab-16|0;ab=e;f=Bb(a);j:{while(1){k:{l:{m:{n:{if(ub(c)>>>0>g>>>0){b=v[Mj(c,g)>>2];if(b>>>0>=2097152){v[22452]=0;R(47,f|0,63);a=v[22452];v[22452]=0;if((a|0)!=1){break l}break k}a=0;while(1){if((a|0)==6){b=7;a=6;break m}d=b&63;t[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(!a){v[22452]=0;R(47,f|0,t[e+10|0]);break n}b=a+1|0;if((b|0)!=2){break m}a=1;b=2;if((d|0)!=1){break m}v[22452]=0;R(47,f|0,t[e+10|0]|64);break n}ab=e+16|0;break j}a=v[22452];v[22452]=0;if((a|0)!=1){break l}break k}i=(-1<<b^-1)<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break l}o:{if((a|0)==(b|0)){a=w[j|0];v[22452]=0;R(47,f|0,(a|i)<<24>>24);h=v[22452];v[22452]=0;a=d;break o}v[22452]=0;a=a-1|0;R(47,f|0,t[a+(e+10|0)|0]|-128);h=v[22452];v[22452]=0}if((h|0)!=1){continue}break}break k}g=g+1|0;continue}break}a=P()|0;O()|0;pb(f);S(a|0);L()}return}ia(a|0,88528,24);L()}b=P()|0;O()|0;pb(a);S(b|0);L()}function je(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=ab-16|0;ab=h;a:{if(jc(v[a>>2],v[a+4>>2])){break a}e=v[b+4>>2];if(e>>>0>=y[a+12>>2]){break a}c=x[b+8>>1];k=v[v[a+48>>2]+12>>2];f=oj(k);if(c>>>0>=f>>>0&(c|0)!=65535){break a}d=(c|0)==65535;l=d?f-1|0:c;f=d?0:c;c=Qc(a,e,f);g=w[b+12|0];i=g&4;b:{c:{if(g&2){break c}j=w[b+10|0];e=c;d=f;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!i){if((j|0)!=w[e+3|0]){break d}break b}if((j|0)==w[e+2|0]){break b}}e=e+6|0;d=d+1|0;continue}}j=l&65535;d=c;e=f;while(1){if(j>>>0>=(e&65535)>>>0){e:{if(!i){if(w[d+3|0]){break e}t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break b}if(w[d+2|0]){break e}t[d+2|0]=w[b+10|0];t[d+4|0]=w[b+11|0];break b}d=d+6|0;e=e+1|0;continue}break}f:{if(!(g&1)){break f}d=v[k+480180>>2]&2;g:{h:{if(!i){while(1){if((f&65535)>>>0<=(l&65535)>>>0){i:{j:{switch(w[c+3|0]-9|0){case 4:if(!zS(v[v[k+8>>2]+88>>2])){break i}d=1;t[c+2|0]=1;t[c+4|0]=w[c+5|0];t[c+3|0]=w[b+10|0];t[c+5|0]=w[b+11|0];break a;case 0:break j;default:break i}}k:{if(d){e=w[c+5|0];if(e>>>0>128){break i}t[c+2|0]=2;t[c+3|0]=w[b+10|0];a=1;break k}t[c+2|0]=2;t[c+3|0]=w[b+10|0];e=w[c+5|0];a=2}t[c+4|0]=a+e>>>a;t[c+5|0]=w[b+11|0];break b}c=c+6|0;f=f+1|0;continue}break}if(!i){break h}}e=w[b+11|0];f=13;l:{switch(w[b+10|0]-1|0){case 1:f=9;e=pm(B(d?2:4,e));break;case 0:break l;default:break g}}t[b+11|0]=e;t[b+10|0]=f;g=g&254;t[b+12|0]=g;break g}c=w[b+11|0];t[h+14|0]=c;e=!d;d=w[b+10|0];m:{n:{if(!(e|(d|0)!=9)){if(c>>>0>128){break m}d=2;c=(c&254)>>>1|0;break n}t[h+15|0]=d;if(!lq(h+15|0,h+14|0,1)){break m}d=w[h+15|0];if(!d){break m}g=w[b+12|0];c=w[h+14|0]}t[b+11|0]=c;t[b+10|0]=d;t[b+12|0]=g&254}g=w[b+12|0]}d=1;if(g&1){break f}t[b+12|0]=g^4;if(je(a,b)){break a}}d=0;o:{p:{switch(v[b>>2]-1|0){case 0:c=v[b+4>>2]+1|0;if(c>>>0>=y[a+12>>2]){break a}v[b+4>>2]=c;break o;case 1:break p;default:break a}}c=v[b+4>>2];if(!c){break a}v[b+4>>2]=c-1}t[b+12|0]=w[b+12|0]|1;d=je(a,b);break a}d=1}ab=h+16|0;return d}function BN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;c=ab-176|0;ab=c;f=v[a+12>>2];i=1<<f;a:{if(!(f&1)){i=i>>>2|0;h=1;break a}k=i>>>1|0;f=0;while(1){if((f|0)==(k|0)){i=i>>>3|0;h=2;f=v[a+12>>2]}else{j=v[b>>2];d=f+k|0;h=Hc(j,d);e=Hc(j,f);l=A[h>>3];m=A[h+8>>3];Yi(c+160|0,e,l,m);h=Hc(v[b>>2],d);j=v[c+172>>2];v[h+8>>2]=v[c+168>>2];v[h+12>>2]=j;j=v[c+164>>2];v[h>>2]=v[c+160>>2];v[h+4>>2]=j;Fx(Hc(v[b>>2],f),l,m);f=f+1|0;continue}break}}j=f&-2;b:while(1){if(j){u=B(i,3);w=i<<1;k=0;c:while(1){if((h|0)==(k|0)){j=j-2|0;i=i>>>2|0;h=h<<2;continue b}d=v[a>>2];f=Hc(d,k<<1);d=Hc(d,k);l=A[d>>3];m=A[d+8>>3];p=A[f>>3];q=A[f+8>>3];ei(c+160|0,l,m,p,q);f=k<<j;d=i+f|0;x=d>>>0<f>>>0?f:d;while(1)if((f|0)==(x|0)){k=k+1|0;continue c}else{g=v[b>>2];d=Hc(g,f);e=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=e;e=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=e;e=c+128|0;r=f+i|0;d=Hc(g,r);ei(e,p,q,A[d>>3],A[d+8>>3]);s=f+w|0;d=Hc(v[b>>2],s);ei(c+112|0,l,m,A[d>>3],A[d+8>>3]);y=A[c+160>>3];z=A[c+168>>3];t=f+u|0;d=Hc(v[b>>2],t);ei(c+96|0,y,z,A[d>>3],A[d+8>>3]);g=c+80|0;d=c+144|0;Kk(g,d,A[c+112>>3],A[c+120>>3]);n=c- -64|0;Yi(n,d,A[c+112>>3],A[c+120>>3]);Kk(c+48|0,e,A[c+96>>3],A[c+104>>3]);d=c+16|0;Rl(d,-0,-1);Yi(c,e,A[c+96>>3],A[c+104>>3]);ei(c+32|0,A[c+16>>3],A[c+24>>3],A[c>>3],A[c+8>>3]);Kk(d,g,A[c+48>>3],A[c+56>>3]);e=Hc(v[b>>2],f);o=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=o;o=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=o;Yi(d,g,A[c+48>>3],A[c+56>>3]);e=Hc(v[b>>2],r);g=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=g;g=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=g;Kk(d,n,A[c+32>>3],A[c+40>>3]);e=Hc(v[b>>2],s);g=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=g;g=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=g;Yi(d,n,A[c+32>>3],A[c+40>>3]);d=Hc(v[b>>2],t);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;f=f+1|0;continue}}}break}ab=c+176|0}function S2(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),k=0,m=C(0),n=0,o=0;d=ab-16|0;ab=d;a:{b:{c:{d:{switch(b-1|0){case 0:c=z[a+48>>2];a=v[a+48>>2];e:{f:{g:{if((a|0)<=8388607){e=C(C(-1)/C(c*c));if(!(a&2147483647)){break e}e=C(C(c-c)/C(0));if((a|0)<0){break e}a=(p(C(c*C(33554432))),j(2));b=-152;break g}if(a>>>0>2139095039){break f}b=-127;c=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;m=C((a>>>23|0)+b|0);c=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));f=C(c*C(c*C(.5)));g=C(c/C(c+C(2)));h=C(g*g);i=C(h*h);e=c;c=(l(2,(p(C(c-f)),j(2))&-4096),q());f=C(C(g*C(f+C(C(h*C(C(i*C(.2849878668785095))+C(.6666666269302368)))+C(i*C(C(i*C(.24279078841209412))+C(.40000972151756287))))))+C(C(e-c)-f));c=C(C(m*C(.3010292053222656))+C(C(c*C(.434326171875))+C(C(f*C(.434326171875))+C(C(m*C(7.903415166765626e-7))+C(C(f+c)*C(-3168997136526741e-20))))))}e=c}c=C(e*C(2e3));if(!(C(D(c))<C(2147483648))){break c}a=~~c;break b;case 1:a=(B(v[v[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:b=ab-16|0;ab=b;h:{i:{j:{k:{a=w[v[a+24>>2]+24648|0];if(a>>>0>=6){a=aa(8)|0;v[22452]=0;b=Q(55,b|0,5084)|0;d=v[22452];v[22452]=0;if((d|0)==1){break k}lc(a,b);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break i}d=P()|0;O()|0;pb(b);break j}ab=b+16|0;a=v[(a<<24>>24<<2)+58504>>2];break h}d=P()|0;O()|0;ba(a|0)}S(d|0)}L()}break b;case 3:v[d>>2]=0;b=ab-80|0;ab=b;k=v[a+24>>2]+24604|0;a=v[k+32>>2];v[b+40>>2]=a;v[b>>2]=v[k+36>>2];n=b+40|0;o=v[Ee(n,b)>>2];l:{if(v[yp(n)+32>>2]==(a|0)){a=-1;if(v[k+36>>2]==v[yp(b)+36>>2]){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}v[d>>2]=a;ab=b+80|0;a=v[d>>2];break b;default:break d}}a=aa(8)|0;v[22452]=0;d=Q(55,d|0,10346)|0;b=v[22452];v[22452]=0;m:{if((b|0)!=1){lc(a,d);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}b=P()|0;O()|0;pb(d);break m}b=P()|0;O()|0;ba(a|0)}S(b|0);L()}a=-2147483648}ab=d+16|0;return a|0}L()}function Kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;d=ab-1120|0;ab=d;v[d+1116>>2]=c;i=ZA(d+56|0,b);q=Yp(i);e=Pb(a);v[22452]=0;a=T(193,b|0)|0;c=v[22452];v[22452]=0;a:{if((c|0)!=1){v[d+16>>2]=a;v[d+48>>2]=85899345;s=d,z=B(v[zb(d+16|0,d+48|0)>>2],50),v[s+32>>2]=z;a=v[zb(d+1116|0,d+32|0)>>2];v[22452]=0;R(317,e|0,a|0);a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;h=T(329,d+32|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;f=Q(330,d+16|0,8192)|0;a=v[22452];v[22452]=0;b:{if((a|0)!=1){c=v[h>>2];a=0;while(1){if((a|0)!=256){g=Fb(c,a);t[g+2|0]=a;u[g>>1]=8192;a=a+1|0;continue}break}l=9;c:{d:while(1){g=0;m=257;while(1){r=l&255;e:{while(1){j=m&65535;while(1){v[22452]=0;n=Q(155,i|0,r|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}k=n&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(Ic(v[e>>2],v[e+4>>2])>>>0>=y[d+1116>>2]){break e}if((k|0)==256){l=9;continue d}a=j>>>0>k>>>0?n:g;c=v[h>>2];p=8192;while(1){a=a&65535;c=Fb(c,a);p=p-1|0;o=p&65535;s=Cb(v[f>>2],o),z=w[c+2|0],t[s|0]=z;c=v[h>>2];a=x[Fb(c,a)>>1];if(a>>>0<8192){continue}break}$b(d+8|0,wb(v[e+4>>2]));s=d,z=wb(v[f>>2]),v[s+48>>2]=z;a=le(d+48|0,o);c=wb(v[f+4>>2]);v[22452]=0;W(318,e|0,v[d+8>>2],a|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=v[f>>2];v[22452]=0;R(331,e|0,Cb(a,o)|0);a=v[22452];v[22452]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){g=n;continue}if(Ic(v[e>>2],v[e+4>>2])>>>0>=y[d+1116>>2]){continue}break}a=w[Cb(v[f>>2],o)|0];c=Fb(v[h>>2],j);u[c>>1]=g;t[c+2|0]=a;a=m+1|0;m=8192;g=n;c=a&65535;if((c|0)==8192){continue}break}l=((c|0)==1<<r)+l|0;m=a;continue}break}break}a=Yp(i);v[22452]=0;Q(146,b|0,((a-q|0)+3&-4)+q|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}Xb(f);ec(h);qb(i);ab=d+1120|0;return}a=P()|0;O()|0;Xb(f);break b}a=P()|0;O()|0}ec(h);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Xb(e);qb(i);S(a|0);L()}function c5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=0,h=C(0),i=C(0),j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=C(0),t=0,u=0,w=0,x=0,y=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=C(0),M=C(0),N=C(0),O=C(0),P=C(0);n=a+44|0;if(Ih(n)){y=Gd(n,0);A=Gd(n,1);B=dd(n,0);D=dd(n,1);o=v[a+4300>>2];l=o+v[a+4292>>2]|0;f=v[a+4288>>2]+o|0;k=a+4304|0;q=v[a+4296>>2];j=q+1|0;t=j+v[a+4272>>2]&4095;m=k+(t<<4)|0;u=j+v[a+4284>>2]&4095;g=((u<<4)+k|0)+12|0;w=j+v[a+4280>>2]&4095;r=((w<<4)+k|0)+8|0;x=j+v[a+4276>>2]&4095;F=((x<<4)+k|0)+4|0;G=a+69840|0;H=a+78032|0;E=d;while(1){if(E){t=t-1&4095;j=(t<<4)+k|0;e=z[j>>2];I=f&1023;f=(I<<3)+G|0;p=z[f+4>>2];K=z[g>>2];L=z[r>>2];M=z[F>>2];N=z[m>>2];O=z[A>>2];P=z[y>>2];x=x-1&4095;m=(x<<4)+k|0;i=z[m+4>>2];s=z[a+4232>>2];h=C(C(i*C(.6180340051651001))+C(z[f>>2]*s));g=o<<3;f=g+G|0;z[f+4>>2]=i+C(h*C(-.6180340051651001));i=e;e=C(C(p*s)+C(e*C(-.6180340051651001)));z[f>>2]=i+C(e*C(.6180340051651001));z[j>>2]=h;z[m+4>>2]=e;J=l&1023;r=(J<<3)+H|0;p=z[r+4>>2];w=w-1&4095;f=(w<<4)+k|0;h=z[f+8>>2];u=u-1&4095;l=(u<<4)+k|0;i=z[l+12>>2];s=z[a+4236>>2];e=C(C(i*C(.6180340051651001))+C(z[r>>2]*s));g=g+H|0;z[g+4>>2]=i+C(e*C(-.6180340051651001));i=h;h=C(C(p*s)+C(h*C(-.6180340051651001)));z[g>>2]=i+C(h*C(.6180340051651001));z[f+8>>2]=e;z[l+12>>2]=h;h=e;e=C(P+C(1.0000000031710769e-30));z[B>>2]=h+C(C(e*z[a+4224>>2])+z[j>>2]);h=C(O+C(1.0000000031710769e-30));z[D>>2]=C(C(h*z[a+4224>>2])+z[m+4>>2])+z[l+12>>2];g=(q<<4)+k|0;i=e;e=z[a+4228>>2];p=C(i*e);z[g>>2]=p+C(C(z[j>>2]*z[a+4240>>2])+C(N*z[a+4244>>2]));e=C(h*e);z[g+4>>2]=e+C(C(z[m+4>>2]*z[a+4248>>2])+C(M*z[a+4252>>2]));z[g+8>>2]=C(C(z[f+8>>2]*z[a+4256>>2])+C(L*z[a+4260>>2]))-e;z[g+12>>2]=p+C(C(z[l+12>>2]*z[a+4264>>2])+C(K*z[a+4268>>2]));g=l+12|0;r=f+8|0;F=m+4|0;E=E-1|0;l=J-1|0;f=I-1|0;D=D+4|0;B=B+4|0;A=A+4|0;y=y+4|0;o=o-1&1023;q=q-1&4095;m=j;continue}else{v[a+4300>>2]=o;v[a+4296>>2]=q;ai(a,b,c,dd(n,0),dd(n,1),d)}break}}}function bba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;f=ab-32|0;ab=f;a:{b:{c:{k=v[a+12>>2];m=v[a+8>>2];d:{if((k|0)<=1&m>>>0<=805306368|(k|0)<=0){if((k|0)>=-2&m>>>0>=3489660928|(k|0)>-2){break c}if((k|0)==-2&m>>>0>2147483647|k>>>0>4294967294){break d}break b}if((k|0)==1&m>>>0>2147483648|k>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}t=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;g=e+(f+16|0)|0;e=a+e|0;v[g>>2]=v[e+44>>2];v[g+4>>2]=v[e+48>>2];b=b+1|0;continue}break}w=v[a+24>>2];x=v[a+20>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;e:while(1){f:{if(!d){b=0;while(1){if((b|0)==2){break f}c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}}b=v[f+8>>2];q=((((v[f+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(b>>>16&65520)+p|0;r=u[b+14>>1];n=u[b+12>>1];s=u[b+10>>1];i=u[b+8>>1];o=u[b+6>>1];g=u[b+4>>1];e=u[b+2>>1];b=u[b>>1];l=0;while(1)if((l|0)==2){y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];j=b;l=b>>31;b=v[a+60>>2];q=b;r=b>>31;b=0;while(1){if((b|0)!=2){n=(b<<2)+f|0;e=v[n>>2];h=(f+16|0)+(b<<3)|0;s=v[h+4>>2];i=v[h>>2];v[h+4>>2]=i;o=e<<8;e=o;e=oia(q,r,e,e>>31);g=db;C=h;h=e;e=Sb(i,-16777216,16776704);e=oia(j,l,e,e>>31);i=h+e|0;h=db+g|0;h=e>>>0>i>>>0?h+1|0:h;e=Sb(s,-16777216,16776704);g=oia(z,A,e,e>>31);i=g+i|0;e=db+h|0;e=g>>>0>i>>>0?e+1|0:e;g=i+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Cc(g,e,24);v[C>>2]=e-(o&y);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],x);v[c+4>>2]=v[c+4>>2]+B(w,v[f+4>>2]);Lb(f+8|0,m,k);c=c+8|0;d=d-1|0;continue e}else{j=q+(l<<1)|0;v[(l<<2)+f>>2]=(((((((B(u[j-8>>1],e)+B(u[j-12>>1],b)|0)+B(u[j-4>>1],g)|0)+B(u[j>>1],o)|0)+B(i,u[j+4>>1])|0)+B(s,u[j+8>>1])|0)+B(n,u[j+12>>1])|0)+B(r,u[j+16>>1])|0)/32768;l=l+1|0;continue}}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+32|0}function LZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=ab-16|0;ab=j;k=fw(g);o=Nv(g);Eg(j,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[22452]=0;g=Q(1129,k|0,g<<24>>24)|0;i=v[22452];v[22452]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[22452]=0;g=Q(1129,k|0,48)|0;h=v[22452];v[22452]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;g=t[i+1|0];v[22452]=0;g=Q(1129,k|0,g|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];gd();if(!LF(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];gd();if(!Dj(h)){break d}g=g+1|0;continue}}e:{if(pd(j)){h=v[f>>2];v[22452]=0;W(1123,k|0,i|0,g|0,h|0);h=v[22452];v[22452]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i<<2);break e}rl(i,g);v[22452]=0;q=T(1121,o|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){ir((i-a<<2)+d|0,v[f>>2]);break e}f:{if(t[oc(j,l)|0]<=0){break f}if(t[oc(j,l)|0]!=(m|0)){break f}m=v[f>>2];v[f>>2]=m+4;v[m>>2]=q;l=(ub(j)-1>>>0>l>>>0)+l|0;m=0}p=t[h|0];v[22452]=0;p=Q(1129,k|0,p|0)|0;n=v[22452];v[22452]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+4;v[n>>2]=p;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=w[g|0];if((i|0)==46){v[22452]=0;i=T(1124,o|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break a}l=v[f>>2];h=l+4|0;v[f>>2]=h;v[l>>2]=i;g=g+1|0;break g}v[22452]=0;i=Q(1129,k|0,i<<24>>24)|0;h=v[22452];v[22452]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=i;g=g+1|0;continue}break}h=v[f>>2]}v[22452]=0;W(1123,k|0,g|0,c|0,h|0);i=v[22452];v[22452]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g<<2)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;pb(j);ab=j+16|0;return}a=P()|0;O()|0;pb(j);S(a|0);L()}function Ar(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return yd(b)}if(b>>>0>=4294967232){v[114934]=48;return 0}e=b>>>0<11?16:b+11&-8;h=a-4|0;i=v[h>>2];c=i&-8;a:{b:{if(!(i&3)){if(e>>>0<256|c>>>0<(e|4)>>>0){break b}if(c-e>>>0<=v[115057]<<1>>>0){break a}break b}g=a-8|0;f=c+g|0;if(c>>>0>=e>>>0){b=c-e|0;if(b>>>0<16){break a}v[h>>2]=i&1|e|2;c=e+g|0;v[c+4>>2]=b|3;v[f+4>>2]=v[f+4>>2]|1;xG(c,b);return a}if(v[114943]==(f|0)){c=c+v[114940]|0;if(c>>>0<=e>>>0){break b}v[h>>2]=i&1|e|2;b=e+g|0;c=c-e|0;v[b+4>>2]=c|1;v[114940]=c;v[114943]=b;return a}if(v[114942]==(f|0)){c=c+v[114939]|0;if(c>>>0<e>>>0){break b}b=c-e|0;c:{if(b>>>0>=16){v[h>>2]=i&1|e|2;d=e+g|0;v[d+4>>2]=b|1;c=c+g|0;v[c>>2]=b;v[c+4>>2]=v[c+4>>2]&-2;break c}v[h>>2]=c|i&1|2;b=c+g|0;v[b+4>>2]=v[b+4>>2]|1;b=0}v[114942]=d;v[114939]=b;return a}d=v[f+4>>2];if(d&2){break b}j=c+(d&-8)|0;if(j>>>0<e>>>0){break b}l=j-e|0;d:{if(d>>>0<=255){b=v[f+8>>2];d=d>>>3|0;c=v[f+12>>2];if((c|0)==(b|0)){n=459748,o=v[114937]&sia(-2,d),v[n>>2]=o;break d}v[b+12>>2]=c;v[c+8>>2]=b;break d}k=v[f+24>>2];c=v[f+12>>2];e:{if((f|0)!=(c|0)){b=v[f+8>>2];v[b+12>>2]=c;v[c+8>>2]=b;break e}f:{b=f+20|0;d=v[b>>2];if(d){break f}b=f+16|0;d=v[b>>2];if(d){break f}c=0;break e}while(1){m=b;c=d;b=c+20|0;d=v[b>>2];if(d){continue}b=c+16|0;d=v[c+16>>2];if(d){continue}break}v[m>>2]=0}if(!k){break d}b=v[f+28>>2];d=(b<<2)+460052|0;g:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break g}n=459752,o=v[114938]&sia(-2,b),v[n>>2]=o;break d}v[(v[k+16>>2]==(f|0)?16:20)+k>>2]=c;if(!c){break d}}v[c+24>>2]=k;b=v[f+16>>2];if(b){v[c+16>>2]=b;v[b+24>>2]=c}b=v[f+20>>2];if(!b){break d}v[c+20>>2]=b;v[b+24>>2]=c}if(l>>>0<=15){v[h>>2]=i&1|j|2;b=g+j|0;v[b+4>>2]=v[b+4>>2]|1;return a}v[h>>2]=i&1|e|2;b=e+g|0;v[b+4>>2]=l|3;c=g+j|0;v[c+4>>2]=v[c+4>>2]|1;xG(b,l);return a}c=yd(b);if(!c){return 0}d=v[h>>2];d=(d&3?-4:-8)+(d&-8)|0;gc(c,a,b>>>0>d>>>0?d:b);xb(a);a=c}return a}function cba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;f=ab-32|0;ab=f;a:{b:{c:{k=v[a+12>>2];m=v[a+8>>2];d:{if((k|0)<=1&m>>>0<=805306368|(k|0)<=0){if((k|0)>=-2&m>>>0>=3489660928|(k|0)>-2){break c}if((k|0)==-2&m>>>0>2147483647|k>>>0>4294967294){break d}break b}if((k|0)==1&m>>>0>2147483648|k>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}w=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;g=e+(f+16|0)|0;e=a+e|0;v[g>>2]=v[e+44>>2];v[g+4>>2]=v[e+48>>2];b=b+1|0;continue}break}x=v[a+24>>2];y=v[a+20>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;e:while(1){f:{if(!d){b=0;while(1){if((b|0)==2){break f}c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}}b=v[f+8>>2];q=(((v[f+12>>2]&2147483647)<<1|b>>>31)&-2)+w|0;b=(b>>>16&65520)+p|0;r=u[b+14>>1];n=u[b+12>>1];s=u[b+10>>1];i=u[b+8>>1];o=u[b+6>>1];g=u[b+4>>1];e=u[b+2>>1];b=u[b>>1];l=0;while(1)if((l|0)==2){z=v[a+72>>2];b=v[a+68>>2];A=b;C=b>>31;b=v[a+64>>2];j=b;l=b>>31;b=v[a+60>>2];q=b;r=b>>31;b=0;while(1){if((b|0)!=2){n=(b<<2)+f|0;e=v[n>>2];h=(f+16|0)+(b<<3)|0;s=v[h+4>>2];i=v[h>>2];v[h+4>>2]=i;o=e<<8;e=o;e=oia(q,r,e,e>>31);g=db;D=h;h=e;e=Sb(i,-16777216,16776704);e=oia(j,l,e,e>>31);i=h+e|0;h=db+g|0;h=e>>>0>i>>>0?h+1|0:h;e=Sb(s,-16777216,16776704);g=oia(A,C,e,e>>31);i=g+i|0;e=db+h|0;e=g>>>0>i>>>0?e+1|0:e;g=i+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Cc(g,e,24);v[D>>2]=e-(o&z);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],y);v[c+4>>2]=v[c+4>>2]+B(x,v[f+4>>2]);Lb(f+8|0,m,k);c=c+8|0;d=d-1|0;continue e}else{j=l+q|0;v[(l<<2)+f>>2]=(((((((B(t[j-4|0],e)+B(t[j-6|0],b)|0)+B(t[j-2|0],g)|0)+B(t[j|0],o)|0)+B(i,t[j+2|0])|0)+B(s,t[j+4|0])|0)+B(n,t[j+6|0])|0)+B(r,t[j+8|0])<<8)/32768;l=l+1|0;continue}}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+32|0}function ai(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0),o=C(0),p=C(0),q=0,r=C(0);m=eb[v[v[a>>2]+136>>2]](a)|0;h=v[a+20>>2];g=m?g:w[h+25|0];j=z[h+144>>2];k=C(1);if(!(eb[v[v[a>>2]+136>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((eb[v[v[a>>2]+152>>2]](a)|0)<=0){break a}if(!PJ(v[a+20>>2])){break a}j=C(C(j+j)+C(-1));k=C(-j)}n=z[a+4196>>2];k=C(k*n);j=C(j*n);h=0;l=a+44|0;m=Gd(l,0);l=Gd(l,1);b:{c:{switch(g|0){case 0:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(C(z[d+g>>2]*j)+C(k*z[g+m>>2]));i=c+g|0;z[i>>2]=z[i>>2]+C(C(z[e+g>>2]*j)+C(k*z[g+l>>2]));h=h+1|0;continue};case 1:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(z[g+m>>2]-C(z[d+g>>2]*j));i=c+g|0;z[i>>2]=z[i>>2]+C(z[g+l>>2]-C(z[e+g>>2]*j));h=h+1|0;continue};case 2:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(z[d+g>>2]-C(z[g+m>>2]*k));i=c+g|0;z[i>>2]=z[i>>2]+C(z[e+g>>2]-C(z[g+l>>2]*k));h=h+1|0;continue};case 3:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]-C(z[d+g>>2]-C(z[g+m>>2]*j));i=c+g|0;z[i>>2]=z[i>>2]-C(z[e+g>>2]-C(z[g+l>>2]*j));h=h+1|0;continue};case 4:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;k=z[i>>2];q=i;r=k;n=z[g+m>>2];i=c+g|0;o=z[i>>2];p=z[g+l>>2];k=C(C(C(C(k+n)+o)+p)*C(.5));z[q>>2]=r-C(C(k+C(k-C(z[d+g>>2]*j)))-n);z[i>>2]=o-C(C(k+C(k-C(z[e+g>>2]*j)))-p);h=h+1|0;continue};case 5:break c;default:break b}}h=PJ(v[a+20>>2]);j=h?C(j*C(.5)):j;k=h?C(k*C(.5)):k;g=0;while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;n=C(z[d+h>>2]-z[h+m>>2]);o=C(z[h+l>>2]-z[e+h>>2]);z[i>>2]=z[i>>2]+C(C(j*n)+C(k*o));h=c+h|0;z[h>>2]=z[h>>2]+C(C(k*n)+C(j*o));g=g+1|0;continue}}d:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break d}if(eb[v[v[a>>2]+136>>2]](a)|0){break d}h=0;while(1){if((f|0)==(h|0)){break d}a=h<<2;d=a+b|0;z[d>>2]=z[a+m>>2]+z[d>>2];d=a+c|0;z[d>>2]=z[a+l>>2]+z[d>>2];h=h+1|0;continue}}}function VZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=ab-16|0;ab=j;k=Ku(g);o=Sv(g);Eg(j,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[22452]=0;g=Q(19,k|0,g<<24>>24)|0;i=v[22452];v[22452]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[22452]=0;g=Q(19,k|0,48)|0;h=v[22452];v[22452]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;g=t[i+1|0];v[22452]=0;g=Q(19,k|0,g|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];gd();if(!LF(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];gd();if(!Dj(h)){break d}g=g+1|0;continue}}e:{if(pd(j)){h=v[f>>2];v[22452]=0;W(1109,k|0,i|0,g|0,h|0);h=v[22452];v[22452]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break e}rl(i,g);v[22452]=0;q=T(1107,o|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){rl((i-a|0)+d|0,v[f>>2]);break e}f:{if(t[oc(j,m)|0]<=0){break f}if(t[oc(j,m)|0]!=(l|0)){break f}l=v[f>>2];v[f>>2]=l+1;t[l|0]=q;m=(ub(j)-1>>>0>m>>>0)+m|0;l=0}p=t[h|0];v[22452]=0;p=Q(19,k|0,p|0)|0;n=v[22452];v[22452]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+1;t[n|0]=p;h=h+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){i=w[g|0];if((i|0)!=46){break g}v[22452]=0;i=T(1110,o|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0}i=v[f>>2];v[22452]=0;W(1109,k|0,g|0,c|0,i|0);i=v[22452];v[22452]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g|0)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;pb(j);ab=j+16|0;return}v[22452]=0;i=Q(19,k|0,i<<24>>24)|0;h=v[22452];v[22452]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;continue}}a=P()|0;O()|0;pb(j);S(a|0);L()}function l4(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=ab-48|0;ab=k;a:{b:{c:{j=No(1,32);d:{e:{if(!j){a=aa(4)|0;gn(a);v[22452]=0;U(110,a|0,88408,25);a=v[22452];v[22452]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:905;c=Rg(k+32|0);f:{g:{h:{if(!i){break h}while(1){d=v[i>>2];if(!d){break h}e=v[i+4>>2];i:{if(e){v[22452]=0;d=Q(55,k+16|0,d|0)|0;f=v[22452];v[22452]=0;j:{if((f|0)!=1){v[22452]=0;f=Q(916,c|0,d|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break j}v[22452]=0;Q(264,f|0,e|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;pb(d);break f}v[22452]=0;d=Q(55,k+16|0,d|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break g}_r(c,d)}pb(d);i=i+8|0;continue}}v[22452]=0;d=T(788,96)|0;e=v[22452];v[22452]=0;k:{l:{m:{if((e|0)!=1){e=v[j+4>>2];f=v[j>>2];v[22452]=0;e=Q(917,f|0,e|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break m}v[k+16>>2]=e;e=v[Oo(k+8|0,k+16|0)>>2];v[22452]=0;ea(948,d|0,a|0,b|0,e|0,c|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break l}v[j+28>>2]=d;oe(k+16|0);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;Qk(c);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;oe(k+16|0)}xb(d);break f}i=V(0)|0;O()|0}Qk(c);_(i|0)|0;v[22452]=0;W(911,4934,j|0,g|0,h|0);a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)!=1){a=v[j+28>>2];if(a){eb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){xb(a);v[j+20>>2]=0}xb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;v[22452]=0;W(911,4934,0,g|0,h|0);a=v[22452];v[22452]=0;if((a|0)==1){break c}$()}ab=k+48|0;return j|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Gb()}L()}function H4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=ab-96|0;ab=e;a:{if(pd(c)){break a}f=w[BI(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+80|0;$q(f,c,0,ub(c)-1|0);tb(c,f);pb(f)}f=e+80|0;Dd(f);g=v[e+80>>2];Dd(e+72|0);g=AI(g,v[e+76>>2],c);Dd(f);b:{c:{d:{e:{f:{if((g|0)==v[e+84>>2]){if(ge(c,21598)){a=aa(8)|0;v[22452]=0;b=Q(55,e+80|0,10443)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}lc(a,b);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}c=P()|0;O()|0;pb(b);break c}if(!d){break f}a=aa(8)|0;v[22452]=0;U(930,e+80|0,17613,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){lc(a,e+80|0);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}c=P()|0;O()|0;pb(e+80|0);break c}c=P()|0;O()|0;ba(a|0);break c}f=Bb(e+80|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:qe(e- -64|0,c);v[22452]=0;c=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=c;b=Y(931,b|0,e+8|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){v[22452]=0;t[e+72|0]=b;R(932,a|0,e+72|0);a=v[22452];v[22452]=0;if((a|0)!=1){break g}}break i;case 1:qe(e+56|0,c);v[22452]=0;c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;b=eE(b,e+16|0,d);c=db;d=v[22452];v[22452]=0;if((d|0)!=1){v[22452]=0;v[e+72>>2]=b;v[e+76>>2]=c;R(934,a|0,e+72|0);a=v[22452];v[22452]=0;if((a|0)!=1){break g}}break i;case 2:qe(e+48|0,c);v[22452]=0;c=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=c;h=+ra(935,b|0,e+24|0,d|0);b=v[22452];v[22452]=0;if((b|0)!=1){v[22452]=0;A[e+72>>3]=h;R(936,a|0,e+72|0);a=v[22452];v[22452]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}qe(e+40|0,c);v[22452]=0;c=v[e+44>>2];v[e+32>>2]=v[e+40>>2];v[e+36>>2]=c;W(937,a|0,b|0,e+32|0,d|0);a=v[22452];v[22452]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;pb(f);break c}Ac(a,f)}pb(f);break e}Bb(a)}ab=e+96|0;return}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function cZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=ab-1072|0;ab=j;v[j+16>>2]=f;v[j+20>>2]=g;v[j+24>>2]=h;v[j+28>>2]=i;a=j+960|0;v[j+956>>2]=a;k=Wv(a,100,11076,j+16|0);v[j+48>>2]=1098;a=j+48|0;o=ee(j+536|0,0,a);v[j+48>>2]=1098;m=ee(j+528|0,0,a);a:{b:{c:{d:{if(k>>>0<100){f=j+960|0;a=j+544|0;break d}a=gd();v[j>>2]=f;v[j+4>>2]=g;v[j+8>>2]=h;v[j+12>>2]=i;k=Ji(j+956|0,a,11076,j);if((k|0)==-1){v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)!=1){break c}break b}f=v[j+956>>2];Ce(o,f);Ce(m,yd(k<<2));if(Oj(m)){v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)==1){break b}break c}a=v[m>>2]}g=j+520|0;zc(g,d);v[22452]=0;q=T(1111,g|0)|0;g=v[22452];v[22452]=0;e:{f:{g:{h:{i:{j:{k:{if((g|0)==1){break k}v[22452]=0;W(1123,q|0,f|0,f+k|0,a|0);g=v[22452];v[22452]=0;if((g|0)==1){break k}p=(k|0)>0?w[f|0]==45:p;h=Bb(j+488|0);f=Bb(j+472|0);g=Bb(j+456|0);v[22452]=0;ma(1150,c|0,p|0,j+520|0,j+512|0,j+508|0,j+504|0,h|0,f|0,g|0,j+452|0);c=v[22452];v[22452]=0;if((c|0)==1){break j}v[j+36>>2]=1098;c=ee(j+40|0,0,j+36|0);i=j+48|0;n=v[j+452>>2];l:{if((n|0)<(k|0)){l=((ub(g)+(k-n<<1)|0)+ub(f)|0)+1|0;break l}l=(ub(g)+ub(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break i}Ce(c,yd(l<<2));i=v[c>>2];if(i){break i}v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)!=1){break c}break h}k=P()|0;O()|0;break f}k=P()|0;O()|0;break g}l=v[d+4>>2];v[22452]=0;oa(1151,i|0,j+36|0,j+32|0,l|0,a|0,(k<<2)+a|0,q|0,p|0,j+512|0,v[j+508>>2],v[j+504>>2],h|0,f|0,g|0,n|0);a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;a=la(1132,b|0,i|0,v[j+36>>2],v[j+32>>2],d|0,e|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break e}}}k=P()|0;O()|0;Bc(c)}Oc(g);Oc(f);pb(h)}Nb(j+520|0);break a}Bc(c);Oc(g);Oc(f);pb(h);Nb(j+520|0);Bc(m);Bc(o);ab=j+1072|0;return a|0}L()}k=P()|0;O()|0}Bc(m);Bc(o);S(k|0);L()}function C4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=ab+-64|0;ab=e;d=v[b+4>>2];a:{if(!d){break a}f=v[b>>2];g=w[Gk(f,d)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}Pk(e+40|0,f,d,d-1|0);d=v[e+44>>2];v[b>>2]=v[e+40>>2];v[b+4>>2]=d}f=e+40|0;Dd(f);d=v[e+40>>2];Dd(e+24|0);d=Fk(d,v[e+28>>2],b);Dd(f);b:{c:{d:{e:{if((d|0)==v[e+44>>2]){d=v[b>>2];f=v[b+4>>2];a=kc(e+56|0,21598);if(yc(d,f,v[a>>2],v[a+4>>2])){a=aa(8)|0;v[22452]=0;c=Q(55,e+40|0,10443)|0;b=v[22452];v[22452]=0;if((b|0)==1){break d}lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(c);break c}d=0;f=0;if(!c){break e}c=aa(8)|0;v[22452]=0;d=Q(938,e+24|0,b|0)|0;a=v[22452];v[22452]=0;f:{g:{h:{if((a|0)!=1){v[22452]=0;U(939,e+40|0,17613,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}lc(c,e+40|0);a=0;v[22452]=0;U(110,c|0,58760,928);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;pb(e+40|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}pb(d);if(!a){break c}}ba(c|0);break c}if(v[d+4>>2]!=1){a=aa(8)|0;v[22452]=0;c=Q(55,e+40|0,11558)|0;b=v[22452];v[22452]=0;if((b|0)!=1){lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(c);break c}b=P()|0;O()|0;ba(a|0);break c}d=v[b>>2];f=v[b+4>>2];c=kc(e+16|0,21598);if(yc(d,f,v[c>>2],v[c+4>>2])){a=aa(8)|0;v[22452]=0;c=Q(55,e+40|0,10443)|0;b=v[22452];v[22452]=0;if((b|0)!=1){lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(c);break c}b=P()|0;O()|0;ba(a|0);break c}d=v[b>>2];f=v[b+4>>2];c=kc(e+8|0,10881);if(yc(d,f,v[c>>2],v[c+4>>2])){a=v[a+8>>2];d=a;f=a>>31;break e}d=0;c=v[b>>2];g=v[b+4>>2];b=kc(e,8598);f=0;if(!yc(c,g,v[b>>2],v[b+4>>2])){break e}d=Qw(v[a+32>>2]);f=0}ab=e- -64|0;db=f;return d|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function gZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=ab-464|0;ab=j;v[j+16>>2]=f;v[j+20>>2]=g;v[j+24>>2]=h;v[j+28>>2]=i;a=j+352|0;v[j+348>>2]=a;k=Wv(a,100,11076,j+16|0);v[j+48>>2]=1098;a=j+48|0;o=ee(j+232|0,0,a);v[j+48>>2]=1098;m=ee(j+224|0,0,a);a:{b:{c:{d:{if(k>>>0<100){f=j+352|0;a=j+240|0;break d}a=gd();v[j>>2]=f;v[j+4>>2]=g;v[j+8>>2]=h;v[j+12>>2]=i;k=Ji(j+348|0,a,11076,j);if((k|0)==-1){v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)!=1){break c}break b}f=v[j+348>>2];Ce(o,f);Ce(m,yd(k));if(Oj(m)){v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)==1){break b}break c}a=v[m>>2]}g=j+216|0;zc(g,d);v[22452]=0;q=T(18,g|0)|0;g=v[22452];v[22452]=0;e:{f:{g:{h:{i:{j:{k:{if((g|0)==1){break k}v[22452]=0;W(1109,q|0,f|0,f+k|0,a|0);g=v[22452];v[22452]=0;if((g|0)==1){break k}p=(k|0)>0?w[f|0]==45:p;h=Bb(j+192|0);f=Bb(j+176|0);g=Bb(j+160|0);v[22452]=0;ma(1148,c|0,p|0,j+216|0,j+208|0,j+207|0,j+206|0,h|0,f|0,g|0,j+156|0);c=v[22452];v[22452]=0;if((c|0)==1){break j}v[j+36>>2]=1098;c=ee(j+40|0,0,j+36|0);i=j+48|0;n=v[j+156>>2];l:{if((n|0)<(k|0)){l=((ub(g)+(k-n<<1)|0)+ub(f)|0)+1|0;break l}l=(ub(g)+ub(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break i}Ce(c,yd(l));i=v[c>>2];if(i){break i}v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)!=1){break c}break h}k=P()|0;O()|0;break f}k=P()|0;O()|0;break g}l=v[d+4>>2];v[22452]=0;oa(1149,i|0,j+36|0,j+32|0,l|0,a|0,a+k|0,q|0,p|0,j+208|0,t[j+207|0],t[j+206|0],h|0,f|0,g|0,n|0);a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;a=la(14,b|0,i|0,v[j+36>>2],v[j+32>>2],d|0,e|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break e}}}k=P()|0;O()|0;Bc(c)}pb(g);pb(f);pb(h)}Nb(j+216|0);break a}Bc(c);pb(g);pb(f);pb(h);Nb(j+216|0);Bc(m);Bc(o);ab=j+464|0;return a|0}L()}k=P()|0;O()|0}Bc(m);Bc(o);S(k|0);L()}function Jj(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=ab-16|0;ab=i;a:{if(!d){break a}h=v[c>>2];if(!h){break a}b:{c:{d:{f=v[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break d}f=h+B(d,20)|0;break c}f=h+((B(d,36318)|0)/1024|0)|0;break c}e:{g=v[a+480208>>2]&16;if(!(!g|(f|0)==4)){f=d>>31;v[i+12>>2]=f+d^f;mc(i+12|0,1020);g=v[i+12>>2];f=c;k=f;f=v[f>>2];l=f;m=f>>31;f:{if((d|0)>0){if(g>>>0<=15){f=ab-16|0;ab=f;rb(f+8|0,a+1074312|0,7);j=sb(v[v[f+8>>2]>>2],v[f+12>>2]);ab=f+16|0;g=v[(g<<2)+(j?37168:37232)>>2];break f}f=ab-16|0;ab=f;rb(f+8|0,a+1074312|0,7);j=sb(v[v[f+8>>2]>>2],v[f+12>>2]);ab=f+16|0;g=v[(g>>>2<<2)+(j?37296:38320)>>2];break f}if(g>>>0<=15){f=ab-16|0;ab=f;rb(f+8|0,a+1074312|0,7);j=sb(v[v[f+8>>2]>>2],v[f+12>>2]);ab=f+16|0;g=v[(g<<2)+(j?37232:37168)>>2];break f}f=ab-16|0;ab=f;rb(f+8|0,a+1074312|0,7);j=sb(v[v[f+8>>2]>>2],v[f+12>>2]);ab=f+16|0;g=v[(g>>>2<<2)+(j?38320:37296)>>2]}g=oia(l,m,g,g>>31)+32768|0;f=db;f=vc(pia(g,g>>>0<32768?f+1|0:f,65536,0),db);v[k>>2]=f;if((f|0)!=(h|0)){break b}rb(i,a+1074312|0,7);h=v[c>>2];if(!(sb(v[v[i>>2]>>2],v[i+4>>2])^(d|0)>0)){f=2147483647;d=1;if((h|0)==2147483647){break b}break e}d=-1;if((h|0)>=2){break e}f=h;break b}g:{if(!g){rb(i,a+1074312|0,7);if(sb(v[v[i>>2]>>2],v[i+4>>2])){break g}h=v[c>>2]}f=h-d|0;break c}f=v[c>>2];if((d|0)<0){h=oia(f,0,14317456,0);g=db;f=oia(f,0,0-d|0,0)+14317456|0;d=db;f=_L(ria(h,g,f,f>>>0<14317456?d+1|0:d),db);break c}d=oia(f,f>>31,d,0);h=db;if((h|0)>=0&d>>>0>=14317456|(h|0)>0){if(e){v[c>>2]=2147483647;break a}v[c>>2]=0;v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248;break a}f=_L(ria(oia(f,0,14317456,0),db,14317456-d|0,0-(h+(d>>>0>14317456)|0)|0),db);break c}f=d+h|0}v[c>>2]=f}if((f|0)>0){break a}v[c>>2]=1;if(v[a+480180>>2]!=2|e){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}ab=i+16|0}function XI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=ab-48|0;ab=k;a:{b:{c:{d:{e:{f:{j=No(1,28);if(!j){a=aa(4)|0;gn(a);v[22452]=0;U(110,a|0,88408,25);a=v[22452];v[22452]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:905;c=Rg(k+32|0);g:{h:{i:{if(!i){break i}while(1){d=v[i>>2];if(!d){break i}e=v[i+4>>2];j:{if(e){v[22452]=0;d=Q(55,k+16|0,d|0)|0;f=v[22452];v[22452]=0;k:{if((f|0)!=1){v[22452]=0;f=Q(916,c|0,d|0)|0;l=v[22452];v[22452]=0;if((l|0)==1){break k}v[22452]=0;Q(264,f|0,e|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;pb(d);break g}v[22452]=0;d=Q(55,k+16|0,d|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break h}_r(c,d)}pb(d);i=i+8|0;continue}}v[22452]=0;d=T(788,80)|0;e=v[22452];v[22452]=0;l:{m:{n:{if((e|0)!=1){e=v[j+4>>2];f=v[j>>2];v[22452]=0;e=Q(917,f|0,e|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break n}v[k+16>>2]=e;e=v[Oo(k+8|0,k+16|0)>>2];v[22452]=0;ea(919,d|0,a|0,b|0,e|0,c|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break m}v[j+24>>2]=d;oe(k+16|0);Qk(c);i=j;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;oe(k+16|0)}xb(d);break g}i=V(0)|0;O()|0}Qk(c);_(i|0)|0;v[22452]=0;W(911,15057,j|0,g|0,h|0);a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Zr(a)}xb(a);i=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){xb(a);v[j+20>>2]=0}xb(j);break d}i=V(0)|0;O()|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;i=0;v[22452]=0;W(911,15057,0,g|0,h|0);a=v[22452];v[22452]=0;if((a|0)==1){break c}$()}ab=k+48|0;return i|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Gb()}L()}function z4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=ab+-64|0;ab=e;f=v[c+4>>2];a:{if(!f){break a}g=v[c>>2];h=w[Gk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Pk(e+40|0,g,f,f-1|0);f=v[e+44>>2];v[c>>2]=v[e+40>>2];v[c+4>>2]=f}f=e+40|0;Dd(f);g=v[e+40>>2];Dd(e+24|0);h=Fk(g,v[e+28>>2],c);Dd(f);f=v[c+4>>2];g=v[c>>2];b:{c:{d:{e:{if((h|0)==v[e+44>>2]){b=kc(e+56|0,21598);if(yc(g,f,v[b>>2],v[b+4>>2])){a=aa(8)|0;v[22452]=0;b=Q(55,e+40|0,10443)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}lc(a,b);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}c=P()|0;O()|0;pb(b);break c}if(d){a=aa(8)|0;v[22452]=0;b=Q(938,e+24|0,c|0)|0;c=v[22452];v[22452]=0;f:{g:{h:{if((c|0)!=1){v[22452]=0;U(939,e+40|0,17613,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break h}lc(a,e+40|0);d=0;v[22452]=0;U(110,a|0,58760,928);c=v[22452];v[22452]=0;if((c|0)!=1){break b}c=P()|0;O()|0;pb(e+40|0);break g}c=P()|0;O()|0;break f}c=P()|0;d=1;O()|0}pb(b);if(!d){break c}}ba(a|0);break c}Bb(a);break e}d=kc(e+16|0,21598);if(yc(g,f,v[d>>2],v[d+4>>2])){a=aa(8)|0;v[22452]=0;b=Q(55,e+40|0,10443)|0;c=v[22452];v[22452]=0;if((c|0)!=1){lc(a,b);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}c=P()|0;O()|0;pb(b);break c}c=P()|0;O()|0;ba(a|0);break c}f=v[c>>2];g=v[c+4>>2];d=kc(e+8|0,12327);if(yc(f,g,v[d>>2],v[d+4>>2])){i:{switch(v[b+52>>2]){case 0:Mb(a,5562);break e;case 1:Mb(a,11259);break e;case 2:Mb(a,9177);break e;default:break i}}Bb(a);break e}d=v[c>>2];f=v[c+4>>2];c=kc(e,11496);if(yc(d,f,v[c>>2],v[c+4>>2])){j:{switch(v[b+56>>2]){case 0:Mb(a,15540);break e;case 1:Mb(a,15545);break e;case 2:Mb(a,12601);break e;case 3:Mb(a,9241);break e;default:break j}}Bb(a);break e}Bb(a)}ab=e- -64|0;return}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function CQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=ab-16|0;ab=f;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=w[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){t[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch((c+96&240)>>>4|0){case 0:t[a+2|0]=4;c=c&15;break b;case 1:t[a+2|0]=3;c=c&15;break b;case 2:t[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;c=c&15}t[a+4|0]=c}e=w[b+4|0];d=w[b+5|0];c=w[b+6|0];d:{if(!(c?1:e|d)){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}t[a+2|0]=15;t[a+3|0]=20;t[a+4|0]=c>>>3;t[f+15|0]=15;h=a,i=w[Qb(b+5|0,f+15|0)|0]|208,t[h+5|0]=i;break d;case 0:t[a+5|0]=d;t[a+3|0]=c;Mf(a);g=w[b+6|0]==15;break d;case 1:t[a+3|0]=2;h=a,i=pi(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 2:t[a+3|0]=3;h=a,i=pi(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 3:t[a+3|0]=4;h=a,i=pi(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 4:t[a+3|0]=5;t[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){t[a+5|0]=d;t[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d;case 12:t[a+3|0]=13;t[a+5|0]=c>>>1;break d;case 15:if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}t[a+5|0]=d;t[a+3|0]=c;CA(a,1);g=(w[a+3|0]&254)==16;break d}t[a+5|0]=d;t[a+3|0]=18;break d}t[a+3|0]=31;t[a+5|0]=c>>>1;break d}t[a+3|0]=31;t[a+5|0]=c>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=c>>>2}b=w[b+3|0];l:{if(!b){break l}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break l}if(w[a+2|0]){break l}t[a+2|0]=2;t[a+4|0]=b>>>2}ab=f+16|0;return g}function rn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ab-16|0;ab=e;v[b+88>>2]=v[b+88>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){rb(e+8|0,a+1074312|0,15);if(sb(v[v[e+8>>2]>>2],v[e+12>>2])){break b}}if(v[a+480180>>2]!=268435456){break a}}c=c?c:w[b+811|0];t[b+812|0]=c;t[b+811|0]=c}if(c){u[b+768>>1]=c}d=v[b+656>>2];c:{if(hj(d)){c=x[b+768>>1];if(!c){break c}f=v[b+856>>2];g=v[a+1074392>>2];i=0-c|0;j=c;c=v[b+708>>2];h=(+(g>>>0)+1)*+(((c|0)<0?i:j)|0)/+y[a+1074416>>2];d:{if(D(h)<2147483648){a=~~h;break d}a=-2147483648}v[b+856>>2]=a;if(w[b+90|0]&16){a=B(v[v[d+44>>2]+36>>2]+1|0,a);v[b+856>>2]=a}a=a-(g?f:0)|0;d=a>>31;f=c>>31;if((f+c^f)>>>0<=(d^a+d)>>>0){if(!c){break c}v[b+708>>2]=0;v[b+852>>2]=c+v[b+852>>2];t[b+851|0]=w[b+851|0]|64;break c}v[b+708>>2]=c-a;v[b+852>>2]=a+v[b+852>>2];t[b+851|0]=w[b+851|0]|64;break c}c=1;e:{if(!(t[b+851|0]&1)){break e}d=v[a+480180>>2];if(d&524352){break e}if(v[a+1074416>>2]==1){rb(e+8|0,a+1074312|0,6);if(sb(v[v[e+8>>2]>>2],v[e+12>>2])){break e}d=v[a+480180>>2]}c=0;if((d|0)!=8){break e}c=(w[a+480208|0]&2)>>>1|0}f:{if(!v[b+700>>2]|!v[b+708>>2]){break f}f=v[a+480180>>2];d=x[b+768>>1];g=(f|0)==268435456&d>>>0>239;if(!(g?t[b+851|0]&1:c)){break f}c=b+700|0;d=B((f|0)==64?2:4,g?d-240|0:d);d=_i(a)?d:0-d|0;f=v[b+700>>2];g=v[b+708>>2];if(!(w[b+851|0]&16?0:(f|0)>=(g|0))){Jj(a,b,c,d,1);d=v[b+708>>2];if((d|0)>=v[b+700>>2]){break f}v[c>>2]=d;break f}if((f|0)<=(g|0)){break f}Jj(a,b,c,0-d|0,1);f=v[b+700>>2];d=v[b+708>>2];g:{if((f|0)<(d|0)){v[c>>2]=d;break g}if((d|0)!=(f|0)){break f}}rb(e+8|0,a+1074312|0,112);if(!sb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}t[b+851|0]=w[b+851|0]|16}if(v[b+700>>2]!=v[b+708>>2]){break c}rb(e+8|0,a+1074312|0,25);if(!sb(v[v[e+8>>2]>>2],v[e+12>>2])&v[a+480180>>2]!=1){break c}v[b+708>>2]=0}ab=e+16|0}function Jaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;h=ab-32|0;ab=h;x=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(h+16|0)|0;e=a+e|0;v[i>>2]=v[e+44>>2];v[i+4>>2]=v[e+48>>2];f=f+1|0;continue}break}i=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;y=v[a+8>>2];z=v[a+12>>2];a:while(1){if(d){f=v[h+8>>2];g=((((v[h+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+x|0;e=(((f>>>16|0)+4&131064)<<1)+b|0;n=u[e+38>>1];o=u[e+36>>1];p=u[e+34>>1];q=u[e+32>>1];r=u[e+30>>1];s=u[e+28>>1];t=u[e+26>>1];l=u[e+24>>1];f=0;while(1)if((f|0)==2){n=v[a+72>>2];e=v[a+68>>2];o=e;p=e>>31;e=v[a+64>>2];q=e;r=e>>31;e=v[a+60>>2];s=e;t=e>>31;f=0;while(1){if((f|0)!=2){l=(f<<2)+h|0;g=v[l>>2];e=(h+16|0)+(f<<3)|0;m=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;w=g<<8;g=w;g=oia(s,t,g,g>>31);A=db;C=e;e=Sb(j,-16777216,16776704);j=oia(q,r,e,e>>31);g=j+g|0;e=db+A|0;e=g>>>0<j>>>0?e+1|0:e;j=g;g=Sb(m,-16777216,16776704);m=oia(o,p,g,g>>31);g=j+m|0;e=db+e|0;e=g>>>0<m>>>0?e+1|0:e;g=g+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Cc(g,e,24);v[C>>2]=e-(n&w);v[l>>2]=(e|0)/256;f=f+1|0;continue}break}e=v[a+32>>2];k=v[a+28>>2]+k|0;v[c>>2]=v[c>>2]+B(v[h>>2],k>>12);i=e+i|0;v[c+4>>2]=v[c+4>>2]+B(v[h+4>>2],i>>12);Lb(h+8|0,y,z);c=c+8|0;d=d-1|0;continue a}else{e=g+(f<<1)|0;v[(f<<2)+h>>2]=(((((B(p,u[e+8>>1])+B(q,u[e+4>>1])|0)+B(o,u[e+12>>1])|0)+B(n,u[e+16>>1])|0)/2|0)+((((B(u[e-8>>1],t)+B(u[e-12>>1],l)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)/2|0)|0)/16384;f=f+1|0;continue}}break}v[a+40>>2]=i;v[a+36>>2]=k;v[a+20>>2]=k>>12;v[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(h+16|0)|0;v[c+44>>2]=v[b>>2];v[c+48>>2]=v[b+4>>2];f=f+1|0;continue}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+32|0}function Tf(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=j;i=w[a+79|0]?x[v[a>>2]+3836>>1]:i;b=x[a+20>>1];l=x[a+22>>1];m=x[a+70>>1];a:{b:{c:{d:{switch(v[a+16>>2]){case 1:c=x[v[a>>2]+3832>>1];f=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((c>>>x[a+44>>1]&7)<<1)>>1]|0:0;g=c;c=x[a+46>>1];f=b+(c?g&c?0:f:f)|0;u[a+20>>1]=f;c=2;h=x[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:c=0;f=x[v[a>>2]+3832>>1];h=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((f>>>x[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=x[a+58>>1];f=b+(f?g&f?0:h:h)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:c=0;v[a+72>>2]=0;break a;case 0:break d}}c=1;f=x[v[a>>2]+3832>>1];k=x[a+24>>1]?B((b^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((f>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=x[a+34>>1];f=b+(f?g&f?0:k:k)|0;u[a+20>>1]=f;if(f<<16>>16>0){break b}}v[a+16>>2]=c;u[a+20>>1]=h}i=((b+l|0)+m|0)+i<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(x[a+12>>1]){case 0:d=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+28400>>1];break e;case 1:d=0;b=x[((b&512?0:b&256?c^255:c)<<1)+28400>>1];break e;case 2:d=0;b=x[((b&256?c^255:c)<<1)+28400>>1];break e;case 3:d=0;b=x[((b&256?0:c)<<1)+28400>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=x[(e<<1)+28400>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=x[(b<<1)+28400>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}u[a+74>>1]=x[a+72>>1];e=a;a=b+i|0;a=(a&65535)>>>0<8191?a:8191;c=0-d^x[((a&255)<<1)+27888>>1]+1024>>>((a&65280)>>>8)<<1;u[e+72>>1]=c}return c<<16>>16}function Kaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;h=ab-32|0;ab=h;y=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(h+16|0)|0;e=a+e|0;v[i>>2]=v[e+44>>2];v[i+4>>2]=v[e+48>>2];f=f+1|0;continue}break}i=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;z=v[a+8>>2];A=v[a+12>>2];a:while(1){if(d){f=v[h+8>>2];g=(((v[h+12>>2]&2147483647)<<1|f>>>31)&-2)+y|0;e=(((f>>>16|0)+4&131064)<<1)+b|0;n=u[e+38>>1];o=u[e+36>>1];p=u[e+34>>1];q=u[e+32>>1];r=u[e+30>>1];s=u[e+28>>1];w=u[e+26>>1];l=u[e+24>>1];f=0;while(1)if((f|0)==2){n=v[a+72>>2];e=v[a+68>>2];o=e;p=e>>31;e=v[a+64>>2];q=e;r=e>>31;e=v[a+60>>2];s=e;w=e>>31;f=0;while(1){if((f|0)!=2){l=(f<<2)+h|0;g=v[l>>2];e=(h+16|0)+(f<<3)|0;m=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;x=g<<8;g=x;g=oia(s,w,g,g>>31);C=db;D=e;e=Sb(j,-16777216,16776704);j=oia(q,r,e,e>>31);g=j+g|0;e=db+C|0;e=g>>>0<j>>>0?e+1|0:e;j=g;g=Sb(m,-16777216,16776704);m=oia(o,p,g,g>>31);g=j+m|0;e=db+e|0;e=g>>>0<m>>>0?e+1|0:e;g=g+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Cc(g,e,24);v[D>>2]=e-(n&x);v[l>>2]=(e|0)/256;f=f+1|0;continue}break}e=v[a+32>>2];k=v[a+28>>2]+k|0;v[c>>2]=v[c>>2]+B(v[h>>2],k>>12);i=e+i|0;v[c+4>>2]=v[c+4>>2]+B(v[h+4>>2],i>>12);Lb(h+8|0,z,A);c=c+8|0;d=d-1|0;continue a}else{e=f+g|0;v[(f<<2)+h>>2]=(((((B(p,t[e+4|0])+B(q,t[e+2|0])|0)+B(o,t[e+6|0])|0)+B(n,t[e+8|0])<<8)/2|0)+((((B(t[e-4|0],w)+B(t[e-6|0],l)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)<<8)/2|0)|0)/16384;f=f+1|0;continue}}break}v[a+40>>2]=i;v[a+36>>2]=k;v[a+20>>2]=k>>12;v[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(h+16|0)|0;v[c+44>>2]=v[b>>2];v[c+48>>2]=v[b+4>>2];f=f+1|0;continue}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+32|0}function mp(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ab-16|0;ab=e;v[e+12>>2]=u[b+780>>1]+w[b+837|0];v[e+8>>2]=u[b+782>>1]+(w[b+838|0]&127);ce(e+12|0,0,127);ce(e+8|0,0,127);k=a+1074312|0;rb(e,k,1);j=v[e+12>>2];a:{if(sb(v[v[e>>2]>>2],v[e+4>>2])){i=v[e+8>>2];break a}u[b+780>>1]=0;t[b+837|0]=j;i=v[e+8>>2];u[b+782>>1]=0;t[b+838|0]=i}rb(e,k,36);l=B(j,d+256|0);m=(l|0)/256|0;b:{if(!(!sb(v[v[e>>2]>>2],v[e+4>>2])|i|(l|0)<65024)){m=-1;if(!Kc(w[b+788|0])){break b}if(Js(b+788|0)|x[b+786>>1]|!(w[b+851|0]&2)){break b}v[b+88>>2]=v[b+88>>2]&-32769;break b}v[b+88>>2]=v[b+88>>2]|32768;f=fe(C(10),C(C(0-i|0)*C(.00937500037252903)));i=ab-16|0;ab=i;g=C(B(j,d+256|0)>>>0);c:{if(v[a+480180>>2]!=33554432){h=C(110);g=C(C(g/(w[a+480209|0]&128?C(10240):C(12288)))+C(.25));break c}h=C(125);g=C(C(g*C(6))/C(65024))}n=i,o=Ah(C(fe(C(2),g)*h)),v[n+12>>2]=o;ce(i+12|0,120,2e4);d=v[i+12>>2];j=v[a+24620>>2];ab=i+16|0;rb(e,k,36);g=C(C(((j|0)<d<<1?j>>>1|0:d)>>>0)*C(6.2831854820251465));d:{if(!(!sb(v[v[e>>2]>>2],v[e+4>>2])|v[a+480208>>2]&32768)){h=C(C(y[a+24620>>2])/g);g=C(C(C(f*h)+f)+C(-1));z[e>>2]=g;f=C(h*h);break d}h=C(f+f);f=C(g/C(y[a+24620>>2]));z[e>>2]=C(C(1)-h)*f;KM(e,C(2));g=C(C(h-z[e>>2])/f);z[e>>2]=g;f=C(C(1)/C(f*f))}h=C(f+C(g+C(1)));g=C(C(f+C(f+g))/h);f=C(C(-f)/h);h=C(C(1)/h);e:{if(w[b+845|0]==1){n=b,o=Ah(C(C(C(1)-h)*C(16777216))),v[n+60>>2]=o;n=b,o=Ah(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Ah(C(f*C(16777216))),v[n+68>>2]=o;a=-1;break e}d=Ah(C(h*C(16777216)));v[b+60>>2]=d;n=b,o=Ah(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Ah(C(f*C(16777216))),v[n+68>>2]=o;a=0;if(d){break e}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break b}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}ab=e+16|0;return m}function _P(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=ab-16|0;ab=l;a:{if((c|0)==(g|0)){f=Zb(l+8|0,f,c);g=ab-16|0;ab=g;d=Xk(d,e,b,c);v[g+12>>2]=d;b:{if((d|0)<=0){d=v[f>>2];break b}c:{if(!c){c=v[f>>2];break c}k=32-c|0;v[g+8>>2]=k;e=d;d=v[jd(g+8|0,g+12|0)>>2];v[g+12>>2]=e-d;e=v[f>>2];c=-1<<c&-1>>>k-d;v[e>>2]=v[e>>2]&(c^-1)|c&v[b>>2];c=d+v[f+4>>2]|0;v[f+4>>2]=c&31;c=e+(c>>>3&536870908)|0;v[f>>2]=c;b=b+4|0;d=v[g+12>>2]}k=c;e=(d|0)/32|0;c=e<<2;Wi(k,b,c);e=d-(e<<5)|0;v[g+12>>2]=e;d=c+v[f>>2]|0;v[f>>2]=d;if((e|0)<=0){break b}e=-1>>>32-e|0;v[d>>2]=v[d>>2]&(e^-1)|e&v[b+c>>2];v[f+4>>2]=v[g+12>>2]}Zb(a,d,v[f+4>>2]);ab=g+16|0;break a}k=a;g=Zb(l,f,g);f=ab-16|0;ab=f;d=Xk(d,e,b,c);v[f+12>>2]=d;d:{if((d|0)<=0){a=v[g+4>>2];break d}e:{if(!c){a=v[g+4>>2];break e}i=32-c|0;v[f+8>>2]=i;a=d;e=f+8|0;d=v[jd(e,f+12|0)>>2];v[f+12>>2]=a-d;a=v[g+4>>2];j=v[b>>2];v[f+8>>2]=d;m=32-a|0;v[f+4>>2]=m;h=v[g>>2];n=v[h>>2];e=v[zb(e,f+4|0)>>2];i=j&(-1<<c&-1>>>i-d);v[h>>2]=(-1<<a&-1>>>m-e^-1)&n|(a>>>0>c>>>0?i<<a-c:i>>>c-a|0);j=a+e|0;a=j&31;v[g+4>>2]=a;h=h+(j>>>3&536870908)|0;v[g>>2]=h;d=d-e|0;if((d|0)>0){v[h>>2]=v[h>>2]&(-1>>>32-d^-1)|i>>>c+e;v[g+4>>2]=d;a=d}b=b+4|0;d=v[f+12>>2]}e=32-a|0;h=-1<<a;i=h^-1;while(1){if((d|0)>=32){c=v[g>>2];d=v[b>>2];v[c>>2]=i&v[c>>2]|d<<a;v[g>>2]=c+4;v[c+4>>2]=h&v[c+4>>2]|d>>>e;d=v[f+12>>2]-32|0;v[f+12>>2]=d;b=b+4|0;continue}break}if((d|0)<=0){break d}i=v[b>>2];v[f+8>>2]=e;c=v[g>>2];b=v[c>>2];j=b;b=v[jd(f+12|0,f+8|0)>>2];j=j&(h&-1>>>e-b^-1);e=i&-1>>>32-d;v[c>>2]=j|e<<a;d=a+b|0;a=d&31;v[g+4>>2]=a;c=c+(d>>>3&536870908)|0;v[g>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<=0){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|e>>>b;a=v[f+12>>2];v[g+4>>2]=a}Zb(k,v[g>>2],a);ab=f+16|0}ab=l+16|0}function WK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=ab-16|0;ab=g;e=B(b,872)+a|0;k=e+1074992|0;a:{b:{if(w[e+1075082|0]&2){h=a+480180|0;e=v[h>>2];j=1;c:{d:{e:{f=v[a+480208>>2];if(f&4096){if(!(e&16777248)){break e}j=!(f&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;j=0;break c}if(!j){break c}rb(g+8|0,a+1074312|0,21);if(!sb(v[v[g+8>>2]>>2],v[g+12>>2])){break c}e=B(b,872)+a|0;f=e+1075811|0;t[f|0]=w[f|0]+(w[e+1075815|0]<<2)}f=B(b,872)+a|0;i=f+1075814|0;l=f+1075811|0;e=Rx(a,w[i|0],w[l|0]);m=f+1075648|0;f:{if(hj(v[m>>2])){z[d>>2]=z[d>>2]+C(C(C(B(w[f+1075816|0],e)|0)*C(.05000000074505806))/C(7680));c=f+1075843|0;d=w[c|0];t[c|0]=d&159|64;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break f}t[c|0]=d|96;break f}d=v[a+480208>>2];if((d&2101248)==2101248){break a}f=v[h>>2];if(d&4096?f&67633152:0){break a}e=f&5?(w[i|0]&3)==1?0-e|0:e:e;i=a+1074312|0;rb(g+8|0,i,21);f=v[a+480208>>2];g:{if(sb(v[v[g+8>>2]>>2],v[g+12>>2])){d=f&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(f&131072){break h}h=v[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?f&4?6:7:6}rb(g+8|0,i,80);if(!sb(v[v[g+8>>2]>>2],v[g+12>>2])){break g}d=w[(B(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=(0-B(w[(B(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0;Jj(a,k,c,d,0);c=Bs(a,k);if(!c){break f}e=v[m>>2];if(e){e=t[e+33|0]}else{e=2}eb[v[v[c>>2]+88>>2]](c,d,e<<24>>24,b)}if(!j){break a}rb(g+8|0,a+1074312|0,21);if(sb(v[v[g+8>>2]>>2],v[g+12>>2])){break a}t[l|0]=w[l|0]+w[(B(b,872)+a|0)+1075815|0];break a}if(!(w[e+1075662|0]&2)){break a}a=Bs(a,k);if(!a){break a}eb[v[v[a>>2]+88>>2]](a,0,0,b);break a}a=B(b,872)+a|0;b=a+1075811|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075816|0],167)}t[b|0]=d+1}ab=g+16|0}function IX(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;r=ab-16|0;ab=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!w[j|0]){break a}j=j+1|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=v[b+4>>2];v[r+8>>2]=v[b>>2];v[r+12>>2]=i;s=ab-16|0;ab=s;u=Sh(s+8|0,v[a+8>>2]);m=j-c|0;k=0;o=0;n=ab-1040|0;ab=n;i=v[e>>2];v[n+12>>2]=i;p=f?f:n+16|0;l=f?g-f>>2:256;e:{f:{if(!(!i|!l)){while(1){g:{q=m>>>2|0;if(q>>>0<l>>>0&m>>>0<=131){break f}q=xF(p,n+12|0,l>>>0<=q>>>0?l:q,b);if((q|0)==-1){k=-1;l=0;i=v[n+12>>2];break g}t=(n+16|0)==(p|0)?0:q;l=l-t|0;p=(t<<2)+p|0;m=i+m|0;i=v[n+12>>2];m=i?m-i|0:0;k=k+q|0;if(!i){break g}if(l){continue}}break}}if(!i){break e}}if(!(!l|!m)){o=i;i=k;while(1){h:{k=lr(p,o,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:o=0;break i;case 0:break e;default:break j}}v[b>>2]=0;break i}i=i+1|0;o=k+o|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}o=i}if(f){v[e>>2]=o}ab=n+1040|0;Rh(u);ab=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{v[h>>2]=f;if(v[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=zE(f,c,j-c|0,r+8|0,v[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}v[e>>2]=c;break n}g=b}c=c+g|0;f=v[h>>2]+4|0;continue}break}v[e>>2]=c;break d}f=v[h>>2]+(k<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break k}c=v[e>>2];if((d|0)==(j|0)){j=d;continue}if(!zE(f,c,1,b,v[a+8>>2])){break m}}a=2;break c}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!w[j|0]){break b}j=j+1|0;continue}}v[e>>2]=c;a=1;break c}c=v[e>>2]}a=(c|0)!=(d|0)}ab=r+16|0;return a|0}f=v[h>>2];continue}}function jr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=ab-128|0;ab=i;v[i+120>>2]=b;k=tF(c,d);v[i+4>>2]=1098;m=sF(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=yd(k);if(!j){v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}Ce(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[22452]=0;h=Q(1100,a|0,i+120|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[22452]=0;b=Q(1101,a|0,i+120|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}b=v[a>>2];v[22452]=0;n=T(1102,b|0)|0;b=v[22452];v[22452]=0;g:{if((b|0)!=1){if(g){break g}v[22452]=0;n=Q(1103,e|0,n|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}q=o+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=q;if(!r){continue e}v[22452]=0;T(1104,a|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((ub(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=t[oc(b,o)|0];j:{if(g){break j}v[22452]=0;p=Q(1103,e|0,p<<24>>24)|0;s=v[22452];v[22452]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n&255)==(p&255)){r=1;if((ub(b)|0)!=(q|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Bc(m);ab=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!pd(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Bc(m);S(b|0)}L()}function ei(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;q=c*d;r=b*e;m=q+r;s=b*d;t=c*e;p=s-t;a:{if(!Bh(p)){break a}if(!Bh(m)){break a}h=Ue(b);f=Ue(c);k=h|f;if((k|0)==1){o(+(f?1:0));f=j(1)|0;i=j(0)|0;o(+c);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);c=+n();o(0);f=j(1)|0;i=j(0)|0;o(+d);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);d=(u=+n(),v=d,w=Bh(d),w?u:v);o(0);f=j(1)|0;i=j(0)|0;o(+e);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);e=(u=+n(),v=e,w=Bh(e),w?u:v);o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=+n()}h=Ue(d);f=Ue(e);b:{if(f?1:h){o(+(f?1:0));f=j(1)|0;g=j(0)|0;o(+e);k=j(1)|0;j(0)|0;l(0,g|0);l(1,f&2147483647|k&-2147483648);e=+n();o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=+n();o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Bh(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Bh(c),w?u:v);break b}if(k){break b}c:{if(Ue(s)){break c}if(Ue(t)){break c}if(Ue(r)){break c}if(!Ue(q)){break a}}o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Bh(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Bh(c),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=(u=+n(),v=d,w=Bh(d),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+e);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);e=(u=+n(),v=e,w=Bh(e),w?u:v)}m=(b*e+d*c)*N;p=(b*d-e*c)*N}Rl(a,p,m)}function hr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=ab-128|0;ab=i;v[i+120>>2]=b;k=tF(c,d);v[i+4>>2]=1098;m=sF(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=yd(k);if(!j){v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}Ce(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[22452]=0;h=Q(1116,a|0,i+120|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[22452]=0;b=Q(1117,a|0,i+120|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}b=v[a>>2];v[22452]=0;n=T(1118,b|0)|0;b=v[22452];v[22452]=0;g:{if((b|0)!=1){if(g){break g}v[22452]=0;n=Q(1119,e|0,n|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}q=o+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=q;if(!r){continue e}v[22452]=0;T(1120,a|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((ub(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=v[Mj(b,o)>>2];j:{if(g){break j}v[22452]=0;p=Q(1119,e|0,p|0)|0;s=v[22452];v[22452]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n|0)==(p|0)){r=1;if((ub(b)|0)!=(q|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Bc(m);ab=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!pd(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Bc(m);S(b|0)}L()}function n8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=ab-144|0;ab=c;e=yl(c+40|0,a);v[22452]=0;d=Q(408,c+24|0,43966)|0;a=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[22452]=0;v[c>>2]=19923456;v[c+4>>2]=0;U(409,e|0,d|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break n}yb(d);if(w[e+3|0]&64){break e}v[22452]=0;d=Q(408,c+24|0,13313)|0;a=v[22452];v[22452]=0;if((a|0)==1){break m}v[22452]=0;da(440,e|0,b|0,d|0,848)|0;a=v[22452];v[22452]=0;if((a|0)==1){break l}yb(d);v[c+20>>2]=0;v[c+16>>2]=0;v[22452]=0;d=Q(408,c+24|0,16694)|0;a=v[22452];v[22452]=0;if((a|0)==1){break k}v[22452]=0;U(849,e|0,c+20|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break j}yb(d);v[22452]=0;d=Q(408,c+24|0,16666)|0;a=v[22452];v[22452]=0;if((a|0)==1){break i}v[22452]=0;U(849,e|0,c+16|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}yb(d);a=v[c+20>>2];d=v[c+16>>2];o:{if(!a|d>>>0<a>>>0){break o}f=v[v[v[v[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}v[b+20>>2]=d;v[b+16>>2]=a}d=Ye(c+24|0);v[22452]=0;f=Q(408,c|0,14097)|0;a=v[22452];v[22452]=0;if((a|0)==1){break d}v[22452]=0;U(850,e|0,d|0,f|0);a=v[22452];v[22452]=0;if((a|0)==1){break g}yb(f);if(jc(v[d>>2],v[d+4>>2])){break f}a=v[b+16>>2];v[22452]=0;R(802,d|0,a|0);a=v[22452];v[22452]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d);break a}a=P()|0;O()|0;yb(f);break b}v[22452]=0;R(851,b|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break c}ec(d)}Sg(e);ab=c+144|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}ec(d)}Sg(e);S(a|0);L()}function Naa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;h=ab-32|0;ab=h;t=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;g=e+(h+16|0)|0;e=a+e|0;v[g>>2]=v[e+44>>2];v[g+4>>2]=v[e+48>>2];f=f+1|0;continue}break}w=v[a+24>>2];x=v[a+20>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;y=v[a+8>>2];z=v[a+12>>2];a:while(1){b:{if(!d){f=0;while(1){if((f|0)==2){break b}b=f<<3;c=b+a|0;b=b+(h+16|0)|0;v[c+44>>2]=v[b>>2];v[c+48>>2]=v[b+4>>2];f=f+1|0;continue}}f=v[h+8>>2];g=((((v[h+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+t|0;e=(((f>>>16|0)+4&131064)<<1)+b|0;l=u[e+38>>1];m=u[e+36>>1];n=u[e+34>>1];o=u[e+32>>1];p=u[e+30>>1];q=u[e+28>>1];r=u[e+26>>1];j=u[e+24>>1];f=0;while(1)if((f|0)==2){l=v[a+72>>2];e=v[a+68>>2];m=e;n=e>>31;e=v[a+64>>2];o=e;p=e>>31;e=v[a+60>>2];q=e;r=e>>31;f=0;while(1){if((f|0)!=2){j=(f<<2)+h|0;g=v[j>>2];e=(h+16|0)+(f<<3)|0;k=v[e+4>>2];i=v[e>>2];v[e+4>>2]=i;s=g<<8;g=s;g=oia(q,r,g,g>>31);A=db;C=e;e=Sb(i,-16777216,16776704);i=oia(o,p,e,e>>31);g=i+g|0;e=db+A|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=Sb(k,-16777216,16776704);k=oia(m,n,g,g>>31);g=i+k|0;e=db+e|0;e=g>>>0<k>>>0?e+1|0:e;g=g+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Cc(g,e,24);v[C>>2]=e-(l&s);v[j>>2]=(e|0)/256;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[h>>2],x);v[c+4>>2]=v[c+4>>2]+B(w,v[h+4>>2]);Lb(h+8|0,y,z);c=c+8|0;d=d-1|0;continue a}else{e=g+(f<<1)|0;v[(f<<2)+h>>2]=(((((B(n,u[e+8>>1])+B(o,u[e+4>>1])|0)+B(m,u[e+12>>1])|0)+B(l,u[e+16>>1])|0)/2|0)+((((B(u[e-8>>1],r)+B(u[e-12>>1],j)|0)+B(u[e-4>>1],q)|0)+B(u[e>>1],p)|0)/2|0)|0)/16384;f=f+1|0;continue}}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+32|0}function Y9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;f=ab-48|0;ab=f;e=DN(f+32|0,1<<v[b+12>>2]);while(1){c=v[a>>2];if(Ag(c,v[a+4>>2])>>>0>d>>>0){c=He(c,d);CN(Hc(v[e>>2],d),A[c>>3]);d=d+1|0;continue}break}BN(b,e);x=f,y=wb(v[e>>2]),v[x+8>>2]=y;u=wb(v[e+4>>2]);while(1){i=v[f+8>>2];if(Tb(i,u)){k=A[i+8>>3];h=ab-32|0;ab=h;o(+A[i>>3]);d=j(1)|0;r=j(0)|0;o(+k);c=j(1)|0;s=j(0)|0;q=d&2147483647;p=c&2147483647;c=(q|0)==(p|0)&r>>>0<s>>>0|q>>>0<p>>>0;d=c?r:s;c=c?q:p;w=c;l(0,d|0);l(1,c|0);m=+n();t=c>>>20|0;g=m;a:{if((t|0)==2047){break a}c=(q|0)==(p|0)&r>>>0>s>>>0|q>>>0>p>>>0;l(0,(c?r:s)|0);c=c?q:p;l(1,c|0);k=+n();b:{if(!(d|w)){break b}c=c>>>20|0;if((c|0)==2047){break b}g=k+m;if((c-t|0)>=65){break a}c:{if(c>>>0>=1534){m=m*1.90109156629516e-211;k=k*1.90109156629516e-211;g=5.260135901548374e210;break c}g=1;if(t>>>0>572){break c}m=m*5.260135901548374e210;k=k*5.260135901548374e210;g=1.90109156629516e-211}KG(h+24|0,h+16|0,k);KG(h+8|0,h,m);g=g*K(A[h>>3]+A[h+16>>3]+A[h+8>>3]+A[h+24>>3]);break a}g=k}m=g;ab=h+32|0;CN(i,So(m));In(f+8|0);continue}break}AN(b,e);yN(e);d=1;while(1){c=v[e>>2];if(Cg(c,v[e+4>>2])>>>1>>>0>d>>>0){Oy(Hc(c,d),2);c=v[e>>2];Oy(Hc(c,(Cg(c,v[e+4>>2])>>>1|0)+d|0),0);d=d+1|0;continue}break}BN(b,e);x=f,y=wb(v[e>>2]),v[x+24>>2]=y;i=wb(v[e+4>>2]);while(1){d=v[f+24>>2];if(Tb(d,i)){xN(f+8|0,d);c=v[f+20>>2];v[d+8>>2]=v[f+16>>2];v[d+12>>2]=c;c=v[f+12>>2];v[d>>2]=v[f+8>>2];v[d+4>>2]=c;In(f+24|0);continue}break}AN(b,e);yN(e);i=v[a>>2];c=Ag(i,v[a+4>>2]);b=v[e>>2];d=0;while(1){if((d|0)==(c|0)){Vj(e);ab=f+48|0}else{a=Hc(b,d);x=He(i,d),z=A[a>>3],A[x>>3]=z;d=d+1|0;continue}break}}function jK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{b:{d=b;e=v[b>>2];if(e){if(!v[b+4>>2]){break b}c=v[b+4>>2];c:{if(c){d=nR(c);break c}while(1){c=gh(d);d=v[d+8>>2];if(!c){continue}break}}e=v[d>>2];if(e){break b}}e=v[d+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[d+8>>2];g=0}d:{e:{if(gh(d)){v[v[d+8>>2]>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=v[d+8>>2]+4|0;break e}v[v[d+8>>2]+4>>2]=e;c=v[d+8>>2]}c=v[c>>2]}h=!w[d+12|0];if((b|0)!=(d|0)){f=v[b+8>>2];v[d+8>>2]=f;if(!gh(b)){f=v[d+8>>2]+4|0}v[f>>2]=d;f=v[b>>2];v[d>>2]=f;Gl(f,d);f=v[b+4>>2];v[d+4>>2]=f;if(f){Gl(f,d)}t[d+12|0]=w[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=w[c+12|0];f:{g:{if(!gh(c)){if(!b){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;Lp(v[c+8>>2]);b=v[c>>2];a=(b|0)==(a|0)?c:a;c=v[b+4>>2]}b=v[c>>2];h:{if(!(w[b+12|0]?0:b)){d=v[c+4>>2];if(w[d+12|0]?0:d){break h}t[c+12|0]=0;i:{b=v[c+8>>2];if((b|0)!=(a|0)){if(w[b+12|0]){break i}a=b}t[a+12|0]=1;return}if(!gh(b)){break g}b=v[b+8>>2]+4|0;break f}d=v[c+4>>2];if(w[d+12|0]?0:d){break h}t[b+12|0]=1;t[c+12|0]=0;Kp(c);c=v[c+8>>2];d=v[c+4>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[d+12|0]=1;Lp(v[c+8>>2]);return}if(!b){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;Kp(v[c+8>>2]);b=v[c+4>>2];a=(b|0)==(a|0)?c:a;c=v[b>>2]}d=v[c>>2];j:{if(w[d+12|0]?0:d){break j}b=v[c+4>>2];if(!(w[b+12|0]?0:b)){t[c+12|0]=0;b=v[c+8>>2];if(!((a|0)!=(b|0)?w[b+12|0]:0)){t[b+12|0]=1;return}if(gh(b)){b=v[b+8>>2]+4|0;break f}b=v[b+8>>2];break f}if(w[d+12|0]?0:d){break j}t[b+12|0]=1;t[c+12|0]=0;Lp(c);c=v[c+8>>2];d=v[c>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[d+12|0]=1;Kp(v[c+8>>2]);return}b=v[b+8>>2]}c=v[b>>2];continue}}t[e+12|0]=1}}function sga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=ab-32|0;ab=f;i=cf(a,c);Xd(f+8|0,v[a+28>>2]);c=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=c;j=a;a:{if(!i){c=0;if(Vc(a,5)){break a}}e=ab-160|0;ab=e;g=yl(e+56|0,v[a+28>>2]);v[22452]=0;a=Q(408,e+8|0,27807)|0;c=v[22452];v[22452]=0;b:{c:{d:{e:{if((c|0)!=1){v[22452]=0;v[e+48>>2]=19923456;v[e+52>>2]=0;U(409,g|0,a|0,e+48|0);c=v[22452];v[22452]=0;if((c|0)==1){break e}yb(a);if(!(w[g+3|0]&64)){break d}break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(a);break c}t[e+48|0]=0;t[e+47|0]=0;v[22452]=0;a=Q(408,e+8|0,10055)|0;c=v[22452];v[22452]=0;f:{g:{h:{i:{if((c|0)!=1){v[22452]=0;U(448,g|0,e+48|0,a|0);c=v[22452];v[22452]=0;if((c|0)==1){break i}yb(a);if(!w[e+48|0]){break b}jf(e+48|0,50);v[22452]=0;a=Q(408,e+8|0,13194)|0;c=v[22452];v[22452]=0;if((c|0)==1){break f}v[22452]=0;U(448,g|0,e+47|0,a|0);c=v[22452];v[22452]=0;if((c|0)==1){break g}yb(a);c=dj(b);h=w[e+48|0];if(c>>>0<h>>>0){a=$y(e+8|0,v[b+12>>2]);v[22452]=0;U(449,b|0,h|0,a|0);c=v[22452];v[22452]=0;if((c|0)==1){break h}Uk(a)}k=x[jj(b,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){c=w[e+47|0];m=b,n=dj(b)>>>0>c>>>0?c:0,t[m+16|0]=n;break b}Re(jj(b,a),k);a=jj(b,a);v[22452]=0;R(450,e+8|0,c|0);l=v[22452];v[22452]=0;if((l|0)!=1){v[22452]=0;W(451,g|0,a|0,e+8|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break j}c=c+1|0;yb(e+8|0);continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(e+8|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(a);break c}c=P()|0;O()|0;Uk(a);break c}c=P()|0;O()|0;yb(a);break c}c=P()|0;O()|0}Sg(g);S(c|0);L()}Sg(g);ab=e+160|0;c=i}Te(j,c,f+24|0);ab=f+32|0}function Oaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;h=ab-32|0;ab=h;w=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;g=e+(h+16|0)|0;e=a+e|0;v[g>>2]=v[e+44>>2];v[g+4>>2]=v[e+48>>2];f=f+1|0;continue}break}x=v[a+24>>2];y=v[a+20>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;z=v[a+8>>2];A=v[a+12>>2];a:while(1){b:{if(!d){f=0;while(1){if((f|0)==2){break b}b=f<<3;c=b+a|0;b=b+(h+16|0)|0;v[c+44>>2]=v[b>>2];v[c+48>>2]=v[b+4>>2];f=f+1|0;continue}}f=v[h+8>>2];g=(((v[h+12>>2]&2147483647)<<1|f>>>31)&-2)+w|0;e=(((f>>>16|0)+4&131064)<<1)+b|0;l=u[e+38>>1];m=u[e+36>>1];n=u[e+34>>1];o=u[e+32>>1];p=u[e+30>>1];q=u[e+28>>1];r=u[e+26>>1];j=u[e+24>>1];f=0;while(1)if((f|0)==2){l=v[a+72>>2];e=v[a+68>>2];m=e;n=e>>31;e=v[a+64>>2];o=e;p=e>>31;e=v[a+60>>2];q=e;r=e>>31;f=0;while(1){if((f|0)!=2){j=(f<<2)+h|0;g=v[j>>2];e=(h+16|0)+(f<<3)|0;k=v[e+4>>2];i=v[e>>2];v[e+4>>2]=i;s=g<<8;g=s;g=oia(q,r,g,g>>31);C=db;D=e;e=Sb(i,-16777216,16776704);i=oia(o,p,e,e>>31);g=i+g|0;e=db+C|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=Sb(k,-16777216,16776704);k=oia(m,n,g,g>>31);g=i+k|0;e=db+e|0;e=g>>>0<k>>>0?e+1|0:e;g=g+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Cc(g,e,24);v[D>>2]=e-(l&s);v[j>>2]=(e|0)/256;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[h>>2],y);v[c+4>>2]=v[c+4>>2]+B(x,v[h+4>>2]);Lb(h+8|0,z,A);c=c+8|0;d=d-1|0;continue a}else{e=f+g|0;v[(f<<2)+h>>2]=(((((B(n,t[e+4|0])+B(o,t[e+2|0])|0)+B(m,t[e+6|0])|0)+B(l,t[e+8|0])<<8)/2|0)+((((B(t[e-4|0],r)+B(t[e-6|0],j)|0)+B(t[e-2|0],q)|0)+B(t[e|0],p)<<8)/2|0)|0)/16384;f=f+1|0;continue}}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+32|0}function Mg(a,b,c,d){var e=0,f=0,g=0,h=0;f=v[a+4>>2];if(!f){b=v[a>>2];f=ab-16|0;ab=f;a:{if((c|0)==189){t[b+3843|0]=d>>>7;t[b+3844|0]=d>>>6&1;break a}e=c&224;if(!e){if((c|0)!=8){if((c|0)!=260){break a}a=0;c=1;while(1){if((a|0)==6){break a}g=b+B(a>>>0<3?a:a+6|0,44)|0;e=g+148|0;g=g+16|0;h=c&d;b:{if(h){Bn(g,e);break b}Bn(g,0)}t[e+40|0]=!h;a=a+1|0;c=c<<1&510;continue}}t[b+3842|0]=d>>>6&1;a=0;while(1){if((a|0)==18){break a}Vy((b+B(a,44)|0)+16|0);a=a+1|0;continue}}if(e-160>>>0<=32){a=c&15;if(a>>>0>8){break a}a=b+B(c&256?a+9|0:a,44)|0;v[f+8>>2]=a+16;b=v[a+52>>2];v[f+12>>2]=b;e=b?2:1;c:{b=c&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}g=d&3;h=d>>>2&7;a=0;c=(d&32)!=0;while(1){if((a|0)==(e|0)){break a}b=v[(f+8|0)+(a<<2)>>2];ON(v[b>>2],c);ON(v[b+4>>2],c);u[b+22>>1]=h;Uy(b);Vy(b);t[b+21|0]=g;Uy(b);Vy(b);a=a+1|0;continue}}a=0;while(1){if((a|0)==(e|0)){break a}b=v[(f+8|0)+(a<<2)>>2];u[b+20>>1]=x[b+20>>1]&768|d&255;Uy(b);a=a+1|0;continue}}t[a+58|0]=(d&32)>>>5;t[a+57|0]=(d&16)>>>4;b=d>>>1&7;u[a+46>>1]=b?9-b|0:0;u[a+48>>1]=d&1;break a}if((e|0)!=224&e>>>0>=129|-4144960>>>c&1){break a}a=t[(c&31)+28992|0];a=(b+B(c&256?a+18|0:a,84)|0)+808|0;d:{switch(e-32>>>5|0){case 0:t[a+79|0]=d>>>7;t[a+80|0]=(d&64)>>>6;t[a+78|0]=(d&32)>>>5;t[a+77|0]=(d&16)>>>4;Cn(a);u[a+14>>1]=x[((d&15)<<1)+29024>>1];break a;case 1:u[a+68>>1]=w[(d>>>6|0)+21583|0];PN(a);u[a+22>>1]=(d&63)<<2;break a;case 2:u[a+24>>1]=d>>>4;Cn(a);u[a+26>>1]=d&15;Cn(a);break a;case 3:b=d>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=d&15;Cn(a);break a;case 6:break d;default:break a}}u[a+12>>1]=d&7}ab=f+16|0;return}eb[v[v[f>>2]>>2]](f,b,c,d)}function jV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=ab+-64|0;ab=f;qc(b);ro(a);a:{if(!Mh(b,f+56|0)){break a}if(!dD(f+56|0)){break a}if(!c){l=1;break a}if(!Hb(b,4)){break a}hv(a);p=f,q=gv(),v[p+32>>2]=q;c=f+32|0;fv(vj(v[a+4>>2])+32|0,c);Pq(c);k=v[vj(v[a+4>>2])+32>>2];c=jk(b);if(c&1){break a}d=c-4|0;Nc(b,d);h=ab-16|0;ab=h;c=h+8|0;Xu(c,b);e=w[Cb(c,0)|0];i=w[Cb(c,1)|0];c=w[Cb(c,2)|0];ab=h+16|0;h=c|(i<<8|e<<16);if(!h){break a}v[22452]=0;R(166,k|0,h|0);c=v[22452];v[22452]=0;l=1;if((c|0)==1){a=V(88408)|0;if((O()|0)==(fa(88408)|0)){_(a|0)|0;$();l=0;break a}S(a|0);L()}Nc(b,4);m=f+32|0;cD(m,b);i=v[k>>2];e=ab-32|0;ab=e;b=v[f+32>>2];t[e+24|0]=w[b|0];t[e+25|0]=w[b+1|0];t[e+26|0]=w[b+2|0];t[e+27|0]=w[b+3|0];c=bD(e+8|0);d=b+d|0;v[c+12>>2]=d-4;v[c+8>>2]=b;uj(c,w[d-1|0]);b=h;b:while(1){c:{d:{e:{if(!b){break e}if(uj(c,1)){break d}d=1;while(1){g=uj(c,2);d=g+d|0;if((g|0)==3){continue}break}v[e+4>>2]=d;mc(e+4|0,b);d=0;g=v[e+4>>2];while(1)if((d|0)==(g|0)){if(!b){break e}break d}else{b=b-1|0;p=i+b|0,q=uj(c,8),t[p|0]=q;d=d+1|0;continue}}ab=e+32|0;break c}g=uj(c,2);d=g+2|0;v[e+4>>2]=d;f:{if((g|0)==3){if(uj(c,1)){g=w[Cb(e+24|0,3)|0]}else{g=7}g=uj(c,g);while(1){j=uj(c,3);d=j+d|0;if((j|0)==7){continue}break}v[e+4>>2]=d;break f}g=uj(c,w[Cb(e+24|0,g)|0])}mc(e+4|0,b);d=0;o=v[e+4>>2];while(1){if((d|0)==(o|0)){continue b}j=0;n=b+g|0;if(h>>>0>n>>>0){j=w[i+n|0]}b=b-1|0;t[i+b|0]=j;d=d+1|0;continue}}break}de(f+16|0,v[k>>2],v[k+4>>2]);Gg(f+24|0,v[f+16>>2],v[f+20>>2]);b=Vd(f+8|0);b=Nq(m,v[f+24>>2],v[f+28>>2],v[b>>2],v[b+4>>2]);Mc(vj(v[a+4>>2])+12|0,b);qb(b)}ab=f- -64|0;return l|0}function nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=ab-32|0;ab=g;s=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+16|0)|0;e=a+e|0;v[h>>2]=v[e+44>>2];v[h+4>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;t=v[a+8>>2];w=v[a+12>>2];a:while(1){if(d){e=v[g+8>>2];f=((((v[g+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+s|0;b=e>>>21&2040;l=u[b+39878>>1];m=u[b+39876>>1];n=u[b+39874>>1];o=u[b+39872>>1];b=0;while(1)if((b|0)==2){l=v[a+72>>2];b=v[a+68>>2];m=b;n=b>>31;b=v[a+64>>2];o=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){q=(b<<2)+g|0;f=v[q>>2];e=(g+16|0)+(b<<3)|0;k=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;r=f<<8;f=r;f=oia(y,z,f,f>>31);p=db;A=e;e=Sb(j,-16777216,16776704);j=oia(o,x,e,e>>31);f=j+f|0;e=db+p|0;e=f>>>0<j>>>0?e+1|0:e;p=f;f=Sb(k,-16777216,16776704);k=oia(m,n,f,f>>31);f=p+k|0;e=db+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[A>>2]=e-(l&r);v[q>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[g>>2],i>>12);h=b+h|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],h>>12);Lb(g+8|0,t,w);c=c+8|0;d=d-1|0;continue a}else{e=f+(b<<1)|0;v[(b<<2)+g>>2]=(((B(n,u[e>>1])+B(o,u[e-4>>1])|0)+B(m,u[e+4>>1])|0)+B(l,u[e+8>>1])|0)/16384;b=b+1|0;continue}}break}v[a+40>>2]=h;v[a+36>>2]=i;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+32|0}function yca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=ab-48|0;ab=f;k=c+484344|0;fg(k,w[b+70|0]|w[b+71|0]<<8);a:{b:{while(1){if((w[b+70|0]|w[b+71|0]<<8)>>>0<=j>>>0){break b}h=v[a+8>>2];e=jg(a);Ob(a,1);c:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=ue(a)+1|0;break c}c=xg(a)}d=xg(a);Nc(a,e+h|0);Md(f,a,d);h=bc(f+24|0,f);qb(f);v[22452]=0;c=Y(217,k|0,j&65535,(c?c>>>0<1024?c:1024:64)|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=Rb(k,j);m=f,n=vg(c),v[m>>2]=n;l=ug(c);while(1){d=v[f>>2];if(!Tb(d,l)){break d}v[22452]=0;c=T(197,h|0)|0;e=v[22452];v[22452]=0;e:{f:{g:{if((e|0)!=1){if(!(c&128)){break g}if(c&1){v[22452]=0;e=T(197,h|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break a}t[d|0]=e}if(c&2){break f}break e}break a}t[d|0]=c;c=255}v[22452]=0;e=T(197,h|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break a}t[d+1|0]=e}e=0;if(c&4){v[22452]=0;e=T(197,h|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break a}}if(c&8){v[22452]=0;g=T(197,h|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break a}t[d+3|0]=g}if(c&16){v[22452]=0;c=T(197,h|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break a}t[d+5|0]=c}h:{i:{c=w[d|0];if(!c){break i}i=255;if((c|0)==97){break h}if(c>>>0>96){break i}i=c+12|0;break h}i=0}t[d|0]=i;j:{if(w[d+5|0]|w[d+3|0]){Mf(d);break j}t[d+3|0]=0}if(w[d+1|0]==255){t[d+1|0]=0}c=e-16|0;k:{if((c&255)>>>0<=64){t[d+4|0]=c;t[d+2|0]=1;break k}if(e>>>0<96){break k}c=e&15;t[d+4|0]=c;e=e-96>>4;t[d+2|0]=w[e+27134|0];if((e|0)!=6){break k}t[d+4|0]=c<<2}ui(f);continue}}j=j+1|0;qb(f+24|0);continue}break}break a}ab=f+48|0;return}a=P()|0;O()|0;qb(f+24|0);S(a|0);L()}function nZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=ab-624|0;ab=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=1133;h=ee(a+200|0,a+208|0,a+16|0);b=a+192|0;zc(b,e);v[22452]=0;i=T(1111,b|0)|0;b=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){t[a+191|0]=0;b=v[e+4>>2];v[22452]=0;b=pa(1141,a+616|0,c|0,d|0,a+192|0,b|0,f|0,a+191|0,i|0,h|0,a+196|0,a+608|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}if(!b){break e}b=w[14630]|w[14631]<<8|(w[14632]<<16|w[14633]<<24);t[a+183|0]=b;t[a+184|0]=b>>>8;t[a+185|0]=b>>>16;t[a+186|0]=b>>>24;b=w[14627]|w[14628]<<8|(w[14629]<<16|w[14630]<<24);v[a+176>>2]=w[14623]|w[14624]<<8|(w[14625]<<16|w[14626]<<24);v[a+180>>2]=b;v[22452]=0;W(1123,i|0,a+176|0,a+186|0,a+128|0);b=v[22452];v[22452]=0;if((b|0)==1){break g}v[a+4>>2]=1098;d=ee(a+8|0,0,a+4|0);c=a+16|0;b=v[a+196>>2];e=b-v[h>>2]|0;if((e|0)<393){break f}Ce(d,yd((e>>2)+2|0));c=v[d>>2];if(c){break f}v[22452]=0;X(1099);b=v[22452];v[22452]=0;if((b|0)==1){break c}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}if(w[a+191|0]){t[c|0]=45;c=c+1|0}e=v[h>>2];while(1){if(b>>>0<=e>>>0){t[c|0]=0;v[a>>2]=g;if((DF(a+16|0,a)|0)!=1){v[22452]=0;Z(1135,7987);b=v[22452];v[22452]=0;if((b|0)!=1){break a}break c}Bc(d)}else{b=a+128|0;j=c,k=w[(a+176|0)+(Mv(b,b+40|0,v[e>>2])-b>>2)|0],t[j|0]=k;c=c+1|0;e=e+4|0;b=v[a+196>>2];continue}break}}v[22452]=0;b=Q(1117,a+616|0,a+608|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}if(b){v[f>>2]=v[f>>2]|2}b=v[a+616>>2];Nb(a+192|0);Bc(h);ab=a+624|0;return b|0}e=P()|0;O()|0;break b}e=P()|0;O()|0;Bc(d)}Nb(a+192|0);Bc(h);S(e|0);L()}L()}function fV(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=ab-48|0;ab=f;h=di(b)^-1;a:{if(nc(v[d>>2],v[d+4>>2])>>>0<=h>>>0){qs(a);break a}di(b);g=c+4|0;if((w[g|0]|w[g+1|0]<<8)>>>0>=60){Ob(b,4)}j=f,k=di(b),v[j+44>>2]=k;Ob(b,4);c=di(b);i=di(b);if(!((c|0)>0&(i|0)>36)){qs(a);break a}if(Sp(ld(v[e>>2],v[Fb(v[d>>2],h)>>2]),13071)){qs(a);break a}dv(f,b,i,c);c=bc(f+24|0,f);qb(f);v[22452]=0;b=T(169,c|0)|0;d=v[22452];v[22452]=0;b:{if((d|0)==1){break b}c:{d:{if(!b){v[22452]=0;T(178,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break d}break b}b=w[g|0]|w[g+1|0]<<8;if(b>>>0<=39){v[22452]=0;Q(179,c|0,8)|0;b=v[22452];v[22452]=0;if((b|0)==1){break b}b=w[g|0]|w[g+1|0]<<8}if((b&65535)>>>0<=59){v[22452]=0;Q(179,c|0,16)|0;b=v[22452];v[22452]=0;if((b|0)==1){break b}}v[22452]=0;T(180,c|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break b}b=w[g|0]|w[g+1|0]<<8;e:{if(b>>>0>=120){v[22452]=0;T(180,c|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break b}v[22452]=0;Q(179,c|0,8)|0;break e}if(b>>>0>=100){v[22452]=0;Q(179,c|0,4)|0;b=v[22452];v[22452]=0;if((b|0)==1){break b}v[22452]=0;T(180,c|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break b}v[22452]=0;Q(179,c|0,4)|0;break e}if(b>>>0>=62){v[22452]=0;T(180,c|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break b}v[22452]=0;Q(179,c|0,4)|0;break e}v[22452]=0;T(180,c|0)|0}b=v[22452];v[22452]=0;if((b|0)==1){break b}v[22452]=0;b=T(180,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}v[22452]=0;U(181,f|0,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break c}bc(a,f);v[a+20>>2]=v[f+44>>2];qb(f)}qb(c);break a}}a=P()|0;O()|0;qb(c);S(a|0);L()}ab=f+48|0}function lq(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=ab-16|0;ab=e;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[a|0];switch(d|0){case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break a;case 2:break j;case 13:break k;case 0:break l;case 5:break c;case 9:break e;case 11:break f;case 20:break g;case 4:break h;case 3:break i;default:break d}}t[a|0]=0;break b}f=1;t[a|0]=1;t[e+15|0]=64;h=b,i=w[Qb(b,e+15|0)|0],t[h|0]=i;break a}d=c;c=w[b|0];if(!(c&3|c>>>0>223?d:1)){break a}t[b|0]=(c&252)>>>2;t[a|0]=12;break b}d=c;c=w[b|0];if(!(c&3|c>>>0>223?d:1)){break a}t[b|0]=(c&252)>>>2;t[a|0]=13;break b}d=w[b|0];if(d>>>0<240){while(1){if((f|0)==10){f=0;break a}g=w[f+43904|0];m:{n:{if(c){if(d>>>0<=g>>>0){break n}break m}if((d|0)!=(g|0)){break m}}t[a|0]=11;t[b|0]=f;break b}f=f+1|0;continue}}t[a|0]=11;t[b|0]=9;break b}o:{p:{q:{d=w[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}t[b|0]=0;t[a|0]=0;break b}t[a|0]=2;t[b|0]=w[b|0]<<2&60|2;break b}c=w[b|0];if(!c){break a}d=c&15;if(!d){t[b|0]=c>>>4;t[a|0]=3;break b}g=c&240;if(!g){t[a|0]=4;break b}if((d|0)==15){t[b|0]=c>>>4;t[a|0]=5;break b}if((g|0)!=240){break a}t[b|0]=d;t[a|0]=6;break b}c=b;b=w[b|0];t[c|0]=(b|0)==255?64:b>>>2|0;t[a|0]=2;break b}if((d|0)!=26){break a}r:{if(c){t[b|0]=0;break r}if(w[b|0]){break a}}t[a|0]=8;break b}s:{if(c){t[e+14|0]=w[b|0]&15;t[e+13|0]=9;c=w[Qb(e+14|0,e+13|0)|0];break s}c=w[b|0];if((c&14)>>>0>9|c&240){break a}}t[b|0]=c&15;t[a|0]=8}f=1}ab=e+16|0;return f}function $ca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=ab-16|0;ab=h;l=h,m=Wj(b),v[l>>2]=m;f=ab-16|0;ab=f;d=b;i=a;a=Kd(a);a:{b:{if(a){b=ac(i);while(1){c:{c=a+14|0;if(ct(d,c)){c=v[a>>2];if(!c){break b}break c}if(ct(c,d)){b=a+4|0;c=v[a+4>>2];if(c){a=b;break c}v[f+12>>2]=a;a=b;break a}v[f+12>>2]=a;a=b;break a}b=a;a=c;continue}}a=ac(i)}v[f+12>>2]=a}b=v[a>>2];if(!b){j=ab-16|0;ab=j;b=ac(i);k=hh(f,pc(48),ih(j+8|0,b));b=v[k>>2]+14|0;g=ab-16|0;ab=g;v[g+8>>2]=v[h>>2];c=v[g+8>>2];d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+24|0]=e;t[b+25|0]=e>>>8;t[b+26|0]=e>>>16;t[b+27|0]=e>>>24;t[b+28|0]=d;t[b+29|0]=d>>>8;t[b+30|0]=d>>>16;t[b+31|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b+16|0]=e;t[b+17|0]=e>>>8;t[b+18|0]=e>>>16;t[b+19|0]=e>>>24;t[b+20|0]=d;t[b+21|0]=d>>>8;t[b+22|0]=d>>>16;t[b+23|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);c=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[b+8|0]=c;t[b+9|0]=c>>>8;t[b+10|0]=c>>>16;t[b+11|0]=c>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;u[b+32>>1]=0;ab=g+16|0;l=ac(k),m=1,t[l+4|0]=m;ab=j+16|0;Pg(i,v[f+12>>2],a,v[f>>2]);b=Pd(f);$k(f);g=1}a=h+8|0;Og(a,$b(f,b),g);ab=f+16|0;a=Jp(a);ab=h+16|0;return a+32|0}function oba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0;g=ab-32|0;ab=g;s=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+16|0)|0;e=a+e|0;v[h>>2]=v[e+44>>2];v[h+4>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];a:while(1){if(d){e=v[g+8>>2];f=(((v[g+12>>2]&2147483647)<<1|e>>>31)&-2)+s|0;b=e>>>21&2040;l=u[b+39878>>1];m=u[b+39876>>1];n=u[b+39874>>1];o=u[b+39872>>1];b=0;while(1)if((b|0)==2){l=v[a+72>>2];b=v[a+68>>2];m=b;n=b>>31;b=v[a+64>>2];o=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;b=0;while(1){if((b|0)!=2){q=(b<<2)+g|0;f=v[q>>2];e=(g+16|0)+(b<<3)|0;k=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;r=f<<8;f=r;f=oia(z,A,f,f>>31);p=db;C=e;e=Sb(j,-16777216,16776704);j=oia(o,y,e,e>>31);f=j+f|0;e=db+p|0;e=f>>>0<j>>>0?e+1|0:e;p=f;f=Sb(k,-16777216,16776704);k=oia(m,n,f,f>>31);f=p+k|0;e=db+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[C>>2]=e-(l&r);v[q>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[g>>2],i>>12);h=b+h|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],h>>12);Lb(g+8|0,w,x);c=c+8|0;d=d-1|0;continue a}else{e=b+f|0;v[(b<<2)+g>>2]=(((B(n,t[e|0])+B(o,t[e-2|0])|0)+B(m,t[e+2|0])|0)+B(l,t[e+4|0])<<8)/16384;b=b+1|0;continue}}break}v[a+40>>2]=h;v[a+36>>2]=i;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+32|0}function aZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=ab-16|0;ab=x;v[c>>2]=a;z=d&512;A=h<<2;while(1){if((y|0)==4){if(ub(n)>>>0>1){C=x,D=kd(n),v[C+8>>2]=D;e=ab-16|0;ab=e;v[e+8>>2]=v[x+8>>2];f=v[te(e+8|0)>>2];ab=e+16|0;C=c,D=Ci(f,rk(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}ab=x+16|0}else{a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];h=pr(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 3:if(pd(n)){break a}h=v[Mj(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 2:if(pd(m)|!z){break a}C=c,D=Ci(kd(m),rk(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=e+A|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!xk(g,2048,v[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=v[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){h=h-4|0;s=v[h>>2];r=p+4|0;v[c>>2]=r;v[p>>2]=s;q=q-1|0;p=r;continue}break}d:{if(!q){s=0;break d}s=pr(g,48);p=v[c>>2]}while(1){r=p+4|0;if((q|0)>0){v[p>>2]=s;q=q-1|0;p=r;continue}break}v[c>>2]=r;v[p>>2]=j}e:{if((e|0)==(h|0)){p=pr(g,48);q=v[c>>2];h=q+4|0;v[c>>2]=h;v[q>>2]=p;break e}if(pd(l)){s=-1}else{s=t[oc(l,0)|0]}q=0;u=0;while(1){if((e|0)!=(h|0)){r=v[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;v[c>>2]=p;v[r>>2]=k;r=0;u=u+1|0;if(ub(l)>>>0<=u>>>0){s=q;break f}s=-1;if(w[oc(l,u)|0]==127){break f}s=t[oc(l,u)|0]}h=h-4|0;q=v[h>>2];v[c>>2]=p+4;v[p>>2]=q;q=r+1|0;continue}break}h=v[c>>2]}ir(B,h)}y=y+1|0;continue}break}}function uZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=ab-288|0;ab=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=1133;h=ee(a+152|0,a+160|0,a+16|0);b=a+144|0;zc(b,e);v[22452]=0;i=T(18,b|0)|0;b=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){t[a+143|0]=0;b=v[e+4>>2];v[22452]=0;b=pa(1134,a+280|0,c|0,d|0,a+144|0,b|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}if(!b){break e}b=w[14630]|w[14631]<<8|(w[14632]<<16|w[14633]<<24);t[a+135|0]=b;t[a+136|0]=b>>>8;t[a+137|0]=b>>>16;t[a+138|0]=b>>>24;b=w[14627]|w[14628]<<8|(w[14629]<<16|w[14630]<<24);v[a+128>>2]=w[14623]|w[14624]<<8|(w[14625]<<16|w[14626]<<24);v[a+132>>2]=b;v[22452]=0;W(1109,i|0,a+128|0,a+138|0,a+118|0);b=v[22452];v[22452]=0;if((b|0)==1){break g}v[a+4>>2]=1098;d=ee(a+8|0,0,a+4|0);c=a+16|0;b=v[a+148>>2];e=b-v[h>>2]|0;if((e|0)<99){break f}Ce(d,yd(e+2|0));c=v[d>>2];if(c){break f}v[22452]=0;X(1099);b=v[22452];v[22452]=0;if((b|0)==1){break c}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}if(w[a+143|0]){t[c|0]=45;c=c+1|0}e=v[h>>2];while(1){if(b>>>0<=e>>>0){t[c|0]=0;v[a>>2]=g;if((DF(a+16|0,a)|0)!=1){v[22452]=0;Z(1135,7987);b=v[22452];v[22452]=0;if((b|0)!=1){break a}break c}Bc(d)}else{b=a+118|0;j=c,k=w[((fi(b,b+10|0,e)-a|0)+a|0)+10|0],t[j|0]=k;c=c+1|0;e=e+1|0;b=v[a+148>>2];continue}break}}v[22452]=0;b=Q(1101,a+280|0,a+272|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break d}if(b){v[f>>2]=v[f>>2]|2}b=v[a+280>>2];Nb(a+144|0);Bc(h);ab=a+288|0;return b|0}e=P()|0;O()|0;break b}e=P()|0;O()|0;Bc(d)}Nb(a+144|0);Bc(h);S(e|0);L()}L()}function cha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=ab-32|0;ab=h;t[h+24|0]=44;v[h+16>>2]=-1;v[h+20>>2]=0;v[h+8>>2]=1042;v[h+12>>2]=2;d=ab+-64|0;ab=d;m=h+8|0;j=v[m>>2]&2?16:10;l=ab-32|0;ab=l;f=ze(l+16|0,1,0);a:{b:{c:{while(1){n=l+8|0;c=Eb(f);o=c;p=ub(f)+c|0;i=x[b>>1];g=0;d:{if((j|0)==10){_w(n,o,p,i);break d}e=i;c=B(j,j);r=B(c,j);q=B(c,c);e:{while(1){e=e&65535;k=g|1;if(e>>>0<j>>>0){break e}k=g|2;if(c>>>0>e>>>0){break e}k=g|3;if(e>>>0<r>>>0){break e}if(e>>>0<q>>>0){k=g+4|0}else{g=g+4|0;e=(e>>>0)/(q>>>0)|0;continue}break}}c=k;if((c|0)>(p-o|0)){v[n+4>>2]=61;v[n>>2]=p;break d}e=c+o|0;c=e;while(1){g=i&65535;i=(g|0)/(j|0)|0;c=c-1|0;t[c|0]=w[(g-B(i,j)|0)+4856|0];if(i&65535){continue}break}v[n+4>>2]=0;v[n>>2]=e}if(!v[l+12>>2]){break c}c=If(ub(f));v[22452]=0;R(59,f|0,c|0);c=v[22452];v[22452]=0;if((c|0)!=1){continue}break}break b}b=v[l+8>>2];c=Eb(f);v[22452]=0;R(60,f|0,b-c|0);b=v[22452];v[22452]=0;f:{if((b|0)!=1){v[22452]=0;R(73,d|0,f|0);b=v[22452];v[22452]=0;if((b|0)!=1){break f}break b}break b}pb(f);ab=l+32|0;break a}a=P()|0;O()|0;pb(f);S(a|0);L()}b=d+16|0;Ik(b,d,v[m>>2]);c=v[m+4>>2];i=v[m>>2];v[22452]=0;W(77,d+32|0,b|0,i|0,c|0);b=v[22452];v[22452]=0;g:{h:{i:{j:{k:{if((b|0)!=1){v[22452]=0;U(78,d+48|0,d+32|0,m|0);b=v[22452];v[22452]=0;if((b|0)==1){break k}v[22452]=0;R(72,a|0,d+48|0);a=v[22452];v[22452]=0;if((a|0)==1){break j}pb(d+48|0);pb(d+32|0);pb(d+16|0);pb(d);ab=d- -64|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;break i}a=P()|0;O()|0;pb(d+48|0)}pb(d+32|0)}pb(d+16|0);pb(d);S(a|0);L()}ab=h+32|0}function Cda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=ab-48|0;ab=e;ed(b,2);Zj(e+16|0,2,a+1|0);f=e+32|0;tc(f,v[e+16>>2],v[e+20>>2],w[e+24|0]);ke(b+43|0,f);pb(f);a:{b:{c:{d:{e:{f=a;switch(w[a|0]){case 2:break b;case 1:break d;case 0:break e;default:break a}}d=v[b+4>>2];a=v[b+8>>2];break c}a=f+16|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=d;a=f+20|0;v[e+32>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[e+16>>2]=d-1;g=e+32|0;d=v[zb(g,e+16|0)>>2];v[b+4>>2]=d;a=f+24|0;v[e+32>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=v[zb(g,b)>>2];v[b+8>>2]=a;u[b+34>>1]=x[b+34>>1]&65533|w[f+31|0]<<1&2}if(a>>>0>d>>>0&a>>>0>=2){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}g=e+16|0;qh(g,f+16|0);a=e+32|0;d=v[e+16>>2];d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;qh(g,f+20|0);d=v[e+16>>2];d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[a+4|0]=d;t[a+5|0]=d>>>8;t[a+6|0]=d>>>16;t[a+7|0]=d>>>24;qh(g,f+24|0);d=v[e+16>>2];d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[a+8|0]=d;t[a+9|0]=d>>>8;t[a+10|0]=d>>>16;t[a+11|0]=d>>>24;v[e+8>>2]=v[e+40>>2];a=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=a;fl(b,1,e)}t[e+32|0]=w[f+28|0];t[e+16|0]=64;h=b,i=w[Qb(e+32|0,e+16|0)|0]<<2,u[h+30>>1]=i;a=f+32|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b+24>>2]=a;b=b+24|0;f:{if(!c){break f}if(w[f|0]==2){a=a&65535;v[b>>2]=a;break f}if(y[b>>2]>=65536){v[b>>2]=65535}a=v[b>>2]}g:{h:{if(!a){c=8363;break h}c=1024;if(a>>>0>1023){break g}}v[b>>2]=c}ab=e+48|0}function Qx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=ab-16|0;ab=e;i=VK(b,c);a:{if(!v[b+656>>2]|!(t[i+6|0]&1)){break a}f=v[i>>2];j=a+1074312|0;rb(e+8|0,j,31);g=sb(v[v[e+8>>2]>>2],v[e+12>>2]);d=Eu(v[b+656>>2],c);if(jc(v[d>>2],v[d+4>>2])){break a}g=f+(g^1)|0;rb(e+8|0,j,31);f=w[d+12|0];b:{c:{if(!sb(v[v[e+8>>2]>>2],v[e+12>>2])){d:{if(!(f&2)){break d}h=w[d+14|0];k=!(v[a+480180>>2]&1048580)+x[Fb(v[d>>2],h)>>1]|0;if(!(w[b+89|0]&8)|(!(f&4)|(h|0)!=w[d+16|0])){f=l}else{rb(e+8|0,j,70);f=sb(v[v[e+8>>2]>>2],v[e+12>>2])}if(f|(g|0)!=(k|0)){break d}g=x[Fb(v[d>>2],w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){a=v[d>>2];if((x[Fb(a,w[d+16|0])>>1]+1|0)!=(g|0)){break b}g=x[Fb(a,w[d+15|0])>>1];rb(e+8|0,j,93);if(!sb(v[v[e+8>>2]>>2],v[e+12>>2])|(c|0)!=1|v[b+88>>2]&2048){break b}t[i+6|0]=w[i+6|0]&254;break b}k=1;f=x[on(v[d+4>>2])>>1];if(g>>>0>f>>>0){break c}break b}e:{f:{if(!(!(f&4)|w[b+669|0]&8)){if(x[i+4>>1]==65535){break f}rb(e+8|0,j,97);if(sb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}f=w[d+12|0]}if(f&2){h=v[d>>2];f=x[Fb(h,w[d+13|0])>>1];h=x[Fb(h,w[d+14|0])>>1]+1|0;break e}f=x[on(v[d+4>>2])>>1];k=g>>>0>f>>>0;h=f;break e}h=v[d>>2];f=x[Fb(h,w[d+15|0])>>1];h=x[Fb(h,w[d+16|0])>>1]+1|0}f=g>>>0<h>>>0?g:f}g:{if(!k|c){break g}g=v[a+480180>>2];c=v[b+88>>2];if(!(!(g&16777248)&(!(c&2048)|(g|0)==16384))){c=c|4096;v[b+88>>2]=c}if(w[on(v[d+4>>2])+2|0]|!(v[a+480180>>2]&16777248?1:x[b+786>>1])){break g}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=c|4096}g=f}rb(e+8|0,j,31);m=i,n=sb(v[v[e+8>>2]>>2],v[e+12>>2])+g|0,v[m>>2]=n}ab=e+16|0}function ss(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=ab-144|0;ab=g;a:{b:{c:{d:{e:{f:{g:{h:{if(!d){break h}e=v[d+4>>2];if(!e&c>>>0<=y[d>>2]|e){break h}a=aa(8)|0;v[22452]=0;Q(97,a|0,21598)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break g}b=P()|0;O()|0;ba(a|0);break a}if(!b){a=aa(8)|0;v[22452]=0;T(791,a|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break f}b=P()|0;O()|0;ba(a|0);break a}e=ab-16|0;ab=e;Gg(e+8|0,b,c);h=g+120|0;b=h;ED(b,v[e+8>>2],v[e+12>>2]);v[b+12>>2]=0;ab=e+16|0;i:{j:{if(a&2){b=zm(g+96|0,h);v[22452]=0;b=T(792,b|0)|0;f=v[22452];v[22452]=0;e=1;if((f|0)==1){break i}if((b|0)==1){break j}e=zm(g+72|0,h);v[22452]=0;f=T(793,e|0)|0;i=v[22452];v[22452]=0;e=1;if((i|0)==1){break e}k=(f|0)==1;if(k){break j}e=zm(g+48|0,h);v[22452]=0;i=Q(794,e|0,d|0)|0;j=v[22452];v[22452]=0;e=1;if((j|0)==1){break d}l=(i|0)==1;if(l){break j}e=zm(g+24|0,h);v[22452]=0;j=Q(795,e|0,d|0)|0;m=v[22452];v[22452]=0;e=1;if((m|0)==1){break c}if((j|0)==1){break j}b=(b|0)==-1?-1:0;b=k?b:(f|0)==-1?-1:b;f=(j|0)==-1?-1:l?b:(i|0)==-1?-1:b}k:{if(!(a&1)){break k}b=31552;while(1){if((b|0)==32068){break k}a=v[b>>2];if(a){e=zm(g,h);v[22452]=0;a=Q(a|0,e|0,d|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break b}e=1;if((a|0)==1){break j}f=(a|0)==-1?-1:f}b=b+12|0;continue}}if(d){e=0;if((f|0)!=-1){break j}e=Fc(v[d>>2],v[d+4>>2])>>>0>c>>>0?-1:0;break j}e=0;if((f|0)!=-1){break j}e=c>>>0>2047?1:-1}ab=g+144|0;return e}b=P()|0;O()|0;break a}ia(a|0,88688,24);L()}ia(a|0,88584,24);L()}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}S(b|0);L()}function KI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=C(0);d=ab-48|0;ab=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==v[v[a>>2]+24604>>2]){break d}c=d+8|0;a=v[a>>2];gc(c,a+24604|0,40);v[d+8>>2]=b;Tx(a,c);break d;case 2:b=a+24|0;a=v[b>>2];e=a+24664|0;f=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=f;e=a+24656|0;f=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=f;e=v[a+24652>>2];v[d+8>>2]=v[a+24648>>2];v[d+12>>2]=e;e=ab-16|0;ab=e;a=3;f:{g:{h:{if(!c|(c|0)>7){break h}a=2;if((c|0)>2){break h}a=1;if((c|0)==2){break h}a=0;if((c|0)>0){break h}b=aa(8)|0;v[22452]=0;c=Q(55,e|0,10737)|0;a=v[22452];v[22452]=0;i:{if((a|0)!=1){lc(b,c);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break g}a=P()|0;O()|0;pb(c);break i}a=P()|0;O()|0;ba(b|0)}S(a|0);L()}ab=e+16|0;break f}L()}t[d+8|0]=a;a=v[b>>2];if(!Rw(d+8|0,a+24648|0)){break d}Sx(a,d+8|0);break d;case 3:b=d+8|0;a=a+24|0;gc(b,v[a>>2]+24604|0,40);e=ab-48|0;ab=e;j:{if((c|0)==-1){Vr(b,v[yp(e+8|0)+32>>2]);Bn(b,v[yp(e+8|0)+36>>2]);break j}if((c|0)<=0){Vr(b,0);Bn(b,0);break j}c=B(c,1e3);Vr(b,c);Bn(b,c)}ab=e+48|0;if(v[v[a>>2]+24636>>2]==v[d+40>>2]&v[v[a>>2]+24640>>2]==v[d+44>>2]){break d}Tx(v[a>>2],d+8|0);break d;default:a=aa(8)|0;v[22452]=0;b=Q(55,d+8|0,10346)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}lc(a,b);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}c=P()|0;O()|0;pb(b);break b;case 0:break e}}g=a,h=fe(C(10),C(C(C(c|0)*C(.0010000000474974513))*C(.5))),z[g+48>>2]=h}ab=d+48|0;return}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function vaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=ab-48|0;ab=f;q=v[a+16>>2];g=Vd(f+16|0);v[g+8>>2]=a+112;i=v[a+128>>2];v[g+16>>2]=i;w=g,x=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[w+12>>2]=x;n=v[a+8>>2];o=v[a+12>>2];if(i){w=g,x=Wf(n,o,i),v[w>>2]=x;v[g+4>>2]=db}h=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];i=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=i;a:while(1){b:{i=b;if(!d){break b}b=v[f+12>>2];v[f+40>>2]=v[f+8>>2];v[f+44>>2]=0;e=(b<<1)+q|0;b=v[g+16>>2];while(1)if((b|0)<=0){b=v[g+8>>2];j=v[b+8>>2];Lb(b,j,v[b+12>>2]);b=v[g+8>>2];j=v[b+4>>2];if(j){Bd(b,u[e+(v[f+44>>2]<<1)>>1]/4<<16>>16);Ad(v[g+8>>2],j);b=v[g+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}d=d-1|0;j=v[a+72>>2];r=v[a+32>>2];m=v[a+28>>2]+m|0;e=v[a+60>>2];p=Uf(b,v[g+12>>2])<<8;b=p;b=oia(e,e>>31,b,b>>31);s=db;e=b;b=v[a+64>>2];k=b;t=b>>31;b=Sb(i,-16777216,16776704);k=oia(k,t,b,b>>31);e=e+k|0;b=db+s|0;b=e>>>0<k>>>0?b+1|0:b;k=e;e=v[a+68>>2];h=Sb(h,-16777216,16776704);e=oia(e,e>>31,h,h>>31);h=k+e|0;b=db+b|0;b=e>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=h>>>0<8388608?b+1|0:b;b=Cc(h,b,24);h=(b|0)/256|0;v[c>>2]=B(m>>12,h)+v[c>>2];l=l+r|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,h);Lb(f+8|0,n,o);b=b-(j&p)|0;c=c+8|0;h=i;continue a}else{Bd(v[g+8>>2],u[e+(v[f+44>>2]<<1)>>1]/4<<16>>16);Ad(v[g+8>>2],4);Lb(f+40|0,v[g>>2],v[g+4>>2]);b=b-1|0;continue}}break}v[a+40>>2]=l;v[a+36>>2]=m;v[a+48>>2]=h;v[a+44>>2]=i;v[a+20>>2]=m>>12;v[a+24>>2]=l>>12;b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+48|0}function eZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=ab-16|0;ab=x;v[c>>2]=a;A=d&512;while(1){if((y|0)==4){if(ub(n)>>>0>1){C=x,D=kd(n),v[C+8>>2]=D;e=ab-16|0;ab=e;v[e+8>>2]=v[x+8>>2];f=v[Fe(e+8|0)>>2];ab=e+16|0;C=c,D=LE(f,Ff(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}ab=x+16|0;return}a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=hl(g,32);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 3:if(pd(n)){break a}q=w[oc(n,0)|0];p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 2:if(pd(m)|!A){break a}C=c,D=LE(kd(m),Ff(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!_g(g,2048,t[r|0])){break c}r=r+1|0;continue}break}q=o;if((q|0)>0){while(1){if(!(!q|e>>>0>=r>>>0)){r=r-1|0;p=w[r|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=p;q=q-1|0;continue}break}if(q){p=hl(g,48)}else{p=0}while(1){s=v[c>>2];v[c>>2]=s+1;if((q|0)>0){t[s|0]=p;q=q-1|0;continue}break}t[s|0]=j}d:{if((e|0)==(r|0)){q=hl(g,48);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break d}if(pd(l)){p=-1}else{p=t[oc(l,0)|0]}q=0;u=0;while(1){if((e|0)==(r|0)){break d}e:{if((q|0)!=(p|0)){s=q;break e}p=v[c>>2];v[c>>2]=p+1;t[p|0]=k;s=0;u=u+1|0;if(ub(l)>>>0<=u>>>0){p=q;break e}p=-1;if(w[oc(l,u)|0]==127){break e}p=t[oc(l,u)|0]}r=r-1|0;q=w[r|0];z=v[c>>2];v[c>>2]=z+1;t[z|0]=q;q=s+1|0;continue}}rl(B,v[c>>2])}y=y+1|0;continue}}function zJ(a){var b=C(0),c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,k=C(0),l=0,m=C(0);d=ab-16|0;ab=d;b=cx(z[a+4216>>2]);e=v[a+16>>2];z[d+12>>2]=b/C(y[e+24620>>2]);v[d+8>>2]=1056964608;b=Po(C(z[El(d+12|0,d+8|0)>>2]*C(6.2831854820251465)));b=C(K(C(C(C(b+b)+C(3))/C(5))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));b=C(C(z[a+4212>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){f=~~b>>>0;break a}f=0}t[a+4272|0]=f;c=2;b:{if(f>>>0<4){break b}c=3;if(f>>>0<8){break b}c=f>>>0<16?4:5}t[a+4273|0]=c;k=fe(C(10),C(BJ(z[a+4208>>2])/C(20)));c=e+24620|0;l=d,m=C(cx(z[a+4220>>2])/C(y[c>>2])),z[l+12>>2]=m;v[d+8>>2]=1056964608;g=z[El(d+12|0,d+8|0)>>2];l=d,m=C(cx(z[a+4224>>2])/C(y[c>>2])),z[l+12>>2]=m;v[d+8>>2]=1056964608;b=C(C(z[El(d+12|0,d+8|0)>>2]*C(6.2831854820251465))*C(.5));i=ab-16|0;ab=i;e=(p(b),j(2));c=e&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=Xm(+b,0);break c}if(c>>>0<=1081824209){h=+b;if(c>>>0<=1075235811){b=Xm(((e|0)>=0?-1.5707963267948966:1.5707963267948966)+h,1);break c}b=Xm(((e|0)>=0?-3.141592653589793:3.141592653589793)+h,0);break c}if(c>>>0<=1088565717){h=+b;if(c>>>0<=1085271519){b=Xm(((e|0)>=0?-4.71238898038469:4.71238898038469)+h,1);break c}b=Xm(((e|0)>=0?-6.283185307179586:6.283185307179586)+h,0);break c}if(c>>>0>=2139095040){b=C(b-b);break c}c=pw(b,i+8|0);b=Xm(A[i+8>>3],c&1)}ab=i+16|0;b=C(C(C(1)-b)/C(b+C(1)));z[a+4268>>2]=b;g=Po(C(g*C(6.2831854820251465)));z[a+4264>>2]=-g;z[a+4260>>2]=C(C(k*C(K(C(C(1)-C(g*g)))))*C(K(C(C(1)-C(b*b)))))*z[(f<<2)+45728>>2];ab=d+16|0}function Eba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=ab-32|0;ab=g;q=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+16|0)|0;e=a+e|0;v[h>>2]=v[e+44>>2];v[h+4>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;r=v[a+8>>2];s=v[a+12>>2];a:while(1){if(d){b=v[g+8>>2];f=b>>>18|0;m=((((v[g+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+q|0;b=0;while(1)if((b|0)==2){m=v[a+72>>2];b=v[a+68>>2];k=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){o=(b<<2)+g|0;f=v[o>>2];e=(g+16|0)+(b<<3)|0;l=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;p=f<<8;f=p;f=oia(y,z,f,f>>31);n=db;A=e;e=Sb(j,-16777216,16776704);j=oia(w,x,e,e>>31);f=j+f|0;e=db+n|0;e=f>>>0<j>>>0?e+1|0:e;n=f;f=Sb(l,-16777216,16776704);l=oia(k,t,f,f>>31);f=n+l|0;e=db+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[A>>2]=e-(m&p);v[o>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[g>>2],i>>12);h=b+h|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],h>>12);Lb(g+8|0,r,s);c=c+8|0;d=d-1|0;continue a}else{k=m+(b<<1)|0;e=u[k>>1];v[(b<<2)+g>>2]=e+((B(f,u[k+4>>1]-e|0)|0)/16384|0);b=b+1|0;continue}}break}v[a+40>>2]=h;v[a+36>>2]=i;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+32|0}function rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=ab-32|0;ab=g;q=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}r=v[a+24>>2];s=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;t=v[a+8>>2];w=v[a+12>>2];a:while(1){b:{if(!d){b=0;while(1){if((b|0)==2){break b}c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}}e=v[g+8>>2];f=((((v[g+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=e>>>21&2040;j=u[b+39878>>1];k=u[b+39876>>1];l=u[b+39874>>1];m=u[b+39872>>1];b=0;while(1)if((b|0)==2){j=v[a+72>>2];b=v[a+68>>2];k=b;l=b>>31;b=v[a+64>>2];m=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){o=(b<<2)+g|0;f=v[o>>2];e=(g+16|0)+(b<<3)|0;i=v[e+4>>2];h=v[e>>2];v[e+4>>2]=h;p=f<<8;f=p;f=oia(y,z,f,f>>31);n=db;A=e;e=Sb(h,-16777216,16776704);h=oia(m,x,e,e>>31);f=h+f|0;e=db+n|0;e=f>>>0<h>>>0?e+1|0:e;n=f;f=Sb(i,-16777216,16776704);i=oia(k,l,f,f>>31);f=n+i|0;e=db+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[A>>2]=e-(j&p);v[o>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],s);v[c+4>>2]=v[c+4>>2]+B(r,v[g+4>>2]);Lb(g+8|0,t,w);c=c+8|0;d=d-1|0;continue a}else{e=f+(b<<1)|0;v[(b<<2)+g>>2]=(((B(l,u[e>>1])+B(m,u[e-4>>1])|0)+B(k,u[e+4>>1])|0)+B(j,u[e+8>>1])|0)/16384;b=b+1|0;continue}}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+32|0}function M2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ab-48|0;ab=c;f=Pb(a);a:{b:{c:{d:{if(Vi(b)){of(c+40|0);break d}v[22452]=0;R(999,c+24|0,b|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}v[22452]=0;a=T(983,c+24|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}v[c+40>>2]=a;Hf(c+24|0)}if(Vi(b)){a=b+36|0}else{a=v[c+40>>2]}e=v[a+4>>2];g=v[a>>2];v[22452]=0;R(172,f|0,en(g,e)|0);e=v[22452];v[22452]=0;e:{if((e|0)!=1){i=c,j=wb(v[a>>2]),v[i+16>>2]=j;b=b+24|0;g=wb(v[a+4>>2]);f:{g:{h:{i:{j:{k:{while(1){a=v[c+16>>2];if(!Tb(a,g)){Ek(c+40|0);ab=c+48|0;return}e=jj(v[b>>2]+484360|0,w[a+16|0]);v[22452]=0;R(1e3,c|0,e|0);d=v[22452];v[22452]=0;if((d|0)!=1){v[22452]=0;R(986,c+24|0,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break k}v[22452]=0;R(174,f|0,c+24|0);d=v[22452];v[22452]=0;if((d|0)==1){break j}pb(c+24|0);pb(c);l:{if(!pd(Gw(v[f+4>>2]))){break l}d=w[a+12|0];v[22452]=0;d=Q(304,e|0,d|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break f}if(!d){break l}d=v[v[b>>2]+1298404>>2];a=Rb(v[b>>2]+484344|0,x[Yb(v[e>>2],v[a+12>>2])>>1]);v[22452]=0;R(993,c|0,a|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}v[22452]=0;W(229,c+24|0,0,d|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break g}a=c+24|0;tb(Gw(v[f+4>>2]),a);pb(a);pb(c)}KH(c+16|0);continue}break}b=P()|0;O()|0;break e}b=P()|0;O()|0;break i}b=P()|0;O()|0;pb(c+24|0)}pb(c);break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;pb(c);break e}b=P()|0;O()|0;break e}b=P()|0;O()|0}Ek(c+40|0);break a}b=P()|0;O()|0;Hf(c+24|0);break a}b=P()|0;O()|0}Uc(f);S(b|0);L()}function lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=Bb(a);k=ub(b);v[22452]=0;R(290,g|0,k|0);a=v[22452];v[22452]=0;a:{b:{if((a|0)!=1){a=0;c:{while(1){d:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break d}return}e=t[oc(b,a)|0];h=e&255;e:{f:{switch(f+1|0){case 1:f=1;g:{switch(h-123|0){case 2:f=3;break e;case 0:break e;default:break g}}f=0;v[22452]=0;Q(291,g|0,e|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){break e}break c;case 2:h:{switch(h-123|0){case 0:f=0;v[22452]=0;Q(291,g|0,123)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}break e;case 2:m=1;e=i+1|0;f=0;if(d>>>0<=i>>>0){i=e;break e}v[22452]=0;Q(292,g|0,ld(c,i)|0)|0;h=v[22452];v[22452]=0;i=e;if((h|0)!=1){break e}a=P()|0;O()|0;break b;default:break h}}f=-1;e=e-48|0;if((e&255)>>>0>9){break e}l=1;f=2;j=e;break e;case 3:f=-1;i:{switch(h-123|0){case 2:f=0;if(d>>>0<=j>>>0){break e}v[22452]=0;Q(292,g|0,ld(c,j)|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){break e}a=P()|0;O()|0;break b;case 0:break e;default:break i}}if((e-48&255)>>>0>9){break e}j=(e+B(j,10)|0)-48|0;l=1;f=2;break e;case 4:f=-1;if((e|0)!=125){break e}f=0;v[22452]=0;Q(291,g|0,125)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}break e;case 0:break f;default:break e}}f=-1}a=a+1|0;continue}break}b=aa(8)|0;v[22452]=0;T(109,b|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;U(110,b|0,41972,24);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ba(b|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}pb(g);S(a|0)}L()}
function waa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0;f=ab-48|0;ab=f;q=v[a+16>>2];g=Vd(f+16|0);v[g+8>>2]=a+112;i=v[a+128>>2];v[g+16>>2]=i;w=g,x=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[w+12>>2]=x;n=v[a+8>>2];o=v[a+12>>2];if(i){w=g,x=Wf(n,o,i),v[w>>2]=x;v[g+4>>2]=db}h=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];i=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=i;a:while(1){b:{i=b;if(!d){break b}b=v[f+12>>2];v[f+40>>2]=v[f+8>>2];v[f+44>>2]=0;e=b+q|0;b=v[g+16>>2];while(1)if((b|0)<=0){b=v[g+8>>2];j=v[b+8>>2];Lb(b,j,v[b+12>>2]);b=v[g+8>>2];j=v[b+4>>2];if(j){Bd(b,t[e+v[f+44>>2]|0]<<6);Ad(v[g+8>>2],j);b=v[g+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}d=d-1|0;j=v[a+72>>2];r=v[a+32>>2];m=v[a+28>>2]+m|0;e=v[a+60>>2];p=Uf(b,v[g+12>>2])<<8;b=p;b=oia(e,e>>31,b,b>>31);s=db;e=b;b=v[a+64>>2];k=b;u=b>>31;b=Sb(i,-16777216,16776704);k=oia(k,u,b,b>>31);e=e+k|0;b=db+s|0;b=e>>>0<k>>>0?b+1|0:b;k=e;e=v[a+68>>2];h=Sb(h,-16777216,16776704);e=oia(e,e>>31,h,h>>31);h=k+e|0;b=db+b|0;b=e>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=h>>>0<8388608?b+1|0:b;b=Cc(h,b,24);h=(b|0)/256|0;v[c>>2]=B(m>>12,h)+v[c>>2];l=l+r|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,h);Lb(f+8|0,n,o);b=b-(j&p)|0;c=c+8|0;h=i;continue a}else{Bd(v[g+8>>2],t[e+v[f+44>>2]|0]<<6);Ad(v[g+8>>2],4);Lb(f+40|0,v[g>>2],v[g+4>>2]);b=b-1|0;continue}}break}v[a+40>>2]=l;v[a+36>>2]=m;v[a+48>>2]=h;v[a+44>>2]=i;v[a+20>>2]=m>>12;v[a+24>>2]=l>>12;b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+48|0}function mW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=Bb(a);k=ub(b);v[22452]=0;R(106,g|0,k|0);a=v[22452];v[22452]=0;a:{b:{if((a|0)!=1){a=0;c:{while(1){d:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break d}return}e=t[oc(b,a)|0];h=e&255;e:{f:{switch(f+1|0){case 1:f=1;g:{switch(h-123|0){case 2:f=3;break e;case 0:break e;default:break g}}f=0;v[22452]=0;Q(107,g|0,e|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){break e}break c;case 2:h:{switch(h-123|0){case 0:f=0;v[22452]=0;Q(107,g|0,123)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}break e;case 2:m=1;e=i+1|0;f=0;if(d>>>0<=i>>>0){i=e;break e}v[22452]=0;Q(108,g|0,ld(c,i)|0)|0;h=v[22452];v[22452]=0;i=e;if((h|0)!=1){break e}a=P()|0;O()|0;break b;default:break h}}f=-1;e=e-48|0;if((e&255)>>>0>9){break e}l=1;f=2;j=e;break e;case 3:f=-1;i:{switch(h-123|0){case 2:f=0;if(d>>>0<=j>>>0){break e}v[22452]=0;Q(108,g|0,ld(c,j)|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){break e}a=P()|0;O()|0;break b;case 0:break e;default:break i}}if((e-48&255)>>>0>9){break e}j=(e+B(j,10)|0)-48|0;l=1;f=2;break e;case 4:f=-1;if((e|0)!=125){break e}f=0;v[22452]=0;Q(107,g|0,125)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}break e;case 0:break f;default:break e}}f=-1}a=a+1|0;continue}break}b=aa(8)|0;v[22452]=0;T(109,b|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;U(110,b|0,41972,24);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ba(b|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}pb(g);S(a|0)}L()}function Fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=ab-32|0;ab=g;q=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+16|0)|0;e=a+e|0;v[h>>2]=v[e+44>>2];v[h+4>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;r=v[a+8>>2];s=v[a+12>>2];a:while(1){if(d){b=v[g+8>>2];f=b>>>10&4194048;m=(((v[g+12>>2]&2147483647)<<1|b>>>31)&-2)+q|0;b=0;while(1)if((b|0)==2){m=v[a+72>>2];b=v[a+68>>2];k=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){o=(b<<2)+g|0;f=v[o>>2];e=(g+16|0)+(b<<3)|0;l=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;p=f<<8;f=p;f=oia(y,z,f,f>>31);n=db;A=e;e=Sb(j,-16777216,16776704);j=oia(w,x,e,e>>31);f=j+f|0;e=db+n|0;e=f>>>0<j>>>0?e+1|0:e;n=f;f=Sb(l,-16777216,16776704);l=oia(k,u,f,f>>31);f=n+l|0;e=db+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[A>>2]=e-(m&p);v[o>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[g>>2],i>>12);h=b+h|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],h>>12);Lb(g+8|0,r,s);c=c+8|0;d=d-1|0;continue a}else{k=b+m|0;e=t[k|0];v[(b<<2)+g>>2]=((B(f,t[k+2|0]-e|0)|0)/16384|0)+(e<<8);b=b+1|0;continue}}break}v[a+40>>2]=h;v[a+36>>2]=i;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+32|0}function $aa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=ab-16|0;ab=g;a:{b:{c:{h=v[a+12>>2];j=v[a+8>>2];d:{if((h|0)<=1&j>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&j>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&j>>>0>2147483647|h>>>0>4294967294){break d}break b}if((h|0)==1&j>>>0>2147483648|h>>>0>1){break b}}q=b+196648|0;break a}q=b+131112|0;break a}q=b+262184|0}t=v[a+16>>2];e=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];m=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=m;while(1){m=b;if(d){w=v[a+72>>2];x=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;b=v[a+64>>2];n=b;r=b>>31;b=Sb(m,-16777216,16776704);b=oia(n,r,b,b>>31);o=db;r=i;i=b;b=v[a+60>>2];n=b;s=b>>31;f=(v[g+12>>2]<<1)+t|0;b=(v[g+8>>2]>>>16&65520)+q|0;f=(((((((B(u[f-4>>1],u[b+2>>1])+B(u[f-6>>1],u[b>>1])|0)+B(u[f-2>>1],u[b+4>>1])|0)+B(u[f>>1],u[b+6>>1])|0)+B(u[f+2>>1],u[b+8>>1])|0)+B(u[f+4>>1],u[b+10>>1])|0)+B(u[f+6>>1],u[b+12>>1])|0)+B(u[f+8>>1],u[b+14>>1])|0)/32768<<8;b=f;b=oia(n,s,b,b>>31);i=i+b|0;p=db+o|0;p=b>>>0>i>>>0?p+1|0:p;b=v[a+68>>2];n=b;s=b>>31;b=Sb(e,-16777216,16776704);e=oia(n,s,b,b>>31);o=e+i|0;b=db+p|0;b=e>>>0>o>>>0?b+1|0:b;e=o+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Cc(e,b,24);b=(e|0)/256|0;v[c>>2]=B(r,b)+v[c>>2];k=k+x|0;v[c+4>>2]=v[c+4>>2]+B(b,k>>12);Lb(g+8|0,j,h);b=e-(f&w)|0;c=c+8|0;d=d-1|0;e=m;continue}break}v[a+40>>2]=k;v[a+36>>2]=l;v[a+48>>2]=e;v[a+44>>2]=m;v[a+20>>2]=l>>12;v[a+24>>2]=k>>12;b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+16|0}function OL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=ab-16|0;ab=c;d=a+1074376|0;e=B(b,872);a:{if(v[(d+e|0)+704>>2]&134218752){break a}h=v[(a+e|0)+1075648>>2];if(!Kj(h)|w[h+15|0]&2){break a}d=ml(a,d,b,2,1);if((d-1&255)>>>0>249){break a}g=v[(B(d,160)+a|0)+906140>>2];if(!g){break a}f=B(b,872)+a|0;d=w[f+1075780|0];b:{if(w[f+1075782|0]==1){t[c+8|0]=64;e=w[Qb(f+1075784|0,c+8|0)|0];break b}e=255;if(w[f+1075783|0]!=13){break b}t[c+8|0]=64;e=w[Qb((B(b,872)+a|0)+1075785|0,c+8|0)|0]}i=a+1074312|0;rb(c+8|0,i,2);if(sb(v[v[c+8>>2]>>2],v[c+12>>2])){if(d){if(Kc(d)){d=w[Cb(h+108|0,d-1|0)|0]}Ll(a,b,d,x[(B(b,872)+a|0)+1075680>>1]);break a}if((e|0)==255){break a}eb[v[v[g>>2]+76>>2]](g,39,e,b);break a}j=v[h+4>>2];if(d){f=w[h+35|0]?j<<2:v[(B(b,872)+a|0)+1075680>>2];k=u[(B(b,872)+a|0)+1075768>>1];rb(c+8|0,i,28);l=c,m=f+(sb(v[v[c+8>>2]>>2],v[c+12>>2])?k<<2:k)|0,v[l+4>>2]=m;ce(c+4|0,0,256);f=a;if(Kc(d)){a=w[Cb(h+108|0,d-1|0)|0]}else{a=d}Ll(f,b,a&255,x[c+4>>1])}f=w[h+35|0];rb(c+8|0,i,101);i=(e|0)!=255;if(sb(v[v[c+8>>2]>>2],v[c+12>>2])){a=(d|0)!=0}else{a=Kc(d)}if(!(a?0:i)&(!a|(f|0)!=1)){break a}c:{switch(w[h+36|0]){case 1:if((e|0)!=255){PK(v[g+20>>2],e<<1);break a}PK(v[g+20>>2],j<<1);break a;case 0:break c;default:break a}}if((e|0)!=255){t[c+8|0]=127;t[c+4|0]=e<<1;m=g,n=7,o=w[Qb(c+8|0,c+4|0)|0],p=b,l=v[v[g>>2]+76>>2],eb[l](m|0,n|0,o|0,p|0);break a}v[c+8>>2]=127;v[c+4>>2]=j<<1;p=g,o=7,n=w[zb(c+8|0,c+4|0)|0],m=b,l=v[v[g>>2]+76>>2],eb[l](p|0,o|0,n|0,m|0)}ab=c+16|0}function L8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-112|0;ab=c;d=c+88|0;kj(d,b,1413829443);v[22452]=0;b=T(169,d|0)|0;d=v[22452];v[22452]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){v[22452]=0;U(747,c- -64|0,a+140|0,1413894985);a=v[22452];v[22452]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){v[22452]=0;a=Q(825,c- -64|0,13585)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}b=28591;if(a){b=Bb(c+48|0);v[22452]=0;a=T(193,c- -64|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break m}v[22452]=0;U(262,c- -64|0,b|0,a|0);a=v[22452];v[22452]=0;if((a|0)==1){break m}v[22452]=0;d=Q(54,c+16|0,b|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break l}v[22452]=0;Z(826,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break k}v[22452]=0;U(827,c+32|0,d|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break j}a=c+32|0;e=tb(b,a);pb(a);pb(c);pb(d);v[22452]=0;U(11,a|0,2,e|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}v[22452]=0;a=T(715,c+32|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break g}pb(c+32|0);pb(e);b=a-1>>>0<19398657?1252:28591}qb(c- -64|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;pb(c)}pb(d);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;pb(c+32|0)}pb(b);break d}a=P()|0;O()|0}qb(c- -64|0);break b}v[22452]=0;a=Q(147,c+88|0,2)|0;b=v[22452];v[22452]=0;if((b|0)==1){break c}b=28591;if(!a){break a}v[22452]=0;b=T(185,c+88|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0}qb(c+88|0);S(a|0);L()}qb(c+88|0);ab=c+112|0;return b|0}function P9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,A=0;f=ab+-64|0;ab=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}k=e<<2;if(k>>>0>d>>>0){break g}s=k-4|0;n=B(b,e);x=n-8|0;h:while(1){v[22452]=0;b=Q(147,c|0,k|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break b}if(!(b&m>>>0<n>>>0)){break g}v[22452]=0;U(181,f+16|0,c|0,d|0);b=v[22452];v[22452]=0;if((b|0)==1){break c}h=f+40|0;b=f+16|0;o=bc(h,b);qb(b);v[22452]=0;R(524,b|0,h|0);b=v[22452];v[22452]=0;if((b|0)==1){break e}y=Sd(f+16|0);p=v[f+16>>2];z=p-4|0;h=0;while(1){if((e|0)==(h|0)){m=(p-k<<1)+m|0;rc(f+16|0);qb(f+40|0);continue h}v[22452]=0;g=T(517,o|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){v[22452]=0;b=T(197,o|0)|0;j=v[22452];v[22452]=0;if((j|0)==1){break f}v[f+8>>2]=b;ce(f+8|0,0,89);v[22452]=0;Q(179,f+40|0,1)|0;b=v[22452];v[22452]=0;if((b|0)==1){break f}j=h+m|0;b=e+h<<2;i:while(1){j:{if(j>>>0>x>>>0){break j}l=0;if(b>>>0>z>>>0){break j}while(1)if((l|0)==8){b=b+s|0;continue i}else{q=v[f+8>>2];i=w[b+y|0];r=l&1;i=r?i>>>4|0:i&15;v[f+8>>2]=q+t[(i&7)+30264|0];A=g;g=u[(q<<1)+30272>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;v[f+12>>2]=A+(i&8?0-g|0:g);ce(f+8|0,0,88);ce(f+12|0,-32768,32767);g=v[f+12>>2];u[(j<<1)+a>>1]=g;l=l+1|0;j=e+j|0;b=b+r|0;continue}}break}h=h+1|0;continue}break}break}break f}qb(c);ab=f- -64|0;return}b=P()|0;O()|0;rc(f+16|0);break d}b=P()|0;O()|0}qb(f+40|0);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}qb(c);S(b|0);L()}function sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0;g=ab-32|0;ab=g;q=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}r=v[a+24>>2];s=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];a:while(1){b:{if(!d){b=0;while(1){if((b|0)==2){break b}c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}}e=v[g+8>>2];f=(((v[g+12>>2]&2147483647)<<1|e>>>31)&-2)+q|0;b=e>>>21&2040;j=u[b+39878>>1];k=u[b+39876>>1];l=u[b+39874>>1];m=u[b+39872>>1];b=0;while(1)if((b|0)==2){j=v[a+72>>2];b=v[a+68>>2];k=b;l=b>>31;b=v[a+64>>2];m=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;b=0;while(1){if((b|0)!=2){o=(b<<2)+g|0;f=v[o>>2];e=(g+16|0)+(b<<3)|0;i=v[e+4>>2];h=v[e>>2];v[e+4>>2]=h;p=f<<8;f=p;f=oia(z,A,f,f>>31);n=db;C=e;e=Sb(h,-16777216,16776704);h=oia(m,y,e,e>>31);f=h+f|0;e=db+n|0;e=f>>>0<h>>>0?e+1|0:e;n=f;f=Sb(i,-16777216,16776704);i=oia(k,l,f,f>>31);f=n+i|0;e=db+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[C>>2]=e-(j&p);v[o>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],s);v[c+4>>2]=v[c+4>>2]+B(r,v[g+4>>2]);Lb(g+8|0,w,x);c=c+8|0;d=d-1|0;continue a}else{e=b+f|0;v[(b<<2)+g>>2]=(((B(l,t[e|0])+B(m,t[e-2|0])|0)+B(k,t[e+2|0])|0)+B(j,t[e+4|0])<<8)/16384;b=b+1|0;continue}}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+32|0}function aba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=ab-16|0;ab=g;a:{b:{c:{h=v[a+12>>2];i=v[a+8>>2];d:{if((h|0)<=1&i>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|h>>>0>4294967294){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}p=v[a+16>>2];b=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];l=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=l;while(1){l=e;if(d){q=v[a+72>>2];r=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+64>>2];m=e;f=e>>31;e=Sb(l,-16777216,16776704);e=oia(m,f,e,e>>31);f=db;m=e;e=v[a+68>>2];b=Sb(b,-16777216,16776704);e=oia(e,e>>31,b,b>>31);n=m+e|0;b=db+f|0;b=e>>>0>n>>>0?b+1|0:b;e=v[a+60>>2];m=e;s=e>>31;f=v[g+12>>2]+p|0;e=(v[g+8>>2]>>>16&65520)+o|0;f=(((((((B(t[f-2|0],u[e+2>>1])+B(t[f-3|0],u[e>>1])|0)+B(t[f-1|0],u[e+4>>1])|0)+B(t[f|0],u[e+6>>1])|0)+B(t[f+1|0],u[e+8>>1])|0)+B(t[f+2|0],u[e+10>>1])|0)+B(t[f+3|0],u[e+12>>1])|0)+B(t[f+4|0],u[e+14>>1])<<8)/32768<<8;e=f;e=oia(m,s,e,e>>31);n=e+n|0;b=db+b|0;b=e>>>0>n>>>0?b+1|0:b;e=n+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Cc(e,b,24);b=(e|0)/256|0;v[c>>2]=B(k>>12,b)+v[c>>2];j=j+r|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,b);Lb(g+8|0,i,h);e=e-(f&q)|0;c=c+8|0;d=d-1|0;b=l;continue}break}v[a+40>>2]=j;v[a+36>>2]=k;v[a+48>>2]=b;v[a+44>>2]=l;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+16|0}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=ab-32|0;ab=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+16|0)|0;e=a+e|0;v[h>>2]=v[e+44>>2];v[h+4>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;p=v[a+8>>2];q=v[a+12>>2];a:while(1){if(d){e=((((v[g+12>>2]&2147483647)<<1|v[g+8>>2]>>>31)&2147483646)<<1)+o|0;b=0;while(1)if((b|0)==2){r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){m=(b<<2)+g|0;f=v[m>>2];e=(g+16|0)+(b<<3)|0;k=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;n=f<<8;f=n;f=oia(y,z,f,f>>31);l=db;A=e;e=Sb(j,-16777216,16776704);j=oia(w,x,e,e>>31);f=j+f|0;e=db+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Sb(k,-16777216,16776704);k=oia(s,t,f,f>>31);f=l+k|0;e=db+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[A>>2]=e-(r&n);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[g>>2],i>>12);h=b+h|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],h>>12);Lb(g+8|0,p,q);c=c+8|0;d=d-1|0;continue a}else{v[(b<<2)+g>>2]=u[e+(b<<1)>>1];b=b+1|0;continue}}break}v[a+40>>2]=h;v[a+36>>2]=i;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+32|0}function I7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;k=ab-16|0;ab=k;i=ab-32|0;ab=i;h=ze(i+16|0,1,0);a:{b:{c:{while(1){f=Eb(h);g=f+ub(h)|0;c=v[b>>2];d=v[b+4>>2];if(!((d|0)>0|(d|0)>=0|(f|0)==(g|0))){t[f|0]=45;e=c;c=0-c|0;f=f+1|0;d=0-(d+((e|0)!=0)|0)|0}m=i;d:{e:{e=g-f|0;if((e|0)<=19){j=E(d);j=B(64-((j|0)==32?E(c|1)+32|0:j)|0,1233)>>>12|0;l=(j<<3)+25808|0;n=e;e=v[l+4>>2];if((n|0)<((j-((d|0)==(e|0)&c>>>0<y[l>>2]|d>>>0<e>>>0)|0)+1|0)){break e}}f:{if(!d&c>>>0<=99999999){e=mw(f,c);break f}if((d|0)==2328306&c>>>0<=1874919423|d>>>0<2328306){d=ria(c,d,1e8,0);g=db;e=mw(f,d);d=oia(d,g,-1e8,-1)+c|0;c=d;d=(c>>>0)/1e4|0;e=Qi(Qi(e,d),c+B(d,-1e4)|0);break f}g=ria(c,d,1874919424,2328306);j=db;l=lw(f,g);g=oia(g,j,-1874919424,-2328307)+c|0;f=d+db|0;d=g;c=ria(d,c>>>0>d>>>0?f+1|0:f,1e8,0);f=db;g=(c>>>0)/1e4|0;e=Qi(Qi(l,g),c+B(g,-1e4)|0);c=oia(c,f,-1e8,-1)+d|0;d=(c>>>0)/1e4|0;e=Qi(Qi(e,d),c+B(d,-1e4)|0)}v[i+8>>2]=e;e=0;break d}v[i+8>>2]=g;e=61}v[m+12>>2]=e;if(!v[i+12>>2]){break c}c=If(ub(h));v[22452]=0;R(59,h|0,c|0);c=v[22452];v[22452]=0;if((c|0)!=1){continue}break}break b}b=v[i+8>>2];c=Eb(h);v[22452]=0;R(60,h|0,b-c|0);b=v[22452];v[22452]=0;g:{if((b|0)!=1){v[22452]=0;R(61,k|0,h|0);b=v[22452];v[22452]=0;if((b|0)!=1){break g}break b}break b}pb(h);ab=i+32|0;break a}a=P()|0;O()|0;pb(h);S(a|0);L()}v[22452]=0;R(58,a|0,k|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(k);ab=k+16|0;return}a=P()|0;O()|0;pb(k);S(a|0);L()}function CU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=ab-32|0;ab=f;qc(c);while(1){a:{if(!Hb(c,3)){break a}g=f+24|0;tq(g,c);i=Zc(g);d=Me(g);g=w[g|0];if(g>>>0>=y[a+12>>2]){break a}h=Qc(a,g,b);e=w[i|0];if(e>>>0<=126){if(!(e|w[d|0])){t[h|0]=254;continue}t[h|0]=e+1;if(w[d|0]==255){continue}t[h+2|0]=1;t[h+4|0]=w[d|0];continue}b:{switch(e-127|0){case 1:t[h+1|0]=w[d|0]+1;continue;case 0:continue;default:break b}}d=t[d|0];t[f+23|0]=d;g=0;e=e&127;if(e>>>0<=23){g=w[e+26208|0]}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{j=w[i|0];switch((j&127)-2|0){case 21:break g;case 18:break h;case 17:break i;case 16:case 20:break j;case 15:break k;case 2:break l;case 1:break m;case 0:case 8:case 9:break n;default:break d}}if((d|0)>=0){break f}e=0-d&15;break e}t[f+16|0]=64;d=w[Qb(f+23|0,f+16|0)|0];if(w[h+2|0]>1){break d}t[h+4|0]=d;t[h+2|0]=1;continue}e=3;if((d|0)>=0){break c}e=0-d&127;break e}if(!d){continue}e=0-d|-16;if((d|0)<0){break e}e=d<<4|15;break e}if(!d){continue}g=(d|0)>=0;if(!g){d=0-d&15;t[f+23|0]=d;j=w[i|0]}e=g?3:2;d=((j|0)==22?-32:-16)|d;t[f+23|0]=d;break c}e=d&15|-48;break e}e=d&15|-64;break e}e=164;if((d|0)==100){break e}v[f+16>>2]=d- -64;v[f+12>>2]=0;v[f+8>>2]=128;d=v[nj(f+16|0,f+12|0,f+8|0)>>2];if(!w[h+3|0]){break d}o:{switch(w[h+2|0]){case 0:case 2:break o;default:continue}}t[h+2|0]=2;t[h+4|0]=(d&254)>>>1;continue}e=d<<4}d=e;t[f+23|0]=d}e=g;if(!g){continue}}t[h+5|0]=d;t[h+3|0]=e;continue}break}ab=f+32|0}function nca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ab-48|0;ab=e;u[e+46>>1]=b;d=ej(a);f=e+32|0;g=sd(f);a:{b:{if(d){v[22452]=0;R(584,f|0,d|0);h=v[22452];v[22452]=0;if((h|0)==1){break b}ZB(f,d)}break a}a=P()|0;O()|0;_c(g);S(a|0);L()}c:{d:{while(1){e:{if((c|0)==(d|0)){if(!(i&65535)){break c}b=wb(v[a>>2]);d=wb(v[a+4>>2]);c=ab-16|0;ab=c;b=Hz(b,d,e+46|0);v[c+8>>2]=b;if(Tb(b,d)){v[c>>2]=b;while(1){f:{Ke(c);b=v[c>>2];if(!Tb(b,d)){break f}b=x[b>>1];if((b|0)==x[e+46>>1]){continue}u[v[c+8>>2]>>1]=b;Ke(c+8|0);continue}break}b=v[c+8>>2]}ab=c+16|0;b=$b(e+24|0,b);c=v[$b(e+16|0,wb(v[a+4>>2]))>>2];d=v[b>>2];b=v[a>>2];b=(fm(d,wb(b))<<1)+b|0;if(Tb(d,c)){Hd(a,Ci(b+(fm(c,d)<<1)|0,v[a+4>>2],b))}wb(b);j=e,k=wb(v[a>>2]),v[j+8>>2]=k;c=wb(v[a+4>>2]);break e}j=Yb(v[f>>2],c),k=c-i|0,u[j>>1]=k;g=v[a+4>>2];h=v[a>>2];v[22452]=0;g=Y(721,h|0,g|0,c|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}c=c+1|0;i=(x[g>>1]==(b|0))+i|0;continue}break}while(1){b=v[e+8>>2];if(!Tb(b,c)){b=v[f>>2];d=wc(b,v[f+4>>2]);c=x[a+28>>1];if(d>>>0<=c>>>0){break c}j=a,k=x[Yb(b,c)>>1],u[j+28>>1]=k;break c}g:{d=v[a+24>>2]+484344|0;b=x[b>>1];if(!he(d,b)){break g}b=Rb(d,b);j=e,k=vg(b),v[j>>2]=k;d=ug(b);while(1){b=v[e>>2];if(!Tb(b,d)){break g}h:{if(w[b+3|0]!=12){break h}i=v[f>>2];h=wc(i,v[f+4>>2]);g=w[b+5|0];if(h>>>0<=g>>>0){break h}j=b,k=w[Yb(i,g)|0],t[j+5|0]=k}ui(e);continue}}Ke(e+8|0);continue}}a=P()|0;O()|0;_c(f);S(a|0);L()}_c(f);ab=e+48|0}function Vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=ab-32|0;ab=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+16|0)|0;e=a+e|0;v[h>>2]=v[e+44>>2];v[h+4>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;p=v[a+8>>2];q=v[a+12>>2];a:while(1){if(d){e=(((v[g+12>>2]&2147483647)<<1|v[g+8>>2]>>>31)&-2)+o|0;b=0;while(1)if((b|0)==2){r=v[a+72>>2];b=v[a+68>>2];s=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){m=(b<<2)+g|0;f=v[m>>2];e=(g+16|0)+(b<<3)|0;k=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;n=f<<8;f=n;f=oia(y,z,f,f>>31);l=db;A=e;e=Sb(j,-16777216,16776704);j=oia(w,x,e,e>>31);f=j+f|0;e=db+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Sb(k,-16777216,16776704);k=oia(s,u,f,f>>31);f=l+k|0;e=db+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[A>>2]=e-(r&n);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[g>>2],i>>12);h=b+h|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],h>>12);Lb(g+8|0,p,q);c=c+8|0;d=d-1|0;continue a}else{v[(b<<2)+g>>2]=t[b+e|0]<<8;b=b+1|0;continue}}break}v[a+40>>2]=h;v[a+36>>2]=i;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+32|0}function zaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=ab-48|0;ab=f;o=v[a+16>>2];g=Vd(f+16|0);v[g+8>>2]=a+112;i=v[a+128>>2];v[g+16>>2]=i;t=g,w=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;l=v[a+8>>2];m=v[a+12>>2];if(i){t=g,w=Wf(l,m,i),v[t>>2]=w;v[g+4>>2]=db}h=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];b=v[a+44>>2];i=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=i;a:while(1){b:{i=b;if(!d){break b}b=v[f+12>>2];v[f+40>>2]=v[f+8>>2];v[f+44>>2]=0;e=(b<<1)+o|0;b=v[g+16>>2];while(1)if((b|0)<=0){b=v[g+8>>2];j=v[b+8>>2];Lb(b,j,v[b+12>>2]);b=v[g+8>>2];j=v[b+4>>2];if(j){Bd(b,u[e+(v[f+44>>2]<<1)>>1]/4<<16>>16);Ad(v[g+8>>2],j);b=v[g+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}d=d-1|0;j=v[a+72>>2];e=v[a+60>>2];n=Uf(b,v[g+12>>2])<<8;b=n;b=oia(e,e>>31,b,b>>31);r=db;e=b;b=v[a+64>>2];k=b;s=b>>31;b=Sb(i,-16777216,16776704);k=oia(k,s,b,b>>31);e=e+k|0;b=db+r|0;b=e>>>0<k>>>0?b+1|0:b;k=e;e=v[a+68>>2];h=Sb(h,-16777216,16776704);e=oia(e,e>>31,h,h>>31);h=k+e|0;b=db+b|0;b=e>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=h>>>0<8388608?b+1|0:b;b=Cc(h,b,24);h=(b|0)/256|0;v[c>>2]=B(h,q)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(h,p);Lb(f+8|0,l,m);b=b-(j&n)|0;c=c+8|0;h=i;continue a}else{Bd(v[g+8>>2],u[e+(v[f+44>>2]<<1)>>1]/4<<16>>16);Ad(v[g+8>>2],4);Lb(f+40|0,v[g>>2],v[g+4>>2]);b=b-1|0;continue}}break}v[a+48>>2]=h;v[a+44>>2]=i;b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+48|0}function c_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=ab-384|0;ab=a;v[a+368>>2]=c;v[a+376>>2]=b;Lv(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Bb(a+200|0);b=Ec(d);v[22452]=0;R(60,d|0,b|0);b=v[22452];v[22452]=0;a:{b:{c:{if((b|0)!=1){c=oc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;h=v[a+232>>2];i=v[a+236>>2];while(1){d:{v[22452]=0;b=Q(1116,a+376|0,a+368|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+196>>2];b=ub(d);if((g|0)==(b+c|0)){v[22452]=0;R(60,d|0,b<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+196>>2]=b+c}v[22452]=0;b=T(1118,v[a+376>>2])|0;g=v[22452];v[22452]=0;if((g|0)==1){break d}if(Kv(b,a+23|0,a+22|0,c,a+196|0,i,h,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[22452]=0;T(1120,a+376|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}gF(a,c,v[a+196>>2],e);b=v[a>>2];c=v[a+4>>2];h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;v[f>>2]=b;v[f+4>>2]=c;tf(a+216|0,a+32|0,v[a+28>>2],e);v[22452]=0;b=Q(1117,a+376|0,a+368|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];pb(d);pb(a+216|0);ab=a+384|0;break a}}b=P()|0;O()|0;pb(d);pb(a+216|0);S(b|0);L()}return b|0}function Iba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=ab-32|0;ab=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;r=v[a+8>>2];s=v[a+12>>2];a:while(1){b:{if(!d){b=0;while(1){if((b|0)==2){break b}c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}}b=v[g+8>>2];f=b>>>18|0;k=((((v[g+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=0;while(1)if((b|0)==2){k=v[a+72>>2];b=v[a+68>>2];i=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){m=(b<<2)+g|0;f=v[m>>2];e=(g+16|0)+(b<<3)|0;j=v[e+4>>2];h=v[e>>2];v[e+4>>2]=h;n=f<<8;f=n;f=oia(y,z,f,f>>31);l=db;A=e;e=Sb(h,-16777216,16776704);h=oia(w,x,e,e>>31);f=h+f|0;e=db+l|0;e=f>>>0<h>>>0?e+1|0:e;l=f;f=Sb(j,-16777216,16776704);j=oia(i,t,f,f>>31);f=l+j|0;e=db+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[A>>2]=e-(k&n);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],q);v[c+4>>2]=v[c+4>>2]+B(p,v[g+4>>2]);Lb(g+8|0,r,s);c=c+8|0;d=d-1|0;continue a}else{i=k+(b<<1)|0;e=u[i>>1];v[(b<<2)+g>>2]=e+((B(f,u[i+4>>1]-e|0)|0)/16384|0);b=b+1|0;continue}}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+32|0}function $2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=ab-32|0;ab=d;f=Pb(a);g=b+24|0;h=ej(Kb(v[g>>2]+484360|0));v[22452]=0;R(172,f|0,h|0);a=v[22452];v[22452]=0;a:{if((a|0)!=1){a=0;while(1){b:{if((a|0)!=(h|0)){c=x[Yb(v[Kb(v[g>>2]+484360|0)>>2],a)>>1];if(lm(v[g>>2]+484344|0,c)){c=v[g>>2];c=Rb(c+484344|0,x[Yb(v[Kb(c+484360|0)>>2],a)>>1]);v[22452]=0;R(993,d|0,c|0);c=v[22452];v[22452]=0;c:{d:{e:{if((c|0)!=1){v[22452]=0;U(980,d+16|0,b|0,d|0);c=v[22452];v[22452]=0;if((c|0)==1){break e}v[22452]=0;R(174,f|0,d+16|0);c=v[22452];v[22452]=0;if((c|0)==1){break d}pb(d+16|0);pb(d);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;pb(d+16|0)}pb(d);break a}f:{switch(c-65534|0){case 0:v[22452]=0;c=Q(55,d+16|0,9211)|0;e=v[22452];v[22452]=0;g:{if((e|0)!=1){v[22452]=0;R(174,f|0,c|0);e=v[22452];v[22452]=0;if((e|0)==1){break g}pb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;pb(c);break a;case 1:v[22452]=0;c=Q(55,d+16|0,9173)|0;e=v[22452];v[22452]=0;h:{if((e|0)!=1){v[22452]=0;R(174,f|0,c|0);e=v[22452];v[22452]=0;if((e|0)==1){break h}pb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;pb(c);break a;default:break f}}v[22452]=0;c=Q(55,d+16|0,14592)|0;e=v[22452];v[22452]=0;i:{if((e|0)!=1){v[22452]=0;R(174,f|0,c|0);e=v[22452];v[22452]=0;if((e|0)==1){break i}pb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;pb(c);break a}ab=d+32|0;return}a=a+1|0;continue}}a=P()|0;O()|0}Uc(f);S(a|0);L()}function m_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=ab-288|0;ab=a;v[a+272>>2]=c;v[a+280>>2]=b;Pv(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Bb(a+208|0);b=Ec(d);v[22452]=0;R(60,d|0,b|0);b=v[22452];v[22452]=0;a:{b:{c:{if((b|0)!=1){c=oc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;h=t[a+238|0];i=t[a+239|0];while(1){d:{v[22452]=0;b=Q(1100,a+280|0,a+272|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+204>>2];b=ub(d);if((g|0)==(b+c|0)){v[22452]=0;R(60,d|0,b<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+204>>2]=b+c}v[22452]=0;b=T(1102,v[a+280>>2])|0;g=v[22452];v[22452]=0;if((g|0)==1){break d}if(Ov(b,a+23|0,a+22|0,c,a+204|0,i,h,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[22452]=0;T(1104,a+280|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}gF(a,c,v[a+204>>2],e);b=v[a>>2];c=v[a+4>>2];h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;v[f>>2]=b;v[f+4>>2]=c;tf(a+224|0,a+32|0,v[a+28>>2],e);v[22452]=0;b=Q(1101,a+280|0,a+272|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];pb(d);pb(a+224|0);ab=a+288|0;break a}}b=P()|0;O()|0;pb(d);pb(a+224|0);S(b|0);L()}return b|0}function KZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=ab-432|0;ab=i;v[i+424>>2]=37;v[i+428>>2]=0;m=gr(i+424|1,13855,v[c+4>>2]);v[i+380>>2]=i+384;a=gd();a:{if(m){j=v[c+8>>2];k=i- -64|0;v[k>>2]=g;v[k+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=j;j=sf(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;j=sf(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=1098;l=ee(i+368|0,0,i+128|0);k=i+384|0;a=k;b:{c:{d:{if((j|0)>=30){a=gd();e:{if(m){j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i+8>>2]=e;v[i+12>>2]=f;v[i>>2]=j;j=Ji(i+380|0,a,i+424|0,i);break e}v[i+32>>2]=e;v[i+36>>2]=f;v[i+40>>2]=g;v[i+44>>2]=h;j=Ji(i+380|0,a,i+424|0,i+32|0)}if((j|0)==-1){v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)==1){break c}break d}a=v[i+380>>2];Ce(l,a)}f=a+j|0;g=Dg(a,f,c);v[i+116>>2]=1098;e=ee(i+120|0,0,i+116|0);f:{g:{if((i+384|0)==(a|0)){j=i+128|0;break g}j=yd(j<<3);if(!j){v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ce(e,j);k=a}a=i+104|0;zc(a,c);v[22452]=0;ja(1131,k|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=v[22452];v[22452]=0;h:{if((a|0)!=1){Nb(i+104|0);v[22452]=0;a=la(1132,b|0,j|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break h}Bc(e);Bc(l);ab=i+432|0;return a|0}c=P()|0;O()|0;Nb(i+104|0);break f}c=P()|0;O()|0}Bc(e);break b}L()}c=P()|0;O()|0}Bc(l);S(c|0);L()}function UZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=ab-256|0;ab=i;v[i+248>>2]=37;v[i+252>>2]=0;m=gr(i+248|1,13855,v[c+4>>2]);v[i+204>>2]=i+208;a=gd();a:{if(m){j=v[c+8>>2];k=i- -64|0;v[k>>2]=g;v[k+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=j;j=sf(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;j=sf(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=1098;l=ee(i+192|0,0,i+128|0);k=i+208|0;a=k;b:{c:{d:{if((j|0)>=30){a=gd();e:{if(m){j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i+8>>2]=e;v[i+12>>2]=f;v[i>>2]=j;j=Ji(i+204|0,a,i+248|0,i);break e}v[i+32>>2]=e;v[i+36>>2]=f;v[i+40>>2]=g;v[i+44>>2]=h;j=Ji(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)==1){break c}break d}a=v[i+204>>2];Ce(l,a)}f=a+j|0;g=Dg(a,f,c);v[i+116>>2]=1098;e=ee(i+120|0,0,i+116|0);f:{g:{if((i+208|0)==(a|0)){j=i+128|0;break g}j=yd(j<<1);if(!j){v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ce(e,j);k=a}a=i+104|0;zc(a,c);v[22452]=0;ja(1126,k|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=v[22452];v[22452]=0;h:{if((a|0)!=1){Nb(i+104|0);v[22452]=0;a=la(14,b|0,j|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break h}Bc(e);Bc(l);ab=i+256|0;return a|0}c=P()|0;O()|0;Nb(i+104|0);break f}c=P()|0;O()|0}Bc(e);break b}L()}c=P()|0;O()|0}Bc(l);S(c|0);L()}function Jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=ab-32|0;ab=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;r=v[a+8>>2];s=v[a+12>>2];a:while(1){b:{if(!d){b=0;while(1){if((b|0)==2){break b}c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}}b=v[g+8>>2];f=b>>>10&4194048;k=(((v[g+12>>2]&2147483647)<<1|b>>>31)&-2)+o|0;b=0;while(1)if((b|0)==2){k=v[a+72>>2];b=v[a+68>>2];i=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){m=(b<<2)+g|0;f=v[m>>2];e=(g+16|0)+(b<<3)|0;j=v[e+4>>2];h=v[e>>2];v[e+4>>2]=h;n=f<<8;f=n;f=oia(y,z,f,f>>31);l=db;A=e;e=Sb(h,-16777216,16776704);h=oia(w,x,e,e>>31);f=h+f|0;e=db+l|0;e=f>>>0<h>>>0?e+1|0:e;l=f;f=Sb(j,-16777216,16776704);j=oia(i,u,f,f>>31);f=l+j|0;e=db+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[A>>2]=e-(k&n);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],q);v[c+4>>2]=v[c+4>>2]+B(p,v[g+4>>2]);Lb(g+8|0,r,s);c=c+8|0;d=d-1|0;continue a}else{i=b+k|0;e=t[i|0];v[(b<<2)+g>>2]=((B(f,t[i+2|0]-e|0)|0)/16384|0)+(e<<8);b=b+1|0;continue}}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+32|0}function b_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=ab-352|0;ab=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Bb(a+208|0);b=a+16|0;zc(b,d);v[22452]=0;b=T(1111,b|0)|0;c=v[22452];v[22452]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22452]=0;W(1123,b|0,79744,79770,a+224|0);b=v[22452];v[22452]=0;if((b|0)==1){break d}Nb(a+16|0);c=Bb(a+192|0);b=Ec(c);v[22452]=0;R(60,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break b}b=oc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[22452]=0;d=Q(1116,a+344|0,a+336|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break e}if(!d){break c}g=v[a+188>>2];d=ub(c);if((g|0)==(d+b|0)){v[22452]=0;R(60,c|0,d<<1);b=v[22452];v[22452]=0;if((b|0)==1){break b}b=Ec(c);v[22452]=0;R(60,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break b}b=oc(c,0);v[a+188>>2]=d+b}v[22452]=0;d=T(1118,v[a+344>>2])|0;g=v[22452];v[22452]=0;if((g|0)==1){break e}if(Nm(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[22452]=0;T(1120,a+344|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;Nb(a+16|0);break a}v[22452]=0;R(60,c|0,v[a+188>>2]-b|0);b=v[22452];v[22452]=0;f:{if((b|0)==1){break f}b=Eb(c);d=gd();v[a>>2]=f;if((fF(b,d,a)|0)!=1){v[e>>2]=4}v[22452]=0;b=Q(1117,a+344|0,a+336|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];pb(c);pb(h);ab=a+352|0;return b|0}}b=P()|0;O()|0;pb(c)}pb(h);S(b|0);L()}function l_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=ab-272|0;ab=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Bb(a+208|0);b=a+16|0;zc(b,d);v[22452]=0;b=T(18,b|0)|0;c=v[22452];v[22452]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22452]=0;W(1109,b|0,79744,79770,a+224|0);b=v[22452];v[22452]=0;if((b|0)==1){break d}Nb(a+16|0);c=Bb(a+192|0);b=Ec(c);v[22452]=0;R(60,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break b}b=oc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[22452]=0;d=Q(1100,a+264|0,a+256|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break e}if(!d){break c}g=v[a+188>>2];d=ub(c);if((g|0)==(d+b|0)){v[22452]=0;R(60,c|0,d<<1);b=v[22452];v[22452]=0;if((b|0)==1){break b}b=Ec(c);v[22452]=0;R(60,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break b}b=oc(c,0);v[a+188>>2]=d+b}v[22452]=0;d=T(1102,v[a+264>>2])|0;g=v[22452];v[22452]=0;if((g|0)==1){break e}if(Om(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[22452]=0;T(1104,a+264|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;Nb(a+16|0);break a}v[22452]=0;R(60,c|0,v[a+188>>2]-b|0);b=v[22452];v[22452]=0;f:{if((b|0)==1){break f}b=Eb(c);d=gd();v[a>>2]=f;if((fF(b,d,a)|0)!=1){v[e>>2]=4}v[22452]=0;b=Q(1101,a+264|0,a+256|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];pb(c);pb(h);ab=a+272|0;return b|0}}b=P()|0;O()|0;pb(c)}pb(h);S(b|0);L()}function bE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-96|0;ab=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){Mb(a,9711);break j}if(!(b&65535)){d=ab-16|0;ab=d;e=Mb(d,4360);Ac(c+80|0,e);pb(e);ab=d+16|0;v[22452]=0;v[c+24>>2]=b>>>24;R(100,c- -64|0,c+24|0);d=v[22452];v[22452]=0;k:{l:{m:{n:{if((d|0)!=1){v[22452]=0;v[c+8>>2]=b>>>16&255;R(101,c+48|0,c+8|0);b=v[22452];v[22452]=0;if((b|0)==1){break n}v[22452]=0;W(102,a|0,c+80|0,c- -64|0,c+48|0);a=v[22452];v[22452]=0;if((a|0)==1){break m}pb(c+48|0);pb(c- -64|0);yb(c+80|0);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;pb(c+48|0)}pb(c- -64|0)}break a}d=ab-16|0;ab=d;e=Mb(d,4084);Ac(c+80|0,e);pb(e);ab=d+16|0;v[22452]=0;v[c+44>>2]=b>>>24;R(100,c- -64|0,c+44|0);d=v[22452];v[22452]=0;if((d|0)==1){break i}v[22452]=0;v[c+40>>2]=b>>>16&255;R(101,c+48|0,c+40|0);d=v[22452];v[22452]=0;if((d|0)==1){break h}v[22452]=0;v[c+20>>2]=b>>>8&255;R(101,c+24|0,c+20|0);d=v[22452];v[22452]=0;if((d|0)==1){break g}v[22452]=0;v[c+4>>2]=b&255;R(101,c+8|0,c+4|0);b=v[22452];v[22452]=0;if((b|0)==1){break f}v[22452]=0;ka(103,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=v[22452];v[22452]=0;if((a|0)==1){break e}pb(c+8|0);pb(c+24|0);pb(c+48|0);pb(c- -64|0);yb(c+80|0)}ab=c+96|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;pb(c+8|0)}pb(c+24|0)}pb(c+48|0)}pb(c- -64|0)}yb(c+80|0);S(b|0);L()}function Aaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;f=ab-48|0;ab=f;o=v[a+16>>2];g=Vd(f+16|0);v[g+8>>2]=a+112;i=v[a+128>>2];v[g+16>>2]=i;u=g,w=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;l=v[a+8>>2];m=v[a+12>>2];if(i){u=g,w=Wf(l,m,i),v[u>>2]=w;v[g+4>>2]=db}h=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];b=v[a+44>>2];i=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=i;a:while(1){b:{i=b;if(!d){break b}b=v[f+12>>2];v[f+40>>2]=v[f+8>>2];v[f+44>>2]=0;e=b+o|0;b=v[g+16>>2];while(1)if((b|0)<=0){b=v[g+8>>2];j=v[b+8>>2];Lb(b,j,v[b+12>>2]);b=v[g+8>>2];j=v[b+4>>2];if(j){Bd(b,t[e+v[f+44>>2]|0]<<6);Ad(v[g+8>>2],j);b=v[g+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}d=d-1|0;j=v[a+72>>2];e=v[a+60>>2];n=Uf(b,v[g+12>>2])<<8;b=n;b=oia(e,e>>31,b,b>>31);r=db;e=b;b=v[a+64>>2];k=b;s=b>>31;b=Sb(i,-16777216,16776704);k=oia(k,s,b,b>>31);e=e+k|0;b=db+r|0;b=e>>>0<k>>>0?b+1|0:b;k=e;e=v[a+68>>2];h=Sb(h,-16777216,16776704);e=oia(e,e>>31,h,h>>31);h=k+e|0;b=db+b|0;b=e>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=h>>>0<8388608?b+1|0:b;b=Cc(h,b,24);h=(b|0)/256|0;v[c>>2]=B(h,q)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(h,p);Lb(f+8|0,l,m);b=b-(j&n)|0;c=c+8|0;h=i;continue a}else{Bd(v[g+8>>2],t[e+v[f+44>>2]|0]<<6);Ad(v[g+8>>2],4);Lb(f+40|0,v[g>>2],v[g+4>>2]);b=b-1|0;continue}}break}v[a+48>>2]=h;v[a+44>>2]=i;b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+48|0}function ii(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!Fd(a)){break a}ek(a);b:{switch(xm(x[a+34>>1])-1|0){case 1:e=ab+-64|0;ab=e;h=v[a+20>>2];c=v[a>>2];d=qd(x[a+34>>1]);f=h+(B(c,d)<<1)|0;while(1){c:{d:{if((g|0)!=16){i=B(d,g);j=B(d,g^-1);c=0;break d}g=f+(d<<5)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];rb(e+32|0,b+1074312|0,33);jO(e+40|0,g,h+(B(d,f)<<1)|0,i-f|0,d,(c&4)>>>2|0,sb(v[v[e+32>>2]>>2],v[e+36>>2]));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];rb(e+32|0,b+1074312|0,33);jO(e+8|0,g+(d<<7)|0,h+(B(a,d)<<1)|0,f-a|0,d,(c&16)>>>4|0,sb(v[v[e+32>>2]>>2],v[e+36>>2]))}ab=e- -64|0;break c}while(1){if((c|0)!=(d|0)){u[f+(c+i<<1)>>1]=x[f+(c-d<<1)>>1];u[h+(c+j<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;continue}break}g=g+1|0;continue}break};return;case 0:break b;default:break a}}e=ab+-64|0;ab=e;h=v[a+20>>2];c=v[a>>2];d=qd(x[a+34>>1]);f=h+B(c,d)|0;while(1){e:{f:{if((g|0)!=16){i=B(d,g);j=B(d,g^-1);c=0;break f}g=f+(d<<4)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];rb(e+32|0,b+1074312|0,33);iO(e+40|0,g,h+B(d,f)|0,i-f|0,d,(c&4)>>>2|0,sb(v[v[e+32>>2]>>2],v[e+36>>2]));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];rb(e+32|0,b+1074312|0,33);iO(e+8|0,g+(d<<6)|0,h+B(a,d)|0,f-a|0,d,(c&16)>>>4|0,sb(v[v[e+32>>2]>>2],v[e+36>>2]))}ab=e- -64|0;break e}while(1){if((c|0)!=(d|0)){t[f+(c+i|0)|0]=w[f+(c-d|0)|0];t[h+(c+j|0)|0]=w[c+h|0];c=c+1|0;continue}break}g=g+1|0;continue}break}}}function xy(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=ab-16|0;ab=h;f=v[c+656>>2];a:{if(!hj(f)){i=v[c+704>>2];f=ab-16|0;ab=f;v[f+12>>2]=d;g=0;b:{if(!d){break b}j=v[b+480180>>2];if(j&20){e=b+1074312|0;rb(f,e,73);d=sb(v[v[f>>2]>>2],v[f+4>>2])?d&65535:d;if(w[b+480208|0]&16){rb(f,e,73);e=sb(v[v[f>>2]>>2],v[f+4>>2])?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=v[((d>>>0)%768<<2)+34096>>2]<<6>>>e|0;break b}if(!d){v[f+12>>2]=1;d=1}g=229079296/(d>>>0)|0;break b}g=227001280/(d>>>0)|0;if(_l(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}mc(f+12|0,16777215);if(j&17408){g=Fc(ria(oia(i?i:8363,0,3506176,0),db,(v[f+12>>2]<<8)+e|0,0),db);break b}if(_i(b)){d=v[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(w[b+480208|0]&16){g=Fc(ria(oia(i?i:8363,0,7012352,0),db,(v[f+12>>2]<<8)+e|0,0),db);break b}g=Fc(ria(-1485242368,13,(v[f+12>>2]<<8)+e|0,0),db)}d=g;ab=f+16|0;f=v[c+656>>2];break a}d=v[c+700>>2]}v[h+12>>2]=d;c=u[c+774>>1];c:{if(!c){break c}c=f?B(t[f+33|0],c):c;if(!c){break c}d=xe(Ej(+(c|0)/393216)*+(d>>>0));v[h+12>>2]=d}d:{if(!f){break d}c=v[f+40>>2];if(!c){break d}e=(c|0)/2|0;f=v[b+1074420>>2];d=oia(f,f>>31,d,d>>31);f=e+d|0;e=db+(e>>31)|0;k=h,l=vc(pia(f,d>>>0>f>>>0?e+1|0:e,c,c>>31),db),v[k+12>>2]=l}mc(h+12|0,2147483647);c=v[h+12>>2];b=pia(0,c,v[b+24620>>2]<<4,0);v[a+8>>2]=c;v[a>>2]=b;v[a+4>>2]=db;ab=h+16|0}function lfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ab-16|0;ab=e;a:{if((c|0)!=4){h=b+236|0;g=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=Cb(g,d),j=w[f+4|0]+1|0,t[i|0]=j;f=f+6|0;i=Yb(h,d),j=(w[f|0]|w[f+1|0]<<8)+1|0,u[i>>1]=j;d=d+1|0;continue}}h=b+236|0;while(1){if((d|0)==96){break a}g=((d<<2)+a|0)+6|0;i=Yb(h,d+12|0),j=(w[g|0]|w[g+1|0]<<8)+1|0,u[i>>1]=j;d=d+1|0;continue}}Tz(a+484|0,b+48|0,0);Tz(a+590|0,b+68|0,0);Tz(a+696|0,b+88|0,5);d=a+806|0;v[b>>2]=w[d|0]|w[d+1|0]<<8;d=t[a+808|0];b:{if((d|0)<0){t[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(t[a|0]&1){t[b+31|0]=d+1;break b}if((d-1&255)>>>0>15){break b}t[b+31|0]=d+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=t[a+809|0];if((d|0)>=0){u[b+28>>1]=(d&255)+1}d=a+810|0;if(t[d|0]<0){break c}}t[b+30|0]=w[d|0]+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;i=b,j=w[Qb(e+15|0,e+14|0)|0]>>>1|0,v[i+4>>2]=j}c=a+813|0;c=w[c|0]|w[c+1|0]<<8;if(c>>>0<=256){v[b+8>>2]=c;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];c=a+820|0;u[e+12>>1]=w[c|0]|w[c+1|0]<<8;u[e+10>>1]=100;i=b,j=w[Lc(e+12|0,e+10|0)|0],t[i+20|0]=j;c=a+822|0;u[e+8>>1]=w[c|0]|w[c+1|0]<<8;u[e+6>>1]=256;i=b,j=x[Lc(e+8|0,e+6|0)>>1]>>>2|0,t[i+19|0]=j;c=w[a+824|0];rm(b,c&127,c>>>7|0);a=w[a+825|0];qm(b,a&127,a>>>7|0);ab=e+16|0}function hQ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=ab-16|0;ab=j;a:{if((b|0)==(c|0)){break a}v[j+12>>2]=-1953789045;Bz(b,c,j+12|0);c=c-b|0;e=c>>2;v[j+8>>2]=e;f=v[a>>2];i=nc(f,v[a+4>>2]);d=11;b:{if(c>>>0>2488){break b}d=7;if(c>>>0>268){break b}d=5;if(c>>>0>152){break b}d=3;if(c>>>0>24){break b}d=e-1>>>1|0}a=i+1|0;v[j+4>>2]=a;c=v[Pc(j+4|0,j+8|0)>>2];m=e-d>>>1|0;k=(m<<2)+b|0;h=v[k>>2];g=B(lt(v[((e<<2)+b|0)-4>>2]^(h^v[b>>2])),1664525);v[k>>2]=g+h;k=d+m|0;d=(k<<2)+b|0;h=d;l=v[d>>2];d=g+i|0;v[h>>2]=l+d;v[b>>2]=d;d=1;while(1)if(d>>>0>i>>>0){while(1)if(a>>>0>=c>>>0){a=c;while(1){if(c+e>>>0<=a>>>0){break a}f=((a+m>>>0)%(e>>>0)<<2)+b|0;h=v[f>>2];i=(a>>>0)%(e>>>0)|0;g=(i<<2)+b|0;d=B(lt(v[((a-1>>>0)%(e>>>0)<<2)+b>>2]+(h+v[g>>2]|0)|0),1566083941);v[f>>2]=d^h;f=((a+k>>>0)%(e>>>0)<<2)+b|0;d=d-i|0;v[f>>2]=d^v[f>>2];v[g>>2]=d;a=a+1|0;continue}}else{f=((a+m>>>0)%(e>>>0)<<2)+b|0;h=v[f>>2];i=(a>>>0)%(e>>>0)|0;g=(i<<2)+b|0;d=B(lt(v[((a-1>>>0)%(e>>>0)<<2)+b>>2]^(h^v[g>>2])),1664525);v[f>>2]=d+h;f=((a+k>>>0)%(e>>>0)<<2)+b|0;d=d+i|0;v[f>>2]=d+v[f>>2];v[g>>2]=d;a=a+1|0;continue}}else{h=d-1|0;l=((d+m>>>0)%(e>>>0)<<2)+b|0;n=v[l>>2];o=(d>>>0)%(e>>>0)|0;p=(o<<2)+b|0;g=B(lt(v[((h>>>0)%(e>>>0)<<2)+b>>2]^(n^v[p>>2])),1664525);v[l>>2]=g+n;l=((d+k>>>0)%(e>>>0)<<2)+b|0;n=v[l>>2];g=v[Fb(f,h)>>2]+(g+o|0)|0;v[l>>2]=g+n;v[p>>2]=g;d=d+1|0;continue}}ab=j+16|0}function dba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=ab-16|0;ab=g;a:{b:{c:{h=v[a+12>>2];i=v[a+8>>2];d:{if((h|0)<=1&i>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|h>>>0>4294967294){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];e=v[a+48>>2];r=v[a+24>>2];s=v[a+20>>2];b=v[a+44>>2];j=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=j;while(1){j=b;if(d){t=v[a+72>>2];b=v[a+64>>2];k=b;l=b>>31;b=Sb(j,-16777216,16776704);b=oia(k,l,b,b>>31);m=db;l=b;b=v[a+60>>2];k=b;n=b>>31;f=(v[g+12>>2]<<1)+q|0;b=(v[g+8>>2]>>>16&65520)+p|0;f=(((((((B(u[f-4>>1],u[b+2>>1])+B(u[f-6>>1],u[b>>1])|0)+B(u[f-2>>1],u[b+4>>1])|0)+B(u[f>>1],u[b+6>>1])|0)+B(u[f+2>>1],u[b+8>>1])|0)+B(u[f+4>>1],u[b+10>>1])|0)+B(u[f+6>>1],u[b+12>>1])|0)+B(u[f+8>>1],u[b+14>>1])|0)/32768<<8;b=f;b=oia(k,n,b,b>>31);n=l+b|0;o=db+m|0;o=b>>>0>n>>>0?o+1|0:o;b=v[a+68>>2];k=b;l=b>>31;b=Sb(e,-16777216,16776704);e=oia(k,l,b,b>>31);m=e+n|0;b=db+o|0;b=e>>>0>m>>>0?b+1|0:b;e=m+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Cc(e,b,24);b=(e|0)/256|0;v[c>>2]=B(b,s)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(b,r);Lb(g+8|0,i,h);b=e-(f&t)|0;c=c+8|0;d=d-1|0;e=j;continue}break}v[a+48>>2]=e;v[a+44>>2]=j;b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+16|0}function Ws(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=ab-32|0;ab=e;if(b&5){if((b|0)==1){d=oia(v[a+24>>2],0,8363,0)+4136|0;c=db;h=a,i=Fc(ria(d,d>>>0<4136?c+1|0:c,8272,0),db),v[h+24>>2]=i}c=ab-16|0;ab=c;f=c+8|0;d=ab-16|0;ab=d;g=v[a+24>>2];a:{if(!g){t[f|0]=0;t[f+1|0]=0;break a}aB(d+8|0,Sb(Tl(So(+(g>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);g=v[d+8>>2];t[d+7|0]=v[d+12>>2];Vs(f,g,d+7|0)}ab=d+16|0;$b(c,a+36|0);$b(c+4|0,a+37|0);t[v[c>>2]]=w[f|0];t[v[c+4>>2]]=w[f+1|0];ab=c+16|0}if(b&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(b&7){u[a+32>>1]=64;c=x[a+34>>1];if(c&8){d=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=d;c=c&16?c|6:c&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=c&65511}b:{if(!(b&4)){break b}c=x[a+34>>1];if(!(c&32)){u[a+28>>1]=128;u[a+34>>1]=c|32}jf(a+40|0,15);jf(a+41|0,63);if(!w[a+41|0]){break b}d=w[a+40|0];if(!d){break b}c=w[a+39|0];if(c){c=pm(Fc(((d<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}t[a+39|0]=c}c:{d:{if((b|0)!=4){if((b|0)==16777216){break c}if((b|0)!=32|w[a+38|0]!=2){break d}t[a+38|0]=3;break d}if(w[a+38|0]!=4){break d}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}e:{if(!(!(w[a+35|0]&2)|b&16777218)){v[e+24>>2]=0;v[e+8>>2]=0;v[e+16>>2]=0;v[e+20>>2]=0;v[e>>2]=0;v[e+4>>2]=0;fl(a,0,e);break e}if(!(w[a+35|0]&2)|(b|0)!=2){break e}a=a+68|0;b=Cb(a,8);t[b|0]=w[b|0]&3;a=Cb(a,9);t[a|0]=w[a|0]&3}ab=e+32|0}function JX(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=ab-16|0;ab=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!v[b>>2]){break a}b=b+4|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=ab-16|0;ab=r;s=Sh(r+8|0,v[a+8>>2]);i=f;j=g-f|0;m=0;o=ab-16|0;ab=o;k=v[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=i?j:0;while(1){l=ow(j>>>0<4?o+12|0:i,v[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}gc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!v[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){v[e>>2]=k}ab=o+16|0;Rh(s);ab=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:v[h>>2]=f;while(1){i:{if(v[e>>2]==(c|0)){break i}b=xv(f,v[c>>2],v[a+8>>2]);if((b|0)==-1){break i}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;continue}break};v[e>>2]=c;break g;case 1:break c;default:break h}}f=m+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=v[e>>2];b=d;continue}b=xv(n+12|0,0,v[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-v[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=w[c|0];i=v[h>>2];v[h>>2]=i+1;t[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=v[e>>2]+4|0;v[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!v[b>>2]){break b}b=b+4|0;continue}}c=v[e>>2]}q=(c|0)!=(d|0)}ab=n+16|0;return q|0}f=v[h>>2];continue}}function Caa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=ab-48|0;ab=f;o=v[a+16>>2];g=Vd(f+16|0);v[g+8>>2]=a+112;e=v[a+128>>2];v[g+16>>2]=e;q=g,r=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;l=v[a+8>>2];m=v[a+12>>2];if(e){q=g,r=Wf(l,m,e),v[q>>2]=r;v[g+4>>2]=db}i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;while(1){if(d){b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;n=(((b&2147483647)<<1|e>>>31)&-2)+o|0;e=v[g+16>>2];a:{b:while(1){c:{if((e|0)<=0){b=v[g+8>>2];e=v[b+8>>2];Lb(b,e,v[b+12>>2]);e=v[g+8>>2];k=v[e+4>>2];if(!k){break a}p=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;h=0;b=0;break c}k=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;b=0;h=0;while(1)if((b|0)==2){Bd(v[g+8>>2],(h|0)/8<<16>>16);Ad(v[g+8>>2],4);Lb(f+40|0,v[g>>2],v[g+4>>2]);e=e-1|0;continue b}else{h=(t[(b+k|0)+n|0]<<8)+h|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){h=(t[(b+p|0)+n|0]<<8)+h|0;b=b+1|0;continue}break}Bd(e,(h|0)/8<<16>>16);Ad(v[g+8>>2],k);e=v[g+8>>2];b=e;h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}d=d-1|0;b=v[a+32>>2];j=v[a+28>>2]+j|0;e=Uf(e,v[g+12>>2]);v[c>>2]=B(j>>12,e)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(e,i>>12);Lb(f+8|0,l,m);c=c+8|0;continue}break}v[a+40>>2]=i;v[a+36>>2]=j;v[a+20>>2]=j>>12;v[a+24>>2]=i>>12;b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+48|0}function vM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ab-32|0;ab=e;f=v[b+64>>2];a:{b:{h=v[b+60>>2];g=x[b+68>>1];if(!((h|0)==-1&(g|0)==65535)){c:{if((f|0)==-1){break c}f=a+1074312|0;rb(e+24|0,f,68);if(sb(v[v[e+24>>2]>>2],v[e+28>>2])){break c}rb(e+16|0,f,103);if(i=sb(v[v[e+16>>2]>>2],v[e+20>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}rb(e+8|0,f,49);if(i=sb(v[v[e+8>>2]>>2],v[e+12>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}f=v[b+64>>2];break b}if((g|0)==65535){u[b+68>>1]=x[b+72>>1]+1}if((h|0)==-1){v[b+60>>2]=0}g=wc(v[c>>2],v[c+4>>2]);f=x[b+68>>1];if(g>>>0<=f>>>0){f=x[c+28>>1];u[b+68>>1]=f}d:{if(x[b+72>>1]==(f&65535)){break d}c=a+1074312|0;rb(e+24|0,c,26);if(sb(v[v[e+24>>2]>>2],v[e+28>>2])){break d}rb(e+16|0,c,68);if(sb(v[v[e+16>>2]>>2],v[e+20>>2])|v[a+480180>>2]==1){break d}c=x[a+480188>>1];f=0;while(1){if((c|0)==(f|0)){break d}t[(B(f,872)+b|0)+1457|0]=0;f=f+1|0;continue}}v[b+52>>2]=v[b+60>>2];if(d){c=1;if(w[a+480208|0]&32){break a}}u[b+74>>1]=x[b+68>>1];c=1;break a}if((f|0)!=-1){break b}c=0;break a}v[b+52>>2]=f;u[b+74>>1]=x[b+72>>1];e:{if(!v[b+20>>2]){break e}c=v[a+480180>>2];if((c|0)==32){rb(e+24|0,a+1074312|0,103);if(sb(v[v[e+24>>2]>>2],v[e+28>>2])){break e}c=v[a+480180>>2]}if((c|0)==2){break e}v[b+52>>2]=v[b+52>>2]+1}c=0;if(y[b+64>>2]<y[Rb(a+484344|0,x[b+70>>1])+12>>2]){break a}v[b+52>>2]=0;u[b+74>>1]=x[b+74>>1]+1;c=0}ab=e+32|0;return c}function nH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=ab-16|0;ab=h;f=a+8|0;g=Yr(f);if(!g){g=Xr(f)}a:{b:{c:{if(b>>>0>=g>>>0){b=aa(8)|0;v[22452]=0;c=Q(55,h|0,5961)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}lc(b,c);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(c);break b}if(c>>>0>=120){b=aa(8)|0;v[22452]=0;c=Q(55,h|0,11292)|0;a=v[22452];v[22452]=0;if((a|0)!=1){lc(b,c);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(c);break b}a=P()|0;O()|0;ba(b|0);break b}g=a+32|0;a=v[g>>2];f=hy(a,65535);i=(f|0)==65535?255:f;u[h>>1]=i;a=a+B(i,872)|0;f=a+1074992|0;Dn(f,v[g>>2],65535,1024);c=c+1|0;t[a+1075794|0]=c;t[a+1075791|0]=c;u[a+1075778>>1]=0;Ml(f);kp(v[g>>2],f,b+1|0,0,1,1);v[a+1075688>>2]=65536;Is(v[g>>2],f,c,0,1,1,65535);l=a+1075684|0,m=Tl(Ay(e*128,-128,128)+128),v[l>>2]=m;l=a+1075680|0,m=Tl(Ay(d*256,0,256)),v[l>>2]=m;b=v[g>>2];a=b+1074478|0;k=a;b=(x[b+480212>>1]<<1)+a|0;f=x[h>>1];c=f;while(1){d:{e:{if((a|0)!=(b|0)){if((c|0)!=x[a>>1]){break e}}else{a=b}break d}a=a+2|0;continue}break}f:{if((a|0)==(b|0)){break f}c=a;while(1){c=c+2|0;if((c|0)==(b|0)){b=a;break f}j=x[c>>1];if((j|0)==(f|0)){continue}u[a>>1]=j;a=a+2|0;f=x[h>>1];continue}}a=Iy(k,b);u[v[g>>2]+480212>>1]=a;ab=h+16|0;return i|0}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function Xx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=88;j=92;k=91;l=85;m=84;n=83;o=5;p=113;q=111;r=107;s=106;t=96;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;c=by(a);a:{b:{c:{d:{switch(b-1|0){default:a=(b|0)==16777216;if(!a&(b|0)!=32){break c}Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(c,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1);if(!a){break a}d=111;e=105;f=99;break b;case 3:Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(c,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1),67,1);p=112;q=98;r=93;s=90;t=89;u=86;v=76;w=75;x=74;y=73;z=72;A=71;d=70;e=69;g=68;case 1:Db(Db(Db(Db(Db(Db(Db(Db(c,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1);m=88;o=v;n=u;l=t;k=s;j=r;i=q;h=p;break;case 2:break c;case 0:break d}}Db(Db(Db(Db(c,o,1),n,1),m,1),l,1);g=k;f=j;e=i;d=h}Db(c,g,1)}Db(Db(Db(c,f,1),e,1),d,1)}}function eha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ab-80|0;ab=d;b=b&4095;u[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=ab-16|0;ab=e;f=Mb(e,4412);Ac(d- -64|0,f);pb(f);ab=e+16|0;v[22452]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=oia(e,e>>31,1e4,0)+14780|0;b=db;b=pia(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(B(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;v[d+44>>2]=g+f;R(88,d+48|0,d+44|0);g=v[22452];v[22452]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){v[22452]=0;v[d+28>>2]=(e+B(f,-12)|0)+1;R(90,d+32|0,d+28|0);e=v[22452];v[22452]=0;if((e|0)==1){break j}v[22452]=0;v[d+12>>2]=(((B(b,306)+5|0)/-10|0)+c|0)+1;R(90,d+16|0,d+12|0);b=v[22452];v[22452]=0;if((b|0)==1){break i}v[22452]=0;ga(360,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}pb(d+16|0);pb(d+32|0);break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;pb(d+16|0)}pb(d+32|0)}pb(d+48|0)}break a}af(d- -64|0,4392);v[22452]=0;R(361,d+48|0,d+78|0);b=v[22452];v[22452]=0;if((b|0)==1){break c}v[22452]=0;U(136,a|0,d- -64|0,d+48|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}}pb(d+48|0);yb(d- -64|0);ab=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;pb(d+48|0)}yb(d- -64|0);S(b|0);L()}function Zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=ab-32|0;ab=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;p=v[a+8>>2];q=v[a+12>>2];a:while(1){b:{if(!d){b=0;while(1){if((b|0)==2){break b}c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}}e=((((v[g+12>>2]&2147483647)<<1|v[g+8>>2]>>>31)&2147483646)<<1)+m|0;b=0;while(1)if((b|0)==2){r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){k=(b<<2)+g|0;f=v[k>>2];e=(g+16|0)+(b<<3)|0;i=v[e+4>>2];h=v[e>>2];v[e+4>>2]=h;l=f<<8;f=l;f=oia(y,z,f,f>>31);j=db;A=e;e=Sb(h,-16777216,16776704);h=oia(w,x,e,e>>31);f=h+f|0;e=db+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Sb(i,-16777216,16776704);i=oia(s,t,f,f>>31);f=j+i|0;e=db+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[A>>2]=e-(r&l);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+4>>2]);Lb(g+8|0,p,q);c=c+8|0;d=d-1|0;continue a}else{v[(b<<2)+g>>2]=u[e+(b<<1)>>1];b=b+1|0;continue}}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+32|0}function NN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=ab-16|0;ab=g;a:{if(Oj(a)){h=ab-16|0;ab=h;e=pc(3848);f=e+808|0;c=e+16|0;while(1){v[c+16>>2]=0;v[c+20>>2]=0;v[c+36>>2]=0;t[c+42|0]=1;u[c+40>>1]=257;v[c+24>>2]=0;v[c+28>>2]=0;u[c+32>>1]=0;c=c+44|0;if((f|0)!=(c|0)){continue}break}f=e+3832|0;c=e+808|0;while(1){v[c>>2]=0;v[c+4>>2]=0;v[c+68>>2]=0;v[c+72>>2]=0;v[c+24>>2]=0;v[c+28>>2]=0;u[c+20>>1]=511;v[c+16>>2]=-1;u[c+14>>1]=1;u[c+6>>1]=0;u[c+8>>1]=0;u[c+10>>1]=0;u[c+12>>1]=0;t[c+73|0]=0;t[c+74|0]=0;t[c+75|0]=0;t[c+76|0]=0;t[c+77|0]=0;t[c+78|0]=0;t[c+79|0]=0;t[c+80|0]=0;c=c+84|0;if((f|0)!=(c|0)){continue}break}c=0;f=0;v[e+3832>>2]=0;v[e+3836>>2]=0;d=e+3837|0;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;while(1){if((f|0)==36){while(1){if((c|0)==18){b:{c=0;f=0;while(1)if((c|0)==18){while(1){if((f|0)==36){break b}Cn((B(f,84)+e|0)+808|0);f=f+1|0;continue}}else{d=(B(c,44)+e|0)+16|0;j=v[(c<<2)+28912>>2];c:{if(!(!(1<<c&3591)|c>>>0>11)){i=d;d=B(j,84)+e|0;SN(i,d+808|0,d+1060|0,d+1312|0,d+1564|0);break c}i=d;d=B(j,84)+e|0;SN(i,d+808|0,d+1060|0,0,0)}c=c+1|0;continue}}}else{v[(B(c,44)+e|0)+32>>2]=e;c=c+1|0;continue}break}RN(e,b)}else{nd((B(f,84)+e|0)+808|0,e);f=f+1|0;continue}break}b=v[yf(h+8|0,e)>>2];ab=h+16|0;v[g+8>>2]=b;b=g+8|0;Vz(a,b);bl(b);break a}RN(v[a>>2],b)}MN(a);ab=g+16|0}function eba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=ab-16|0;ab=g;a:{b:{c:{h=v[a+12>>2];i=v[a+8>>2];d:{if((h|0)<=1&i>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|h>>>0>4294967294){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}n=v[a+16>>2];b=v[a+48>>2];o=v[a+24>>2];p=v[a+20>>2];e=v[a+44>>2];j=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=j;while(1){j=e;if(d){q=v[a+72>>2];e=v[a+64>>2];k=e;f=e>>31;e=Sb(j,-16777216,16776704);e=oia(k,f,e,e>>31);f=db;k=e;e=v[a+68>>2];b=Sb(b,-16777216,16776704);e=oia(e,e>>31,b,b>>31);l=k+e|0;b=db+f|0;b=e>>>0>l>>>0?b+1|0:b;e=v[a+60>>2];k=e;r=e>>31;f=v[g+12>>2]+n|0;e=(v[g+8>>2]>>>16&65520)+m|0;f=(((((((B(t[f-2|0],u[e+2>>1])+B(t[f-3|0],u[e>>1])|0)+B(t[f-1|0],u[e+4>>1])|0)+B(t[f|0],u[e+6>>1])|0)+B(t[f+1|0],u[e+8>>1])|0)+B(t[f+2|0],u[e+10>>1])|0)+B(t[f+3|0],u[e+12>>1])|0)+B(t[f+4|0],u[e+14>>1])<<8)/32768<<8;e=f;e=oia(k,r,e,e>>31);l=e+l|0;b=db+b|0;b=e>>>0>l>>>0?b+1|0:b;e=l+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Cc(e,b,24);b=(e|0)/256|0;v[c>>2]=B(b,p)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(b,o);Lb(g+8|0,i,h);e=e-(f&q)|0;c=c+8|0;d=d-1|0;b=j;continue}break}v[a+48>>2]=b;v[a+44>>2]=j;b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+16|0}function MX(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=ab-16|0;ab=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{while(1){c=v[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=t[c|0];j=i&255;d:{if((i|0)>=0){u[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=w[c+1|0];if((i&192)!=128){break a}u[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=w[c+2|0];i=w[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}u[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=w[c+3|0];i=w[c+2|0];c=w[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;u[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=i<<6&960|k&63|56320;b=v[a+12>>2]+4|0}v[a+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];ab=a+16|0;return b|0}function GA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=ab-32|0;ab=h;a:{if(b&4){break a}e=w[a+14|0];b:{if(e>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|e>>>0<=w[a+13|0]){break a}if(Td(a)>>>0<=e>>>0){break a}e=x[xc(v[a>>2],v[a+4>>2],e)>>1];d=xc(v[a>>2],v[a+4>>2],w[a+14|0]-1|0);c=w[a+14|0];if(x[d>>1]<(e-1|0)){c=x[xc(v[a>>2],v[a+4>>2],c)>>1]-1&65535;e=wp(a,c,64,64);n=h,o=wb(v[a>>2]),v[n+16>>2]=o;d=$b(h+24|0,Wk(h+16|0,w[a+14|0]));k=Qn(h+8|0,c,e&255);m=ab-32|0;ab=m;c=v[d>>2];d=v[a>>2];c=(yt(c,wb(d))<<2)+d|0;i=v[a+4>>2];c:{d:{if(i>>>0<y[vb(a)>>2]){if((c|0)!=(i|0)){break d}DR(a,k);break c}d=vb(a);f=_f(m+8|0,fh(a,nc(v[a>>2],i)+1|0),c-v[a>>2]>>2,d);v[22452]=0;R(723,f|0,k|0);d=v[22452];v[22452]=0;if((d|0)!=1){d=v[f+4>>2];j=f+4|0;Gn(v[a>>2],c,j);e=v[a+4>>2];g=f+8|0;while(1){if((c|0)!=(e|0)){Pn(v[g>>2],c);v[g>>2]=v[g>>2]+4;c=c+4|0;continue}break}cc(a,j);cc(a+4|0,g);cc(vb(a),ic(f));v[f>>2]=v[f+4>>2];c=d;Zf(f);break c}a=P()|0;O()|0;Zf(f);S(a|0);L()}f=ab-16|0;ab=f;j=v[a+4>>2];d=(j-(c+4|0)|0)+c|0;g=li(f,a,i-d>>2);l=v[g+4>>2];e=d;while(1){if(e>>>0>=i>>>0){dc(g);Wp(c,d,j);ab=f+16|0}else{Pn(l,e);l=l+4|0;v[g+4>>2]=l;e=e+4|0;continue}break}t[c+2|0]=w[k+2|0];u[c>>1]=x[k>>1]}wb(c);ab=m+32|0;break a}t[a+14|0]=c-1}if((b|0)!=16777216){t[a+17|0]=255}ab=h+32|0}function e_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=C(0);a=ab-368|0;ab=a;v[a+352>>2]=c;v[a+360>>2]=b;Lv(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Bb(a+184|0);b=Ec(d);v[22452]=0;R(60,d|0,b|0);b=v[22452];v[22452]=0;a:{b:{c:{if((b|0)!=1){c=oc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[22452]=0;b=Q(1116,a+360|0,a+352|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+180>>2];b=ub(d);if((g|0)==(b+c|0)){v[22452]=0;R(60,d|0,b<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+180>>2]=b+c}v[22452]=0;b=T(1118,v[a+360>>2])|0;g=v[22452];v[22452]=0;if((g|0)==1){break d}if(Kv(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22452]=0;T(1120,a+360|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=jF(c,v[a+180>>2],e),z[j>>2]=k;tf(a+200|0,a+16|0,v[a+12>>2],e);v[22452]=0;b=Q(1117,a+360|0,a+352|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];pb(d);pb(a+200|0);ab=a+368|0;break a}}b=P()|0;O()|0;pb(d);pb(a+200|0);S(b|0);L()}return b|0}function Qfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=v[a>>2];b=Bt(c,v[a+4>>2]);if(b>>>0<=63){g=ab-32|0;ab=g;f=64-b|0;c=v[vb(a)>>2];d=v[a+4>>2];a:{if(f>>>0<=(c-d|0)/33>>>0){b=ab-16|0;ab=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+B(f,33);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){dc(b);ab=b+16|0}else{lA(a);a=a+33|0;v[b+4>>2]=a;continue}break}break a}i=vb(a);c=g+8|0;h=Bt(v[a>>2],d)+f|0;d=ab-16|0;ab=d;v[d+12>>2]=h;e=ab-16|0;ab=e;v[e+12>>2]=130150524;v[e+8>>2]=2147483647;b=v[zb(e+12|0,e+8|0)>>2];ab=e+16|0;b:{if(b>>>0>=h>>>0){e=CR(a);if(e>>>0<b>>>1>>>0){v[d+8>>2]=e<<1;b=v[Pc(d+8|0,d+12|0)>>2]}ab=d+16|0;break b}hd();L()}e=Bt(v[a>>2],v[a+4>>2]);Ve(c+12|0,i);if(b){if(b>>>0>=130150525){Oe(11129);L()}d=pc(B(b,33))}else{d=0}v[c>>2]=d;e=d+B(e,33)|0;v[c+8>>2]=e;v[c+4>>2]=e;j=ic(c),k=d+B(b,33)|0,v[j>>2]=k;b=ab-16|0;ab=b;v[b>>2]=v[c+8>>2];d=v[c+8>>2];v[b+8>>2]=c+8;v[b+4>>2]=d+B(f,33);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){lA(d);d=v[b>>2]+33|0;v[b>>2]=d;continue}break}xd(b);ab=b+16|0;b=c+4|0;f=v[a>>2];d=v[a+4>>2]-f|0;e=v[b>>2]+B((d|0)/-33|0,33)|0;v[b>>2]=e;if((d|0)>0){gc(e,f,d)}cc(a,b);cc(a+4|0,c+8|0);cc(vb(a),ic(c));v[c>>2]=v[c+4>>2];b=v[c+4>>2];a=v[c+8>>2];while(1){if((a|0)!=(b|0)){a=a-33|0;v[c+8>>2]=a;continue}break}a=v[c>>2];if(a){ic(c);xb(a)}}ab=g+32|0;return}if((b|0)!=64){Hd(a,c+2112|0)}}function o_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=C(0);a=ab-272|0;ab=a;v[a+256>>2]=c;v[a+264>>2]=b;Pv(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Bb(a+192|0);b=Ec(d);v[22452]=0;R(60,d|0,b|0);b=v[22452];v[22452]=0;a:{b:{c:{if((b|0)!=1){c=oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=t[a+222|0];i=t[a+223|0];while(1){d:{v[22452]=0;b=Q(1100,a+264|0,a+256|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+188>>2];b=ub(d);if((g|0)==(b+c|0)){v[22452]=0;R(60,d|0,b<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+188>>2]=b+c}v[22452]=0;b=T(1102,v[a+264>>2])|0;g=v[22452];v[22452]=0;if((g|0)==1){break d}if(Ov(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22452]=0;T(1104,a+264|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=jF(c,v[a+188>>2],e),z[j>>2]=k;tf(a+208|0,a+16|0,v[a+12>>2],e);v[22452]=0;b=Q(1101,a+264|0,a+256|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];pb(d);pb(a+208|0);ab=a+272|0;break a}}b=P()|0;O()|0;pb(d);pb(a+208|0);S(b|0);L()}return b|0}
function _ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=ab-32|0;ab=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;p=v[a+8>>2];q=v[a+12>>2];a:while(1){b:{if(!d){b=0;while(1){if((b|0)==2){break b}c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}}e=(((v[g+12>>2]&2147483647)<<1|v[g+8>>2]>>>31)&-2)+m|0;b=0;while(1)if((b|0)==2){r=v[a+72>>2];b=v[a+68>>2];s=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){k=(b<<2)+g|0;f=v[k>>2];e=(g+16|0)+(b<<3)|0;i=v[e+4>>2];h=v[e>>2];v[e+4>>2]=h;l=f<<8;f=l;f=oia(y,z,f,f>>31);j=db;A=e;e=Sb(h,-16777216,16776704);h=oia(w,x,e,e>>31);f=h+f|0;e=db+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Sb(i,-16777216,16776704);i=oia(s,u,f,f>>31);f=j+i|0;e=db+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Cc(f,e,24);v[A>>2]=e-(r&l);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+4>>2]);Lb(g+8|0,p,q);c=c+8|0;d=d-1|0;continue a}else{v[(b<<2)+g>>2]=t[b+e|0]<<8;b=b+1|0;continue}}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+32|0}function tga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=ab-32|0;ab=g;c=cf(a,c);d=g+8|0;Xd(d,v[a+28>>2]);e=v[d+12>>2];v[g+24>>2]=v[d+8>>2];v[g+28>>2]=e;a:{if(!c){b:{d=0;if(!Vc(a,5)){break b}break a}}d=ab-144|0;ab=d;h=yl(d+40|0,v[a+28>>2]);v[22452]=0;f=Q(408,d+24|0,43971)|0;e=v[22452];v[22452]=0;c:{d:{e:{f:{if((e|0)!=1){v[22452]=0;v[d+16>>2]=19923456;v[d+20>>2]=0;U(409,h|0,f|0,d+16|0);e=v[22452];v[22452]=0;if((e|0)==1){break f}yb(f);if(!(w[h+3|0]&64)){break e}break c}e=P()|0;O()|0;break d}e=P()|0;O()|0;yb(f);break d}k=d,l=lf(b),u[k+16>>1]=l;u[d+14>>1]=65535;v[22452]=0;f=Q(408,d+24|0,10066)|0;e=v[22452];v[22452]=0;g:{if((e|0)!=1){v[22452]=0;e=Y(438,h|0,d+14|0,f|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break g}yb(f);if((e|0)!=1){u[d+16>>1]=x[d+14>>1]}lg(d+16|0,4e3);f=x[d+16>>1];h:{if(lf(b)>>>0>=f>>>0){break h}v[22452]=0;R(216,b|0,f|0);e=v[22452];v[22452]=0;if((e|0)!=1){break h}e=P()|0;O()|0;break d}e=0;i:{while(1){if((e|0)==(f|0)){break c}i=Rb(b,e);v[22452]=0;R(439,d+24|0,e|0);j=v[22452];v[22452]=0;if((j|0)!=1){v[22452]=0;da(440,h|0,i|0,d+24|0,441)|0;i=v[22452];v[22452]=0;if((i|0)==1){break i}e=e+1|0;yb(d+24|0);continue}break}e=P()|0;O()|0;break d}e=P()|0;O()|0;yb(d+24|0);break d}e=P()|0;O()|0;break d}e=P()|0;O()|0;yb(f)}Sg(h);S(e|0);L()}Sg(h);ab=d+144|0;d=c}Te(a,d,g+24|0);ab=g+32|0}function d_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=ab-368|0;ab=a;v[a+352>>2]=c;v[a+360>>2]=b;Lv(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Bb(a+184|0);b=Ec(d);v[22452]=0;R(60,d|0,b|0);b=v[22452];v[22452]=0;a:{b:{c:{if((b|0)!=1){c=oc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[22452]=0;b=Q(1116,a+360|0,a+352|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+180>>2];b=ub(d);if((g|0)==(b+c|0)){v[22452]=0;R(60,d|0,b<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+180>>2]=b+c}v[22452]=0;b=T(1118,v[a+360>>2])|0;g=v[22452];v[22452]=0;if((g|0)==1){break d}if(Kv(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22452]=0;T(1120,a+360|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=hF(c,v[a+180>>2],e),A[j>>3]=k;tf(a+200|0,a+16|0,v[a+12>>2],e);v[22452]=0;b=Q(1117,a+360|0,a+352|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];pb(d);pb(a+200|0);ab=a+368|0;break a}}b=P()|0;O()|0;pb(d);pb(a+200|0);S(b|0);L()}return b|0}function n_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=ab-272|0;ab=a;v[a+256>>2]=c;v[a+264>>2]=b;Pv(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Bb(a+192|0);b=Ec(d);v[22452]=0;R(60,d|0,b|0);b=v[22452];v[22452]=0;a:{b:{c:{if((b|0)!=1){c=oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=t[a+222|0];i=t[a+223|0];while(1){d:{v[22452]=0;b=Q(1100,a+264|0,a+256|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+188>>2];b=ub(d);if((g|0)==(b+c|0)){v[22452]=0;R(60,d|0,b<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+188>>2]=b+c}v[22452]=0;b=T(1102,v[a+264>>2])|0;g=v[22452];v[22452]=0;if((g|0)==1){break d}if(Ov(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22452]=0;T(1104,a+264|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=hF(c,v[a+188>>2],e),A[j>>3]=k;tf(a+208|0,a+16|0,v[a+12>>2],e);v[22452]=0;b=Q(1101,a+264|0,a+256|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];pb(d);pb(a+208|0);ab=a+272|0;break a}}b=P()|0;O()|0;pb(d);pb(a+208|0);S(b|0);L()}return b|0}function YG(a){var b=0,c=0,d=0;ne(v[a+80>>2],v[a+20>>2]);while(1){if((b|0)<v[a+24>>2]){ne(v[a+80>>2],v[v[a+28>>2]+(b<<2)>>2]);b=b+1|0;continue}break}ne(v[a+80>>2],v[a+28>>2]);a:{if(!v[a+396>>2]){break a}while(1){if(v[a+264>>2]<=(c|0)){break a}d=v[a+396>>2]+B(c,24)|0;if(v[d+16>>2]){b=0;while(1){if((b|0)<v[(v[a+124>>2]+B(w[d+13|0],2096)|0)+4>>2]){ne(v[a+80>>2],v[v[d+16>>2]+(b<<2)>>2]);b=b+1|0;continue}break}ne(v[a+80>>2],v[d+16>>2])}ne(v[a+80>>2],v[d+20>>2]);c=c+1|0;continue}}if(v[a+124>>2]){c=0;while(1){if((c|0)<v[a+120>>2]){b=v[a+124>>2]+B(c,2096)|0;ne(v[a+80>>2],v[b+8>>2]);ne(v[a+80>>2],v[b+28>>2]);ne(v[a+80>>2],v[b+32>>2]);ne(v[a+80>>2],v[b+2084>>2]);b=v[b+2088>>2];ne(v[a+80>>2],b?b-4|0:0);c=c+1|0;continue}break}ne(v[a+80>>2],v[a+124>>2])}ne(v[a+80>>2],v[a+260>>2]);ne(v[a+80>>2],v[a+396>>2]);if(v[a+404>>2]){b=0;while(1){if((b|0)<v[a+400>>2]){ne(v[a+80>>2],v[(v[a+404>>2]+B(b,40)|0)+4>>2]);b=b+1|0;continue}break}ne(v[a+80>>2],v[a+404>>2])}c=0;b=0;while(1){if(!(v[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;ne(v[a+80>>2],v[d+800>>2]);ne(v[a+80>>2],v[d+928>>2]);ne(v[a+80>>2],v[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;ne(v[a+80>>2],v[b+1068>>2]);ne(v[a+80>>2],v[b+1076>>2]);ne(v[a+80>>2],v[b+1084>>2]);ne(v[a+80>>2],v[b+1092>>2]);ne(v[a+80>>2],v[b+1100>>2]);c=c+1|0;continue}break}}function yn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=ab-16|0;ab=d;g=a+1074312|0;rb(d+8|0,g,96);i=b,j=(k=0,l=v[b+660>>2],m=sb(v[v[d+8>>2]>>2],v[d+12>>2]),m?k:l)+c|0,v[i+660>>2]=j;f=v[a+480180>>2];e=v[b+84>>2];if(!(!(f&18)|e>>>0>c>>>0|(!(w[b+88|0]&2)|!e))){h=c;c=v[b+80>>2];c=((h-c>>>0)%(e-c>>>0)|0)+c|0}c=c>>>(v[b+88>>2]&1&(f|0)==16384)|0;a:{b:{if(!Kc(w[b+788|0])){rb(d+8|0,g,114);if(!sb(v[v[d+8>>2]>>2],v[d+12>>2])){break b}}e=v[b+656>>2];c:{if(!e){break c}f=w[b+788|0];if(!Kc(f)){break c}e=x[Yb(e+236|0,f-1|0)>>1];if(!e|e>>>0>x[a+480190>>1]){break a}}if(w[a+480210|0]&32){e=c;c=v[b+660>>2];v[b+660>>2]=e+c}v[b>>2]=0;v[b+4>>2]=c;if((!(w[b+88|0]&2)|y[b+84>>2]>c>>>0)&y[b+76>>2]>c>>>0){break a}rb(d+8|0,g,57);d:{if(!sb(v[v[d+8>>2]>>2],v[d+12>>2])){c=v[a+480180>>2];if((c|0)!=16){break d}}v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break a}if(!(c&1048581)){rb(d+8|0,g,27);if(sb(v[v[d+8>>2]>>2],v[d+12>>2])){if(w[a+480208|0]&4){c=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=c;break a}v[b>>2]=0;v[b+4>>2]=0;break a}c=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=c;if(!(w[a+480208|0]&4)){break a}a=v[b+76>>2];if(a>>>0<5){break a}v[b>>2]=0;v[b+4>>2]=a-2;break a}if(!(w[b+88|0]&2)|(c|0)!=1){break a}a=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=a;break a}if(!(v[a+480180>>2]&268582928)|y[b+76>>2]<=c>>>0){break a}v[b>>2]=0;v[b+4>>2]=c}ab=d+16|0}function j3(a){a=a|0;var b=0,c=0,d=0,e=0;d=ab-160|0;ab=d;e=Mb(d,11574);v[22452]=0;b=d+12|0;Q(55,b|0,10912)|0;c=v[22452];v[22452]=0;a:{b:{if((c|0)==1){break a}v[22452]=0;b=d+24|0;Q(55,b|0,11404)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}v[22452]=0;b=d+36|0;Q(55,b|0,10904)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}v[22452]=0;b=d+48|0;Q(55,b|0,8230)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}v[22452]=0;b=d+60|0;Q(55,b|0,10889)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}v[22452]=0;b=d+72|0;Q(55,b|0,8296)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}v[22452]=0;b=d+84|0;Q(55,b|0,5581)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}v[22452]=0;b=d+96|0;Q(55,b|0,11978)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}v[22452]=0;b=d+108|0;Q(55,b|0,11347)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}v[22452]=0;b=d+120|0;Q(55,b|0,12179)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}v[22452]=0;b=d+132|0;Q(55,b|0,5433)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}v[22452]=0;b=d+144|0;Q(55,b|0,7253)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}v[22452]=0;Y(990,a|0,e|0,13)|0;a=v[22452];v[22452]=0;if((a|0)==1){break b}b=d+156|0;while(1){b=pb(b-12|0);if((e|0)!=(b|0)){continue}break}ab=d+160|0;return}b=d+156|0}a=P()|0;O()|0;while(1){b=pb(b-12|0);if((e|0)!=(b|0)){continue}break}S(a|0);L()}function h_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=ab-352|0;ab=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mi(d);i=Ao(d,a+224|0);zo(a+208|0,d,a+332|0);d=Bb(a+192|0);c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;a:{b:{c:{if((c|0)!=1){c=oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22452]=0;g=Q(1116,a+344|0,a+336|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=ub(d);if((h|0)==(g+c|0)){v[22452]=0;R(60,d|0,g<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+188>>2]=g+c}v[22452]=0;g=T(1118,v[a+344>>2])|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(Nm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[22452]=0;T(1120,a+344|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=pF(c,v[a+188>>2],e,b),v[k>>2]=l;v[f+4>>2]=db;tf(a+208|0,a+16|0,v[a+12>>2],e);v[22452]=0;b=Q(1117,a+344|0,a+336|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];pb(d);pb(a+208|0);ab=a+352|0;break a}}b=P()|0;O()|0;pb(d);pb(a+208|0);S(b|0);L()}return b|0}function f_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=ab-352|0;ab=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mi(d);i=Ao(d,a+224|0);zo(a+208|0,d,a+332|0);d=Bb(a+192|0);c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;a:{b:{c:{if((c|0)!=1){c=oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22452]=0;g=Q(1116,a+344|0,a+336|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=ub(d);if((h|0)==(g+c|0)){v[22452]=0;R(60,d|0,g<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+188>>2]=g+c}v[22452]=0;g=T(1118,v[a+344>>2])|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(Nm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[22452]=0;T(1120,a+344|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=kF(c,v[a+188>>2],e,b),v[k>>2]=l;v[f+4>>2]=db;tf(a+208|0,a+16|0,v[a+12>>2],e);v[22452]=0;b=Q(1117,a+344|0,a+336|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];pb(d);pb(a+208|0);ab=a+352|0;break a}}b=P()|0;O()|0;pb(d);pb(a+208|0);S(b|0);L()}return b|0}function Uda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[vb(a)>>2]){c=ab-16|0;ab=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+56;a=v[c+4>>2];v[22452]=0;R(624,a|0,b|0);a=v[22452];v[22452]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+56;dc(c);ab=c+16|0;break a}a=P()|0;O()|0;dc(c);S(a|0);L()}return}h=ab-32|0;ab=h;i=vb(a);f=h+8|0;g=Ep(v[a>>2],v[a+4>>2])+1|0;d=ab-16|0;ab=d;v[d+12>>2]=g;e=ab-16|0;ab=e;v[e+12>>2]=76695844;v[e+8>>2]=2147483647;c=v[zb(e+12|0,e+8|0)>>2];ab=e+16|0;b:{if(c>>>0>=g>>>0){e=cQ(a);if(e>>>0<c>>>1>>>0){v[d+8>>2]=e<<1;c=v[Pc(d+8|0,d+12|0)>>2]}ab=d+16|0;break b}hd();L()}e=Ep(v[a>>2],v[a+4>>2]);Ve(f+12|0,i);if(c){if(c>>>0>=76695845){Oe(11129);L()}d=pc(B(c,56))}else{d=0}v[f>>2]=d;e=d+B(e,56)|0;v[f+8>>2]=e;v[f+4>>2]=e;j=ic(f),k=d+B(c,56)|0,v[j>>2]=k;c=v[f+8>>2];v[22452]=0;R(624,c|0,b|0);b=v[22452];v[22452]=0;c:{if((b|0)!=1){v[f+8>>2]=v[f+8>>2]+56;e=v[a>>2];b=v[a+4>>2];d=f+4|0;while(1){if((b|0)!=(e|0)){c=v[d>>2]-56|0;b=b-56|0;Sj(c,b);Sj(c+12|0,b+12|0);zz(c+24|0,b+24|0);u[c+52>>1]=x[b+52>>1];g=v[b+48>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=g;g=v[b+40>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=g;v[d>>2]=v[d>>2]-56;continue}break}cc(a,d);cc(a+4|0,f+8|0);cc(vb(a),ic(f));v[f>>2]=v[f+4>>2];bQ(f);ab=h+32|0;break c}a=P()|0;O()|0;bQ(f);S(a|0);L()}}function i_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=ab-352|0;ab=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mi(d);i=Ao(d,a+224|0);zo(a+208|0,d,a+332|0);d=Bb(a+192|0);c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;a:{b:{c:{if((c|0)!=1){c=oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22452]=0;g=Q(1116,a+344|0,a+336|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=ub(d);if((h|0)==(g+c|0)){v[22452]=0;R(60,d|0,g<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+188>>2]=g+c}v[22452]=0;g=T(1118,v[a+344>>2])|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(Nm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[22452]=0;T(1120,a+344|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=qF(c,v[a+188>>2],e,b),v[k>>2]=l;tf(a+208|0,a+16|0,v[a+12>>2],e);v[22452]=0;b=Q(1117,a+344|0,a+336|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];pb(d);pb(a+208|0);ab=a+352|0;break a}}b=P()|0;O()|0;pb(d);pb(a+208|0);S(b|0);L()}return b|0}function g_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=ab-352|0;ab=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mi(d);i=Ao(d,a+224|0);zo(a+208|0,d,a+332|0);d=Bb(a+192|0);c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;a:{b:{c:{if((c|0)!=1){c=oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22452]=0;g=Q(1116,a+344|0,a+336|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=ub(d);if((h|0)==(g+c|0)){v[22452]=0;R(60,d|0,g<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+188>>2]=g+c}v[22452]=0;g=T(1118,v[a+344>>2])|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(Nm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[22452]=0;T(1120,a+344|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=oF(c,v[a+188>>2],e,b),u[k>>1]=l;tf(a+208|0,a+16|0,v[a+12>>2],e);v[22452]=0;b=Q(1117,a+344|0,a+336|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];pb(d);pb(a+208|0);ab=a+352|0;break a}}b=P()|0;O()|0;pb(d);pb(a+208|0);S(b|0);L()}return b|0}function dF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=ab-352|0;ab=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mi(d);i=Ao(d,a+224|0);zo(a+208|0,d,a+332|0);d=Bb(a+192|0);c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;a:{b:{c:{if((c|0)!=1){c=oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22452]=0;g=Q(1116,a+344|0,a+336|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=ub(d);if((h|0)==(g+c|0)){v[22452]=0;R(60,d|0,g<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+188>>2]=g+c}v[22452]=0;g=T(1118,v[a+344>>2])|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(Nm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[22452]=0;T(1120,a+344|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=lF(c,v[a+188>>2],e,b),v[k>>2]=l;tf(a+208|0,a+16|0,v[a+12>>2],e);v[22452]=0;b=Q(1117,a+344|0,a+336|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];pb(d);pb(a+208|0);ab=a+352|0;break a}}b=P()|0;O()|0;pb(d);pb(a+208|0);S(b|0);L()}return b|0}function NX(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=ab-16|0;ab=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;c=v[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=x[c>>1];c:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<=0){break a}v[a+8>>2]=c+1;t[c|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break e}if((g-v[a+8>>2]|0)<4){break a}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;t[f|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;continue}break}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];ab=a+16|0;return f|0}function r_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=ab-240|0;ab=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mi(d);Bo(a+208|0,d,a+223|0);d=Bb(a+192|0);c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;a:{b:{c:{if((c|0)!=1){c=oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[22452]=0;g=Q(1100,a+232|0,a+224|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=ub(d);if((h|0)==(g+c|0)){v[22452]=0;R(60,d|0,g<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+188>>2]=g+c}v[22452]=0;g=T(1102,v[a+232>>2])|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(Om(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,79744)){break c}v[22452]=0;T(1104,a+232|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=pF(c,v[a+188>>2],e,b),v[j>>2]=k;v[f+4>>2]=db;tf(a+208|0,a+16|0,v[a+12>>2],e);v[22452]=0;b=Q(1101,a+232|0,a+224|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];pb(d);pb(a+208|0);ab=a+240|0;break a}}b=P()|0;O()|0;pb(d);pb(a+208|0);S(b|0);L()}return b|0}function p_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=ab-240|0;ab=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mi(d);Bo(a+208|0,d,a+223|0);d=Bb(a+192|0);c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;a:{b:{c:{if((c|0)!=1){c=oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[22452]=0;g=Q(1100,a+232|0,a+224|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=ub(d);if((h|0)==(g+c|0)){v[22452]=0;R(60,d|0,g<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+188>>2]=g+c}v[22452]=0;g=T(1102,v[a+232>>2])|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(Om(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,79744)){break c}v[22452]=0;T(1104,a+232|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=kF(c,v[a+188>>2],e,b),v[j>>2]=k;v[f+4>>2]=db;tf(a+208|0,a+16|0,v[a+12>>2],e);v[22452]=0;b=Q(1101,a+232|0,a+224|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];pb(d);pb(a+208|0);ab=a+240|0;break a}}b=P()|0;O()|0;pb(d);pb(a+208|0);S(b|0);L()}return b|0}function fe(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0),k=0;f=(p(b),j(2));d=hE(f);a:{b:{c:{d:{c=(p(a),j(2));e:{if(c-2139095040>>>0>=2164260864){if(d){break e}break c}if(!d){break d}}i=C(1);if((c|0)==1065353216){break b}e=f<<1;if(!e){break b}d=e>>>0<4278190081;e=c<<1;a=C(a+b);if(!(d&e>>>0<=4278190080)){break a}if((e|0)==2130706432){break b}a=((f^-1)>>>31|0)==(e>>>0<2130706432|0)?C(0):C(b*b);break a}if(hE(c)){i=C(a*a);if((c|0)<0){i=(gE(f)|0)==1?C(-i):i}if((f|0)>=0){break b}a=FG(C(C(1)/i));break a}if((c|0)<0){e=gE(f);if(!e){a=$I(a);break a}c=c&2147483647;e=((e|0)==1)<<16}if(c>>>0>8388607){break c}c=((p(C(a*C(8388608))),j(2))&2147483647)-192937984|0}f=c-1060306944|0;d=f>>>15&240;g=+(l(2,c-(f&-8388608)|0),q())*A[d+89024>>3]+-1;h=g*g;h=((g*.288457581109214+-.36092606229713164)*(h*h)+((g*.480898481472577+-.7213474675006291)*h+(g*1.4426950408774342+(A[d+89032>>3]+ +(f>>23)))))*+b;o(+h);d=j(1)|0;j(0)|0;f:{d=d&2147450880;if((d|0)==1079967744|d>>>0<1079967744){break f}if(h>127.99999995700433){a=JD(e);break a}if(!(h<=-150)){break f}a=eD(e);break a}k=h;g=A[160];h=g+h;g=k-(h-g);k=(A[161]*g+A[162])*(g*g)+(A[163]*g+1);o(+h);j(1)|0;c=j(0)|0;f=e+c|0;f=f<<15;d=((c&31)<<3)+1024|0;e=v[d>>2];c=e;d=v[d+4>>2]+f|0;l(0,c|0);l(1,(c>>>0<c>>>0?d+1|0:d)|0);i=C(k*+n())}a=i}return a}function Ry(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{e=a;b:{c:{h=a+62|0;f=Cb(h,b);a=t[f|0];if((a|0)==-1){break c}if((a|0)>=0){break b}a=a&127;d=Yb(e+26|0,a);g=x[d>>1];if((g|0)!=65535&(b|0)!=(g|0)){break c}u[d>>1]=b;t[f|0]=a;break b}l=e+8|0;i=e+26|0;d=255;a=0;g=255;while(1){if((a|0)!=18){j=Yb(i,a);k=x[j>>1];if((k|0)==65535){u[j>>1]=b;t[f|0]=a;break b}else{if(!(w[Cb(l,a)|0]&32)){g=t[Cb(h,k)|0]>=0?g:a;d=a}a=a+1|0;continue}}break}if((d&255)!=255){a=(g&255)==255?d:g;d=Yb(i,a&255);m=Cb(h,x[d>>1]),n=255,t[m|0]=n;u[d>>1]=b;t[f|0]=a}a=Rk(e,b)}g=a&255;if((g|0)==255){break a}if(Oj(e)){break a}d=ld(e+318|0,g);a=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[d+8|0]=a;t[d+9|0]=a>>>8;t[d+10|0]=a>>>16;t[d+11|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;t[d+4|0]=a;t[d+5|0]=a>>>8;t[d+6|0]=a>>>16;t[d+7|0]=a>>>24;f=LN(g);h=f+3|0;a=0;while(1){if((a|0)==2){Mg(e,b,Ts(g)|192,w[Cb(c,10)|0])}else{d=a?h:f;Mg(e,b,(d|32)&65535,w[Cb(c,a)|0]);Mg(e,b,(d|64)&65535,w[Cb(c,a+2|0)|0]);Mg(e,b,(d|96)&65535,w[Cb(c,a+4|0)|0]);Mg(e,b,(d|128)&65535,w[Cb(c,a+6|0)|0]);Mg(e,b,(d|224)&65535,w[Cb(c,a+8|0)|0]);a=a+1|0;continue}break}}}function s_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=ab-240|0;ab=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mi(d);Bo(a+208|0,d,a+223|0);d=Bb(a+192|0);c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;a:{b:{c:{if((c|0)!=1){c=oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[22452]=0;g=Q(1100,a+232|0,a+224|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=ub(d);if((h|0)==(g+c|0)){v[22452]=0;R(60,d|0,g<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+188>>2]=g+c}v[22452]=0;g=T(1102,v[a+232>>2])|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(Om(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,79744)){break c}v[22452]=0;T(1104,a+232|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=qF(c,v[a+188>>2],e,b),v[j>>2]=k;tf(a+208|0,a+16|0,v[a+12>>2],e);v[22452]=0;b=Q(1101,a+232|0,a+224|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];pb(d);pb(a+208|0);ab=a+240|0;break a}}b=P()|0;O()|0;pb(d);pb(a+208|0);S(b|0);L()}return b|0}function q_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=ab-240|0;ab=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mi(d);Bo(a+208|0,d,a+223|0);d=Bb(a+192|0);c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;a:{b:{c:{if((c|0)!=1){c=oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[22452]=0;g=Q(1100,a+232|0,a+224|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=ub(d);if((h|0)==(g+c|0)){v[22452]=0;R(60,d|0,g<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+188>>2]=g+c}v[22452]=0;g=T(1102,v[a+232>>2])|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(Om(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,79744)){break c}v[22452]=0;T(1104,a+232|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=oF(c,v[a+188>>2],e,b),u[j>>1]=k;tf(a+208|0,a+16|0,v[a+12>>2],e);v[22452]=0;b=Q(1101,a+232|0,a+224|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];pb(d);pb(a+208|0);ab=a+240|0;break a}}b=P()|0;O()|0;pb(d);pb(a+208|0);S(b|0);L()}return b|0}function mF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=ab-240|0;ab=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mi(d);Bo(a+208|0,d,a+223|0);d=Bb(a+192|0);c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;a:{b:{c:{if((c|0)!=1){c=oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[22452]=0;g=Q(1100,a+232|0,a+224|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=ub(d);if((h|0)==(g+c|0)){v[22452]=0;R(60,d|0,g<<1);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=Ec(d);v[22452]=0;R(60,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}c=oc(d,0);v[a+188>>2]=g+c}v[22452]=0;g=T(1102,v[a+232>>2])|0;h=v[22452];v[22452]=0;if((h|0)==1){break d}if(Om(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,79744)){break c}v[22452]=0;T(1104,a+232|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!ub(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=lF(c,v[a+188>>2],e,b),v[j>>2]=k;tf(a+208|0,a+16|0,v[a+12>>2],e);v[22452]=0;b=Q(1101,a+232|0,a+224|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];pb(d);pb(a+208|0);ab=a+240|0;break a}}b=P()|0;O()|0;pb(d);pb(a+208|0);S(b|0);L()}return b|0}function QZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=ab-16|0;ab=k;l=fw(g);g=Nv(g);Eg(k,g);a:{b:{if(pd(k)){v[22452]=0;W(1123,l|0,a|0,c|0,d|0);g=v[22452];v[22452]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[22452]=0;j=Q(1129,l|0,h<<24>>24)|0;h=v[22452];v[22452]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[22452]=0;h=Q(1129,l|0,48)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[22452]=0;h=Q(1129,l|0,h|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}rl(j,c);i=0;v[22452]=0;o=T(1121,g|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){ir((j-a<<2)+d|0,v[f>>2]);g=v[f>>2];break a}e:{if(!w[oc(k,h)|0]){break e}if(t[oc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=o;h=(ub(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[22452]=0;n=Q(1129,l|0,n|0)|0;m=v[22452];v[22452]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;O()|0;pb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;pb(k);ab=k+16|0}function OG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=C(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=Yd(a,k),v[p>>2]=q;g=d+1076|0;p=g,q=Yd(a,k),v[p>>2]=q;i=Yd(a,c&-4);v[d+1084>>2]=i;a:{h=v[h>>2];if(!h){break a}g=v[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=C(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))/j);p=i+(e<<2)|0,r=C(Ge(f)),z[p>>2]=r;p=i+(g<<2)|0,r=C(-C(ki(f))),z[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+C(C(C(e<<2)*C(3.1415927410125732))/j);p=h+l|0,r=C(Ge(f)),z[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=C(-C(ki(f))),z[p>>2]=r;f=+C(C(C(C(m|0)*C(3.1415927410125732))/j)*C(.5));p=g+l|0,r=C(C(Ge(f))*C(.5)),z[p>>2]=r;p=g+n|0,r=C(C(ki(f))*C(.5)),z[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=Yd(a,k);v[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=C(ki((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=C(ki(+C(j*j)*1.5707963705062866)),z[p>>2]=r;b=b+1|0;continue}break}b=Yd(a,c>>2&-2);v[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-Bl(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=zl(a)>>>c<<2,u[p>>1]=q;a=a+1|0;continue}break}return 1}Vb(a,3);return 0}function Baa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=ab-48|0;ab=e;m=v[a+16>>2];f=Vd(e+16|0);v[f+8>>2]=a+112;h=v[a+128>>2];v[f+16>>2]=h;o=f,p=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;k=v[a+8>>2];l=v[a+12>>2];if(h){o=f,p=Wf(k,l,h),v[o>>2]=p;v[f+4>>2]=db}h=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=b;a:while(1){if(d){b=v[e+12>>2];g=v[e+8>>2];v[e+40>>2]=g;v[e+44>>2]=0;g=((((b&2147483647)<<1|g>>>31)&2147483646)<<1)+m|0;b=v[f+16>>2];while(1)if((b|0)<=0){b=v[f+8>>2];i=v[b+8>>2];Lb(b,i,v[b+12>>2]);b=v[f+8>>2];i=v[b+4>>2];if(i){n=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Bd(n,(u[(b<<1|2)+g>>1]+u[g+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Ad(v[f+8>>2],i);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;g=v[a+32>>2];j=v[a+28>>2]+j|0;b=Uf(b,v[f+12>>2]);v[c>>2]=B(j>>12,b)+v[c>>2];h=g+h|0;v[c+4>>2]=v[c+4>>2]+B(b,h>>12);Lb(e+8|0,k,l);c=c+8|0;continue a}else{i=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Bd(v[f+8>>2],(u[(i<<1|2)+g>>1]+u[g+((i&2147483646)<<1)>>1]|0)/8<<16>>16);Ad(v[f+8>>2],4);Lb(e+40|0,v[f>>2],v[f+4>>2]);b=b-1|0;continue}}break}v[a+40>>2]=h;v[a+36>>2]=j;v[a+20>>2]=j>>12;v[a+24>>2]=h>>12;b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;ab=e+48|0}function Kg(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=ab-16|0;ab=f;v[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=v[a+480180>>2];if(!_l(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=x[((B(a,-12)+e&255)<<1)+33408>>1]<<4>>>a|0;break a}if(!d){v[f+12>>2]=8363;d=8363}if(_i(a)){a=((e&255)>>>0)/12|0;b=oia(v[(B(a,-12)+e<<6&960)+37296>>2]<<a,0,d,0);a=db;c=a>>>21|0;h=f,i=Fc((a&2097151)<<11|b>>>21,c),v[h>>2]=i;mc(f,2147483647);e=v[f>>2];break a}if(w[a+480208|0]&16){a=e&255;e=x[((a>>>0)%12<<1)+33408>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;mc(f+12|0,-1>>>a|0);e=Fc(ria(oia(x[((B(a,-12)+e&255)<<1)+33408>>1],0,267616,0),db,v[f+12>>2]<<a,0),db);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{rb(f,a+1074312|0,76);b=sb(v[v[f>>2]>>2],v[f+4>>2])?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;e=(a|0)>1?a:1;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(B(c,-12)+a<<3&248)|0;v[f>>2]=d+8;ce(f,0,103);a=b>>31;b=(a+b^a)&15;a=d+(a|1)|0;a=(a|0)>-8?a:-8;e=B(b,x[(((a|0)<95?a:95)<<1)+33904>>1])+B(x[(v[f>>2]<<1)+33888>>1],16-b|0)<<1>>>c|0;break a}if(!((c&255)>>>0<16&b-25>>>0<=83)){a=((e&255)>>>0)/12|0;e=x[(B((c&240)>>>4|0,12)+(B(a,-12)+e&255)<<1)+33008>>1]<<5>>>a|0;break a}e=x[(b<<1)+32782>>1]<<2}ab=f+16|0;return e}function b9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=ab-16|0;ab=h;f=b+1298304|0;if(!td(f)){d=ab-16|0;ab=d;c=pc(12);v[22452]=0;e=T(885,c|0)|0;g=v[22452];v[22452]=0;a:{if((g|0)!=1){c=v[yf(d+8|0,e)>>2];ab=d+16|0;break a}a=P()|0;O()|0;xb(c);S(a|0);L()}v[h+8>>2]=c;c=h+8|0;wL(f,Pd(c));ys(c)}c=v[f>>2];f=ab-48|0;ab=f;d=f+16|0;lL(d,a);v[22452]=0;U(8,f+32|0,0,d|0);d=v[22452];v[22452]=0;b:{c:{if((d|0)!=1){pb(f+16|0);m=f,n=wb(v[c>>2]),v[m+8>>2]=n;l=wb(v[c+4>>2]);c=0;d=0;d:{while(1){e:{g=v[f+8>>2];if(!Tb(g,l)){if(!d){break e}c=v[d+4>>2];if(!c){break e}v[22452]=0;Y(c|0,d|0,b|0,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break e}break d}i=0;e=v[g>>2];if(v[e+32>>2]==(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))){i=v[e+36>>2]==(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))}v[22452]=0;R(886,f+16|0,e+8|0);e=v[22452];v[22452]=0;if((e|0)==1){break d}e=ab-16|0;ab=e;j=f+16|0;qe(e+8|0,j);qe(e,f+32|0);k=YL(v[e+8>>2],v[e+12>>2],v[e>>2],v[e+4>>2]);ab=e+16|0;pb(j);f:{if(!(!i|(k|0)!=0)){d=v[g>>2];c=3;break f}if((c|0)<2&i){d=v[g>>2];c=2;break f}e=!k&(c|0)<=0;d=e?v[g>>2]:d;c=e?1:c}te(f+8|0);continue}break}pb(f+32|0);ab=f+48|0;break b}d=P()|0;O()|0;pb(f+32|0);break c}d=P()|0;O()|0;pb(f+16|0)}S(d|0);L()}ab=h+16|0}function GR(a,b){var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;d=w[a|0];a:{if(d>>>0>21){break a}t[a|0]=w[d+26672|0];b:{switch(d-8|0){case 0:t[b|0]=w[b|0]<<1;break a;case 4:t[b|0]=w[b|0]+1>>>1;break a;case 5:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);break a;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=w[b|0];switch((d>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 4:break i;case 3:break j;case 1:break k;case 0:break l;case 14:break c;case 10:break d;default:break m}}t[a|0]=0;break a}t[a|0]=29;t[c+15|0]=w[b|0]&15;t[c+14|0]=14;e=b,f=w[Qb(c+15|0,c+14|0)|0]<<4|15,t[e|0]=f;break a}t[a|0]=29;t[c+13|0]=w[b|0]&15;t[c+12|0]=14;e=b,f=w[Qb(c+13|0,c+12|0)|0]|240,t[e|0]=f;break a}t[b|0]=d&15|48;break a}t[a|0]=35;t[b|0]=w[b|0]<<4^128;break a}t[b|0]=d&15|176;break a}t[b|0]=d&15|64;break a}t[a|0]=15;t[b|0]=w[b|0]&15;break a}t[a|0]=24;t[b|0]=(w[b|0]<<3&120)+8&240;break a}t[a|0]=24;t[b|0]=(w[b|0]&15)+1>>>1;break a}t[a|0]=10;break a;case 8:a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?-16:a<<2&240;break a}if(a>>>0<=239){t[b|0]=a<<2&48|15;break a}t[b|0]=a<<4|15;break a;case 9:break b;default:break a}}a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?15:a>>>2|0;break a}if(a>>>0>239){break a}t[b|0]=a>>>2&3|240}ab=c+16|0}function YQ(a,b){var c=0;a:{b:{c:{d:{if(ae(a,16671)){break d}if(ae(a,17440)){break d}if(ae(a,13553)){break d}if(ae(a,13670)){break d}if(!ae(a,14235)){break c}}u[b+10>>1]=4;v[b>>2]=12010;break b}e:{f:{if(ae(a,17435)){break f}if(ae(a,13563)){break f}if(!ae(a,16656)){break e}}t[b+12|0]=1;v[b>>2]=8378;u[b+10>>1]=4;return 1}g:{if(!ae(a,14281)){if(!ae(a,14286)){break g}}u[b+10>>1]=8;v[b>>2]=8156;break b}h:{if(!ae(a,15265)){if(!ae(a,15270)){break h}}v[b>>2]=17043;u[b+10>>1]=t[a+2|0]-48;break b}i:{if(!ae(a,26874)){if(!ae(a,26879)){break i}}v[b+4>>2]=1;v[b>>2]=16849;u[b+10>>1]=w[a|0]==56?8:4;return 1}if(!(Ib(a,15432,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=8496;a=t[a+3|0];u[b+8>>1]=1088;u[b+10>>1]=a-48;break b}j:{if(Ib(a,13598,3)){if(Ib(a,13732,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+15|0]=1;t[b+13|0]=1;v[b>>2]=8255;u[b+10>>1]=t[a+3|0]-48;return 1}k:{if((w[a|0]-49&255)>>>0>8){break k}if(!Ib(a+1|0,13756,3)){t[b+14|0]=1;v[b>>2]=8544;u[b+10>>1]=t[a|0]-48;return 1}if((w[a+1|0]-48&255)>>>0>9){break k}c=a+2|0;if(Ib(c,14084,2)){if(Ib(c,13760,2)){break k}}t[b+14|0]=1;v[b>>2]=8544;u[b+10>>1]=(t[a+1|0]+B(t[a|0],10)|0)-528;return 1}c=0;if(Ib(a,13419,3)|(w[a+3|0]-49&255)>>>0>8){break a}v[b>>2]=8405;u[b+10>>1]=t[a+3|0]-48}c=1}return c}function $Y(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=ab-496|0;ab=a;g=a+488|0;zc(g,d);v[22452]=0;m=T(1111,g|0)|0;g=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(ub(f)){g=v[Mj(f,0)>>2];v[22452]=0;h=Q(1129,m|0,45)|0;k=v[22452];v[22452]=0;if((k|0)==1){break g}n=(g|0)==(h|0)}k=Bb(a+456|0);g=Bb(a+440|0);h=Bb(a+424|0);v[22452]=0;ma(1150,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,g|0,h|0,a+420|0);c=v[22452];v[22452]=0;if((c|0)==1){break f}v[a+4>>2]=1098;c=ee(a+8|0,0,a+4|0);j=ub(f);l=v[a+420>>2];h:{if((j|0)>(l|0)){i=((ub(h)+(j-l<<1)|0)+ub(g)|0)+1|0;break h}i=(ub(h)+ub(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}Ce(c,yd(i<<2));j=v[c>>2];if(j){break e}v[22452]=0;X(1099);b=v[22452];v[22452]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}o=v[d+4>>2];i=Eb(f);f=ub(f);v[22452]=0;oa(1151,j|0,a+4|0,a|0,o|0,i|0,i+(f<<2)|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],k|0,g|0,h|0,l|0);f=v[22452];v[22452]=0;if((f|0)!=1){v[22452]=0;b=la(1132,b|0,j|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Bc(c)}Oc(h);Oc(g);pb(k)}Nb(a+488|0);S(f|0);L()}Bc(c);Oc(h);Oc(g);pb(k);Nb(a+488|0);ab=a+496|0;return b|0}function $U(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=ab-1088|0;ab=e;Nh(a);Jb(a+20|0,0,1040);v[a+1064>>2]=0;v[a+1068>>2]=0;v[a+1060>>2]=c;g=a+1072|0;v[g>>2]=0;v[g+4>>2]=0;v[a+1080>>2]=0;t[a+1084|0]=d;g=a+1064|0;d=c;a:{b:{c:while(1){if(qd(x[d+34>>1])>>>0<=h>>>0){break a}v[a+1064>>2]=0;v[a+1068>>2]=0;d=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(y[c>>2]<=d>>>0){break j}v[22452]=0;d=Q(147,b|0,2)|0;f=v[22452];v[22452]=0;if((f|0)==1){break i}if(!d){break j}v[22452]=0;d=T(185,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break h}if(!d){break e}v[22452]=0;U(181,e|0,b|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break g}d=e+24|0;f=Oq(d,e);Mc(a,f);gc(a+20|0,f+20|0,1040);qb(d);qb(e);v[a+1076>>2]=0;v[a+1080>>2]=0;d=v[a+1060>>2];if(xm(x[d+34>>1])>>>0>=2){d=v[d+20>>2];v[22452]=0;R(186,a|0,d+(h<<1)|0);d=v[22452];v[22452]=0;if((d|0)!=1){break e}break f}d=v[d+20>>2];v[22452]=0;R(187,a|0,d+h|0);d=v[22452];v[22452]=0;if((d|0)==1){break f}break e}h=h+1|0;d=v[a+1060>>2];continue c}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=V(30480)|0;if((O()|0)!=(fa(30480)|0)){break b}_(d|0)|0;v[22452]=0;X(17);d=v[22452];v[22452]=0;if((d|0)==1){break d}}d=v[g>>2];continue}break}break}d=P()|0;O()|0}qb(a);S(d|0);L()}ab=e+1088|0;return a|0}function _Z(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=ab-16|0;ab=k;l=Ku(g);g=Sv(g);Eg(k,g);a:{b:{if(pd(k)){v[22452]=0;W(1109,l|0,a|0,c|0,d|0);g=v[22452];v[22452]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[22452]=0;j=Q(19,l|0,h<<24>>24)|0;h=v[22452];v[22452]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[22452]=0;h=Q(19,l|0,48)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[22452]=0;h=Q(19,l|0,h|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}rl(j,c);i=0;v[22452]=0;o=T(1107,g|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){rl((j-a|0)+d|0,v[f>>2]);g=v[f>>2];break a}e:{if(!w[oc(k,h)|0]){break e}if(t[oc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(ub(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[22452]=0;n=Q(19,l|0,n|0)|0;m=v[22452];v[22452]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;O()|0;pb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;pb(k);ab=k+16|0}function GF(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{g:{c=v[a+4>>2];h:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break h}c=cd(a)}switch(c-43|0){case 0:case 2:break g;default:break f}}f=(c|0)==45;g=!b;c=v[a+4>>2];i:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break i}c=cd(a)}b=c-58|0;if(g|b>>>0>4294967285){break e}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){break d}break a}b=c-58|0}if(b>>>0<4294967286){break c}b=c-48|0;if(b>>>0<10){while(1){e=(B(e,10)+c|0)-48|0;d=(e|0)<214748364;c=v[a+4>>2];j:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break j}c=cd(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}k:{if(b>>>0>=10){break k}while(1){b=oia(e,d,10,0);c=b+c|0;d=db;d=b>>>0>c>>>0?d+1|0:d;b=c;e=b-48|0;d=d-(b>>>0<48)|0;b=v[a+4>>2];l:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break l}c=cd(a)}b=c-48|0;if(b>>>0>9){break k}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=v[a+4>>2];m:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;b=w[b|0];break m}b=cd(a)}if(b-48>>>0<10){continue}break}}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){v[a+4>>2]=v[a+4>>2]-1}db=f?0-(((e|0)!=0)+d|0)|0:d;return f?0-e|0:e}v[a+4>>2]=v[a+4>>2]-1;break b}if(v[a+116>>2]<0){break a}}v[a+4>>2]=v[a+4>>2]-1}db=-2147483648;return 0}function Gaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=ab-48|0;ab=f;m=v[a+16>>2];g=Vd(f+16|0);v[g+8>>2]=a+112;e=v[a+128>>2];v[g+16>>2]=e;q=g,r=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;j=v[a+8>>2];k=v[a+12>>2];if(e){q=g,r=Wf(j,k,e),v[q>>2]=r;v[g+4>>2]=db}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;while(1){if(d){v[f+40>>2]=e;v[f+44>>2]=0;l=(((b&2147483647)<<1|e>>>31)&-2)+m|0;e=v[g+16>>2];a:{b:while(1){c:{if((e|0)<=0){b=v[g+8>>2];e=v[b+8>>2];Lb(b,e,v[b+12>>2]);e=v[g+8>>2];i=v[e+4>>2];if(!i){break a}p=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;h=0;b=0;break c}i=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;b=0;h=0;while(1)if((b|0)==2){Bd(v[g+8>>2],(h|0)/8<<16>>16);Ad(v[g+8>>2],4);Lb(f+40|0,v[g>>2],v[g+4>>2]);e=e-1|0;continue b}else{h=(t[(b+i|0)+l|0]<<8)+h|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){h=(t[(b+p|0)+l|0]<<8)+h|0;b=b+1|0;continue}break}Bd(e,(h|0)/8<<16>>16);Ad(v[g+8>>2],i);e=v[g+8>>2];b=e;h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}d=d-1|0;h=v[c>>2];b=Uf(e,v[g+12>>2]);v[c>>2]=h+B(b,o);v[c+4>>2]=v[c+4>>2]+B(b,n);Lb(f+8|0,j,k);c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}v[a>>2]=e;v[a+4>>2]=b;ab=f+48|0}function Laa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=ab-16|0;ab=h;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];l=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=l;o=v[a+8>>2];p=v[a+12>>2];while(1){l=e;if(d){q=v[a+72>>2];r=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+64>>2];g=e;m=e>>31;e=Sb(l,-16777216,16776704);e=oia(g,m,e,e>>31);g=db;m=e;e=v[a+68>>2];f=Sb(f,-16777216,16776704);i=oia(e,e>>31,f,f>>31);e=m+i|0;f=db+g|0;f=e>>>0<i>>>0?f+1|0:f;m=e;e=v[a+60>>2];i=e;s=e>>31;e=(v[h+12>>2]<<1)+n|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+b|0;g=(((((B(u[e+4>>1],u[g+34>>1])+B(u[e+2>>1],u[g+32>>1])|0)+B(u[e+6>>1],u[g+36>>1])|0)+B(u[e+8>>1],u[g+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+26>>1])+B(u[e-6>>1],u[g+24>>1])|0)+B(u[e-2>>1],u[g+28>>1])|0)+B(u[e>>1],u[g+30>>1])|0)/2|0)|0)/16384<<8;e=g;i=oia(i,s,e,e>>31);e=m+i|0;f=db+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(k>>12,e)+v[c>>2];j=j+r|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Lb(h+8|0,o,p);e=f-(g&q)|0;c=c+8|0;d=d-1|0;f=l;continue}break}v[a+40>>2]=j;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=l;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+16|0}function dZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=ab-192|0;ab=a;g=a+184|0;zc(g,d);v[22452]=0;m=T(18,g|0)|0;g=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(ub(f)){g=w[oc(f,0)|0];v[22452]=0;h=Q(19,m|0,45)|0;k=v[22452];v[22452]=0;if((k|0)==1){break g}n=(g|0)==(h&255)}k=Bb(a+160|0);g=Bb(a+144|0);h=Bb(a+128|0);v[22452]=0;ma(1148,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,g|0,h|0,a+124|0);c=v[22452];v[22452]=0;if((c|0)==1){break f}v[a+4>>2]=1098;c=ee(a+8|0,0,a+4|0);j=ub(f);l=v[a+124>>2];h:{if((j|0)>(l|0)){i=((ub(h)+(j-l<<1)|0)+ub(g)|0)+1|0;break h}i=(ub(h)+ub(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}Ce(c,yd(i));j=v[c>>2];if(j){break e}v[22452]=0;X(1099);b=v[22452];v[22452]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}o=v[d+4>>2];i=Eb(f);f=ub(f);v[22452]=0;oa(1149,j|0,a+4|0,a|0,o|0,i|0,f+i|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],k|0,g|0,h|0,l|0);f=v[22452];v[22452]=0;if((f|0)!=1){v[22452]=0;b=la(14,b|0,j|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Bc(c)}pb(h);pb(g);pb(k)}Nb(a+184|0);S(f|0);L()}Bc(c);pb(h);pb(g);pb(k);Nb(a+184|0);ab=a+192|0;return b|0}function mca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=ab-48|0;ab=d;l=a+480190|0;c=x[l>>1];t[d+32|0]=0;qN(b,c+1|0,d+32|0);a:{j=a+480192|0;if(!x[j>>1]){break a}g=Pb(d+32|0);c=a+484344|0;p=d,q=vg(c),v[p+24>>2]=q;o=ug(c);m=a+480188|0;while(1){i=v[d+24>>2];if(!Tb(i,o)){c=x[a+480190>>1];while(1)if(c){rb(d+8|0,v[b>>2],c);if(!sb(v[v[d+8>>2]>>2],v[d+12>>2])){f=Fd((B(c,104)+a|0)+484380|0)+f|0}c=c-1|0;continue}else{Xb(g);break a}}b:{if(!Gh(i)){break b}c=x[m>>1];v[22452]=0;t[d+8|0]=0;U(722,g|0,c|0,d+8|0);c=v[22452];v[22452]=0;if((c|0)!=1){p=d,q=wb(v[i>>2]),v[p+16>>2]=q;k=0;c:while(1){f=0;if(y[i+12>>2]<=k>>>0){break b}while(1){if(x[m>>1]<=f>>>0){k=k+1|0;continue c}d:{c=v[d+16>>2];if(!Kc(w[c|0])){break d}e:{f:{c=w[c+1|0];if(c){h=x[j>>1];break f}h=x[j>>1];c=w[Cb(v[g>>2],f)|0];if(c){break f}c=1;break e}p=Cb(v[g>>2],f),q=c,t[p|0]=q;e=(h&65535)>>>0<c>>>0;h=e?h:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(h&65535)>>>0){break d}e=v[((e<<2)+a|0)+900380>>2];g:{if(!e){break g}e=x[Yb(e+236|0,w[v[d+16>>2]]-1|0)>>1];if(e>>>0>x[l>>1]){break g}n=d+8|0;rb(n,v[b>>2],e);mg(n,1)}c=c+1|0;continue}}f=f+1|0;ui(d+16|0);continue}}}a=P()|0;O()|0;Xb(g);S(a|0);L()}pL(d+24|0);continue}}ab=d+48|0;return f&65535}function WU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-32|0;ab=d;if(!Ib(a,13628,4)){ed(b,32);fo(b);Hh(d,1,a+4|0);c=d+16|0;tc(c,v[d>>2],v[d+4>>2],w[d+8|0]);ke(b+43|0,c);pb(c);u[b+30>>1]=w[a+19|0]<<2;lg(b+30|0,256);u[b+32>>1]=w[a+17|0];lg(b+32|0,64);c=a+47|0;u[b+28>>1]=(w[c|0]&127)<<2;lg(b+28|0,256);if(t[c|0]<0){u[b+34>>1]=x[b+34>>1]|32}e=a+18|0;c=w[e|0];if(c&16){u[b+34>>1]=x[b+34>>1]|2;c=w[e|0]}if(c&32){u[b+34>>1]=x[b+34>>1]|8;c=w[e|0]}if(c&64){u[b+34>>1]=x[b+34>>1]|4;c=w[e|0]}if(c<<24>>24<0){u[b+34>>1]=x[b+34>>1]|16}c=a+60|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c?c:8363;v[b+24>>2]=c>>>0>256?c:256;c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a- -64|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+68|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);ek(b);t[b+38|0]=w[(w[a+79|0]&7)+39856|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=w[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}u[b+34>>1]=c|x[b+34>>1]}a=a+72|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}ab=d+32|0;return c|0}function mia(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}f=d;if(!f){break i}e=E(f)-E(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;bb=a-B(b,c)|0;cb=0;db=0;return b}f=d;if(!a){break g}if(!f){break f}g=f-1|0;if(g&f){break f}bb=a;cb=e&g;a=e>>>nia(f)|0;db=0;return a}f=c-1|0;if(!(f&c)){break e}h=(E(c)+33|0)-E(e)|0;g=0-h|0;break c}h=e+1|0;g=63-e|0;break c}bb=0;a=(e>>>0)/(f>>>0)|0;cb=e-B(a,f)|0;db=0;return a}e=E(f)-E(e)|0;if(e>>>0<31){break d}break b}bb=a&f;cb=0;if((c|0)==1){break a}d=a;c=nia(c);a=c&31;if((c&63)>>>0>=32){e=0;a=b>>>a|0}else{e=b>>>a|0;a=((1<<a)-1&b)<<32-a|d>>>a}db=e;return a}h=e+1|0;g=63-e|0}i=a;e=h&63;f=e&31;if((e&63)>>>0>=32){e=0;k=b>>>f|0}else{e=b>>>f|0;k=((1<<f)-1&b)<<32-f|i>>>f}f=e;e=g&63;a=e&31;if((e&63)>>>0>=32){e=i<<a;a=0}else{e=(1<<a)-1&i>>>32-a|b<<a;a=i<<a}b=e;if(h){e=d-1|0;g=c-1|0;e=(g|0)!=-1?e+1|0:e;i=e;while(1){j=k;e=f<<1|j>>>31;f=j<<1;j=e;f=b>>>31|f;e=i-((f>>>0>g>>>0)+e|0)>>31;l=e;m=c&e;k=f-m|0;f=j-((d&e)+(f>>>0<m>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;j=0;l=l&1;n=l;h=h-1|0;if(h){continue}break}}bb=k;cb=f;e=b<<1|a>>>31;a=l|a<<1;db=e|j;return a}bb=a;cb=b;a=0;b=0}db=b;return a}function Maa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=ab-16|0;ab=h;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];l=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=l;o=v[a+8>>2];p=v[a+12>>2];while(1){l=e;if(d){q=v[a+72>>2];r=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+64>>2];g=e;m=e>>31;e=Sb(l,-16777216,16776704);e=oia(g,m,e,e>>31);g=db;m=e;e=v[a+68>>2];f=Sb(f,-16777216,16776704);i=oia(e,e>>31,f,f>>31);e=m+i|0;f=db+g|0;f=e>>>0<i>>>0?f+1|0:f;m=e;e=v[a+60>>2];i=e;s=e>>31;e=v[h+12>>2]+n|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+b|0;g=(((((B(t[e+2|0],u[g+34>>1])+B(t[e+1|0],u[g+32>>1])|0)+B(t[e+3|0],u[g+36>>1])|0)+B(t[e+4|0],u[g+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+26>>1])+B(t[e-3|0],u[g+24>>1])|0)+B(t[e-1|0],u[g+28>>1])|0)+B(t[e|0],u[g+30>>1])<<8)/2|0)|0)/16384<<8;e=g;i=oia(i,s,e,e>>31);e=m+i|0;f=db+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(k>>12,e)+v[c>>2];j=j+r|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Lb(h+8|0,o,p);e=f-(g&q)|0;c=c+8|0;d=d-1|0;f=l;continue}break}v[a+40>>2]=j;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=l;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+16|0}function EJ(a){var b=0,c=C(0),d=0,e=0,f=C(0),g=0,h=0,i=C(0),k=0,m=0,n=C(0);d=ab-16|0;ab=d;b=v[v[a+16>>2]+24620>>2];m=a,n=fe(C(10),C(C(C(z[a+4208>>2]*C(120))+C(-60))/C(20))),z[m+4232>>2]=n;i=C(C(b>>>0)/C(1e3));m=a,n=fe(C(10),C(C(-1)/C(i*C(C(z[a+4212>>2]*C(499.989990234375))+C(.009999999776482582))))),z[m+4236>>2]=n;m=a,n=fe(C(10),C(C(-1)/C(i*C(C(z[a+4216>>2]*C(2950))+C(50))))),z[m+4240>>2]=n;v[d+12>>2]=1325400064;c=C(fe(C(10),C(BJ(z[a+4220>>2])/C(20)))*C(2147483648));b=(p(c),j(2));f=C(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){e=b<<1;if(!e){b=ab-16|0;z[b+12>>2]=-1;f=C(z[b+12>>2]/C(0));break a}if((b|0)==2139095040){break b}if(!(e>>>0<4278190080&(b|0)>=0)){f=$I(c);break a}b=(p(C(c*C(8388608))),j(2))-192937984|0}e=b-1060306944|0;g=e>>>15&240;h=+(l(2,b-(e&-8388608)|0),q())*A[g+3568>>3]+-1;k=h*h;c=C((A[479]*k+(A[480]*h+A[481]))*k+(+(e>>23)*A[478]+A[g+3576>>3]+h))}f=c}z[d+8>>2]=C(C(f*C(67108864))/C(.6931471824645996))+C(67108864);m=a,n=C(z[El(d+12|0,d+8|0)>>2]*C(4.656612873077393e-10)),z[m+4244>>2]=n;z[a+4248>>2]=C(C(-1)/C(C(z[a+4224>>2]*C(99))+C(1)))+C(1);c=C(C(C(z[a+4228>>2]*C(4))*i)+C(2));c:{if(C(D(c))<C(2147483648)){g=~~c;break c}g=-2147483648}v[a+4252>>2]=g;ab=d+16|0}function fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=ab-16|0;ab=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=((((v[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+l|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];t=u[e+2>>1];w=u[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+m|0;v[(h<<2)+f>>2]=(((((((B(u[e-8>>1],t)+B(u[e-12>>1],w)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)+B(u[e+4>>1],q)|0)+B(u[e+8>>1],p)|0)+B(u[e+12>>1],o)|0)+B(u[e+16>>1],n)|0)/32768;h=h+1|0;continue}break}e=v[a+32>>2];k=v[a+28>>2]+k|0;v[c>>2]=v[c>>2]+B(v[f>>2],k>>12);j=e+j|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],j>>12);Lb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=j;v[a+36>>2]=k;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function gL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=ab-16|0;ab=e;c=a+484360|0;while(1){a:{d=Kb(c);f=wc(v[d>>2],v[d+4>>2]);d=b&65535;if(f>>>0<=d>>>0){break a}if(aq(Kb(c),d)){break a}b=b+1|0;continue}break}c=Kb(c);if(wc(v[c>>2],v[c+4>>2])>>>0>d>>>0){d=a+1074312|0;f=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(f|0)){fL(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){An(a+1298264|0,1);v[a+1074456>>2]=v[a+480200>>2];v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];v[a+480208>>2]=v[a+480208>>2]&-769;ty(a+1074376|0);u[a+1074450>>1]=0;v[a+1074392>>2]=-2;b=a+1074428|0;v[b>>2]=0;v[b+4>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074376>>2]=0;v[a+1074380>>2]=0}else{Dn((B(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}t[c+797|0]=0;v[c+700>>2]=0;t[c+841|0]=0;t[c+805|0]=0;v[c+708>>2]=0;t[c+821|0]=0;v[c+764>>2]=0;t[c+819|0]=0;t[c+820|0]=0;rb(e+8|0,d,23);if(sb(v[v[e+8>>2]>>2],v[e+12>>2])){t[c+807|0]=1;t[c+808|0]=0}t[c+839|0]=0;c=c+872|0;continue}break}u[a+1074450>>1]=b;u[a+1074446>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}ab=e+16|0}function uha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=ab-288|0;ab=e;Pe(b);a:{if(!Hb(a,1)){break a}while(1){d=e+32|0;Zm(e+8|0,d,d+256|0);d=ab-32|0;ab=d;k=v[a>>2];g=v[a+8>>2];Gg(d+16|0,v[e+8>>2],v[e+12>>2]);l=v[v[k>>2]+28>>2];h=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=h;eb[l|0](d+24|0,k,g,d+8|0);Gg(e+16|0,v[d+24>>2],v[d+28>>2]);ab=d+32|0;v[e+28>>2]=v[e+20>>2];p=e,q=c-ub(b)|0,v[p+4>>2]=q;d=v[zb(e+28|0,e+4|0)>>2];if(!d){break a}t[e+16|0]=0;k=e+32|0;m=k+d|0;d=e+16|0;l=fi(k,m,d);p=e,q=Ff(b),v[p+16>>2]=q;Yg(e,d);g=ab-32|0;ab=g;i=v[e>>2];v[g+24>>2]=i;p=g,q=kd(b),v[p+8>>2]=q;h=am(g+24|0,g+8|0);b:{c:{d=k;f=hi(d,l);if(!f){break c}if(!rs(b,d)){i=ub(b);j=Ec(b);d:{if(f>>>0<=j-i>>>0){j=Eb(b);n=i-h|0;if(!n){break d}o=h+j|0;_j(f+o|0,o,n);break d}Kl(b,j,(f+i|0)-j|0,i,h,0,f);j=v[b>>2]}f=f+i|0;cg(b,f);t[g+8|0]=0;md(f+j|0,g+8|0);f=h+j|0;while(1){if((d|0)==(l|0)){break c}md(f,d);d=d+1|0;f=f+1|0;continue}}d=pg(g+8|0,d,l);h=Eb(d);f=ub(d);v[22452]=0;da(353,b|0,i|0,h|0,f+h|0)|0;h=v[22452];v[22452]=0;if((h|0)!=1){pb(d);break b}a=P()|0;O()|0;pb(d);S(a|0);L()}p=g,q=kd(b),v[p+8>>2]=q;le(g+8|0,h)}ab=g+32|0;Ob(a,l-k|0);if(l>>>0>=m>>>0){continue}break}Ob(a,1)}ab=e+288|0}function MZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ab-384|0;ab=f;v[f+376>>2]=37;v[f+380>>2]=0;h=gr(f+376|1,21598,v[c+4>>2]);v[f+332>>2]=f+336;a=gd();a:{if(h){g=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=g;g=sf(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;g=sf(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=1098;i=ee(f+320|0,0,f+80|0);j=f+336|0;a=j;b:{c:{d:{if((g|0)>=30){a=gd();e:{if(h){g=v[c+8>>2];A[f+8>>3]=e;v[f>>2]=g;g=Ji(f+332|0,a,f+376|0,f);break e}A[f+16>>3]=e;g=Ji(f+332|0,a,f+376|0,f+16|0)}if((g|0)==-1){v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)==1){break c}break d}a=v[f+332>>2];Ce(i,a)}k=a+g|0;l=Dg(a,k,c);v[f+68>>2]=1098;h=ee(f+72|0,0,f+68|0);f:{g:{if((f+336|0)==(a|0)){g=f+80|0;break g}g=yd(g<<3);if(!g){v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ce(h,g);j=a}a=f+56|0;zc(a,c);v[22452]=0;ja(1131,j|0,l|0,k|0,g|0,f+68|0,f- -64|0,a|0);a=v[22452];v[22452]=0;h:{if((a|0)!=1){Nb(f+56|0);v[22452]=0;a=la(1132,b|0,g|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break h}Bc(h);Bc(i);ab=f+384|0;return a|0}c=P()|0;O()|0;Nb(f+56|0);break f}c=P()|0;O()|0}Bc(h);break b}L()}c=P()|0;O()|0}Bc(i);S(c|0);L()}function WZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ab-208|0;ab=f;v[f+200>>2]=37;v[f+204>>2]=0;h=gr(f+200|1,21598,v[c+4>>2]);v[f+156>>2]=f+160;a=gd();a:{if(h){g=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=g;g=sf(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;g=sf(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=1098;i=ee(f+144|0,0,f+80|0);j=f+160|0;a=j;b:{c:{d:{if((g|0)>=30){a=gd();e:{if(h){g=v[c+8>>2];A[f+8>>3]=e;v[f>>2]=g;g=Ji(f+156|0,a,f+200|0,f);break e}A[f+16>>3]=e;g=Ji(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)==1){break c}break d}a=v[f+156>>2];Ce(i,a)}k=a+g|0;l=Dg(a,k,c);v[f+68>>2]=1098;h=ee(f+72|0,0,f+68|0);f:{g:{if((f+160|0)==(a|0)){g=f+80|0;break g}g=yd(g<<1);if(!g){v[22452]=0;X(1099);a=v[22452];v[22452]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ce(h,g);j=a}a=f+56|0;zc(a,c);v[22452]=0;ja(1126,j|0,l|0,k|0,g|0,f+68|0,f- -64|0,a|0);a=v[22452];v[22452]=0;h:{if((a|0)!=1){Nb(f+56|0);v[22452]=0;a=la(14,b|0,g|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break h}Bc(h);Bc(i);ab=f+208|0;return a|0}c=P()|0;O()|0;Nb(f+56|0);break f}c=P()|0;O()|0}Bc(h);break b}L()}c=P()|0;O()|0}Bc(i);S(c|0);L()}function T_(){var a=0,b=0,c=0;b=ab-16|0;ab=b;bs(463008);v[115764]=-1;v[115762]=463064;v[115760]=89496;v[115752]=74436;t[463060]=0;a=b+8|0;rr(a,463008);c=v[v[115752]+8>>2];v[22452]=0;R(c|0,463008,a|0);a=v[22452];v[22452]=0;a:{if((a|0)!=1){Nb(b+8|0);ab=b+16|0;break a}a=P()|0;O()|0;Nb(b+8|0);Fl(463008);S(a|0);L()}is(462336);v[115584]=74568;v[115582]=74548;v[115583]=0;jn(462336,463008);b=ab-16|0;ab=b;oG(463072);v[115780]=-1;v[115778]=463128;v[115776]=89496;v[115768]=74660;t[463124]=0;a=b+8|0;rr(a,463072);c=v[v[115768]+8>>2];v[22452]=0;R(c|0,463072,a|0);a=v[22452];v[22452]=0;b:{if((a|0)!=1){Nb(b+8|0);ab=b+16|0;break b}a=P()|0;O()|0;Nb(b+8|0);Fo(463072);S(a|0);L()}RF(462424);v[115606]=74792;v[115604]=74772;v[115605]=0;jn(462424,463072);VF(463136,89640,463184);Zv(462504,463136);UF(463192,89640,463240);Yv(462588,463192);VF(463248,89336,463296);Zv(462672,463248);Zv(462840,v[(v[v[115668]-12>>2]+462672|0)+24>>2]);UF(463304,89336,463352);Yv(462756,463304);Yv(462924,v[(v[v[115689]-12>>2]+462756|0)+24>>2]);TF(v[v[115582]-12>>2]+462328|0);SF(v[v[115604]-12>>2]+462416|0);MI(v[v[115668]-12>>2]+462672|0);MI(v[v[115689]-12>>2]+462756|0);TF(v[v[115668]-12>>2]+462672|0);SF(v[v[115689]-12>>2]+462756|0)}function jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=ab-16|0;ab=f;ed(b,0);fo(b);e=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=e;break a}g=b,h=xe(Ej(+(e+1408|0)/1536)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?e:e^128;t[b+36|0]=w[a+4|0]}t[f+15|0]=w[a+5|0];t[f+14|0]=64;g=b,h=w[Qb(f+15|0,f+14|0)|0]<<2,u[g+30>>1]=h;d=a+6|0;d=w[d|0]|w[d+1|0]<<8;if(d>>>0<=256){u[b+28>>1]=d;u[b+34>>1]=x[b+34>>1]|32}d=a+8|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+12|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+16|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);e=a+20|0;d=w[e|0]|w[e+1|0]<<8;if(d&16){u[b+34>>1]=x[b+34>>1]|2;d=w[e|0]|w[e+1|0]<<8}if(d&32){u[b+34>>1]=x[b+34>>1]|4;d=w[e|0]|w[e+1|0]<<8}if(d&256){u[b+34>>1]=x[b+34>>1]|8;d=w[e|0]|w[e+1|0]<<8}if(d&512){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+39856|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[f+13|0]=w[a+26|0];t[f+12|0]=64;g=b,h=w[Qb(f+13|0,f+12|0)|0],u[g+32>>1]=h}c=a+27|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=a+31|0;v[b+16>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);ab=f+16|0}function f2(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ab-80|0;ab=e;a:{b:{c:{d:{e:{if(Vi(a)){of(e+72|0);break e}c=e+32|0;fn(c,a);v[22452]=0;c=T(983,c|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break d}v[e+72>>2]=c;Hf(e+32|0)}if(Vi(a)){c=a+36|0}else{c=v[e+72>>2]}f=v[a+8>>2];if((f|0)==-1){d=v[c+4>>2];f=d-24|0;g=v[c>>2];h=en(g,d);j=A[f>>3];d=0;while(1){if((d|0)==(h|0)){c=f;break c}c=_k(g,d);if(i+A[c>>3]>b){break c}d=d+1|0;i=i+j;continue}}c=_k(v[c>>2],f);break b}d=P()|0;O()|0;Hf(e+32|0);break a}b=b-i}f=a+24|0;d=v[f>>2];g=x[c+12>>1];v[22452]=0;R(1016,d|0,g|0);d=v[22452];v[22452]=0;if((d|0)!=1){f:{d=v[f>>2];g=w[a+64|0];c=_K(PQ(e+32|0,b),w[c+16|0],x[c+12>>1],v[c+8>>2]);v[22452]=0;h=v[c+12>>2];v[e+16>>2]=v[c+8>>2];v[e+20>>2]=h;h=v[c+20>>2];v[e+24>>2]=v[c+16>>2];v[e+28>>2]=h;h=v[c+4>>2];v[e+8>>2]=v[c>>2];v[e+12>>2]=h;W(1017,e+56|0,d|0,(g?7:1)|0,e+8|0);c=v[22452];v[22452]=0;if((c|0)==1){break f}c=$K(v[e+60>>2]);d=t[c+26|0]&1;g=v[(d?c+8|0:c+12|0)>>2];d=x[(d?c+20|0:c+22|0)>>1];b=A[c>>3];ni(e+56|0);u[v[f>>2]+1074448>>1]=d;u[v[f>>2]+1074450>>1]=d;v[v[f>>2]+1074428>>2]=g;v[v[f>>2]+1074392>>2]=-2;b=i+b;A[a+16>>3]=b;Ek(e+72|0);ab=e+80|0;return+b}}d=P()|0;O()|0;Ek(e+72|0)}S(d|0);L()}function PX(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=ab-16|0;ab=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{while(1){j=v[a+12>>2];if(!(j>>>0>=d>>>0|f>>>0>=g>>>0)){i=t[j|0];c=i&255;c:{if((i|0)>=0){i=1;break c}b=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-j|0)<2){break b}i=w[j+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-j|0)<3){break b}k=w[j+2|0];i=w[j+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-j|0)<4){break b}l=w[j+3|0];m=w[j+2|0];k=w[j+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}v[f>>2]=c;v[a+12>>2]=i+j;f=v[a+8>>2]+4|0;v[a+8>>2]=f;continue}break}b=d>>>0>j>>>0;break a}b=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];ab=a+16|0;return b|0}function gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;f=ab-16|0;ab=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=(((v[f+12>>2]&2147483647)<<1|h>>>31)&-2)+l|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];h=0;while(1){if((h|0)!=2){e=h+m|0;v[(h<<2)+f>>2]=(((((((B(t[e-4|0],w)+B(t[e-6|0],x)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)|0)+B(t[e+2|0],q)|0)+B(t[e+4|0],p)|0)+B(t[e+6|0],o)|0)+B(t[e+8|0],n)<<8)/32768;h=h+1|0;continue}break}e=v[a+32>>2];k=v[a+28>>2]+k|0;v[c>>2]=v[c>>2]+B(v[f>>2],k>>12);j=e+j|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],j>>12);Lb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=j;v[a+36>>2]=k;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function iP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=v[a>>2];e=eh(c,v[a+4>>2]);if(e>>>0<b>>>0){g=ab-32|0;ab=g;f=b-e|0;b=v[vb(a)>>2];c=v[a+4>>2];a:{if(f>>>0<=b-c>>8>>>0){b=ab-16|0;ab=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(f<<8);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);ab=b+16|0}else{lz(a);a=a+256|0;v[b+4>>2]=a;continue}break}break a}i=vb(a);b=g+8|0;e=a;h=eh(v[a>>2],c)+f|0;c=ab-16|0;ab=c;v[c+12>>2]=h;d=ab-16|0;ab=d;v[d+12>>2]=16777215;v[d+8>>2]=2147483647;a=v[zb(d+12|0,d+8|0)>>2];ab=d+16|0;b:{if(a>>>0>=h>>>0){d=mz(e);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Pc(c+8|0,c+12|0)>>2]}ab=c+16|0;break b}hd();L()}d=eh(v[e>>2],v[e+4>>2]);Ve(b+12|0,i);if(a){if(a>>>0>=16777216){Oe(11129);L()}c=pc(a<<8)}else{c=0}v[b>>2]=c;d=c+(d<<8)|0;v[b+8>>2]=d;v[b+4>>2]=d;j=ic(b),k=c+(a<<8)|0,v[j>>2]=k;a=ab-16|0;ab=a;v[a>>2]=v[b+8>>2];c=v[b+8>>2];v[a+8>>2]=b+8;v[a+4>>2]=c+(f<<8);c=v[a>>2];while(1){if(v[a+4>>2]!=(c|0)){lz(c);c=v[a>>2]+256|0;v[a>>2]=c;continue}break}xd(a);ab=a+16|0;rd(e,b);e=v[b+4>>2];a=v[b+8>>2];while(1){if((a|0)!=(e|0)){a=a-256|0;v[b+8>>2]=a;continue}break}a=v[b>>2];if(a){ic(b);xb(a)}}ab=g+32|0;return}if(b>>>0<e>>>0){Hd(a,c+(b<<8)|0)}}function T9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=ab-16|0;ab=j;k=ab-32|0;ab=k;g=k+28|0;f=k+24|0;e=ab-32|0;ab=e;v[e+24>>2]=b;a:{b:{if(!jc(b,v[$b(e+16|0,Jf(a))>>2])){h=x[c>>1];i=v[c+4>>2];if(!Os(h,i,id(e+24|0))){break b}}v[e+16>>2]=b;f=$b(e+8|0,Ip(a));c:{if(!jc(v[e+16>>2],v[f>>2])){i=id(My(e+16|0));f=x[c>>1];h=v[c+4>>2];if(!Ns(i,f,h)){break c}}if(!v[b>>2]){v[g>>2]=b;break a}b=v[e+16>>2];v[g>>2]=b;b=b+4|0;break a}b=Ly(a,g,f,h);break a}if(Ns(id(e+24|0),h,i)){f=Ky(b);v[e+16>>2]=f;d:{if(!jc(f,v[$b(e+8|0,Jf(a))>>2])){h=x[c>>1];i=v[c+4>>2];if(!Os(h,i,id(e+16|0))){break d}}if(!v[v[e+24>>2]+4>>2]){v[g>>2]=b;b=b+4|0;break a}v[g>>2]=f;b=f;break a}b=Ly(a,g,h,i);break a}v[g>>2]=b;v[f>>2]=b;b=f}ab=e+32|0;e=v[b>>2];if(!e){e=ab-16|0;ab=e;g=ac(a);f=k+8|0;h=hh(f,pc(36),ih(e+8|0,g));g=v[h>>2]+16|0;i=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=i;Sj(g+8|0,d);m=ac(h),n=1,t[m+4|0]=n;ab=e+16|0;Pg(a,v[k+28>>2],b,v[f>>2]);e=Pd(f);jN(f);l=1}Og(j,$b(k+8|0,e),l);ab=k+32|0;if(!w[ac(j)|0]){a=id(j)+8|0;iN(a);v[a>>2]=v[d>>2];v[a+4>>2]=v[d+4>>2];b=vb(d);m=vb(a),n=v[b>>2],v[m>>2]=n;v[b>>2]=0;v[d>>2]=0;v[d+4>>2]=0}a=v[$b(j+8|0,v[j>>2])>>2];ab=j+16|0;return a|0}function E5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=C(0),r=0,s=C(0),t=0;i=ab-16|0;ab=i;a:{m=a+44|0;if(!Ih(m)){break a}j=Gd(m,0);k=Gd(m,1);f=dd(m,0);g=dd(m,1);s=z[a+4212>>2];v[i+12>>2]=d;n=d;while(1){if(!n){ai(a,b,c,dd(m,0),dd(m,1),d);break a}h=v[a+4224>>2];r=v[a+4220>>2];b:{if(h>>>0<r>>>0){v[i+8>>2]=r-h;l=v[zb(i+12|0,i+8|0)>>2];e=0;c:{if(s<C(1)){e=h+l|0;o=e>>>0<h>>>0?h:e;p=C(C(1)/C(r>>>0));while(1){if((h|0)==(o|0)){break c}q=C(h>>>0);z[f>>2]=p*C(z[j>>2]*q);z[g>>2]=p*C(z[k>>2]*q);h=h+1|0;g=g+4|0;k=k+4|0;f=f+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){z[f>>2]=z[j>>2];z[g>>2]=z[k>>2];e=e+1|0;g=g+4|0;k=k+4|0;f=f+4|0;j=j+4|0;continue}break}e=h+l|0}n=n-l|0;v[i+12>>2]=n;break b}t=v[a+4216>>2];e=t-h|0;v[i+4>>2]=e;l=v[zb(i+12|0,i+4|0)>>2];o=0;d:{if(s<C(1)){o=e-l|0;p=C(C(1)/C(r>>>0));while(1){if(e>>>0<=o>>>0){break d}q=C(e>>>0);z[f>>2]=p*C(z[j>>2]*q);z[g>>2]=p*C(z[k>>2]*q);e=e-1|0;g=g+4|0;k=k+4|0;f=f+4|0;j=j+4|0;continue}}while(1){if((l|0)!=(o|0)){v[f>>2]=0;v[g>>2]=0;o=o+1|0;g=g+4|0;f=f+4|0;continue}break}e=l<<2;k=e+k|0;j=e+j|0}n=n-l|0;v[i+12>>2]=n;e=h+l|0;e=e>>>0<t>>>0?e:0}v[a+4224>>2]=e;continue}}ab=i+16|0}function k9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=ab-32|0;ab=f;v[f+16>>2]=c;v[f+24>>2]=b;o=Af(a);while(1){if(Qg(f+24|0,f+16|0)){$b(f+8|0,o);b=v[f+8>>2];m=f+24|0;h=id(m);l=ab-16|0;ab=l;n=0;k=ab-16|0;ab=k;i=ab-32|0;ab=i;e=i+28|0;c=i+24|0;d=ab-32|0;ab=d;v[d+24>>2]=b;a:{b:{if(!jc(b,v[$b(d+16|0,Jf(a))>>2])){g=w[h|0];j=v[h+4>>2];if(!jy(g,j,id(d+24|0))){break b}}v[d+16>>2]=b;c=$b(d+8|0,Ip(a));c:{if(!jc(v[d+16>>2],v[c>>2])){j=id(My(d+16|0));c=w[h|0];g=v[h+4>>2];if(!iy(j,c,g)){break c}}if(!v[b>>2]){v[e>>2]=b;break a}b=v[d+16>>2];v[e>>2]=b;b=b+4|0;break a}b=ky(a,e,c,g);break a}if(iy(id(d+24|0),g,j)){c=Ky(b);v[d+16>>2]=c;d:{if(!jc(c,v[$b(d+8|0,Jf(a))>>2])){g=w[h|0];j=v[h+4>>2];if(!jy(g,j,id(d+16|0))){break d}}if(!v[v[d+24>>2]+4>>2]){v[e>>2]=b;b=b+4|0;break a}v[e>>2]=c;b=c;break a}b=ky(a,e,g,j);break a}v[e>>2]=b;v[c>>2]=b;b=c}ab=d+32|0;d=v[b>>2];if(!d){d=ab-16|0;ab=d;e=ac(a);c=i+8|0;e=hh(c,pc(28),ih(d+8|0,e));vz(v[e>>2]+16|0,h);p=ac(e),q=1,t[p+4|0]=q;ab=d+16|0;Pg(a,v[i+28>>2],b,v[c>>2]);d=Pd(c);$k(c);n=1}Og(k+8|0,$b(i+8|0,d),n);ab=i+32|0;ab=k+16|0;$b(l+8|0,v[k+8>>2]);ab=l+16|0;Uj(m);continue}else{ab=f+32|0}break}}function wF(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=ab-16|0;ab=l;f=w[a|0];a:{if(!f){g=a;break a}g=a;b:{while(1){if(!uk(f<<24>>24)){break b}f=w[g+1|0];g=g+1|0;if(f){continue}break}break a}c:{f=f&255;switch(f-43|0){case 0:case 2:break c;default:break a}}m=(f|0)==45?-1:0;g=g+1|0}d:{if(!(c&-17|w[g|0]!=48)){o=1;if((w[g+1|0]&223)==88){g=g+2|0;j=16;break d}g=g+1|0;j=c?c:8;break d}j=c?c:10}p=j>>31;c=0;while(1){e:{f=-48;i=t[g|0];f:{if((i-48&255)>>>0<10){break f}f=-87;if((i-97&255)>>>0<26){break f}f=-55;if((i-65&255)>>>0>25){break e}}i=f+i|0;if((i|0)>=(j|0)){break e}hf(l,j,p,0,0,k,h,0,0);f=1;g:{if(v[l+8>>2]|v[l+12>>2]){break g}q=oia(k,h,j,p);n=db;r=i>>31;s=r^-1;if((n|0)==(s|0)&(i^-1)>>>0<q>>>0|n>>>0>s>>>0){break g}h=n+r|0;f=i+q|0;h=f>>>0<i>>>0?h+1|0:h;k=f;o=1;f=c}g=g+1|0;c=f;continue}break}if(b){v[b>>2]=o?g:a}h:{i:{j:{if(c){v[114934]=68;a=d&1;m=a?0:m;k=d;h=e;break j}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|m)){v[114934]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break i}v[114934]=68;break h}a=m;b=a^k;d=b-a|0;c=a>>31;e=(c^h)-((a>>>0>b>>>0)+c|0)|0}ab=l+16|0;db=e;return d}function cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,z=0,A=0;i=ab-16|0;ab=i;ed(d,32);e=i+8|0;cP(e,a+20|0,v[b>>2]);h=ac(e);cP(i,a+36|0,v[c>>2]);a=0;h=v[h>>2];if(h-838861>>>0>=4294128436){a=v[ac(i)>>2];v[d>>2]=B(h,320);u[d+34>>1]=1;a:{l=sg(d);if(!l){break a}k=h<<2;f=+(k>>>0);p=+(a>>>0)/f;q=+(h>>>0)/f;r=1/+y[d>>2];s=+y[i>>2];t=+y[e>>2];h=0;b:while(1){if((h|0)==(k|0)){break a}m=+(h>>>0);n=0;o=0;if(Fd(b)){f=m*q+t;c:{if(f<4294967296&f>=0){g=~~f>>>0;break c}g=0}a=g;f=f-+(a>>>0);e=x[b+34>>1];a=qd(e);g=B(g,a);d:{if(e&1){j=v[b+20>>2];e=x[j+(g<<1)>>1];a=u[j+(a+g<<1)>>1];break d}e=v[b+20>>2];a=w[e+(a+g|0)|0]<<8;e=w[e+g|0]<<8}o=+(e<<16>>16)*(1-f)+f*+(a<<16>>16)}if(Fd(c)){f=m*p+s;e:{if(f<4294967296&f>=0){g=~~f>>>0;break e}g=0}a=g;f=f-+(a>>>0);e=x[c+34>>1];a=qd(e);g=B(g,a);f:{if(e&1){j=v[c+20>>2];e=x[j+(g<<1)>>1];a=u[j+(a+g<<1)>>1];break f}e=v[c+20>>2];a=w[e+(a+g|0)|0]<<8;e=w[e+g|0]<<8}n=+(e<<16>>16)*(1-f)+f*+(a<<16>>16)}e=0;a=h;while(1)if((e|0)==80){h=h+1|0;continue b}else{f=r*+(a>>>0);z=v[d+20>>2]+(a<<1)|0,A=sz(o*(1-f)+n*f),u[z>>1]=A;a=a+k|0;e=e+1|0;continue}}}a=(l|0)!=0}ab=i+16|0;return a|0}
function vd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab+-64|0;ab=d;v[a+480180>>2]=b;b=Rp(a);uz(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;ts(a+8|0,b);b=1;while(1){c=b&65535;if(c>>>0>x[a+480192>>1]){v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;Yx(a,4);e=ab+-64|0;ab=e;b=a+484344|0;ws(b);f=ck(v[b>>2],v[b+4>>2]);c=zx(e+8|0,b);v[22452]=0;U(790,b|0,f|0,c|0);b=v[22452];v[22452]=0;a:{if((b|0)!=1){Lk(c);ab=e- -64|0;break a}a=P()|0;O()|0;Lk(c);S(a|0);L()}_N(a+484360|0);Pe(a+1298308|0);Pe(a+1298320|0);Pe(a+1298332|0);c=a+1298344|0;d=Jb(d,0,64);b=BL(d);tb(c,b);tb(c+12|0,b+12|0);tb(c+24|0,b+24|0);tb(c+36|0,b+36|0);tb(c+48|0,b+48|0);v[c+60>>2]=v[b+60>>2];zs(b);uc(a+1298408|0);uc(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}ab=d- -64|0;return}e=((c<<2)+a|0)+900380|0;c=v[e>>2];if(c){zt(c)}xb(c);v[e>>2]=0;b=b+1|0;continue}}function Yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=ab-32|0;ab=e;u[e+28>>1]=c;u[e+30>>1]=b;u[e+26>>1]=d;i=x[v[v[a+24>>2]+8>>2]+12>>1];a:{if(i>>>0<=b>>>0){break a}if(!c|ej(a)>>>0>=i>>>0){break a}lg(e+28|0,i-b&65535);p=e,q=el(a),u[p+8>>1]=q;f=x[e+28>>1];qR(a,f+x[Ne(e+30|0,e+8|0)>>1]|0);c=v[a>>2];if(wc(c,v[a+4>>2])>>>0<b>>>0){mf(a,b);c=v[a>>2]}p=e,q=wb(c),v[p+8>>2]=q;c=ab-16|0;ab=c;v[c+8>>2]=v[e+8>>2];b=v[cO(c+8|0,b)>>2];ab=c+16|0;b=v[$b(e+16|0,b)>>2];g=e+26|0;l=ab-32|0;ab=l;c=a;a=v[c>>2];d=(fm(b,wb(a))<<1)+a|0;a=f;b:{if(!a){break b}b=v[vb(c)>>2];f=v[c+4>>2];if(a>>>0<=b-f>>1>>>0){b=a;j=f-d|0;h=j>>1;if(h>>>0<a>>>0){ao(c,a-h|0,g);b=h;if(!j){break b}}m=ab-16|0;ab=m;j=f;o=v[c+4>>2];h=(o-((a<<1)+d|0)|0)+d|0;n=Ai(m,c,f-h>>1);k=v[n+4>>2];f=h;while(1){if(f>>>0>=j>>>0){dc(n);Wp(d,h,o);ab=m+16|0}else{wi(k,x[f>>1]);k=k+2|0;v[n+4>>2]=k;f=f+2|0;continue}break}if(d>>>0<=g>>>0){g=((y[c+4>>2]>g>>>0?a:0)<<1)+g|0}wt(d,b,g);break b}b=vb(c);b=qj(l+8|0,rj(c,wc(v[c>>2],f)+a|0),d-v[c>>2]>>1,b);rC(b,a,g);d=$N(c,b,d);Bi(b)}wb(d);ab=l+32|0;if(wc(v[c>>2],v[c+4>>2])>>>0<=i>>>0){break a}mf(c,i)}ab=e+32|0}function ST(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;f=ab-144|0;ab=f;v[22452]=0;n=T(265,a|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){e=f+8|0;o=e|4;p=e|6;q=e|5;j=e|2;k=e|3;r=c+480192|0;while(1){a:{if((l&65535)>>>0>=n>>>0){qb(a);ab=f+144|0;return}v[22452]=0;R(284,a|0,f+8|0);e=v[22452];v[22452]=0;if((e|0)!=1){b:{e=f+8|0;e=Ab(w[e|0]|w[e+1|0]<<8);if(!e|e>>>0>x[r>>1]){break b}e=v[((e<<2)+c|0)+900380>>2];if(!e){break b}g=zi(e,b);c:{if(!w[k|0]){break c}e=w[j|0];if(e&1){t[g+12|0]=w[g+12|0]|1;e=w[j|0]}if(e&2){t[g+12|0]=w[g+12|0]|4;e=w[j|0]}if(!(e&4)){break c}t[g+12|0]=w[g+12|0]|2}t[f+4|0]=w[k|0];t[f+7|0]=31;e=w[Qb(f+4|0,f+7|0)|0];v[22452]=0;m=e+1&255;R(285,g|0,m|0);e=v[22452];v[22452]=0;if((e|0)==1){break a}t[g+13|0]=w[q|0];t[g+14|0]=w[p|0];e=w[o|0];t[g+15|0]=e;t[g+16|0]=e;e=0;while(1){if((e|0)==(m|0)){break b}h=(f+8|0)+(e<<2)|0;i=h+8|0;i=Ab(w[i|0]|w[i+1|0]<<8);s=Fb(v[g>>2],e),y=i,u[s>>1]=y;h=h+10|0;h=Ab(w[h|0]|w[h+1|0]<<8);u[f+4>>1]=d?h+128>>>2|0:h;lg(f+4|0,64);s=Fb(v[g>>2],e),y=w[f+4|0],t[s+2|0]=y;e=e+1|0;continue}}l=l+1|0;continue}}break}}b=P()|0;O()|0;qb(a);S(b|0);L()}function Faa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=ab-48|0;ab=f;l=v[a+16>>2];g=Vd(f+16|0);v[g+8>>2]=a+112;e=v[a+128>>2];v[g+16>>2]=e;o=g,p=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;j=v[a+8>>2];k=v[a+12>>2];if(e){o=g,p=Wf(j,k,e),v[o>>2]=p;v[g+4>>2]=db}m=v[a+24>>2];n=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;a:while(1){if(d){v[f+40>>2]=e;v[f+44>>2]=0;e=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+l|0;b=v[g+16>>2];while(1)if((b|0)<=0){b=v[g+8>>2];h=v[b+8>>2];Lb(b,h,v[b+12>>2]);b=v[g+8>>2];h=v[b+4>>2];if(h){i=b;b=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Bd(i,(u[(b<<1|2)+e>>1]+u[e+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Ad(v[g+8>>2],h);b=v[g+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}d=d-1|0;i=v[c>>2];b=Uf(b,v[g+12>>2]);v[c>>2]=i+B(b,n);v[c+4>>2]=v[c+4>>2]+B(b,m);Lb(f+8|0,j,k);c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue a}else{h=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Bd(v[g+8>>2],(u[(h<<1|2)+e>>1]+u[e+((h&2147483646)<<1)>>1]|0)/8<<16>>16);Ad(v[g+8>>2],4);Lb(f+40|0,v[g>>2],v[g+4>>2]);b=b-1|0;continue}}break}v[a>>2]=e;v[a+4>>2]=b;ab=f+48|0}function e7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=ab-16|0;ab=h;if(!w[a+4242|0]){kx(a);a:{if(!w[a+4240|0]){break a}e=hL(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;js(a)}f=a+4256|0;b:{if(w[a+4244|0]){if(A[f>>3]>1){v[f>>2]=0;v[f+4>>2]=1072693248}break b}i=(v[a+4232>>2]&-2)!=4;e=A[f>>3];c:{if(D(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){ix(a);e=A[a+4256>>3]}A[f>>3]=e-+(g|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=ki(A[f>>3]*6.283185307179586);break d;case 1:e=D(A[f>>3]+-.5)*-4+1;break d;case 2:e=A[f>>3];e=e+e+-1;break d;case 3:e=A[f>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=A[a+4280>>3]*e+A[a+4272>>3]*(1-e)}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];LM(h+8|0,1);g=Hj(a);f:{if(!g){break f}f=v[a+4236>>2];if(w[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|Nn(A[h+8>>3]*127)<<16,j=v[v[g>>2]+68>>2],eb[j](k|0,l|0)|0;break f}eb[v[v[g>>2]+44>>2]](g,f,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4264>>3]*+(d>>>0)+A[a+4256>>3]}g=a;a=a+44|0;ai(g,b,c,Gd(a,0),Gd(a,1),d);ab=h+16|0}function Fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;l=ab-48|0;ab=l;if(lf(b)>>>0>c>>>0){while(1){f=m&65535;if(f>>>0<=c>>>0){e=Nf(v[b>>2],f);if(Gh(e)){n=l+24|0;e=vg(e);o=ug(Nf(v[b>>2],f));g=OO(l,d);j=ab-16|0;ab=j;v[j+8>>2]=e;while(1){if(Tb(e,o)){i=ab-16|0;ab=i;if(!(w[e+5|0]|w[e+3|0]!=4)){f=i+8|0;rb(f,v[g>>2],x[g+14>>1]);mg(f,0);t[e+3|0]=0}h=w[e+2|0];if(!(w[e+4|0]|(h|0)!=11)){f=i+8|0;rb(f,v[g>>2],x[g+14>>1]);mg(f,0);t[e+2|0]=0;h=0}a:{b:{if(!w[e|0]){rb(i+8|0,v[g>>2],x[g+14>>1]);if(sb(v[v[i+8>>2]>>2],v[i+12>>2])){break b}h=w[e+2|0]}k=w[e+3|0];f=i+8|0;rb(f,v[g>>2],x[g+14>>1]);mg(f,(k|0)==4|(h|0)==11);h=w[e+3|0];break a}h=w[e+3|0];f=w[e+2|0];if(!(h|(f|0)==11)){t[e+5|0]=0;h=4;t[e+3|0]=4;break a}if(f|(h|0)==4){break a}t[e+4|0]=0;t[e+2|0]=11}c:{d:{e:{if(!(!w[g+16|0]|h)){t[e+3|0]=17;k=0;h=125;break e}k=0;f:{switch(h-16|0){case 1:break d;case 0:break f;default:break c}}if(w[e+5|0]){break c}k=1;h=6}t[e+5|0]=h}t[g+16|0]=k}u[g+14>>1]=(x[g+14>>1]+1>>>0)%x[g+12>>1];ab=i+16|0;ui(j+8|0);e=v[j+8>>2];continue}break}LO(n,g);ab=j+16|0;Be(n);Be(g)}m=m+1|0;continue}break}}LO(a,d);ab=l+48|0}function OW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(Bg(a,v[b+8>>2],e)){sv(b,c,d);return}a:{if(Bg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;if(v[b+44>>2]!=4){f=a+16|0;h=f+(v[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}u[b+52>>1]=0;pv(f,b,c,c,1,e);if(w[b+54|0]){break d}e:{if(!w[b+53|0]){break e}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break c}g=1;if(w[a+8|0]&2){break e}break c}g=1;if(!(t[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}v[b+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}f=v[a+12>>2];g=a+16|0;br(g,b,c,d,e);if((f|0)<2){break a}g=g+(f<<3)|0;f=a+24|0;a=v[a+8>>2];if(!(!(a&2)&v[b+36>>2]!=1)){while(1){if(w[b+54|0]){break a}br(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}br(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|v[b+36>>2]==1&v[b+24>>2]==1){break a}br(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function Paa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=ab-16|0;ab=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];j=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=j;o=v[a+8>>2];p=v[a+12>>2];while(1){j=e;if(d){q=v[a+72>>2];e=v[a+64>>2];g=e;k=e>>31;e=Sb(j,-16777216,16776704);e=oia(g,k,e,e>>31);g=db;k=e;e=v[a+68>>2];f=Sb(f,-16777216,16776704);i=oia(e,e>>31,f,f>>31);e=k+i|0;f=db+g|0;f=e>>>0<i>>>0?f+1|0:f;k=e;e=v[a+60>>2];i=e;r=e>>31;e=(v[h+12>>2]<<1)+n|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+b|0;g=(((((B(u[e+4>>1],u[g+34>>1])+B(u[e+2>>1],u[g+32>>1])|0)+B(u[e+6>>1],u[g+36>>1])|0)+B(u[e+8>>1],u[g+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+26>>1])+B(u[e-6>>1],u[g+24>>1])|0)+B(u[e-2>>1],u[g+28>>1])|0)+B(u[e>>1],u[g+30>>1])|0)/2|0)|0)/16384<<8;e=g;i=oia(i,r,e,e>>31);e=k+i|0;f=db+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Lb(h+8|0,o,p);e=f-(g&q)|0;c=c+8|0;d=d-1|0;f=j;continue}break}v[a+48>>2]=f;v[a+44>>2]=j;b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+16|0}function l9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=ab-32|0;ab=f;v[f+16>>2]=c;v[f+24>>2]=b;n=Af(a);while(1){if(Qg(f+24|0,f+16|0)){$b(f+8|0,n);b=v[f+8>>2];l=f+24|0;i=id(l);k=ab-16|0;ab=k;m=0;j=ab-16|0;ab=j;g=ab-32|0;ab=g;e=g+28|0;c=g+24|0;d=ab-32|0;ab=d;v[d+24>>2]=b;a:{b:{if(!jc(b,v[$b(d+16|0,Jf(a))>>2])){h=w[i|0];if(!my(h,id(d+24|0))){break b}}v[d+16>>2]=b;c=$b(d+8|0,Ip(a));c:{if(!jc(v[d+16>>2],v[c>>2])){h=id(My(d+16|0));c=w[i|0];if(!ly(h,c)){break c}}if(!v[b>>2]){v[e>>2]=b;break a}b=v[d+16>>2];v[e>>2]=b;b=b+4|0;break a}b=ny(a,e,c);break a}if(ly(id(d+24|0),h)){c=Ky(b);v[d+16>>2]=c;d:{if(!jc(c,v[$b(d+8|0,Jf(a))>>2])){h=w[i|0];if(!my(h,id(d+16|0))){break d}}if(!v[v[d+24>>2]+4>>2]){v[e>>2]=b;b=b+4|0;break a}v[e>>2]=c;b=c;break a}b=ny(a,e,h);break a}v[e>>2]=b;v[c>>2]=b;b=c}ab=d+32|0;d=v[b>>2];if(!d){d=ab-16|0;ab=d;e=ac(a);c=g+8|0;e=hh(c,pc(24),ih(d+8|0,e));UL(v[e>>2]+16|0,i);o=ac(e),p=1,t[o+4|0]=p;ab=d+16|0;Pg(a,v[g+28>>2],b,v[c>>2]);d=Pd(c);$k(c);m=1}Og(j+8|0,$b(g+8|0,d),m);ab=g+32|0;ab=j+16|0;$b(k+8|0,v[j+8>>2]);ab=k+16|0;Uj(l);continue}else{ab=f+32|0}break}}function pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;h=ab-16|0;ab=h;g=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];p=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;q=v[a+8>>2];r=v[a+12>>2];while(1){b=e;if(d){s=v[a+72>>2];t=v[a+32>>2];j=v[a+28>>2]+j|0;e=j>>12;f=v[a+64>>2];k=f;n=f>>31;f=Sb(b,-16777216,16776704);f=oia(k,n,f,f>>31);l=db;n=e;o=f;e=v[a+60>>2];m=e;w=e>>31;e=(v[h+12>>2]<<1)+p|0;f=v[h+8>>2]>>>21&2040;k=(((B(u[e>>1],u[f+39874>>1])+B(u[e-2>>1],u[f+39872>>1])|0)+B(u[e+2>>1],u[f+39876>>1])|0)+B(u[e+4>>1],u[f+39878>>1])|0)/16384<<8;e=k;m=oia(m,w,e,e>>31);f=o+m|0;e=db+l|0;e=f>>>0<m>>>0?e+1|0:e;o=f;f=v[a+68>>2];g=Sb(g,-16777216,16776704);l=oia(f,f>>31,g,g>>31);f=o+l|0;g=db+e|0;g=f>>>0<l>>>0?g+1|0:g;e=f+8388608|0;g=e>>>0<8388608?g+1|0:g;g=Cc(e,g,24);e=(g|0)/256|0;v[c>>2]=B(n,e)+v[c>>2];i=i+t|0;v[c+4>>2]=v[c+4>>2]+B(e,i>>12);Lb(h+8|0,q,r);e=g-(s&k)|0;c=c+8|0;d=d-1|0;g=b;continue}break}v[a+40>>2]=i;v[a+36>>2]=j;v[a+48>>2]=g;v[a+44>>2]=b;v[a+20>>2]=j>>12;v[a+24>>2]=i>>12;b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+16|0}function $7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0,q=C(0);i=ab-16|0;ab=i;h=u[d+2>>1];j=u[d>>1];a:{if((h|0)<(j|0)){break a}l=v[b>>2];k=nc(l,v[b+4>>2]);if(!k){break a}g=u[e>>1];if((g|0)<(j|0)|(g|0)>(h|0)|(k-1&65535)>>>0>(h-g&65535)>>>0|y[a+36>>2]>65535){break a}g=0;while(1){if((g|0)!=(k|0)){n=Fb(l,g);g=g+1|0;if(!(z[n>>2]<C(0))){continue}break a}break}m=z[c>>2];if(m<=C(0)){break a}u[a+28>>1]=j;u[a>>1]=1;o=a,p=oK(k),u[o+30>>1]=p;z[a+32>>2]=D(m);Ij(a+4|0,(h-j|0)+1|0);c=wb(v[b>>2]);b=wb(v[b+4>>2]);o=i,p=wb(v[a+4>>2]),v[o+8>>2]=p;f=c;c=Wk(i+8|0,u[e>>1]-u[d>>1]|0);f=no(f,b,c);b=ab-16|0;ab=b;v[b+8>>2]=c;Wk(b+8|0,f-c>>2);ab=b+16|0;c=u[a+28>>1];b=u[e>>1];f=b;while(1){if((b&65535)!=32768&(c|0)<(f|0)){b=v[a+4>>2];f=f-1|0;g=f-c|0;h=Fb(b,g+u[a+30>>1]|0);o=Fb(b,g),q=C(z[h>>2]/z[a+32>>2]),z[o>>2]=q;b=x[e>>1];continue}else{e=u[a+30>>1];b=b<<16>>16;f=e+b|0;d=u[d+2>>1];b=(b|0)<=(32767-e|0);while(1){if(b&(d|0)>=(f|0)){g=v[a+4>>2];h=Fb(g,f-(c+e|0)|0);o=Fb(g,f-c|0),q=C(z[a+32>>2]*z[h>>2]),z[o>>2]=q;f=f+1|0;continue}else{Wo(a)}break}}break}f=1}ab=i+16|0;return f|0}function Qaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=ab-16|0;ab=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];j=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=j;o=v[a+8>>2];p=v[a+12>>2];while(1){j=e;if(d){q=v[a+72>>2];e=v[a+64>>2];g=e;k=e>>31;e=Sb(j,-16777216,16776704);e=oia(g,k,e,e>>31);g=db;k=e;e=v[a+68>>2];f=Sb(f,-16777216,16776704);i=oia(e,e>>31,f,f>>31);e=k+i|0;f=db+g|0;f=e>>>0<i>>>0?f+1|0:f;k=e;e=v[a+60>>2];i=e;r=e>>31;e=v[h+12>>2]+n|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+b|0;g=(((((B(t[e+2|0],u[g+34>>1])+B(t[e+1|0],u[g+32>>1])|0)+B(t[e+3|0],u[g+36>>1])|0)+B(t[e+4|0],u[g+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+26>>1])+B(t[e-3|0],u[g+24>>1])|0)+B(t[e-1|0],u[g+28>>1])|0)+B(t[e|0],u[g+30>>1])<<8)/2|0)|0)/16384<<8;e=g;i=oia(i,r,e,e>>31);e=k+i|0;f=db+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Lb(h+8|0,o,p);e=f-(g&q)|0;c=c+8|0;d=d-1|0;f=j;continue}break}v[a+48>>2]=f;v[a+44>>2]=j;b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+16|0}function jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=ab-16|0;ab=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=((((v[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+j|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];t=u[e+2>>1];w=u[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+m|0;v[(h<<2)+f>>2]=(((((((B(u[e-8>>1],t)+B(u[e-12>>1],w)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)+B(u[e+4>>1],q)|0)+B(u[e+8>>1],p)|0)+B(u[e+12>>1],o)|0)+B(u[e+16>>1],n)|0)/32768;h=h+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],k);Lb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function P6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=ab+-64|0;ab=c;g=Pb(a);v[22452]=0;Z(887,g|0);b=v[22452];v[22452]=0;a:{if((b|0)!=1){b=44720;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((b|0)==45032){ab=c- -64|0;return a|0}k:{d=ng(44);if(d){h=v[b>>2];f=v[b+4>>2];v[22452]=0;f=Q(55,c+32|0,f|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break k}v[22452]=0;R(888,c+48|0,f|0);e=v[22452];v[22452]=0;if((e|0)==1){break j}e=v[b+8>>2];v[22452]=0;e=Q(55,c|0,e|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break i}v[22452]=0;R(888,c+16|0,e|0);i=v[22452];v[22452]=0;if((i|0)==1){break h}v[22452]=0;da(889,d|0,h|0,c+48|0,c+16|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break g}yb(c+16|0);pb(e);yb(c+48|0);pb(f);v[c+60>>2]=d;v[22452]=0;R(890,g|0,c+60|0);f=v[22452];v[22452]=0;if((f|0)==1){break b}v[d+32>>2]=v[b+12>>2];v[d+36>>2]=v[b+16>>2];t[d+40|0]=w[b+20|0];t[d+41|0]=w[d+41|0]&253|w[b+21|0]<<1}b=b+24|0;continue}break}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;yb(c+16|0)}pb(e)}yb(c+48|0)}pb(f)}xb(d);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}ec(g);S(b|0);L()}function Jha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=ab-1072|0;ab=d;v[d+1068>>2]=c;o=d,p=ue(b),t[o+8|0]=p;t[d+4|0]=1;c=d+8|0;g=w[$e(c,d+4|0)|0];f=ZA(c,b);l=Yp(f);v[22452]=0;c=T(193,b|0)|0;e=v[22452];v[22452]=0;a:{if((e|0)!=1){v[d+4>>2]=c;v[d>>2]=536870911;mc(d+1068|0,v[zb(d+4|0,d)>>2]<<3);v[22452]=0;m=v[d+1068>>2];k=Q(330,a|0,m|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;c=8;h=Q(155,f|0,8)|0;a=v[22452];v[22452]=0;b:{if((a|0)!=1){c:{o=Cb(v[k>>2],0),p=h,t[o|0]=p;i=1;a=g;while(1){c=c&255;n=c>>>0>9?c:9;e=a;d:{e:{while(1){if(i>>>0>=m>>>0){break d}v[22452]=0;j=Q(155,f|0,c|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=g;continue}break}break c}a=j>>>1|0;h=(j&1?0-a|0:a)+h|0;o=Cb(v[k>>2],i),p=h,t[o|0]=p;i=i+1|0;a=g;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:g;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=Yp(f);v[22452]=0;Q(146,b|0,((a-l|0)+3&-4)+l|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break b}}}c=P()|0;O()|0;Xb(k);break a}qb(f);ab=d+1072|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0}qb(f);S(c|0);L()}function jZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=ab-448|0;ab=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=1133;b=ee(a+24|0,a+32|0,a+20|0);h=a+16|0;zc(h,e);v[22452]=0;h=T(1111,h|0)|0;i=v[22452];v[22452]=0;if((i|0)!=1){a:{t[a+15|0]=0;e=v[e+4>>2];v[22452]=0;c=pa(1141,a+440|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(me(g)){nd(v[g>>2],0);Qd(g,0);break d}nd(g,0);ye(g,0)}if(w[a+15|0]){v[22452]=0;c=Q(1129,h|0,45)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}v[22452]=0;R(49,g|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break a}}v[22452]=0;c=Q(1129,h|0,48)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}e=v[b>>2];d=v[a+20>>2];h=d-4|0;while(1){if(!((c|0)!=v[e>>2]|e>>>0>=h>>>0)){e=e+4|0;continue}break}v[22452]=0;Y(1146,g|0,e|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break c}break a}v[22452]=0;c=Q(1117,a+440|0,a+432|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}if(c){v[f>>2]=v[f>>2]|2}c=v[a+440>>2];Nb(a+16|0);Bc(b);ab=a+448|0;return c|0}}}c=P()|0;O()|0;Nb(a+16|0);Bc(b);S(c|0);L()}function U6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0;c=ab-32|0;ab=c;a:{b=v[a+20>>2];b:{if(!b){break b}v[b+148>>2]=-1;h=c,i=eb[v[v[a>>2]+40>>2]](a)|0,v[h+16>>2]=i;v[c+8>>2]=1073741822;f=v[jd(c+16|0,c+8|0)>>2];b=f<<2;if(!b){break b}d=v[a+20>>2];v[22452]=0;R(279,d+4|0,b+4|0);b=v[22452];v[22452]=0;c:{d:{if((b|0)!=1){d=c+8|0;b=v[a+20>>2];de(d,v[b+4>>2],v[b+8>>2]);v[c>>2]=0;v[c+4>>2]=0;e=v[d+4>>2];b=c+16|0;v[b>>2]=v[d>>2];v[b+4>>2]=e;d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;e=ab-16|0;ab=e;v[e+12>>2]=0;d=e+12|0;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;QJ(b,d);ab=e+16|0;b=v[v[a>>2]+180>>2];v[22452]=0;R(b|0,a|0,-1);b=v[22452];v[22452]=0;if((b|0)==1){break d}d=(f|0)>0?f:0;b=0;while(1){if((b|0)==(d|0)){b=v[v[a>>2]+184>>2];v[22452]=0;Z(b|0,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}break d}e=v[v[a>>2]+48>>2];v[22452]=0;g=C(Ua(e|0,a|0,b|0));e=v[22452];v[22452]=0;if((e|0)!=1){z[c+8>>2]=g;b=b+1|0;QJ(c+16|0,c+8|0);continue}break}b=V(88408)|0;break c}b=V(88408)|0;break c}b=V(88408)|0}if((O()|0)!=(fa(88408)|0)){break a}_(b|0)|0;uc(v[a+20>>2]+4|0);$()}ab=c+32|0;return}S(b|0);L()}function dU(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=ab-32|0;ab=g;t[g+12|0]=0;m=zB(g+16|0,d,g+12|0);f=v[m>>2];v[g+12>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=w[a|0];if(!(!i|(k|0)!=(e&255))){v[g+8>>2]=w[a+1|0];i=a+2|0;j=zb(g+8|0,g+12|0);b:{k=b-2|0;if(!k){break b}j=v[j>>2];if(!(j&255)){break b}i=w[i|0];while(1){if(!(j&255)){break a}t[f|0]=i;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;j=j-1|0;continue}}t[f|0]=e;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;t[f|0]=k;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=v[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=t[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;t[c|0]=k;e=e-1|0;c=c+1|0;continue}break}Xb(m);ab=g+32|0;return}n=w[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;t[l|0]=w[l|0]|B(f&n,257)>>>(h-j&7);l=b+1|0;b=d>>>0>l>>>0?l:0;j=j+1|0;h=(d>>>0<=l>>>0)+h|0;f=(f<<8|f)>>>1&255;continue}}}function ML(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=ab-16|0;ab=f;e=B(b,872)+a|0;a:{if(c){rb(f+8|0,a+1074312|0,90);if(!sb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075803|0]=c}t[(B(b,872)+a|0)+1075804|0]=c;break a}c=w[e+1075804|0]}e=e+1074992|0;h=c&255;j=0-h|0;i=d?i:!(v[a+480180>>2]&204473357);HL(a,b,j,i);g=v[a+480180>>2];b:{c:{if((g|0)!=268435456){if((g|0)!=16777216){break c}k=v[(B(b,872)+a|0)+1075648>>2];if(!k|!v[k+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){GL(v[a+1074392>>2],v[a+1074416>>2],e,240-h|0);break b}if(!(b>>>0<224|d)){FL(e,224-h|0);break b}EL(e,j);break b}v[(B(b,872)+a|0)+1075700>>2]=65535}d:{if(!((c&255)>>>0>223&i)){break d}e:{d=h&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}cy(a,e,d);break b}if((g|0)==524288){break d}JL(a,e,d);break b}if((g|0)!=524288){break b}}f:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break f}if(v[a+1074416>>2]==1){rb(f+8|0,a+1074312|0,6);if(sb(v[v[f+8>>2]>>2],v[f+12>>2])){break f}g=v[a+480180>>2]}if(g&32832){break f}if(!(v[a+480208>>2]&2)|(g|0)!=8){break b}}Jj(a,e,(B(b,872)+a|0)+1075692|0,0-(h<<2)|0,0)}ab=f+16|0}function qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=ab-16|0;ab=h;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];m=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;n=v[a+8>>2];o=v[a+12>>2];while(1){b=e;if(d){p=v[a+72>>2];q=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+64>>2];g=e;l=e>>31;e=Sb(b,-16777216,16776704);e=oia(g,l,e,e>>31);g=db;l=e;e=v[a+68>>2];f=Sb(f,-16777216,16776704);i=oia(e,e>>31,f,f>>31);e=l+i|0;f=db+g|0;f=e>>>0<i>>>0?f+1|0:f;l=e;e=v[a+60>>2];i=e;r=e>>31;e=v[h+12>>2]+m|0;g=v[h+8>>2]>>>21&2040;g=(((B(t[e|0],u[g+39874>>1])+B(t[e-1|0],u[g+39872>>1])|0)+B(t[e+1|0],u[g+39876>>1])|0)+B(t[e+2|0],u[g+39878>>1])<<8)/16384<<8;e=g;i=oia(i,r,e,e>>31);e=l+i|0;f=db+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(k>>12,e)+v[c>>2];j=j+q|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Lb(h+8|0,n,o);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}v[a+40>>2]=j;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+16|0}function OT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=ab-32|0;ab=e;t[e+24|0]=44;v[e+16>>2]=-1;v[e+20>>2]=0;v[e+8>>2]=1058;v[e+12>>2]=2;c=ab+-64|0;ab=c;h=e+8|0;i=v[h>>2]&2?16:10;f=ab-32|0;ab=f;d=ze(f+16|0,1,0);a:{b:{c:{while(1){g=Eb(d);OI(f+8|0,g,ub(d)+g|0,v[b>>2],i);if(!v[f+12>>2]){break c}g=If(ub(d));v[22452]=0;R(59,d|0,g|0);g=v[22452];v[22452]=0;if((g|0)!=1){continue}break}break b}b=v[f+8>>2];i=Eb(d);v[22452]=0;R(60,d|0,b-i|0);b=v[22452];v[22452]=0;d:{if((b|0)!=1){v[22452]=0;R(61,c|0,d|0);b=v[22452];v[22452]=0;if((b|0)!=1){break d}break b}break b}pb(d);ab=f+32|0;break a}a=P()|0;O()|0;pb(d);S(a|0);L()}b=c+16|0;Ik(b,c,v[h>>2]);d=v[h+4>>2];f=v[h>>2];v[22452]=0;W(75,c+32|0,b|0,f|0,d|0);b=v[22452];v[22452]=0;e:{f:{g:{h:{i:{if((b|0)!=1){v[22452]=0;U(76,c+48|0,c+32|0,h|0);b=v[22452];v[22452]=0;if((b|0)==1){break i}v[22452]=0;R(58,a|0,c+48|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}pb(c+48|0);pb(c+32|0);pb(c+16|0);pb(c);ab=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;pb(c+48|0)}pb(c+32|0)}pb(c+16|0);pb(c);S(a|0);L()}ab=e+32|0}function CA(a,b){a:{b:{switch((w[a+3|0]|64)+-64|0){case 0:t[a+3|0]=w[a+5|0]?37:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(b){break a}b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=b?32:31;return;case 29:t[a+3|0]=b?33:0;return;case 27:t[a+3|0]=b?34:0;return;case 30:t[a+3|0]=b?35:0;return;case 31:t[a+3|0]=b?36:0;return;case 50:t[a+3|0]=b?25:0;return;case 51:t[a+3|0]=b?30:0;return;default:break b}}t[a+3|0]=0}}function vt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=ab-32|0;ab=e;t[e+24|0]=44;v[e+16>>2]=-1;v[e+20>>2]=0;v[e+8>>2]=1058;v[e+12>>2]=2;c=ab+-64|0;ab=c;h=e+8|0;i=v[h>>2]&2?16:10;f=ab-32|0;ab=f;d=ze(f+16|0,1,0);a:{b:{c:{while(1){g=Eb(d);PI(f+8|0,g,ub(d)+g|0,w[b|0],i);if(!v[f+12>>2]){break c}g=If(ub(d));v[22452]=0;R(59,d|0,g|0);g=v[22452];v[22452]=0;if((g|0)!=1){continue}break}break b}b=v[f+8>>2];i=Eb(d);v[22452]=0;R(60,d|0,b-i|0);b=v[22452];v[22452]=0;d:{if((b|0)!=1){v[22452]=0;R(61,c|0,d|0);b=v[22452];v[22452]=0;if((b|0)!=1){break d}break b}break b}pb(d);ab=f+32|0;break a}a=P()|0;O()|0;pb(d);S(a|0);L()}b=c+16|0;Ik(b,c,v[h>>2]);d=v[h+4>>2];f=v[h>>2];v[22452]=0;W(75,c+32|0,b|0,f|0,d|0);b=v[22452];v[22452]=0;e:{f:{g:{h:{i:{if((b|0)!=1){v[22452]=0;U(76,c+48|0,c+32|0,h|0);b=v[22452];v[22452]=0;if((b|0)==1){break i}v[22452]=0;R(58,a|0,c+48|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}pb(c+48|0);pb(c+32|0);pb(c+16|0);pb(c);ab=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;pb(c+48|0)}pb(c+32|0)}pb(c+16|0);pb(c);S(a|0);L()}ab=e+32|0}function kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;f=ab-16|0;ab=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=(((v[f+12>>2]&2147483647)<<1|h>>>31)&-2)+j|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];h=0;while(1){if((h|0)!=2){e=h+m|0;v[(h<<2)+f>>2]=(((((((B(t[e-4|0],w)+B(t[e-6|0],x)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)|0)+B(t[e+2|0],q)|0)+B(t[e+4|0],p)|0)+B(t[e+6|0],o)|0)+B(t[e+8|0],n)<<8)/32768;h=h+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],k);Lb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function dR(a,b,c,d,e){var f=0,g=0;f=ab-16|0;ab=f;g=x[c>>1];a:{if((d&255)>>>0<=4){while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!We(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!We(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!We(a,f+13|0)){break a}d=w[f+13|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!We(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!We(a,f+11|0)){break a}d=w[f+11|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}ab=f+16|0}function p8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=ab-32|0;ab=j;e=b;b=v[a>>2];f=B(os(e,wb(b)),6)+b|0;a:{if(!c){break a}b=v[vb(a)>>2];h=v[a+4>>2];if((b-h|0)/6>>>0>=c>>>0){b=c;g=h-f|0;e=(g|0)/6|0;if(e>>>0<c>>>0){yA(a,c-e|0,d);b=e;if(!g){break a}}k=ab-16|0;ab=k;m=v[a+4>>2];g=B((m-(B(c,6)+f|0)|0)/6|0,6)+f|0;l=_p(k,a,(h-g|0)/6|0);i=v[l+4>>2];e=g;while(1){if(e>>>0>=h>>>0){dc(l);e=g-f|0;if(e){Wi(m+B((e|0)/-6|0,6)|0,f,e)}ab=k+16|0}else{Et(i,e);i=i+6|0;v[l+4>>2]=i;e=e+6|0;continue}break}e=f;d=e>>>0<=d>>>0?B(y[a+4>>2]>d>>>0?c:0,6)+d|0:d;while(1){if(b){a=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[e|0]=a;t[e+1|0]=a>>>8;t[e+2|0]=a>>>16;t[e+3|0]=a>>>24;a=w[d+4|0]|w[d+5|0]<<8;t[e+4|0]=a;t[e+5|0]=a>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=vb(a);e=ZR(j+8|0,rA(a,Yj(v[a>>2],h)+c|0),(f-v[a>>2]|0)/6|0,b);YR(e,c,d);b=v[e+4>>2];d=e+4|0;WR(v[a>>2],f,d);g=v[a+4>>2];c=e+8|0;while(1){if((f|0)!=(g|0)){Et(v[c>>2],f);v[c>>2]=v[c>>2]+6;f=f+6|0;continue}break}cc(a,d);cc(a+4|0,c);cc(vb(a),ic(e));v[e>>2]=v[e+4>>2];f=b;XR(e)}wb(f);ab=j+32|0}function ct(a,b){var c=0,d=0,e=0;d=ab-48|0;ab=d;e=d+24|0;XO(e,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);XO(d,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);a=v[e>>2];c=Ab(w[a|0]|w[a+1|0]<<8);a=v[d>>2];b=1;a:{if(c>>>0<Ab(w[a|0]|w[a+1|0]<<8)>>>0){break a}a=v[d>>2];c=Ab(w[a|0]|w[a+1|0]<<8);a=v[e>>2];b=0;if(c>>>0<Ab(w[a|0]|w[a+1|0]<<8)>>>0){break a}a=v[e+4>>2];c=Ab(w[a|0]|w[a+1|0]<<8);a=v[d+4>>2];b=1;b:{if(c>>>0<Ab(w[a|0]|w[a+1|0]<<8)>>>0){break b}a=v[d+4>>2];c=Ab(w[a|0]|w[a+1|0]<<8);a=v[e+4>>2];b=0;if(c>>>0<Ab(w[a|0]|w[a+1|0]<<8)>>>0){break b}a=v[e+8>>2];c=Ab(w[a|0]|w[a+1|0]<<8);a=v[d+8>>2];b=1;c:{if(c>>>0<Ab(w[a|0]|w[a+1|0]<<8)>>>0){break c}a=v[d+8>>2];c=Ab(w[a|0]|w[a+1|0]<<8);a=v[e+8>>2];b=0;if(c>>>0<Ab(w[a|0]|w[a+1|0]<<8)>>>0){break c}a=v[e+12>>2];c=Ab(w[a|0]|w[a+1|0]<<8)<<16>>16;a=v[d+12>>2];b=1;d:{if((c|0)<Ab(w[a|0]|w[a+1|0]<<8)<<16>>16){break d}a=v[d+12>>2];c=Ab(w[a|0]|w[a+1|0]<<8)<<16>>16;a=v[e+12>>2];b=0;if((c|0)<Ab(w[a|0]|w[a+1|0]<<8)<<16>>16){break d}a=v[e+16>>2];b=Ab(w[a|0]|w[a+1|0]<<8);a=v[d+16>>2];b=b>>>0<Ab(w[a|0]|w[a+1|0]<<8)>>>0}}}}a=b;ab=d+48|0;return a}function fn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=ab-80|0;ab=c;g=Pb(a);e=b+24|0;a:{b:{if(dj(v[e>>2]+484360|0)){b=0;c:{d:{e:while(1){if(dj(v[e>>2]+484360|0)>>>0<=b>>>0){break d}f=v[e>>2];a=_K(QQ(c+40|0,1),b&255,0,0);v[22452]=0;d=v[a+12>>2];v[c+16>>2]=v[a+8>>2];v[c+20>>2]=d;d=v[a+20>>2];v[c+24>>2]=v[a+16>>2];v[c+28>>2]=d;d=v[a+4>>2];v[c+8>>2]=v[a>>2];v[c+12>>2]=d;W(1017,c- -64|0,f|0,0,c+8|0);a=v[22452];v[22452]=0;if((a|0)==1){break c}j=c,k=wb(v[c+64>>2]),v[j+32>>2]=k;f=wb(v[c+68>>2]);while(1){a=v[c+32>>2];if(!Tb(a,f)){b=b+1|0;ni(c- -64|0);continue e}h=A[a>>3];d=v[a+16>>2];i=x[a+24>>1];a=c+40|0;v[a+16>>2]=b;v[a+12>>2]=i;v[a+8>>2]=d;A[a>>3]=h;v[22452]=0;R(1036,g|0,a|0);a=v[22452];v[22452]=0;if((a|0)!=1){_y(c+32|0);continue}break}break}a=P()|0;O()|0;ni(c- -64|0);break b}ab=c+80|0;return}a=P()|0;O()|0;break b}b=aa(8)|0;v[22452]=0;c=Q(55,c+40|0,7228)|0;a=v[22452];v[22452]=0;if((a|0)!=1){lc(b,c);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(c);break b}a=P()|0;O()|0;ba(b|0)}Hf(g);S(a|0)}L()}function NL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;f=ab-16|0;ab=f;e=B(b,872)+a|0;a:{if(c){rb(f+8|0,a+1074312|0,90);if(!sb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075804|0]=c}t[(B(b,872)+a|0)+1075803|0]=c;break a}c=w[e+1075803|0]}e=e+1074992|0;h=c&255;i=d?i:!(v[a+480180>>2]&204473357);HL(a,b,h,i);g=v[a+480180>>2];b:{c:{if((g|0)!=268435456){if((g|0)!=16777216){break c}j=v[(B(b,872)+a|0)+1075648>>2];if(!j|!v[j+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){GL(v[a+1074392>>2],v[a+1074416>>2],e,h-240|0);break b}if(!(b>>>0<224|d)){FL(e,h-224|0);break b}EL(e,h);break b}v[(B(b,872)+a|0)+1075700>>2]=1}d:{if(!((c&255)>>>0>223&i)){break d}e:{d=h&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}dy(a,e,d);break b}if((g|0)==524288){break d}IL(a,e,d);break b}if((g|0)!=524288){break b}}f:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break f}if(v[a+1074416>>2]==1){rb(f+8|0,a+1074312|0,6);if(sb(v[v[f+8>>2]>>2],v[f+12>>2])){break f}g=v[a+480180>>2]}if(g&32832){break f}if(!(v[a+480208>>2]&2)|(g|0)!=8){break b}}Jj(a,e,(B(b,872)+a|0)+1075692|0,h<<2,0)}ab=f+16|0}function Daa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ab-48|0;ab=e;m=v[a+16>>2];f=Vd(e+16|0);v[f+8>>2]=a+112;g=v[a+128>>2];v[f+16>>2]=g;n=f,o=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;k=v[a+8>>2];l=v[a+12>>2];if(g){n=f,o=Wf(k,l,g),v[n>>2]=o;v[f+4>>2]=db}g=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=b;a:while(1){if(d){b=v[e+12>>2];v[e+40>>2]=v[e+8>>2];v[e+44>>2]=0;h=(b<<1)+m|0;b=v[f+16>>2];while(1)if((b|0)<=0){b=v[f+8>>2];j=v[b+8>>2];Lb(b,j,v[b+12>>2]);b=v[f+8>>2];j=v[b+4>>2];if(j){Bd(b,u[h+(v[e+44>>2]<<1)>>1]/4<<16>>16);Ad(v[f+8>>2],j);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}d=d-1|0;h=v[a+32>>2];i=v[a+28>>2]+i|0;b=Uf(b,v[f+12>>2]);v[c>>2]=B(i>>12,b)+v[c>>2];g=g+h|0;v[c+4>>2]=v[c+4>>2]+B(b,g>>12);Lb(e+8|0,k,l);c=c+8|0;continue a}else{Bd(v[f+8>>2],u[h+(v[e+44>>2]<<1)>>1]/4<<16>>16);Ad(v[f+8>>2],4);Lb(e+40|0,v[f>>2],v[f+4>>2]);b=b-1|0;continue}}break}v[a+40>>2]=g;v[a+36>>2]=i;v[a+20>>2]=i>>12;v[a+24>>2]=g>>12;b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;ab=e+48|0}function Dn(a,b,c,d){var e=0;e=ab-16|0;ab=e;t[a+841|0]=0;v[a+708>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;t[a+797|0]=0;v[a+764>>2]=0;u[a+802>>1]=0;u[a+804>>1]=0;v[a+696>>2]=0;v[a+668>>2]=0;v[a+88>>2]=v[a+88>>2]|6144;rb(e+8|0,b+1074312|0,23);if(sb(v[v[e+8>>2]>>2],v[e+12>>2])){t[a+807|0]=1;t[a+808|0]=0}t[a+846|0]=0;t[a+839|0]=0;u[a+774>>1]=0;t[a+850|0]=255;v[a+660>>2]=0;t[a+851|0]=w[a+851|0]&224;Kn(a+788|0);v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;t[a+845|0]=0;t[a+838|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+820>>1]=0;t[a+819|0]=0;u[a+836>>1]=32512;u[a+842>>1]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+852>>2]=0;v[a+856>>2]=0;t[a+851|0]=w[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+748>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|d;break a}v[a+748>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+784>>1]=0;t[a+795|0]=0;t[a+796|0]=0;ab=e+16|0}function t8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=ab-16|0;ab=e;ed(c,0);d=a+36|0;u[e+14>>1]=w[d|0]|w[d+1|0]<<8;u[e+12>>1]=32767;g=c,h=(x[Lc(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,u[g+28>>1]=h;d=a+38|0;u[e+10>>1]=w[d|0]|w[d+1|0]<<8;u[e+8>>1]=32767;g=c,h=(x[Lc(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,u[g+30>>1]=h;u[c+32>>1]=64;d=a+44|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+56|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=w[b+166|0];if(d>>>0<=4){t[c+38|0]=w[d+42874|0]}d=b+167|0;d=w[d|0]|w[d+1|0]<<8;t[c+39|0]=d;f=b+171|0;f=(w[f|0]|w[f+1|0]<<8)>>>4|0;t[c+41|0]=f;b=b+169|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if((b|f)&255){t[c+39|0]=d^-1}b=a+40|0;a=w[b|0]|w[b+1|0]<<8;if(a&4){u[c+34>>1]=x[c+34>>1]|1;a=w[b|0]|w[b+1|0]<<8}if(a&8){u[c+34>>1]=x[c+34>>1]|2;a=w[b|0]|w[b+1|0]<<8}if(a&16){u[c+34>>1]=x[c+34>>1]|4;a=w[b|0]|w[b+1|0]<<8}if(a&32){u[c+34>>1]=x[c+34>>1]|32}ab=e+16|0}function pZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=ab-160|0;ab=a;v[a+144>>2]=c;v[a+152>>2]=b;v[a+20>>2]=1133;b=ee(a+24|0,a+32|0,a+20|0);h=a+16|0;zc(h,e);v[22452]=0;h=T(18,h|0)|0;i=v[22452];v[22452]=0;if((i|0)!=1){a:{t[a+15|0]=0;e=v[e+4>>2];v[22452]=0;c=pa(1134,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}Pe(g);if(w[a+15|0]){v[22452]=0;c=Q(19,h|0,45)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}v[22452]=0;R(47,g|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break a}}v[22452]=0;c=Q(19,h|0,48)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}e=v[b>>2];d=v[a+20>>2];h=d-1|0;c=c&255;while(1){if(!((c|0)!=w[e|0]|e>>>0>=h>>>0)){e=e+1|0;continue}break}v[22452]=0;Y(1140,g|0,e|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break c}break a}v[22452]=0;c=Q(1101,a+152|0,a+144|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}if(c){v[f>>2]=v[f>>2]|2}c=v[a+152>>2];Nb(a+16|0);Bc(b);ab=a+160|0;return c|0}}}c=P()|0;O()|0;Nb(a+16|0);Bc(b);S(c|0);L()}function TJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=C(0);c=ab-80|0;ab=c;d=v[b>>2];e=v[b+4>>2];b=Vd(c+48|0);b=Nq(c+56|0,d,e,v[b>>2],v[b+4>>2]);v[22452]=0;d=T(193,b|0)|0;e=v[22452];v[22452]=0;a:{if((e|0)==1){break a}v[22452]=0;d=Y(883,b|0,c+8|0,d|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break a}b:{if(!d){break b}if(Ib(c+8|0,17567,4)){break b}d=c+8|4;if(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)){break b}d=c+16|0;f=a,g=Ed((l(2,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)),q()),C(0)),z[f+4220>>2]=g;d=c+20|0;f=a,g=Ed((l(2,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)),q()),C(0)),z[f+4224>>2]=g;d=c+24|0;f=a,g=Ed((l(2,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)),q()),C(0)),z[f+4228>>2]=g;d=c+28|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);if(d>>>0<=5){v[a+4232>>2]=d}d=c+32|0;v[a+4236>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[a+4240|0]=w[c+36|0]!=0;t[a+4241|0]=w[c+37|0]!=0;t[a+4242|0]=w[c+38|0]!=0;t[a+4243|0]=w[c+39|0]!=0;t[a+4244|0]=w[c+40|0]!=0;ks(a)}qb(b);ab=c+80|0;return}a=P()|0;O()|0;qb(b);S(a|0);L()}function PG(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=ab-208|0;ab=d;v[d+8>>2]=1;v[d+12>>2]=0;h=b<<2;a:{if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;f=4;e=2;while(1){g=b;b=(b+f|0)+4|0;v[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;f=g;if(b>>>0<h>>>0){continue}break}f=(a+h|0)-4|0;b:{if(f>>>0<=a>>>0){f=0;e=1;h=0;b=1;g=0;break b}e=1;b=1;while(1){c:{if((e&3)==3){sw(a,c,b,d+16|0);Dr(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(y[(d+16|0)+(g<<2)>>2]>=f-a>>>0){Cr(a,c,e,v[d+12>>2],b,0,d+16|0);break d}sw(a,c,b,d+16|0)}if((b|0)==1){Br(d+8|0,1);b=0;break c}Br(d+8|0,g);b=1}g=v[d+8>>2];e=g|1;v[d+8>>2]=e;a=a+4|0;if(f>>>0>a>>>0){continue}break}h=g>>>0>1;f=v[d+12>>2];g=(f|0)!=0}Cr(a,c,e,f,b,0,d+16|0);if(!(g?1:(b|0)!=1|h)){break a}while(1){e:{if((b|0)<=1){g=d+8|0;h=JG(g);Dr(g,h);f=v[d+12>>2];e=v[d+8>>2];b=b+h|0;break e}e=d+8|0;Br(e,2);v[d+8>>2]=v[d+8>>2]^7;Dr(e,1);f=a-4|0;h=d+16|0;g=b-2|0;Cr(f-v[h+(g<<2)>>2]|0,c,v[d+8>>2],v[d+12>>2],b-1|0,1,h);Br(e,1);e=v[d+8>>2]|1;v[d+8>>2]=e;b=f;f=v[d+12>>2];Cr(b,c,e,f,g,1,h);b=g}a=a-4|0;if((b|0)!=1|(e|0)!=1|f){continue}break}}ab=d+208|0}function Hs(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ab-16|0;ab=e;f=a+1074312|0;rb(e+8|0,f,77);a:{if(j=sb(v[v[e+8>>2]>>2],v[e+12>>2]),k=0,l=v[c+88>>2]&134218752,l?j:k){break a}b:{c:{if(d){g=w[c+841|0];if(!g){break c}d=g-1|0;t[c+841|0]=d;if(d&255){break b}rb(e+8|0,f,16);if(!sb(v[v[e+8>>2]>>2],v[e+12>>2])&v[a+480180>>2]!=2){break a}a=v[b+48>>2]+1|0}else{a=v[b+48>>2]}v[c+764>>2]=a;break a}rb(e+8|0,f,17);d:{if(sb(v[v[e+8>>2]>>2],v[e+12>>2])|v[a+480180>>2]&3){break d}g=b+616|0;i=x[a+480188>>1];while(1){if((h&65535)>>>0>=i>>>0){break d}if(w[g+841|0]?(c|0)!=(g|0):0){break a}g=g+872|0;h=h+1|0;continue}}t[c+841|0]=d}d=v[c+764>>2];v[b+56>>2]=d;e:{if((d|0)==-1){break e}f:{if(v[b+60>>2]==-1){break f}rb(e+8|0,f,68);if(!sb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}v[b+60>>2]=d}v[b+64>>2]=d;rb(e+8|0,f,103);if(!sb(v[v[e+8>>2]>>2],v[e+12>>2])){break e}u[b+68>>1]=65535}if(v[a+480180>>2]!=2){break a}d=x[a+480188>>1];a=0;while(1){if((a|0)==(d|0)){break a}f=B(a,872)+b|0;v[f+1380>>2]=v[c+764>>2];t[f+1457|0]=w[c+841|0];a=a+1|0;continue}}ab=e+16|0}function OP(a){a=a|0;var b=0,c=0,d=0,e=0;c=ab-80|0;ab=c;v[c+72>>2]=0;v[c+76>>2]=0;b=c- -64|0;v[b>>2]=0;v[b+4>>2]=0;v[c+56>>2]=0;v[c+60>>2]=0;v[c+48>>2]=0;v[c+52>>2]=0;dz(a,ez(a),c+48|0);b=kc(c+40|0,14165);Ie(ie(a,0),v[b>>2],v[b+4>>2]);b=kc(c+32|0,14269);Ie(ie(a,1),v[b>>2],v[b+4>>2]);b=kc(c+24|0,5457);Ie(ie(a,3),v[b>>2],v[b+4>>2]);b=kc(c+16|0,15650);Ie(ie(a,4),v[b>>2],v[b+4>>2]);b=kc(c+8|0,9236);Ie(ie(a,8),v[b>>2],v[b+4>>2]);e=ie(a+288|0,0);b=ab-16|0;ab=b;d=e;e=kc(b+8|0,4893);Ie(d,v[e>>2],v[e+4>>2]);ab=b+16|0;e=a+800|0;b=0;a=ab-80|0;ab=a;a:{b:{while(1){if((b|0)==128){break a}v[a+76>>2]=b<<3;c:{d:{if(b>>>0<=15){af(a+32|0,4045);v[22452]=0;R(281,a+16|0,a+76|0);d=v[22452];v[22452]=0;if((d|0)==1){break c}v[22452]=0;U(282,a+48|0,a+32|0,a+16|0);d=v[22452];v[22452]=0;if((d|0)!=1){d=a+48|0;qe(a- -64|0,d);Ie(ie(e,b),v[a+64>>2],v[a+68>>2]);pb(d);pb(a+16|0);yb(a+32|0);break d}b=P()|0;O()|0;pb(a+16|0);break b}kc(a+8|0,21598);Ie(ie(e,b),v[a+8>>2],v[a+12>>2])}b=b+1|0;continue}break}b=P()|0;O()|0}yb(a+32|0);S(b|0);L()}ab=a+80|0;ab=c+80|0}function E6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),x=0,y=0,A=0,E=C(0);j=a+44|0;i=Gd(j,0);k=Gd(j,1);m=dd(j,0);n=dd(j,1);h=a+4208|0;g=nc(v[h>>2],v[a+4212>>2]);p=B(v[v[a+16>>2]+1074404>>2],w[a+4233|0]);f=p<<1;if(g>>>0<f>>>0){Ij(h,f)}h=w[a+4232|0];a:{if(h){x=h-1|0;h=0;while(1){if((d|0)==(h|0)){break a}s=z[k>>2];f=v[a+4220>>2];f=f>>>0<p>>>0?f:0;g=f-p|0;o=v[a+4208>>2];g=((g|0)<0?f:g)<<1;y=Fb(o,g);e=z[Fb(o,g|1)>>2];t=z[i>>2];u=z[y>>2];q=C(t+u);z[m>>2]=q;r=C(s+e);z[n>>2]=r;e=C(0);l=C(0);b:{c:{switch(x|0){case 0:e=z[a+4224>>2];l=C(r*e);e=C(q*e);break b;case 1:case 2:e=z[a+4224>>2];l=C(q*e);e=C(r*e);break b;case 3:break c;default:break b}}e=C(C(C(C(t+s)*C(.5))+u)*z[a+4224>>2]);l=e}n=n+4|0;m=m+4|0;k=k+4|0;i=i+4|0;g=f<<1;A=Fb(o,g),E=C(D(e))<C(1.0000000195414814e-24)?C(0):e,z[A>>2]=E;A=Fb(o,g|1),E=C(D(l))<C(1.0000000195414814e-24)?C(0):l,z[A>>2]=E;v[a+4220>>2]=f+1;h=h+1|0;continue}}f=i;i=d<<2;fk(f,f+i|0,m);fk(k,i+k|0,n)}ai(a,b,c,dd(j,0),dd(j,1),d)}function UG(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=0;a:{if(w[b+21|0]){p=B(d,g);k=v[e>>2];l=v[f>>2];n=v[b>>2];b:{while(1){if((h|0)>0){if(v[a+1396>>2]<=9){Bk(a)}j=v[a+1392>>2];g=u[(((j&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){i=j;j=w[g+v[b+8>>2]|0];v[a+1392>>2]=i>>>j;m=v[a+1396>>2]-j|0;j=(m|0)<0;v[a+1396>>2]=j?0:m;j=j?-1:g;break c}j=Al(a,b)}if((j|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((j|0)<0){if(!w[a+1376|0]){b=0;if(v[a+1384>>2]){break b}}Vb(a,21);return 0}g=0;m=B(d,l);n=((m+n|0)+k|0)>(p|0)?(p-m|0)+k|0:n;m=(n|0)>0?n:0;j=B(j,v[b>>2]);o=C(0);d:{if(w[b+22|0]){while(1){if((g|0)==(m|0)){break d}o=C(o+z[v[b+28>>2]+(g+j<<2)>>2]);i=v[(k<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=o+z[i>>2]}k=k+1|0;i=(k|0)==(d|0);k=i?0:k;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(m|0)){break d}i=v[(k<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+C(z[v[b+28>>2]+(g+j<<2)>>2]+C(0))}k=k+1|0;i=(k|0)==(d|0);k=i?0:k;g=g+1|0;l=i+l|0;continue}}h=h-n|0;continue}break}v[e>>2]=k;v[f>>2]=l;b=1}return b}Vb(a,21);return 0}ca(7470,13164,1887,6512);L()}function Eaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ab-48|0;ab=e;m=v[a+16>>2];f=Vd(e+16|0);v[f+8>>2]=a+112;g=v[a+128>>2];v[f+16>>2]=g;n=f,o=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;k=v[a+8>>2];l=v[a+12>>2];if(g){n=f,o=Wf(k,l,g),v[n>>2]=o;v[f+4>>2]=db}g=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=b;a:while(1){if(d){b=v[e+12>>2];v[e+40>>2]=v[e+8>>2];v[e+44>>2]=0;h=b+m|0;b=v[f+16>>2];while(1)if((b|0)<=0){b=v[f+8>>2];j=v[b+8>>2];Lb(b,j,v[b+12>>2]);b=v[f+8>>2];j=v[b+4>>2];if(j){Bd(b,t[h+v[e+44>>2]|0]<<6);Ad(v[f+8>>2],j);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}d=d-1|0;h=v[a+32>>2];i=v[a+28>>2]+i|0;b=Uf(b,v[f+12>>2]);v[c>>2]=B(i>>12,b)+v[c>>2];g=g+h|0;v[c+4>>2]=v[c+4>>2]+B(b,g>>12);Lb(e+8|0,k,l);c=c+8|0;continue a}else{Bd(v[f+8>>2],t[h+v[e+44>>2]|0]<<6);Ad(v[f+8>>2],4);Lb(e+40|0,v[f>>2],v[f+4>>2]);b=b-1|0;continue}}break}v[a+40>>2]=g;v[a+36>>2]=i;v[a+20>>2]=i>>12;v[a+24>>2]=g>>12;b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;ab=e+48|0}function CM(a,b){var c=0,d=0,e=0,f=0;d=ab-16|0;ab=d;a:{b:{switch(w[a+480224|0]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=oia(c,c>>31,5e4,0);e=db;b=v[Pc(d+12|0,d+8|0)>>2];c=vc(pia(c,e,b,b>>31),db);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=oia(c,c>>31,1e4,0);e=db;b=v[Pc(d+12|0,d+8|0)>>2];c=vc(pia(c,e,b,b>>31),db);break a;case 1:break b}}f=60/(+y[b+44>>2]/1e4*(+(oia(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(db>>>0)*4294967296))*+y[a+24620>>2];c:{d:{c=a+484344|0;e=x[b+70>>1];if(!he(c,e)){break d}c=Rb(c,e);if(!(jc(v[c+24>>2],v[c+28>>2])^1)){break d}c=c+24|0;break c}c=a+480248|0}e=v[c>>2];c=v[c+4>>2];if(!jc(e,c)){f=f*+y[Fb(e,y[b+48>>2]%(nc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(D(f)<2147483648){c=~~f;break e}c=-2147483648}f=A[b+8>>3]+(f-+(c>>>0));A[b+8>>3]=f;if(f>=1){A[b+8>>3]=f+-1;c=c+1|0;break a}if(!(A[a+1074384>>3]<=-1)){break a}A[b+8>>3]=f+1;c=c-1|0}b=oia(v[a+480244>>2],0,c,0)+32768|0;a=db;a=b>>>0<32768?a+1|0:a;a=Fc((a&65535)<<16|b>>>16,a>>>16|0);ab=d+16|0;return a?a:1}function Tga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=ab-48|0;ab=c;i=a+484344|0;j=a+480280|0;while(1){a:{if(Hb(b,9)){e=c+44|0;Tn(b,e);d=jg(b);b:{if(!Ib(e,13972,4)){break b}if(!Ib(c+44|0,13628,4)){break b}if(!Ib(c+44|0,13804,4)){break b}if(!Ib(c+44|0,13809,4)){break b}if(Hb(b,d)){break a}}gg(b,8)}ab=c+48|0;return k|0}Md(c,b,d);e=bc(c+24|0,c);qb(c);d=j;c:{d:{e:{if(!Ib(c+44|0,13532,4)){while(1){if((d|0)==(i|0)){break c}v[22452]=0;f=T(148,e|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break e}t[d+8|0]=f;d=d+32|0;continue}}if(w[c+44|0]!=70){break d}f=w[c+45|0];h=(f|0)==88;f:{if(!h){if((f-48&255)>>>0>9){break d}d=t[c+46|0];if((d|0)>47){break f}break d}d=t[c+46|0];if((d|0)<48){break d}}if(d>>>0>57){break d}g=t[c+47|0];if((g|0)<48|(g|0)>57){break d}d=(g+(h?-16:B(f,100)+48|0)|0)+B(d,10)&255;if(d>>>0>249){break c}v[22452]=0;R(397,e|0,(B(d,160)+a|0)+906300|0);d=v[22452];v[22452]=0;if((d|0)!=1){break c}}a=P()|0;O()|0;qb(c+24|0);S(a|0);L()}if(Ib(c+44|0,13548,4)){break c}v[a+1074308>>2]=0;k=1}qb(c+24|0);continue}}function iW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-32|0;ab=d;f=Pb(a);a=0;a:{b:{c:{d:{e:{while(1){if((mv(b,c,a)|0)==-1){break b}e=mv(b,c,a);v[22452]=0;W(113,d|0,b|0,a|0,e-a|0);e=v[22452];v[22452]=0;if((e|0)!=1){v[22452]=0;R(114,d+16|0,d|0);e=v[22452];v[22452]=0;if((e|0)==1){break e}v[22452]=0;R(115,f|0,d+16|0);e=v[22452];v[22452]=0;if((e|0)==1){break d}pb(d+16|0);pb(d);a=mv(b,c,a)+ub(c)|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;pb(d+16|0)}pb(d);break a}f:{g:{h:{i:{j:{k:{if(jc(v[f>>2],v[f+4>>2])){v[22452]=0;W(113,d+16|0,b|0,a|0,-1);c=v[22452];v[22452]=0;if((c|0)==1){break j}c=d+16|0;e=ub(c);pb(c);if(!e){break k}}v[22452]=0;W(113,d|0,b|0,a|0,-1);a=v[22452];v[22452]=0;if((a|0)==1){break i}v[22452]=0;R(114,d+16|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}v[22452]=0;R(115,f|0,d+16|0);a=v[22452];v[22452]=0;if((a|0)==1){break g}pb(d+16|0);pb(d)}ab=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break f}a=P()|0;O()|0;pb(d+16|0)}pb(d)}Uc(f);S(a|0);L()}function h6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=C(0),s=0,t=0,u=0,w=0,x=C(0);a:{j=v[a+4272>>2];if(!j){break a}g=a+44|0;if(!Ih(g)){break a}m=Gd(g,0);n=Gd(g,1);o=dd(g,0);p=dd(g,1);q=d;while(1){if(q){e=z[n>>2];k=v[a+4256>>2];l=v[a+4268>>2];h=l<<1;i=Fb(k,h);f=z[m>>2];z[i>>2]=f;w=Fb(k,h|1),x=e,z[w>>2]=x;r=z[a+4276>>2];e=C(C(D(DJ(C(C(C(D(f))+C(D(e)))*C(536870912)),31,5)))*C(4.656612873077393e-10));e=C(C(C(r-e)*z[(e>=r?4236:4240)+a>>2])+e);z[a+4276>>2]=e;f=z[a+4244>>2];e=C(C(C(C(f-(e<f?f:e))*z[a+4248>>2])+C(.9999998807907104))*C(2147483648));b:{if(e<C(4294967296)&e>=C(0)){h=~~e>>>0;break b}h=0}s=((((v[a+4252>>2]+(l<<12)|0)+j|0)-1|0)/4096|0)%(j|0)<<1;f=z[Fb(k,s)>>2];i=h<<5;t=i;u=i|-2147483648;i=h>>>0<67108864;e=C(z[a+4232>>2]*C(C((i?t:u)>>>(i?31:32-(h>>>26|0)|0)>>>0)*C(4.656612873077393e-10)));z[o>>2]=f*e;w=p,x=C(z[Fb(k,s|1)>>2]*e),z[w>>2]=x;v[a+4268>>2]=((l?0:j)+l|0)-1;q=q-1|0;p=p+4|0;o=o+4|0;n=n+4|0;m=m+4|0;continue}else{ai(a,b,c,dd(g,0),dd(g,1),d)}break}}}function Hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=ab-16|0;ab=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+8>>2];p=v[a+12>>2];while(1){b=e;if(d){q=v[a+72>>2];r=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+64>>2];i=e;h=e>>31;e=Sb(b,-16777216,16776704);e=oia(i,h,e,e>>31);i=db;l=e;e=v[a+68>>2];f=Sb(f,-16777216,16776704);h=oia(e,e>>31,f,f>>31);e=l+h|0;f=db+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;e=v[a+60>>2];h=e;s=e>>31;m=v[g+12>>2]+n|0;e=t[m|0];l=i;i=((B(t[m+1|0]-e|0,v[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=oia(h,s,e,e>>31);e=l+h|0;f=db+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(k>>12,e)+v[c>>2];j=j+r|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Lb(g+8|0,o,p);e=f-(i&q)|0;c=c+8|0;d=d-1|0;f=b;continue}break}v[a+40>>2]=j;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+16|0}function TG(a,b,c,d,e){var f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=0;if(!(a&3)){k=a>>2;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){if((k|0)>0){b=d-4|0;g=z[b>>2];i=z[a>>2];j=z[d>>2];z[a>>2]=i+j;c=a-4|0;f=z[c>>2];z[c>>2]=f+z[b>>2];i=C(i-j);f=C(f-g);z[d>>2]=C(i*z[e>>2])-C(z[e+4>>2]*f);z[b>>2]=C(f*z[e>>2])+C(i*z[e+4>>2]);b=d-12|0;i=z[b>>2];c=a-8|0;f=z[c>>2];h=c;c=d-8|0;j=z[c>>2];z[h>>2]=f+j;h=a-12|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+32>>2])-C(z[e+36>>2]*g);z[b>>2]=C(g*z[e+32>>2])+C(f*z[e+36>>2]);b=d-20|0;i=z[b>>2];c=a-16|0;f=z[c>>2];h=c;c=d-16|0;j=z[c>>2];z[h>>2]=f+j;h=a-20|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+64>>2])-C(z[e+68>>2]*g);z[b>>2]=C(g*z[e+64>>2])+C(f*z[e+68>>2]);b=d-28|0;i=z[b>>2];c=a-24|0;f=z[c>>2];h=c;c=d-24|0;j=z[c>>2];z[h>>2]=f+j;h=a-28|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+96>>2])-C(z[e+100>>2]*g);z[b>>2]=C(g*z[e+96>>2])+C(f*z[e+100>>2]);k=k-1|0;d=d-32|0;a=a-32|0;e=e+128|0;continue}break}return}ca(15739,13164,2423,9182);L()}function hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=ab-16|0;ab=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){m=v[a+32>>2];e=(v[f+12>>2]<<1)+l|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(u[e-4>>1],u[h+2>>1])+B(u[e-6>>1],u[h>>1])|0)+B(u[e-2>>1],u[h+4>>1])|0)+B(u[e>>1],u[h+6>>1])|0)+B(u[e+2>>1],u[h+8>>1])|0)+B(u[e+4>>1],u[h+10>>1])|0)+B(u[e+6>>1],u[h+12>>1])|0)+B(u[e+8>>1],u[h+14>>1])|0)/32768|0;k=v[a+28>>2]+k|0;v[c>>2]=v[c>>2]+B(e,k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(e,j>>12);Lb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=j;v[a+36>>2]=k;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function Gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=ab-16|0;ab=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+8>>2];p=v[a+12>>2];while(1){b=e;if(d){q=v[a+72>>2];r=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+64>>2];i=e;h=e>>31;e=Sb(b,-16777216,16776704);e=oia(i,h,e,e>>31);i=db;l=e;e=v[a+68>>2];f=Sb(f,-16777216,16776704);h=oia(e,e>>31,f,f>>31);e=l+h|0;f=db+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;e=v[a+60>>2];h=e;s=e>>31;m=(v[g+12>>2]<<1)+n|0;e=u[m>>1];l=i;i=e+((B(u[m+2>>1]-e|0,v[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=oia(h,s,e,e>>31);e=l+h|0;f=db+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(k>>12,e)+v[c>>2];j=j+r|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Lb(g+8|0,o,p);e=f-(i&q)|0;c=c+8|0;d=d-1|0;f=b;continue}break}v[a+40>>2]=j;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+16|0}function E7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=ab-16|0;ab=f;e=ab-160|0;ab=e;d=e+24|0;c=d+56|0;g=is(c);v[d>>2]=73956;v[g>>2]=73976;v[d>>2]=73996;v[c>>2]=74016;h=c;c=d+4|0;jn(h,c);v[d>>2]=73956;v[g>>2]=73976;bs(c);v[c>>2]=73440;Bb(c+32|0);v[c+44>>2]=0;v[c+48>>2]=16;c=v[v[d>>2]-12>>2];v[22452]=0;g=ha(62)|0;h=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{if((h|0)==1){break f}v[22452]=0;U(63,e+16|0,c+(e+24|0)|0,g|0);c=v[22452];v[22452]=0;if((c|0)==1){break f}Nb(e+16|0);c=ab-16|0;ab=c;v[c+8>>2]=17;ab=c+16|0;Gl(v[v[d>>2]-12>>2]+d|0,v[c+8>>2]);i=A[b>>3];v[22452]=0;Va(64,d|0,+i)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}v[22452]=0;R(65,e|0,d|0);b=v[22452];v[22452]=0;if((b|0)==1){break d}v[22452]=0;R(61,f|0,e|0);b=v[22452];v[22452]=0;if((b|0)==1){break c}pb(e);Ro(d);ab=e+160|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;pb(e)}Ro(d);S(a|0);L()}v[22452]=0;R(58,a|0,f|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(f);ab=f+16|0;return}a=P()|0;O()|0;pb(f);S(a|0);L()}function zha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=ab-16|0;ab=f;ed(b,32);e=a+4|0;h=b,i=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[h>>2]=i;e=a+10|0;e=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[b+4>>2]=e;g=e;e=a+14|0;h=b,i=g+Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0,v[h+8>>2]=i;if(!(d?0:c)){c=a+46|0;c=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}v[b+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;d=Ab(w[d|0]|w[d+1|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}Tp(b,+(c|0)*.0006510416666666666);t[f+15|0]=w[a+9|0];t[f+14|0]=64;h=b,i=w[Qb(f+15|0,f+14|0)|0]<<2,u[h+30>>1]=i;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}ab=f+16|0}function dz(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a|0]=e;t[a+1|0]=e>>>8;t[a+2|0]=e>>>16;t[a+3|0]=e>>>24;t[a+4|0]=d;t[a+5|0]=d>>>8;t[a+6|0]=d>>>16;t[a+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[a+24|0]=e;t[a+25|0]=e>>>8;t[a+26|0]=e>>>16;t[a+27|0]=e>>>24;t[a+28|0]=d;t[a+29|0]=d>>>8;t[a+30|0]=d>>>16;t[a+31|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[a+16|0]=e;t[a+17|0]=e>>>8;t[a+18|0]=e>>>16;t[a+19|0]=e>>>24;t[a+20|0]=d;t[a+21|0]=d>>>8;t[a+22|0]=d>>>16;t[a+23|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);e=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+8|0]=e;t[a+9|0]=e>>>8;t[a+10|0]=e>>>16;t[a+11|0]=e>>>24;t[a+12|0]=d;t[a+13|0]=d>>>8;t[a+14|0]=d>>>16;t[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function k_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=ab-32|0;ab=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=eb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}zc(g,d);v[22452]=0;b=T(1111,g|0)|0;a=v[22452];v[22452]=0;d:{e:{f:{g:{if((a|0)!=1){Nb(g);zc(g,d);v[22452]=0;a=T(1112,g|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break g}Nb(g);v[22452]=0;R(1113,g|0,a|0);d=v[22452];v[22452]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[22452]=0;R(1114,g|12,a|0);a=v[22452];v[22452]=0;if((a|0)==1){break f}v[22452]=0;d=g+24|0;a=qa(1115,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Oc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Nb(g);break d}b=P()|0;O()|0;Nb(g);break d}b=P()|0;O()|0;Oc(g);break d}b=P()|0;O()|0;while(1){d=Oc(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}ab=g+32|0;return b|0}function iba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=ab-16|0;ab=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){m=v[a+32>>2];e=v[f+12>>2]+l|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(t[e-2|0],u[h+2>>1])+B(t[e-3|0],u[h>>1])|0)+B(t[e-1|0],u[h+4>>1])|0)+B(t[e|0],u[h+6>>1])|0)+B(t[e+1|0],u[h+8>>1])|0)+B(t[e+2|0],u[h+10>>1])|0)+B(t[e+3|0],u[h+12>>1])|0)+B(t[e+4|0],u[h+14>>1])<<8)/32768|0;k=v[a+28>>2]+k|0;v[c>>2]=v[c>>2]+B(e,k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(e,j>>12);Lb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=j;v[a+36>>2]=k;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function w_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=ab-32|0;ab=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=eb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}zc(g,d);v[22452]=0;b=T(18,g|0)|0;a=v[22452];v[22452]=0;d:{e:{f:{g:{if((a|0)!=1){Nb(g);zc(g,d);v[22452]=0;a=T(1094,g|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break g}Nb(g);v[22452]=0;R(1095,g|0,a|0);d=v[22452];v[22452]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[22452]=0;R(1096,g|12,a|0);a=v[22452];v[22452]=0;if((a|0)==1){break f}v[22452]=0;d=g+24|0;a=qa(1097,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=pb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Nb(g);break d}b=P()|0;O()|0;Nb(g);break d}b=P()|0;O()|0;pb(g);break d}b=P()|0;O()|0;while(1){d=pb(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}ab=g+32|0;return b|0}function Ej(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;o(+a);b=j(1)|0;e=j(0)|0;f=b>>>20&2047;a:{if(f-969>>>0>=63){if(f>>>0<=968){return a+1}b:{if(f>>>0<1033){break b}c=0;if(!e&(b|0)==-1048576){break a}if((f|0)==2047){return a+1}if((b|0)>0|(b|0)>=0){return ar(3.105036184601418e231)}if(b>>>0<3230714880){break b}return ar(1.2882297539194267e-231)}b=b<<1|e>>>31;e=e<<1;f=(b|0)==-2129002496&(e|0)!=0|b>>>0>2165964800?0:f}c=A[177];g=c+a;a=a-(g-c);c=a*a;h=c*c*(a*A[182]+A[181]);c=c*(a*A[180]+A[179]);a=a*A[178];o(+g);j(1)|0;e=j(0)|0;d=e<<4&2032;a=h+(c+(a+A[d+1464>>3]));d=d+1472|0;i=v[d>>2];b=v[d+4>>2];d=i;i=0;d=d+i|0;b=(e<<13)+b|0;b=d>>>0<i>>>0?b+1|0:b;if(!f){c:{if(!(e&-2147483648)){l(0,d|0);l(1,b+-1048576|0);c=+n();a=c*a+c;a=a+a;break c}e=ab-16|0;l(0,d|0);l(1,b+1071644672|0);c=+n();g=c*a;a=g+c;if(a<1){b=e;v[b+8>>2]=0;v[b+12>>2]=1048576;A[b+8>>3]=A[b+8>>3]*2.2250738585072014e-308;h=a+1;a=h+(g+(c-a)+(a+(1-h)))+-1;a=a==0?0:a}a=a*2.2250738585072014e-308}return a}l(0,d|0);l(1,b|0);c=+n();c=c*a+c}return c}function aw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;p=a;i=ab-1040|0;ab=i;q=v[114934];a:{b:{a=i+16|0;l=x[((b>>>0>149?0:b)<<1)+87344>>1]+85520|0;c=v[v[114936]+20>>2];if(c){j=v[c+4>>2];c=v[c>>2];e=v[c>>2]+1794895138|0;h=tl(v[c+8>>2],e);f=tl(v[c+12>>2],e);d=tl(v[c+16>>2],e);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|f)&3|(k>>>0<=f>>>0|d>>>0>=k>>>0)){break c}r=d>>>2|0;s=f>>>2|0;f=0;while(1){k=h>>>1|0;m=k+f|0;n=m<<1;d=c+(n+s<<2)|0;o=tl(v[d>>2],e);d=tl(v[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|w[c+(d+o|0)|0]){break c}d=Zi(l,c+d|0);if(!d){f=c+(r+n<<2)|0;h=tl(v[f>>2],e);e=tl(v[f+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break c}g=w[c+(e+h|0)|0]?0:c+e|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;f=d?f:m;continue}}}g=g?g:l;c=Pf(g);d:{if(c>>>0>=1024){gc(a,g,1023);t[a+1023|0]=0;g=68;break d}gc(a,g,c+1|0);g=0}if(g){if((g|0)!=28){break b}a=21598}break a}ya();L()}if(!w[a|0]){v[i>>2]=b;a=i+16|0;Wv(a,1024,12981,i)}v[114934]=q;Mb(p,a);ab=i+1040|0}function tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=ab-16|0;ab=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];e=v[a+44>>2];o=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;p=v[a+8>>2];q=v[a+12>>2];while(1){b=e;if(d){r=v[a+72>>2];e=v[a+64>>2];g=e;i=e>>31;e=Sb(b,-16777216,16776704);e=oia(g,i,e,e>>31);j=db;l=e;e=v[a+60>>2];k=e;s=e>>31;e=(v[h+12>>2]<<1)+o|0;g=v[h+8>>2]>>>21&2040;i=(((B(u[e>>1],u[g+39874>>1])+B(u[e-2>>1],u[g+39872>>1])|0)+B(u[e+2>>1],u[g+39876>>1])|0)+B(u[e+4>>1],u[g+39878>>1])|0)/16384<<8;e=i;k=oia(k,s,e,e>>31);g=l+k|0;e=db+j|0;e=g>>>0<k>>>0?e+1|0:e;l=g;g=v[a+68>>2];f=Sb(f,-16777216,16776704);j=oia(g,g>>31,f,f>>31);g=l+j|0;f=db+e|0;f=g>>>0<j>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,n)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,m);Lb(h+8|0,p,q);e=f-(r&i)|0;c=c+8|0;d=d-1|0;f=b;continue}break}v[a+48>>2]=f;v[a+44>>2]=b;b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+16|0}function zj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=ab-32|0;ab=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;zc(b,d);c=0;v[22452]=0;j=T(1111,b|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){Nb(i+8|0);v[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(wk(i+24|0,i+16|0)){break b}c:{if((Jm(j,v[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}d:{e:{b=Jm(j,v[c>>2]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+8|0)==(h|0)){break b}k=b;b=Jm(j,v[g+8>>2])}l=i,m=eb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+8|0;break c}if(xk(j,8192,v[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(xk(j,8192,v[g>>2])){continue}}break}while(1){if(!ur(i+24|0,i+16|0)){break c}if(!xk(j,8192,yk(v[i+24>>2]))){break c}Sm(i+24|0);continue}}if((hl(j,yk(v[i+24>>2]))|0)==(hl(j,v[g>>2])|0)){g=g+4|0;Sm(i+24|0);break c}v[e>>2]=4}c=v[e>>2];continue}break}v[e>>2]=4}if(wk(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}ab=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Nb(i+8|0);S(a|0);L()}function cf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ab-80|0;ab=d;c=v[a+28>>2];Im(v[v[c>>2]-12>>2]+c|0,0);if(!Vc(a,4)){Hv(a)}a:{if(!v[a+4>>2]){break a}if(Vc(a,6)){break a}if(Vc(a,7)){break a}f=v[a+28>>2];c=v[a+84>>2];g=B(v[a+20>>2],v[a+4>>2]);e=g+v[a+80>>2]|0;c=Zg(d- -64|0,e,e>>>0<g>>>0?c+1|0:c);e=v[c+12>>2];v[d+24>>2]=v[c+8>>2];v[d+28>>2]=e;e=v[c+4>>2];v[d+16>>2]=v[c>>2];v[d+20>>2]=e;yj(f,d+16|0)}e=0;b:{if(!Vc(a,5)){break b}f=Cg(v[a+44>>2],v[a+48>>2]);c=0;while(1){if((c|0)==(f|0)){break b}g=(v[a+96>>2]+c>>>0)%(f>>>0)|0;i=Hc(v[a+44>>2],g);h=v[i>>2];c:{j=v[a+32>>2];if(Ic(j,v[a+36>>2])>>>0<=h>>>0){break c}h=Mm(d+48|0,Cb(j,h),x[i+12>>1]);i=Jv(b,h);yb(h);if(!i){break c}v[a+96>>2]=(g+1>>>0)%(f>>>0);e=Hc(v[a+44>>2],g);b=v[e+4>>2];if(!b){break b}f=v[a+28>>2];c=v[a+12>>2];e=b+v[a+8>>2]|0;c=e>>>0<b>>>0?c+1|0:c;b=Zg(d+32|0,e,c);c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;yj(f,d);e=Hc(v[a+44>>2],g);break b}c=c+1|0;continue}}ab=d+80|0;return e}function tc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{f=ab-48|0;ab=f;d=d&255;e=c-(((d|0)==1|(d|0)==4)&(c|0)!=0)|0;c=Bb(a);b:{c:{d:{e:{f:{g:{h:{if((d-1&255)>>>0<=1){t[f+32|0]=0;a=fi(b,b+e|0,f+32|0);v[22452]=0;Y(53,c|0,b|0,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}if((d-3&255)>>>0>1){break h}v[22452]=0;b=Y(53,c|0,b|0,b+e|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break g}d=kd(b);e=Ff(b);g=kd(b);a=ab-32|0;ab=a;v[a+16>>2]=e;v[a+24>>2]=d;v[a+8>>2]=g;while(1){if(aj(a+24|0,a+16|0)){d=a+8|0;e=a+24|0;g=t[v[e>>2]];t[v[d>>2]]=g?g:32;Fe(e);Fe(d);continue}break}ab=a+32|0;v[22452]=0;d=Q(54,f+16|0,b|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break f}v[22452]=0;e=Q(55,f|0,17769)|0;a=v[22452];v[22452]=0;if((a|0)==1){break e}v[22452]=0;U(56,f+32|0,d|0,e|0);a=v[22452];v[22452]=0;if((a|0)==1){break d}a=f+32|0;tb(b,a);pb(a);pb(e);pb(d)}ab=f+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;pb(e)}pb(d)}pb(c);S(a|0);L()}}function MO(a,b,c){var d=0,e=0;d=w[a|0]&15;t[a|0]=w[d+27072|0];a:{b:{c:{switch(d|0){case 0:if(w[b|0]?c>>>0>=51:0){break b}t[a|0]=0;return;case 5:d:{e:{d=w[b|0];e=d&15;f:{if(!((e|0)!=2&(d&240)!=32)){t[a|0]=20;d=159;t[b|0]=159;break f}if((e|0)==12){break e}}if(c>>>0<51){break b}if((d&240)==192){break d}break b}if(c>>>0<51){break b}}t[a|0]=25;t[b|0]=0;return;case 7:if(c>>>0>51){break b}t[a|0]=0;return;case 10:a=w[b|0]&240;if(!a){break b}t[b|0]=a;return;case 11:t[b|0]=B(w[b|0]&15,17);return;case 12:t[b|0]=w[b|0]>>>2;return;case 13:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);return;case 14:g:{switch((w[b|0]>>>4|0)-1|0){case 0:t[a|0]=2;break a;case 1:t[a|0]=3;break a;case 7:if(c>>>0<52){break b}t[a|0]=20;t[b|0]=w[b|0]&15|96;return;case 8:t[a|0]=15;t[b|0]=w[b|0]&15;return;case 9:t[a|0]=11;t[b|0]=w[b|0]<<4|15;return;case 10:t[a|0]=11;break a;case 11:case 12:break g;default:break b}}t[a|0]=20;return;case 15:break c;default:break b}}if(w[b|0]<48){break b}t[a|0]=17}return}t[b|0]=w[b|0]|240}function i4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22452]=0;Z(949,a|0);e=v[22452];v[22452]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[22452]=0;Z(925,b|0);e=v[22452];v[22452]=0;if((e|0)==1){break e}e=0;v[22452]=0;Z(950,c|0);f=v[22452];v[22452]=0;if((f|0)==1){break e}a=Jb(c,0,d);if(!w[b|0]){break b}if(Zi(b,7184)|(d|0)!=8){break d}v[a+4>>2]=951;v[a>>2]=952;break c}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,12250,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();return 0}if(!(Zi(b,11215)|(d|0)!=64)){v[a+60>>2]=953;v[a+56>>2]=954;v[a+52>>2]=955;v[a+48>>2]=956;v[a+44>>2]=957;v[a+40>>2]=958;v[a+36>>2]=959;v[a+32>>2]=960;v[a+28>>2]=961;v[a+24>>2]=962;v[a+20>>2]=963;v[a+16>>2]=964;v[a+12>>2]=965;v[a+8>>2]=966;v[a+4>>2]=967;v[a>>2]=968;break c}if(Zi(b,15101)|(d|0)!=24){break b}v[a+20>>2]=969;v[a+16>>2]=970;v[a+12>>2]=971;v[a+8>>2]=972;v[a+4>>2]=973;v[a>>2]=974}e=1}return e|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function PT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=ab-32|0;ab=h;e=b;b=v[a>>2];b=(fm(e,wb(b))<<1)+b|0;a:{f=v[a+4>>2];b:{if(f>>>0<y[vb(a)>>2]){if((b|0)==(f|0)){d=ab-16|0;ab=d;a=Ai(d,a,1);eq(v[a+4>>2],c);v[a+4>>2]=v[a+4>>2]+2;dc(a);ab=d+16|0;break b}i=ab-16|0;ab=i;j=v[a+4>>2];d=(j-(b+2|0)|0)+b|0;k=Ai(i,a,f-d>>1);g=v[k+4>>2];e=d;while(1){if(e>>>0>=f>>>0){dc(k);while(1){if((b|0)!=(d|0)){d=d-2|0;j=HT(j-2|0,d);continue}break}ab=i+16|0}else{eq(g,e);g=g+2|0;v[k+4>>2]=g;e=e+2|0;continue}break}c=b>>>0<=c>>>0?((y[a+4>>2]>c>>>0)<<1)+c|0:c;a=w[c|0];t[b+1|0]=w[c+1|0];t[b|0]=a;break b}d=vb(a);d=qj(h+8|0,rj(a,wc(v[a>>2],f)+1|0),b-v[a>>2]>>1,d);v[22452]=0;R(286,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break a}c=v[d+4>>2];f=d+4|0;Gn(v[a>>2],b,f);g=v[a+4>>2];e=d+8|0;while(1){if((b|0)!=(g|0)){eq(v[e>>2],b);v[e>>2]=v[e>>2]+2;b=b+2|0;continue}break}cc(a,f);cc(a+4|0,e);cc(vb(a),ic(d));v[d>>2]=v[d+4>>2];b=c;Bi(d)}wb(b);ab=h+32|0;return}a=P()|0;O()|0;Bi(d);S(a|0);L()}function Aj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=ab-32|0;ab=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;zc(b,d);c=0;v[22452]=0;j=T(18,b|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){Nb(i+8|0);v[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(Cj(i+24|0,i+16|0)){break b}c:{if((Km(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=Km(j,t[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=Km(j,t[g+2|0])}l=i,m=eb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break c}if(_g(j,8192,t[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(_g(j,8192,t[g|0])){continue}}break}while(1){if(!Eo(i+24|0,i+16|0)){break c}if(!_g(j,8192,Ak(v[i+24>>2]))){break c}vl(i+24|0);continue}}if((Qv(j,Ak(v[i+24>>2]))|0)==(Qv(j,t[g|0])|0)){g=g+1|0;vl(i+24|0);break c}v[e>>2]=4}c=v[e>>2];continue}break}v[e>>2]=4}if(Cj(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}ab=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Nb(i+8|0);S(a|0);L()}function oO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0;h=ab-16|0;ab=h;if(hj(v[a+656>>2])){e=w[(Kc(w[a+797|0])?797:799)+a|0];rb(h+8|0,d+1074312|0,34);if(!(!sb(v[v[h+8>>2]>>2],v[h+12>>2])|!e|e>>>0>120)){e=w[Cb(v[a+656>>2]+108|0,e-1|0)|0]}l=C(C(v[a+704>>2])*b);d=v[v[a+656>>2]+44>>2];f=(c+e<<16)-3997696>>16;a:{b:{c=v[a+852>>2]+u[a+772>>1]|0;if(c){g=v[d+36>>2];if(g){break b}}b=Il(d,c+f<<16>>16);break a}k=g+1|0;i=ux(c,k);e=ln(c,k);b=C(1);j=u[d+28>>1];c=f+i<<16>>16;c:{if((j|0)>(c|0)){break c}f=v[d+4>>2];if((c|0)>(nc(f,v[d+8>>2])+j<<16)-65536>>16){break c}if(!e){b=z[Fb(f,c-j|0)>>2];break a}d:{e:{f:{switch(x[d>>1]-1|0){case 2:g=v[d+16>>2];if(!nc(g,v[d+20>>2])){break e}b=z[Fb(g,e-1|0)>>2];break d;case 0:break f;default:break e}}i=v[d+16>>2];if(!nc(i,v[d+20>>2])){break e}b=z[Fb(i,(e+B(g,ln(c,x[d+30>>1])<<16>>16)|0)-1|0)>>2];break d}b=fe(C(Il(d,(c<<16)+65536>>16)/Il(d,c)),C(C(e|0)/C(k|0)))}b=C(b*z[Fb(f,c-j|0)>>2])}}m=a,n=gj(C(C(l*b)*C(16))),v[m+700>>2]=n}ab=h+16|0}function Hfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=ab-432|0;ab=d;qc(b);fA(b,d+376|0,d+296|0,d+8|0);f=d+408|0;if(Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){e=w[d+427|0]+1|0}else{e=1}m=d,n=pi(e),t[m+4|0]=n;i=w[Qb(26800,d+4|0)|0];t[d+7|0]=i;u[d+4>>1]=4;f=d+392|0;k=d+291|0;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=d+8|0;e=Ab(w[e|0]|w[e+1|0]<<8)<<16>>16;if(!((e|0)<0|w[k|0]>63)){g=e&65535;e=0;while(1){if((e|0)==(g|0)){c:{e=d+296|0;g=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));if(g>>>0>l>>>0){if(Nc(b,g)){break c}}t[d+7|0]=h+1;break b}}else{d:{if(!Nc(b,Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))+(e<<2)|0)){break d}if(!Nc(b,hm(b))){break d}e:{if(!c){j=ue(b);break e}j=hq(b)}u[d+2>>1]=j;m=d,n=x[Ne(d+4|0,d+2|0)>>1],u[m+4>>1]=n}e=e+1|0;continue}break}l=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));fA(b,d+376|0,d+296|0,d+8|0);h=h+1|0;continue}break}Nu(a);break a}u[a>>1]=x[d+4>>1];t[a+2|0]=w[d+7|0]}ab=d+432|0}
function Ew(a,b,c,d){var e=0,f=0,g=0,h=0;g=ab-32|0;ab=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=d<<4|c>>>28;f=c<<4|b>>>28;c=e;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){e=c+1073741824|0;a=f+1|0;e=a?e:e+1|0;f=a;break a}e=c+1073741824|0;if(b^134217728|a){break a}b=f&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){e=c;c=d<<4|e>>>28;f=e<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;zf(g+16|0,a,b,c,e,h-15233|0);Yl(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;b=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){a=f+1|0;e=a?e:e+1|0;f=a;break a}if(a^134217728|b){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}ab=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function Raa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=ab-16|0;ab=f;h=v[a+40>>2];i=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){g=v[f+8>>2];m=((((v[f+12>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+j|0;e=(((g>>>16|0)+4&131064)<<1)+b|0;n=u[e+38>>1];o=u[e+36>>1];p=u[e+34>>1];q=u[e+32>>1];r=u[e+30>>1];s=u[e+28>>1];t=u[e+26>>1];w=u[e+24>>1];g=0;while(1){if((g|0)!=2){e=(g<<1)+m|0;v[(g<<2)+f>>2]=(((((B(u[e+8>>1],p)+B(u[e+4>>1],q)|0)+B(u[e+12>>1],o)|0)+B(u[e+16>>1],n)|0)/2|0)+((((B(u[e-8>>1],t)+B(u[e-12>>1],w)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)/2|0)|0)/16384;g=g+1|0;continue}break}e=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[f>>2],i>>12);h=e+h|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],h>>12);Lb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=h;v[a+36>>2]=i;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=ab-16|0;ab=h;f=v[a+48>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+44>>2];m=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;n=v[a+8>>2];o=v[a+12>>2];while(1){b=e;if(d){p=v[a+72>>2];e=v[a+64>>2];g=e;j=e>>31;e=Sb(b,-16777216,16776704);e=oia(g,j,e,e>>31);g=db;j=e;e=v[a+68>>2];f=Sb(f,-16777216,16776704);i=oia(e,e>>31,f,f>>31);e=j+i|0;f=db+g|0;f=e>>>0<i>>>0?f+1|0:f;j=e;e=v[a+60>>2];i=e;q=e>>31;e=v[h+12>>2]+m|0;g=v[h+8>>2]>>>21&2040;g=(((B(t[e|0],u[g+39874>>1])+B(t[e-1|0],u[g+39872>>1])|0)+B(t[e+1|0],u[g+39876>>1])|0)+B(t[e+2|0],u[g+39878>>1])<<8)/16384<<8;e=g;i=oia(i,q,e,e>>31);e=j+i|0;f=db+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,l)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,k);Lb(h+8|0,n,o);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}v[a+48>>2]=f;v[a+44>>2]=b;b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+16|0}function Tk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Bb(a);d=ub(c);v[22452]=0;R(48,a|0,d|0);d=v[22452];v[22452]=0;d:{if((d|0)!=1){e:{while(1){if(ub(c)>>>0>b>>>0){d=t[oc(c,b)|0];f:{if((d|0)>=0){v[22452]=0;R(49,a|0,d&255);d=v[22452];v[22452]=0;if((d|0)!=1){break f}break e}v[22452]=0;R(49,a|0,65533);d=v[22452];v[22452]=0;if((d|0)==1){break e}}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Bb(a);d=ub(c);v[22452]=0;R(48,a|0,d|0);d=v[22452];v[22452]=0;g:{if((d|0)!=1){while(1){if(ub(c)>>>0<=b>>>0){break g}d=w[oc(c,b)|0];v[22452]=0;R(49,a|0,d|0);d=v[22452];v[22452]=0;if((d|0)!=1){b=b+1|0;continue}break}}break a}return;case 3:op(a,c,49744);return;case 5:op(a,c,50768);return;case 4:op(a,c,51792);return;case 6:op(a,c,52816);return;default:a=aa(8)|0;v[22452]=0;Q(45,a|0,11013)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=P()|0;O()|0;ba(a|0);S(b|0);L();case 0:break c}}ZM(a,c);return}ia(a|0,88528,24);L()}b=P()|0;O()|0;Oc(a);S(b|0);L()}function Ho(a,b,c,d,e,f){var g=C(0),h=0,i=C(0),j=0,k=C(0),l=C(0);b=(c<<2)+b|0;c=b+(d<<2)|0;a=a>>2;d=f<<2;while(1){if((a|0)>0){f=c-4|0;i=z[f>>2];k=z[b>>2];l=z[c>>2];z[b>>2]=k+l;h=b-4|0;g=z[h>>2];z[h>>2]=g+z[f>>2];k=C(k-l);g=C(g-i);z[c>>2]=C(k*z[e>>2])-C(z[e+4>>2]*g);z[f>>2]=C(g*z[e>>2])+C(k*z[e+4>>2]);f=c-12|0;k=z[f>>2];h=b-8|0;g=z[h>>2];j=h;h=c-8|0;l=z[h>>2];z[j>>2]=g+l;j=b-12|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=d+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);f=c-20|0;k=z[f>>2];h=b-16|0;g=z[h>>2];j=h;h=c-16|0;l=z[h>>2];z[j>>2]=g+l;j=b-20|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=d+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);f=c-28|0;k=z[f>>2];h=b-24|0;g=z[h>>2];j=h;h=c-24|0;l=z[h>>2];z[j>>2]=g+l;j=b-28|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=d+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);e=d+e|0;a=a-1|0;c=c-32|0;b=b-32|0;continue}break}}function Lha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=ab-32|0;ab=h;e=b;b=v[a>>2];b=TA(e,wb(b))+b|0;e=US(c,d);a:{if((e|0)<=0){break a}f=v[vb(a)>>2];g=v[a+4>>2];if((f-g|0)>=(e|0)){v[h+8>>2]=d;k=g-b|0;if((k|0)<(e|0)){v[h+8>>2]=c;XS(h+8|0,k);f=v[h+8>>2];l=ab-16|0;ab=l;i=zk(l,a,e-k|0);j=ab-16|0;ab=j;v[j+8>>2]=f;while(1){if(Tb(f,d)){Bj(v[i+4>>2],w[f|0]);Fe(j+8|0);v[i+4>>2]=v[i+4>>2]+1;f=v[j+8>>2];continue}break}ab=j+16|0;dc(i);ab=l+16|0;if((k|0)<=0){break a}}f=ab-16|0;ab=f;j=v[a+4>>2];d=(j-(b+e|0)|0)+b|0;i=zk(f,a,g-d|0);e=v[i+4>>2];a=d;while(1){if(a>>>0>=g>>>0){dc(i);Wp(b,d,j);ab=f+16|0}else{Bj(e,w[a|0]);e=e+1|0;v[i+4>>2]=e;a=a+1|0;continue}break}fk(c,v[h+8>>2],b);break a}f=vb(a);g=xl(h+8|0,ul(a,Ic(v[a>>2],g)+e|0),b-v[a>>2]|0,f);e=ab-32|0;ab=e;v[e+24>>2]=c;c=Dv(e+8|0,g+8|0,US(c,d));while(1){d=v[c>>2];if((d|0)!=v[c+4>>2]){Bj(d,w[v[e+24>>2]]);v[c>>2]=v[c>>2]+1;Fe(e+24|0);continue}break}xd(c);ab=e+32|0;b=TS(a,g,b);wl(g)}wb(b);ab=h+32|0}function Mf(a){var b=0;a:{b:{switch(w[a+3|0]){case 0:if(!w[a+5|0]){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 14:t[a+3|0]=19;return;case 15:if(w[a+5|0]<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=37;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 37:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function Dx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=ab-16|0;ab=e;d=w[a+2|0];if(!(!d|(d|0)==255)){v[e+12>>2]=d+1;v[e+8>>2]=10;Wg(b,v[jd(e+12|0,e+8|0)>>2]);i=w[a+3|0];t[b+15|0]=i;t[b+16|0]=i;j=w[a+4|0];t[b+13|0]=j;k=w[a+5|0];t[b+14|0]=k;h=511;a:{b:{switch(c-1|0){case 1:f=4096;h=128;break a;case 0:break b;default:break a}}f=32768;h=1024}n=h>>>1|f;c=v[b>>2];f=0;c:{while(1){if(Td(b)>>>0<=f>>>0){d:{c=w[b+12|0]&-2|t[a|0]&1;t[b+12|0]=c;if(w[a|0]&2){break d}c=c&251;break c}}else{l=Fb(c,f);m=(f<<2)+a|0;d=m+6|0;g=(w[d|0]|w[d+1|0]<<8)>>>4|0;u[l>>1]=g;e:{f:{if(!f){g=0;d=0;break f}d=x[Fb(c,f-1|0)>>1];if(g>>>0>=d>>>0){break e}g=d+1|0;d=f}o=Fb(c,d),p=g,u[o>>1]=p}d=m+8|0;v[e+12>>2]=(((w[d|0]|w[d+1|0]<<8)<<16>>16)+n|0)/(h|0);v[e+8>>2]=0;v[e+4>>2]=64;o=l,p=v[nj(e+12|0,e+8|0,e+4|0)>>2],t[o+2|0]=p;f=f+1|0;continue}break}c=c&-5|(Td(b)>>>0>=i>>>0)<<2}t[b+12|0]=c;if(j>>>0<=k>>>0?w[a|0]&4:0){a=c&-3|(Td(b)>>>0>=j>>>0)<<1}else{a=c&253}t[b+12|0]=a}ab=e+16|0}function YV(a){a=a|0;var b=0,c=0,d=0,e=0;b=ab+-64|0;ab=b;e=Bb(a);v[22452]=0;a=ha(117)|0;c=v[22452];v[22452]=0;a:{b:{if((c|0)==1){break b}c:{d:{if(!a){break d}v[22452]=0;c=Q(1,b+32|0,8934)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}v[22452]=0;a=ha(117)|0;d=v[22452];v[22452]=0;e:{f:{g:{h:{if((d|0)==1){break h}v[22452]=0;v[b+12>>2]=a;R(123,b+16|0,b+12|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}v[22452]=0;U(2,b+48|0,c|0,b+16|0);a=v[22452];v[22452]=0;if((a|0)==1){break g}d=b+48|0;a=tb(e,d);pb(d);pb(b+16|0);pb(c);v[22452]=0;c=ha(119)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}if(!c){break e}v[22452]=0;Q(124,a|0,17443)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break e}break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;pb(b+16|0)}pb(c);break a}v[22452]=0;c=ha(118)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}if(!c){break d}v[22452]=0;Q(124,a|0,16745)|0;a=v[22452];v[22452]=0;if((a|0)==1){break b}}ab=b- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}pb(e);S(a|0);L()}function Tha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ab-2608|0;ab=d;ZA(d,a);v[d+1060>>2]=0;v[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){t[a+4|0]=0;u[a>>1]=0;u[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}v[22452]=0;Z(313,d|0);a=v[22452];v[22452]=0;a:{b:{if((a|0)!=1){if((u[d+1068>>1]|u[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(f|0)){break a}v[22452]=0;i=Q(155,d|0,1)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}a=0;d:{while(1){v[22452]=0;j=Q(155,d|0,1)|0;e=v[22452];v[22452]=0;if((e|0)==1){break d}a=u[(d+B(a,6)|0)+(j?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+B(a,6)|0;g=w[e+1072|0];if(u[e+1068>>1]<0){break e}if(u[e+1070>>1]>=0){continue}}break}g=(i?-1:0)^g;h=(h&255)+(g&255)|0;t[b+f|0]=h;f=f+1|0;continue}break}a=V(30480)|0;break b}a=V(30480)|0;break b}a=V(30480)|0}if((O()|0)==(fa(30480)|0)){_(a|0)|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0}qb(d);S(a|0);L()}a=Yp(d);qb(d);ab=d+2608|0;return a|0}function cV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=ab-96|0;ab=d;qc(b);ro(a);a:{if(!Vu(b,d+56|0)){break a}if(!VC(d+56|0)){break a}b:{if(!c){break b}c=d+56|4;if(!Hb(b,Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))-28|0)){break a}hv(a);g=d,h=gv(),v[g+32>>2]=h;e=d+32|0;fv(vj(v[a+4>>2])+32|0,e);Pq(e);f=v[vj(v[a+4>>2])+32>>2];v[22452]=0;R(182,e|0,b|0);b=v[22452];v[22452]=0;c:{if((b|0)==1){break c}e=v[d+32>>2];c=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));b=w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24);v[22452]=0;c=da(183,e|0,c-28|0,f|0,Wb(b)|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break c}e=0;if(!c){break a}de(d+16|0,v[f>>2],v[f+4>>2]);Gg(d+24|0,v[d+16>>2],v[d+20>>2]);b=Vd(d+8|0);b=Nq(d+32|0,v[d+24>>2],v[d+28>>2],v[b>>2],v[b+4>>2]);Mc(vj(v[a+4>>2])+12|0,b);qb(b);break b}b=Ca(88408,26072)|0;a=O()|0;d:{if((fa(88408)|0)==(a|0)){break d}if((fa(26072)|0)==(a|0)){break d}S(b|0);L()}_(b|0)|0;$();e=0;break a}e=1}ab=d+96|0;return e|0}function eR(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{d=ab+-64|0;ab=d;h=v[c>>2]&2?16:10;f=ab-32|0;ab=f;e=ze(f+16|0,1,0);b:{c:{d:{while(1){g=Eb(e);Yw(f+8|0,g,ub(e)+g|0,v[b>>2],h);if(!v[f+12>>2]){break d}g=If(ub(e));v[22452]=0;R(59,e|0,g|0);g=v[22452];v[22452]=0;if((g|0)!=1){continue}break}break c}b=v[f+8>>2];h=Eb(e);v[22452]=0;R(60,e|0,b-h|0);b=v[22452];v[22452]=0;e:{if((b|0)!=1){v[22452]=0;R(61,d|0,e|0);b=v[22452];v[22452]=0;if((b|0)!=1){break e}break c}break c}pb(e);ab=f+32|0;break b}a=P()|0;O()|0;pb(e);S(a|0);L()}b=d+16|0;Ik(b,d,v[c>>2]);e=v[c+4>>2];f=v[c>>2];v[22452]=0;W(75,d+32|0,b|0,f|0,e|0);b=v[22452];v[22452]=0;f:{g:{h:{i:{if((b|0)!=1){v[22452]=0;U(76,d+48|0,d+32|0,c|0);b=v[22452];v[22452]=0;if((b|0)==1){break i}v[22452]=0;R(58,a|0,d+48|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}pb(d+48|0);pb(d+32|0);pb(d+16|0);pb(d);ab=d- -64|0;break a}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;pb(d+48|0)}pb(d+32|0)}pb(d+16|0);pb(d);S(a|0);L()}}function Su(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{d=ab+-64|0;ab=d;h=v[c>>2]&2?16:10;f=ab-32|0;ab=f;e=ze(f+16|0,1,0);b:{c:{d:{while(1){g=Eb(e);OI(f+8|0,g,ub(e)+g|0,v[b>>2],h);if(!v[f+12>>2]){break d}g=If(ub(e));v[22452]=0;R(59,e|0,g|0);g=v[22452];v[22452]=0;if((g|0)!=1){continue}break}break c}b=v[f+8>>2];h=Eb(e);v[22452]=0;R(60,e|0,b-h|0);b=v[22452];v[22452]=0;e:{if((b|0)!=1){v[22452]=0;R(73,d|0,e|0);b=v[22452];v[22452]=0;if((b|0)!=1){break e}break c}break c}pb(e);ab=f+32|0;break b}a=P()|0;O()|0;pb(e);S(a|0);L()}b=d+16|0;Ik(b,d,v[c>>2]);e=v[c+4>>2];f=v[c>>2];v[22452]=0;W(77,d+32|0,b|0,f|0,e|0);b=v[22452];v[22452]=0;f:{g:{h:{i:{if((b|0)!=1){v[22452]=0;U(78,d+48|0,d+32|0,c|0);b=v[22452];v[22452]=0;if((b|0)==1){break i}v[22452]=0;R(72,a|0,d+48|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}pb(d+48|0);pb(d+32|0);pb(d+16|0);pb(d);ab=d- -64|0;break a}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;pb(d+48|0)}pb(d+32|0)}pb(d+16|0);pb(d);S(a|0);L()}}function Mr(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{d=ab+-64|0;ab=d;h=v[c>>2]&2?16:10;f=ab-32|0;ab=f;e=ze(f+16|0,1,0);b:{c:{d:{while(1){g=Eb(e);Yw(f+8|0,g,ub(e)+g|0,v[b>>2],h);if(!v[f+12>>2]){break d}g=If(ub(e));v[22452]=0;R(59,e|0,g|0);g=v[22452];v[22452]=0;if((g|0)!=1){continue}break}break c}b=v[f+8>>2];h=Eb(e);v[22452]=0;R(60,e|0,b-h|0);b=v[22452];v[22452]=0;e:{if((b|0)!=1){v[22452]=0;R(73,d|0,e|0);b=v[22452];v[22452]=0;if((b|0)!=1){break e}break c}break c}pb(e);ab=f+32|0;break b}a=P()|0;O()|0;pb(e);S(a|0);L()}b=d+16|0;Ik(b,d,v[c>>2]);e=v[c+4>>2];f=v[c>>2];v[22452]=0;W(77,d+32|0,b|0,f|0,e|0);b=v[22452];v[22452]=0;f:{g:{h:{i:{if((b|0)!=1){v[22452]=0;U(78,d+48|0,d+32|0,c|0);b=v[22452];v[22452]=0;if((b|0)==1){break i}v[22452]=0;R(72,a|0,d+48|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}pb(d+48|0);pb(d+32|0);pb(d+16|0);pb(d);ab=d- -64|0;break a}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;pb(d+48|0)}pb(d+32|0)}pb(d+16|0);pb(d);S(a|0);L()}}function ju(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{d=ab+-64|0;ab=d;h=v[c>>2]&2?16:10;f=ab-32|0;ab=f;e=ze(f+16|0,1,0);b:{c:{d:{while(1){g=Eb(e);PI(f+8|0,g,ub(e)+g|0,w[b|0],h);if(!v[f+12>>2]){break d}g=If(ub(e));v[22452]=0;R(59,e|0,g|0);g=v[22452];v[22452]=0;if((g|0)!=1){continue}break}break c}b=v[f+8>>2];h=Eb(e);v[22452]=0;R(60,e|0,b-h|0);b=v[22452];v[22452]=0;e:{if((b|0)!=1){v[22452]=0;R(73,d|0,e|0);b=v[22452];v[22452]=0;if((b|0)!=1){break e}break c}break c}pb(e);ab=f+32|0;break b}a=P()|0;O()|0;pb(e);S(a|0);L()}b=d+16|0;Ik(b,d,v[c>>2]);e=v[c+4>>2];f=v[c>>2];v[22452]=0;W(77,d+32|0,b|0,f|0,e|0);b=v[22452];v[22452]=0;f:{g:{h:{i:{if((b|0)!=1){v[22452]=0;U(78,d+48|0,d+32|0,c|0);b=v[22452];v[22452]=0;if((b|0)==1){break i}v[22452]=0;R(72,a|0,d+48|0);a=v[22452];v[22452]=0;if((a|0)==1){break h}pb(d+48|0);pb(d+32|0);pb(d+16|0);pb(d);ab=d- -64|0;break a}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;pb(d+48|0)}pb(d+32|0)}pb(d+16|0);pb(d);S(a|0);L()}}function QX(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=ab-16|0;ab=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=v[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=v[a+8>>2];if((g-f|0)<=0){break a}v[a+8>>2]=f+1;t[f|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}c=v[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if((f|0)<4){break b}v[a+8>>2]=c+1;t[c|0]=b>>>18|240;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>12&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;continue}break}c=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];ab=a+16|0;return c|0}function Wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=ab-16|0;ab=h;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;o=v[a+8>>2];p=v[a+12>>2];while(1){b=e;if(d){q=v[a+72>>2];r=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+60>>2];g=e;i=e>>31;m=u[(v[h+12>>2]<<1)+n>>1]<<8;e=m;e=oia(g,i,e,e>>31);l=db;g=e;e=v[a+64>>2];i=e;s=e>>31;e=Sb(b,-16777216,16776704);i=oia(i,s,e,e>>31);g=g+i|0;e=db+l|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=v[a+68>>2];f=Sb(f,-16777216,16776704);l=oia(g,g>>31,f,f>>31);g=i+l|0;f=db+e|0;f=g>>>0<l>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(k>>12,e)+v[c>>2];j=j+r|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Lb(h+8|0,o,p);e=f-(q&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}v[a+40>>2]=j;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+16|0}function LI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=ab-32|0;ab=d;a:{b:{c:{d:{e:{f:{g:{h:{if(Vi(a)){of(d+24|0);break h}c=d+8|0;fn(c,a);v[22452]=0;c=T(983,c|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break g}v[d+24>>2]=c;Hf(d+8|0)}if(Vi(a)){c=a+36|0}else{c=v[d+24>>2]}if((b|0)==-1){f=v[c>>2];h=4194304;e=0;break e}if((b|0)>=0){e=b;f=v[c>>2];if((en(f,v[c+4>>2])|0)>(b|0)){break e}}b=aa(8)|0;v[22452]=0;c=Q(55,d+8|0,10873)|0;a=v[22452];v[22452]=0;if((a|0)==1){break f}lc(b,c);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}a=P()|0;O()|0;pb(c);break d}a=P()|0;O()|0;Hf(d+8|0);break c}a=P()|0;O()|0;ba(b|0);break d}v[a+8>>2]=b;b=a+24|0;g=v[b>>2];v[g+480208>>2]=v[g+480208>>2]&-4194305|h;si(v[b>>2]+484360|0,w[_k(f,e)+16|0]);b=_k(v[c>>2],e);c=v[b+8>>2];b=v[b+12>>2];v[22452]=0;+ra(1014,a|0,b|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){break a}a=P()|0;O()|0}Ek(d+24|0)}S(a|0)}L()}v[a+16>>2]=0;v[a+20>>2]=0;Ek(d+24|0);ab=d+32|0}function Saa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;f=ab-16|0;ab=f;h=v[a+40>>2];i=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){g=v[f+8>>2];m=(((v[f+12>>2]&2147483647)<<1|g>>>31)&-2)+j|0;e=(((g>>>16|0)+4&131064)<<1)+b|0;n=u[e+38>>1];o=u[e+36>>1];p=u[e+34>>1];q=u[e+32>>1];r=u[e+30>>1];s=u[e+28>>1];w=u[e+26>>1];x=u[e+24>>1];g=0;while(1){if((g|0)!=2){e=g+m|0;v[(g<<2)+f>>2]=(((((B(t[e+4|0],p)+B(t[e+2|0],q)|0)+B(t[e+6|0],o)|0)+B(t[e+8|0],n)<<8)/2|0)+((((B(t[e-4|0],w)+B(t[e-6|0],x)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)<<8)/2|0)|0)/16384;g=g+1|0;continue}break}e=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[f>>2],i>>12);h=e+h|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],h>>12);Lb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=h;v[a+36>>2]=i;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function mx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);c=ab-48|0;ab=c;a:{b=v[a+20>>2];b:{if(!b){break b}d=v[b+4>>2];b=v[b+8>>2];if(Ic(d,b)>>>0<4){break b}de(c+16|0,d,b);b=Vd(c+8|0);d=WS(c+24|0,v[c+16>>2],v[c+20>>2],v[b>>2],v[b+4>>2]);v[22452]=0;b=T(148,d|0)|0;f=v[22452];v[22452]=0;c:{if((f|0)!=1){if(b){break c}b=v[v[a>>2]+40>>2];v[22452]=0;f=T(b|0,a|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break a}b=v[a+20>>2];if(Ic(v[b+4>>2],v[b+8>>2])-4>>>0<f<<2>>>0){break c}b=v[v[a>>2]+172>>2];v[22452]=0;R(b|0,a|0,-1);b=v[22452];v[22452]=0;if((b|0)==1){break a}b=0;while(1){if((b|0)==(f|0)){b=v[v[a>>2]+176>>2];v[22452]=0;Z(b|0,a|0);a=v[22452];v[22452]=0;if((a|0)!=1){break c}break a}v[22452]=0;g=C(Ba(420,d|0));e=v[22452];v[22452]=0;d:{if((e|0)==1){break d}e=v[v[a>>2]+44>>2];v[22452]=0;Aa(e|0,a|0,b|0,C(Hl(g)?g:C(0)));e=v[22452];v[22452]=0;if((e|0)==1){break d}b=b+1|0;continue}break}break a}break a}qb(d)}ab=c+48|0;return}a=P()|0;O()|0;qb(d);S(a|0);L()}function Yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=ab-16|0;ab=h;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;o=v[a+8>>2];p=v[a+12>>2];while(1){b=e;if(d){q=v[a+72>>2];r=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+60>>2];g=e;i=e>>31;m=t[v[h+12>>2]+n|0]<<16;e=m;e=oia(g,i,e,e>>31);l=db;g=e;e=v[a+64>>2];i=e;s=e>>31;e=Sb(b,-16777216,16776704);i=oia(i,s,e,e>>31);g=g+i|0;e=db+l|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=v[a+68>>2];f=Sb(f,-16777216,16776704);l=oia(g,g>>31,f,f>>31);g=i+l|0;f=db+e|0;f=g>>>0<l>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(k>>12,e)+v[c>>2];j=j+r|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Lb(h+8|0,o,p);e=f-(q&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}v[a+40>>2]=j;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+16|0}function Haa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=ab-48|0;ab=g;k=v[a+16>>2];e=Vd(g+16|0);v[e+8>>2]=a+112;f=v[a+128>>2];v[e+16>>2]=f;n=e,o=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;i=v[a+8>>2];j=v[a+12>>2];if(f){n=e,o=Wf(i,j,f),v[n>>2]=o;v[e+4>>2]=db}l=v[a+24>>2];m=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=b;a:while(1){if(d){v[g+40>>2]=f;v[g+44>>2]=0;f=(b<<1)+k|0;b=v[e+16>>2];while(1)if((b|0)<=0){b=v[e+8>>2];h=v[b+8>>2];Lb(b,h,v[b+12>>2]);b=v[e+8>>2];h=v[b+4>>2];if(h){Bd(b,u[f+(v[g+44>>2]<<1)>>1]/4<<16>>16);Ad(v[e+8>>2],h);b=v[e+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}d=d-1|0;f=v[c>>2];b=Uf(b,v[e+12>>2]);v[c>>2]=f+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Lb(g+8|0,i,j);c=c+8|0;f=v[g+8>>2];b=v[g+12>>2];continue a}else{Bd(v[e+8>>2],u[f+(v[g+44>>2]<<1)>>1]/4<<16>>16);Ad(v[e+8>>2],4);Lb(g+40|0,v[e>>2],v[e+4>>2]);b=b-1|0;continue}}break}v[a>>2]=f;v[a+4>>2]=b;ab=g+48|0}function r7(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=ab-32|0;ab=d;v[22452]=0;g=Q(12,d+24|0,a|0)|0;c=v[22452];v[22452]=0;a:{b:{c:{if((c|0)!=1){d:{if(!w[g|0]){break d}c=d+16|0;zc(c,v[v[a>>2]-12>>2]+a|0);v[22452]=0;c=T(69,c|0)|0;e=v[22452];v[22452]=0;e:{f:{if((e|0)!=1){Nb(d+16|0);e=xi(d+8|0,a);f=v[v[a>>2]-12>>2];v[22452]=0;f=a+f|0;h=T(13,f|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break f}e=v[e>>2];v[22452]=0;c=Oa(70,c|0,e|0,f|0,h|0,+b)|0;e=v[22452];v[22452]=0;if((e|0)==1){break f}v[d+16>>2]=c;if(!Au(d+16|0)){break d}c=v[v[a>>2]-12>>2];v[22452]=0;R(15,a+c|0,5);c=v[22452];v[22452]=0;if((c|0)!=1){break d}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;Nb(d+16|0);break e}c=V(0)|0;O()|0}dk(g);break c}dk(g);break b}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[22452]=0;Z(16,a+c|0);c=v[22452];v[22452]=0;if((c|0)==1){break a}$()}ab=d+32|0;return a|0}a=P()|0;O()|0;v[22452]=0;X(17);d=v[22452];v[22452]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function mI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;v[a+4>>2]=b;v[a>>2]=89848;e=(b>>>0)/48|0;d=((0-b|0)!=(B(e,-48)|0))+e|0;v[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;v[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){g=-1<<c}else{g=(1<<c)-1&-1>>>32-c|-1<<c}c=0;v[a+24>>2]=c;f=f?g&65536:0;v[a+28>>2]=f;g=0-c|0;h=ria(c,f,d,0);c=65536-(f+((c|0)!=0)|0)|0;f=db;if((c|0)==(f|0)&g>>>0>h>>>0|c>>>0>f>>>0){d=d+1|0;v[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;v[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){c=-1<<c}else{c=(1<<c)-1&-1>>>32-c|-1<<c}v[a+24>>2]=0;v[a+28>>2]=f?c&65536:0}v[a+16>>2]=d-((b>>>0)%(d>>>0)|0);b=e>>>0<63;d=63-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}v[a+48>>2]=b?c:-1;v[a+52>>2]=b?d:-1;d=64-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}v[a+40>>2]=e?c:0;v[a+44>>2]=e?d:0;c=e+1|0;e=c&31;if((c&63)>>>0>=32){d=-1<<e}else{d=(1<<e)-1&-1>>>32-e|-1<<e}v[a+32>>2]=0;v[a+36>>2]=b?d&65536:0;return a}function b2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=ab-2144|0;ab=b;px(b+96|0);a:{b:{c:{f=v[c+4>>2];if(!f){a=aa(8)|0;v[22452]=0;b=Q(55,b+80|0,10414)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}lc(a,b);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}c=P()|0;O()|0;pb(b);break b}g=v[c>>2];d=v[c+12>>2];c=v[c+8>>2];v[b+72>>2]=c;v[b+76>>2]=d;e=v[b+76>>2];v[b+32>>2]=v[b+72>>2];v[b+36>>2]=e;v[b+68>>2]=f;v[b+64>>2]=g;e=v[b+68>>2];v[b+24>>2]=v[b+64>>2];v[b+28>>2]=e;h=VH(b+24|0);if(h){v[b+56>>2]=c;v[b+60>>2]=d;c=v[b+60>>2];v[b+16>>2]=v[b+56>>2];v[b+20>>2]=c;v[b+52>>2]=f;v[b+48>>2]=g;c=v[b+52>>2];v[b+8>>2]=v[b+48>>2];v[b+12>>2]=c;c=OH(b+8|0)}else{c=0}v[b+80>>2]=c;v[b+84>>2]=0;c=0;d=2048;while(1){d:{e=eb[f|0](g,(b+96|0)+c|0,d)|0;c=e+c|0;if(!e){break d}d=d-e|0;if(d){continue}}break}d=a;a=Zb(b+40|0,b+96|0,c);a=ss(d,v[a>>2],v[a+4>>2],h?b+80|0:0);ab=b+2144|0;return a|0}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function mga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=ab-32|0;ab=d;b=ab-32|0;ab=b;v[b+16>>2]=1073741824;u[b+22>>1]=12;c=pc(64);v[22452]=0;e=T(811,c|0)|0;f=v[22452];v[22452]=0;a:{b:{c:{if((f|0)!=1){c=yf(b+8|0,e);e=v[c>>2];v[22452]=0;R(812,e|0,a|0);a=v[22452];v[22452]=0;if((a|0)==1){break c}a=v[c>>2];v[22452]=0;a=Y(813,a|0,b+22|0,b+16|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}d:{if(!a){of(b+24|0);break d}a=v[c>>2];v[22452]=0;R(814,a|0,15);a=v[22452];v[22452]=0;if((a|0)==1){break c}Oh(b+24|0,c)}bg(c);ab=b+32|0;a=v[b+24>>2];break a}a=P()|0;O()|0;xb(c);break b}a=P()|0;O()|0;bg(c)}S(a|0);L()}v[d+24>>2]=a;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}c=v[d+24>>2];v[22452]=0;b=Q(1,d+8|0,(a<<2)+32160|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){v[22452]=0;U(445,c|0,a|0,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break g}pb(b);a=a+1|0;continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;pb(b)}bg(d+24|0);S(a|0);L()}ab=d+32|0;return v[d+24>>2]}function v9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=ab-16|0;ab=g;d=a+4|0;b=v[d>>2]+223860|0;if(FM(b)){IM(b)}v[a+24>>2]=0;v[a+28>>2]=0;v[v[d>>2]>>2]=0;b=v[a>>2];v[v[d>>2]+40>>2]=v[b+480196>>2];v[v[d>>2]+44>>2]=v[b+480204>>2];v[v[d>>2]+80>>2]=v[b+480200>>2];c=x[b+480188>>1];v[g+8>>2]=0;v[g+12>>2]=0;e=g+8|0;u[e+4>>1]=65280;v[e>>2]=0;f=ab-16|0;ab=f;v[f+12>>2]=c;b=a+8|0;a:{if(Fm(b)>>>0>=c>>>0){h=v[b>>2];i=Ag(h,v[b+4>>2]);v[f+8>>2]=i;j=v[zb(f+12|0,f+8|0)>>2];while(1){if(j){v[h>>2]=v[e>>2];u[h+4>>1]=x[e+4>>1];j=j-1|0;h=h+8|0;continue}break}if(c>>>0>i>>>0){VL(b,c-i|0,e);break a}Hd(b,v[b>>2]+(c<<3)|0);break a}iN(b);vN(b,Kq(b,c));VL(b,c,e)}ab=f+16|0;b=0;while(1){e=v[a>>2];if(x[e+480188>>1]<=b>>>0){ab=g+16|0}else{c=B(b,872);Dn((c+v[d>>2]|0)+616|0,e,b&65535,134217728);t[(c+v[d>>2]|0)+1433|0]=0;t[(c+v[d>>2]|0)+1432|0]=0;t[(c+v[d>>2]|0)+1415|0]=0;t[(c+v[d>>2]|0)+1418|0]=0;t[(c+v[d>>2]|0)+1413|0]=0;b=b+1|0;continue}break}}function dx(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;o(+a);e=j(1)|0;c=j(0)|0;a:{b:{d=e>>>20&2047;if(d-969>>>0<63){k=d;break b}if(d>>>0<=968){return a+1}if(d>>>0<1033){break b}b=0;if(!c&(e|0)==-1048576){break a}if((d|0)==2047){return a+1}if((e|0)<0){return ar(1.2882297539194267e-231)}return ar(3.105036184601418e231)}b=A[170];f=A[169]*a+b;b=f-b;b=b*A[172]+(b*A[171]+a);a=b*b;g=a*a*(b*A[176]+A[175]);a=a*(b*A[174]+A[173]);o(+f);j(1)|0;h=j(0)|0;c=h<<4&2032;b=g+(a+(A[c+1464>>3]+b));d=c+1472|0;c=h<<13;e=0;i=v[d>>2]+e|0;c=c+v[d+4>>2]|0;c=e>>>0>i>>>0?c+1|0:c;d=i;if(!k){c:{if(!(h&-2147483648)){l(0,d|0);l(1,c-1058013184|0);a=+n();a=(a*b+a)*5.486124068793689e303;break c}e=ab-16|0;l(0,d|0);l(1,c+1071644672|0);g=+n();f=g*b;a=f+g;if(a<1){v[e+8>>2]=0;v[e+12>>2]=1048576;A[e+8>>3]=A[e+8>>3]*2.2250738585072014e-308;b=a+1;a=b+(f+(g-a)+(a+(1-b)))+-1;a=a==0?0:a}a=a*2.2250738585072014e-308}return a}l(0,d|0);l(1,c|0);a=+n();b=a*b+a}return b}function F7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];c=sj(d,v[a+4>>2]);if(c>>>0<b>>>0){g=ab-32|0;ab=g;e=b-c|0;b=v[vb(a)>>2];c=v[a+4>>2];a:{if(e>>>0<=b-c>>11>>>0){b=ab-16|0;ab=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){dc(b);ab=b+16|0}else{px(a);a=a+2048|0;v[b+4>>2]=a;continue}break}break a}h=vb(a);i=g+8|0;b=a;f=sj(v[a>>2],c)+e|0;c=ab-16|0;ab=c;v[c+12>>2]=f;d=ab-16|0;ab=d;v[d+12>>2]=2097151;v[d+8>>2]=2147483647;a=v[zb(d+12|0,d+8|0)>>2];ab=d+16|0;b:{if(a>>>0>=f>>>0){d=qx(b);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Pc(c+8|0,c+12|0)>>2]}ab=c+16|0;break b}hd();L()}d=$J(i,a,sj(v[b>>2],v[b+4>>2]),h);c=d;a=ab-16|0;ab=a;v[a>>2]=v[c+8>>2];f=v[c+8>>2];v[a+8>>2]=c+8;v[a+4>>2]=f+(e<<11);c=v[a>>2];while(1){if(v[a+4>>2]!=(c|0)){px(c);c=v[a>>2]+2048|0;v[a>>2]=c;continue}break}xd(a);ab=a+16|0;rd(b,d);_J(d)}ab=g+32|0;return}if(b>>>0<c>>>0){Hd(a,d+(b<<11)|0)}}function G1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(y[a+4>>2]<y[vb(a)>>2]){c=ab-16|0;ab=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+24;HI(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+24;dc(c);ab=c+16|0;return}g=ab-32|0;ab=g;h=vb(a);d=g+8|0;f=en(v[a>>2],v[a+4>>2])+1|0;e=ab-16|0;ab=e;v[e+12>>2]=f;a:{c=$Q();if(f>>>0<=c>>>0){f=ut(a);if(f>>>0<c>>>1>>>0){v[e+8>>2]=f<<1;c=v[Pc(e+8|0,e+12|0)>>2]}ab=e+16|0;break a}hd();L()}f=en(v[a>>2],v[a+4>>2]);Ve(d+12|0,h);if(c){if(c>>>0>=178956971){Oe(11129);L()}e=pc(B(c,24))}else{e=0}v[d>>2]=e;f=e+B(f,24)|0;v[d+8>>2]=f;v[d+4>>2]=f;i=ic(d),j=e+B(c,24)|0,v[i>>2]=j;HI(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+24;b=d+4|0;f=v[a>>2];c=v[a+4>>2]-f|0;e=v[b>>2]+B((c|0)/-24|0,24)|0;v[b>>2]=e;if((c|0)>0){gc(e,f,c)}cc(a,b);cc(a+4|0,d+8|0);cc(vb(a),ic(d));v[d>>2]=v[d+4>>2];a=v[d+4>>2];b=v[d+8>>2];while(1){if((a|0)!=(b|0)){b=b-24|0;v[d+8>>2]=b;continue}break}a=v[d>>2];if(a){ic(d);xb(a)}ab=g+32|0}function gI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=ab-32|0;ab=c;e=v[a>>2];a=v[e>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];j=v[a+8>>2];h=v[a+4>>2];k=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=ab-32|0;ab=a;a:{b:{if(y[c+4>>2]>=h>>>0){if(vf(c)>>>0<j>>>0){break b}l=b+12|0;c:while(1){e=0;if((f|0)==(j|0)){break a}while(1)if((e|0)==(h|0)){f=f+1|0;continue c}else{i=Hg(k,h,e,f);d=Fb(v[b>>2],e);g=be(Xf(A[i>>3])*134217728);i=d;d=(v[d>>2]>>1)+Sl(g)|0;m=d;d=Pr(l)+d&-4096;v[i>>2]=m-d;A[a+24>>3]=+(d|0)*7.450580596923828e-9;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;g=be(A[qg(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(g)<2147483648){d=~~g;break d}d=-2147483648}d=Jc(d);n=an(c,e,f),o=d,u[n>>1]=o;e=e+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}ab=a+32|0;ab=c+32|0}function cfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=ab-48|0;ab=f;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;Tn(b,f+44|0);d=w[f+45|0];e=w[f+46|0];a:{if(!AO(w[f+44|0],d,e)){break a}g=w[f+47|0];t[a+4|0]=1;h=d>>>3&3;c=(h|0)!=3;i=d>>>1&3;d=i^3;g=g>>>0<192;u[a+2>>1]=x[(B(c,6)+(d<<1)|0)+27368>>1]<<g;j=B(B(w[(d+B(c,3)|0)+27144|0],x[((B(c,90)+B(d,30)|0)+(e>>>3&30)|0)+27152>>1]),1e3);d=e>>>1|0;e=B(((j>>>0)/x[(B(h,6)+(d&6)|0)+27344>>1]|0)+(d&1)|0,(i|0)==3?4:1);u[a>>1]=e;d=w[(g|c<<1)+27380|0];if(d+8>>>0>(e&65535)>>>0){break a}c=ab-32|0;ab=c;v[c+28>>2]=d+4;v[c+8>>2]=36;e=v[zb(c+28|0,c+8|0)>>2];if(!Hb(b,e)){e=Ze(b)}g=c+8|0;Cq(g,f);h=Zb(c+16|0,v[c+8>>2],e);_b(c,b,v[h>>2],v[h+4>>2]);Cq(g,f);Jb(v[c+8>>2]+e|0,0,36-e|0);Ob(b,v[c+28>>2]);ab=c+32|0;b=2;c=d>>>0>2?d:2;while(1){if((b|0)!=(c|0)){e=b+f|0;b=b+1|0;if(!w[e|0]){continue}break a}break}b=d+f|0;if(Ib(b,9537,4)){b=Ib(b,11034,4)}else{b=0}t[a+5|0]=!b}ab=f+48|0;return a|0}function $H(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=ab-32|0;ab=c;e=v[a>>2];a=v[e>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];j=v[a+8>>2];h=v[a+4>>2];k=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=ab-32|0;ab=a;a:{b:{if(y[c+4>>2]>=h>>>0){if(vf(c)>>>0<j>>>0){break b}l=b+12|0;c:while(1){e=0;if((f|0)==(j|0)){break a}while(1)if((e|0)==(h|0)){f=f+1|0;continue c}else{i=Hg(k,h,e,f);d=Fb(v[b>>2],e);g=be(Xf(A[i>>3])*134217728);i=d;d=(v[d>>2]>>1)+Sl(g)|0;m=d;d=Pr(l)+d&-4096;v[i>>2]=m-d;A[a+24>>3]=+(d|0)*7.450580596923828e-9;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;g=be(A[qg(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(g)<2147483648){d=~~g;break d}d=-2147483648}d=Jc(d);n=$m(c,e,f),o=d,u[n>>1]=o;e=e+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}ab=a+32|0;ab=c+32|0}function Ov(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=ab-16|0;ab=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!ub(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!ub(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=fi(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+79744|0];d:{e:{switch((f&-2)-22|0){case 2:b=v[e>>2];if((b|0)!=(d|0)&(w[b-1|0]&95)!=(w[c|0]&127)){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!ub(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}ab=m+16|0;return a}function LH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=ab-80|0;ab=e;v[e+72>>2]=c;c=Oh(a,e+72|0);h=of(a+4|0);i=of(a+24|0);j=of(a+32|0);k=Pb(a+36|0);v[a+56>>2]=3;l=Pb(a+68|0);v[22452]=0;R(920,a|0,d|0);f=v[22452];v[22452]=0;a:{b:{c:{d:{if((f|0)!=1){f=v[b>>2];g=v[b+4>>2];m=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=m;v[e+32>>2]=f;v[e+36>>2]=g;b=Vd(e+24|0);f=v[b+4>>2];b=v[b>>2];g=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=g;v[22452]=0;g=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=g;W(908,e+48|0,e+8|0,b|0,f|0);b=v[22452];v[22452]=0;if((b|0)==1){break d}v[22452]=0;U(922,a|0,e+48|0,d|0);b=v[22452];v[22452]=0;if((b|0)==1){break c}qb(e+48|0);v[22452]=0;Z(923,a|0);b=v[22452];v[22452]=0;if((b|0)==1){break b}oe(e+72|0);ab=e+80|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;qb(e+48|0);break a}a=P()|0;O()|0}Uc(l);Hf(k);Lo(j);Zh(i);Yh(h);oe(c);oe(e+72|0);S(a|0);L()}function Iaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=ab-48|0;ab=g;k=v[a+16>>2];e=Vd(g+16|0);v[e+8>>2]=a+112;f=v[a+128>>2];v[e+16>>2]=f;n=e,o=Vf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;i=v[a+8>>2];j=v[a+12>>2];if(f){n=e,o=Wf(i,j,f),v[n>>2]=o;v[e+4>>2]=db}l=v[a+24>>2];m=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=b;a:while(1){if(d){v[g+40>>2]=f;v[g+44>>2]=0;f=b+k|0;b=v[e+16>>2];while(1)if((b|0)<=0){b=v[e+8>>2];h=v[b+8>>2];Lb(b,h,v[b+12>>2]);b=v[e+8>>2];h=v[b+4>>2];if(h){Bd(b,t[f+v[g+44>>2]|0]<<6);Ad(v[e+8>>2],h);b=v[e+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}d=d-1|0;f=v[c>>2];b=Uf(b,v[e+12>>2]);v[c>>2]=f+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Lb(g+8|0,i,j);c=c+8|0;f=v[g+8>>2];b=v[g+12>>2];continue a}else{Bd(v[e+8>>2],t[f+v[g+44>>2]|0]<<6);Ad(v[e+8>>2],4);Lb(g+40|0,v[e>>2],v[e+4>>2]);b=b-1|0;continue}}break}v[a>>2]=f;v[a+4>>2]=b;ab=g+48|0}function Rp(a){var b=0,c=0,d=0,e=0,f=0;e=ab-16|0;ab=e;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}c=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}c=b;if((b|0)==16777216){break a}}c=32;break a}c=b;break a}c=4;if(x[a+480192>>1]){break a}a=a+484344|0;d=vg(a);v[e+8>>2]=d;a=ug(a);while(1){if(!Tb(d,a)){c=1;break a}if(!(!Gh(d)|v[d+12>>2]==64)){break a}pL(e+8|0);d=v[e+8>>2];continue}}c=16777216;break a}c=32;f=x[a+480188>>1];if(f>>>0>16){break a}while(1){if((d|0)==(f|0)){break b}b=(d<<5)+a|0;if(t[b+480281|0]&1){break a}d=d+1|0;if(x[b+480286>>1]==64){continue}break}break a}c=2}ab=e+16|0;return c}function iV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=ab-32|0;ab=k;c=zm(k+8|0,a);f=ab-48|0;ab=f;l=-1;a:{if(!WC(c,f+8|0)){break a}l=0;if(!$C(f+8|0)){break a}p=v[c+12>>2];b:{a=f+8|0;d=a+16|0;if(!Zk(c,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))){break b}n=a+4|0;d=a+12|0;while(1){c:{if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0>o>>>0){if(Qf(c,5)){break c}}g=m&1;break b}h=0;g=1;d:{if((w[n|0]|w[n+1|0]<<8)>>>0>=64){a=kq(c);i=a&63;j=a&128;e:{if(!(a&64)){break e}e=6;while(1){a=kq(c);i=(a&127)<<e|i;if(!(a&128)){break e}a=e>>>0<25;e=e+7|0;if(a){continue}break}}a=j?-2147483648:i;if(((j?(i|0)>=0?0-i|0:a:a)|0)<=0){break d}}while(1){e=kq(c);if(e){j=h>>>0>4;a=j&g;if(!((g^1)&1|j)){a=(gp(e<<24>>24)&255)==w[h+13071|0]}g=a;h=h+1|0;continue}break}Rc(c,4);m=(h|0)==5?g&1?1:m:m}o=o+1|0;continue}}Zk(c,p);if(!g){break a}l=we(c,b,_C(f+8|0),0)}ab=f+48|0;ab=k+32|0;return l|0}function Lba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=ab-16|0;ab=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+8>>2];p=v[a+12>>2];while(1){b=e;if(d){q=v[a+72>>2];e=v[a+64>>2];i=e;h=e>>31;e=Sb(b,-16777216,16776704);e=oia(i,h,e,e>>31);i=db;j=e;e=v[a+68>>2];f=Sb(f,-16777216,16776704);h=oia(e,e>>31,f,f>>31);e=j+h|0;f=db+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;e=v[a+60>>2];h=e;r=e>>31;k=v[g+12>>2]+n|0;e=t[k|0];j=i;i=((B(t[k+1|0]-e|0,v[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=oia(h,r,e,e>>31);e=j+h|0;f=db+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Lb(g+8|0,o,p);e=f-(i&q)|0;c=c+8|0;d=d-1|0;f=b;continue}break}v[a+48>>2]=f;v[a+44>>2]=b;b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+16|0}function lba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ab-16|0;ab=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){e=(v[f+12>>2]<<1)+j|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(u[e-4>>1],u[h+2>>1])+B(u[e-6>>1],u[h>>1])|0)+B(u[e-2>>1],u[h+4>>1])|0)+B(u[e>>1],u[h+6>>1])|0)+B(u[e+2>>1],u[h+8>>1])|0)+B(u[e+4>>1],u[h+10>>1])|0)+B(u[e+6>>1],u[h+12>>1])|0)+B(u[e+8>>1],u[h+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(e,l);v[c+4>>2]=v[c+4>>2]+B(e,k);Lb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function Kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=ab-16|0;ab=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+8>>2];p=v[a+12>>2];while(1){b=e;if(d){q=v[a+72>>2];e=v[a+64>>2];i=e;h=e>>31;e=Sb(b,-16777216,16776704);e=oia(i,h,e,e>>31);i=db;j=e;e=v[a+68>>2];f=Sb(f,-16777216,16776704);h=oia(e,e>>31,f,f>>31);e=j+h|0;f=db+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;e=v[a+60>>2];h=e;r=e>>31;k=(v[g+12>>2]<<1)+n|0;e=u[k>>1];j=i;i=e+((B(u[k+2>>1]-e|0,v[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=oia(h,r,e,e>>31);e=j+h|0;f=db+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Lb(g+8|0,o,p);e=f-(i&q)|0;c=c+8|0;d=d-1|0;f=b;continue}break}v[a+48>>2]=f;v[a+44>>2]=b;b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;ab=g+16|0}function BM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{g=b;c=ab-16|0;ab=c;d=Bb(a);while(1){b:{c:{d:{e:{if(ub(g)>>>0>f>>>0){b=v[Mj(g,f)>>2];if(b>>>0>=2097152){v[22452]=0;R(51,d|0,63);a=v[22452];v[22452]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;t[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(!a){v[22452]=0;R(51,d|0,t[c+10|0]);break e}b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}v[22452]=0;R(51,d|0,t[c+10|0]|64);break e}ab=c+16|0;break a}a=v[22452];v[22452]=0;if((a|0)!=1){break c}break b}i=(-1<<b^-1)<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}f:{if((a|0)==(b|0)){a=w[j|0];v[22452]=0;R(51,d|0,(a|i)<<24>>24);h=v[22452];v[22452]=0;a=e;break f}v[22452]=0;a=a-1|0;R(51,d|0,t[a+(c+10|0)|0]|-128);h=v[22452];v[22452]=0}if((h|0)!=1){continue}break}break b}f=f+1|0;continue}break}a=P()|0;O()|0;pb(d);S(a|0);L()}}function Oz(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=ab-32|0;ab=g;OQ(a,b);i=ab-16|0;ab=i;ed(c,1);a=b+22|0;h=Ab(w[a|0]|w[a+1|0]<<8)<<1;v[c>>2]=h;t[c+37|0]=w[b+24|0]<<4;t[i+15|0]=w[b+25|0];t[i+14|0]=64;l=c,m=w[Qb(i+15|0,i+14|0)|0]<<2,u[l+30>>1]=m;a=b+26|0;f=Ab(w[a|0]|w[a+1|0]<<8);a=f<<1;j=b+28|0;k=Ab(w[j|0]|w[j+1|0]<<8);j=k<<1;a=k>>>0>=2?a+j>>>0<=h>>>0?a:f+j>>>0>h>>>0?a:f:a;a:{b:{switch(h|0){case 2:v[c>>2]=0;break a;case 0:break a;default:break b}}v[c+4>>2]=a;f=a+j|0;v[c+8>>2]=f;if(a>>>0>=h>>>0){a=h-1|0;v[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=h>>>0))){v[c+8>>2]=0;break a}if(a>>>0>=f>>>0){break a}u[c+34>>1]=x[c+34>>1]|2}ab=i+16|0;gl(g,3,b);a=g+16|0;tc(a,v[g>>2],v[g+4>>2],w[g+8|0]);d=sc(d,a);c=d+32|0;pb(a);while(1){if((c|0)!=(d|0)){if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}d=d+1|0;continue}break}a=Qz(b);ab=g+32|0;return a}function MF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ab-32|0;ab=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[Ee(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=or(v[a+32>>2]);if((g|0)==-1){break a}t[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];g=v[d>>2];j=v[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(_F(v[a+36>>2],d,i,f,c+16|0,c+23|0,h,c+12|0)-1|0){case 2:break d;case 0:break e;case 1:break b;default:break c}}d=v[a+40>>2];v[d>>2]=g;v[d+4>>2]=j;if((e|0)==8){break b}d=or(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((nr(rg(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break a}}d=rg(t[c+23|0]);v[a+48>>2]=d;break a}d=rg(t[c+23|0]);break a}d=-1}ab=c+32|0;return d}function Wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=Bt(c,d);d=b&63;if(e>>>0>d>>>0){c=HR(c,d);d=0;g=ab-16|0;ab=g;t[a+12|0]=0;uc(a);e=ab-32|0;ab=e;if(Ch(a)>>>0<=14){f=vb(a);f=_f(e+8|0,15,nc(v[a>>2],v[a+4>>2]),f);rd(a,f);Zf(f)}ab=e+32|0;f=0-w[c+1|0]|0;while(1){a:{if((d|0)==15){break a}e=c+(d<<1)|0;h=w[e+1|0];if(!h){break a}t[g+7|0]=64;f=h+(f<<16>>16)|0;h=Qn(g+8|0,f&65535,w[Qb(e+2|0,g+7|0)|0]);b:{if(y[a+4>>2]<y[vb(a)>>2]){DR(a,h);break b}i=ab-32|0;ab=i;e=vb(a);e=_f(i+8|0,fh(a,nc(v[a>>2],v[a+4>>2])+1|0),nc(v[a>>2],v[a+4>>2]),e);Pn(v[e+8>>2],h);v[e+8>>2]=v[e+8>>2]+4;rd(a,e);Zf(e);ab=i+32|0}d=d+1|0;continue}break}d=w[c+32|0];t[a+14|0]=d>>>4;t[a+13|0]=d&15;c=w[c+31|0];d=c&15;t[a+15|0]=d;t[a+16|0]=d;if(c&16){t[a+12|0]=w[a+12|0]|4}if(c&32){t[a+12|0]=w[a+12|0]|2}ab=g+16|0}c:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break c}c=w[a+12|0]&-2|jc(v[a>>2],v[a+4>>2])^1;a=a+12|0}t[a|0]=c}function LX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=t[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((w[a+1|0]&192)==128){break b}break a}g=f&255;c:{d:{if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=w[a+3|0];i=w[a+2|0];f=w[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4;break b}if((f&224)!=128){break a}}g=3;if((h&192)!=128){break a}}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function V5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=0,q=0,r=0,s=C(0),t=C(0),u=C(0),x=C(0),y=0,A=0,B=0,E=0,F=C(0);f=ab-16|0;ab=f;k=v[a+4240>>2];a:{if(!k){break a}g=a+44|0;if(!Ih(g)){break a}o=z[a+4220>>2];B=f,E=Gd(g,0),v[B+8>>2]=E;B=f,E=Gd(g,1),v[B+12>>2]=E;B=f,E=dd(g,0),v[B>>2]=E;B=f,E=dd(g,1),v[B+4>>2]=E;x=C(C(1)-o);l=d;b:while(1){if(l){m=v[a+4244>>2];y=m<<1;p=v[a+4208>>2];A=w[a+4264|0];e=0;n=0;while(1)if((e|0)==2){e=m+1|0;v[a+4244>>2]=(e|0)==(k|0)?0:e;l=l-1|0;continue b}else{h=(A?1-n|0:e)&255;j=v[((h<<2)+a|0)+4248>>2];q=e<<2;r=q+(f+8|0)|0;i=v[r>>2];v[r>>2]=i+4;j=m-j|0;s=z[Fb(p,h+((j>>31&k)+j<<1)|0)>>2];t=z[i>>2];u=C(C(s*z[a+4224>>2])+C(t*z[a+4260>>2]));B=Fb(p,e+y|0),F=C(D(u))<C(1.0000000195414814e-24)?C(0):u,z[B>>2]=F;h=f+q|0;i=v[h>>2];v[h>>2]=i+4;z[i>>2]=C(t*x)+C(o*s);n=n+1|0;e=e+1|0;continue}}break}ai(a,b,c,dd(g,0),dd(g,1),d)}ab=f+16|0}function NF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ab-32|0;ab=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[Ee(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=or(v[a+32>>2]);if((g|0)==-1){break a}t[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];g=v[d>>2];j=v[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(_F(v[a+36>>2],d,i,f,c+16|0,c+20|0,h,c+12|0)-1|0){case 2:break d;case 0:break e;case 1:break b;default:break c}}d=v[a+40>>2];v[d>>2]=g;v[d+4>>2]=j;if((e|0)==8){break b}d=or(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((nr(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break a}}d=v[c+20>>2];v[a+48>>2]=d;break a}d=v[c+20>>2];break a}d=-1}ab=c+32|0;return d}function mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ab-16|0;ab=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){e=v[f+12>>2]+j|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(t[e-2|0],u[h+2>>1])+B(t[e-3|0],u[h>>1])|0)+B(t[e-1|0],u[h+4>>1])|0)+B(t[e|0],u[h+6>>1])|0)+B(t[e+1|0],u[h+8>>1])|0)+B(t[e+2|0],u[h+10>>1])|0)+B(t[e+3|0],u[h+12>>1])|0)+B(t[e+4|0],u[h+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,l);v[c+4>>2]=v[c+4>>2]+B(e,k);Lb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ab-16|0;ab=e;u[e+12>>1]=0;v[e+8>>2]=0;j=8;n=B(c,d)<<1;while(1){if((d|0)!=(l|0)){h=(l<<1)+b|0;o=n+h|0;while(1){if(h>>>0<o>>>0){u[e+6>>1]=0;dR(a,e+15|0,e+12|0,j,e+6|0);g=x[e+6>>1];c=j;while(1){a:{if(!(c&255)){break a}f=x[e+12>>1]<<1;i=f&254;u[e+12>>1]=i;if(i){f=(f&65534)>>>0>255}else{if(!We(a,e+5|0)){break a}f=w[e+5|0];u[e+12>>1]=f<<1&254|1;f=f>>>7|0}c=c-1|0;g=f|g<<1;continue}break}c=1;i=g&65535;b:{if(i>>>0<4){break b}f=15;while(1){c=f;m=f&255;if(i>>>m&1){break b}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;g=f-1^(g&65534)>>>1;f=g+x[e+8>>1]|0;u[e+6>>1]=f;u[h>>1]=f;v[e+8>>2]=((g>>1)-(k<<16>>16)|0)+(f<<16>>16<<1);h=(d<<1)+h|0;j=(c+j&254)>>>1|0;c=-32768;k=v[e+8>>2];c:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break c}}v[e+8>>2]=c}k=f;continue}break}l=l+1|0;continue}break}ab=e+16|0}function OX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=t[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((w[a+1|0]&192)==128){break b}break a}g=b&255;c:{d:{if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=w[a+2|0];b=w[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((b&224)==160){break c}break a}if((b&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>4294967284){break a}f=w[a+3|0];h=w[a+2|0];b=w[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0<48){break e}break a;case 4:if((b&240)==128){break e}break a;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}break b}if((b&224)!=128){break a}}f=3;if((h&192)!=128){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function FB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=ab-560|0;ab=f;u[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=v[e>>2];b:{if(b){c=lO(f,c);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);e=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=e;t[b+8|0]=e>>>8;t[b+9|0]=e>>>16;t[b+10|0]=e>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;Ux(b+48|0,c+48|0);Ux(b+68|0,c+68|0);Ux(b+88|0,c+88|0);gc(b+108|0,c+108|0,448);d=b;zt(c);break b}b=ng(556);if(!b){v[e>>2]=0;break a}d=lO(b,c);v[e>>2]=b}g=a,h=x[Ne(a+480192|0,f+558|0)>>1],u[g+480192>>1]=h}ab=f+560|0;return d|0}function dfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ab-16|0;ab=e;u[e+12>>1]=0;v[e+8>>2]=0;n=B(c,d);k=4;while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){if(i>>>0<o>>>0){t[e+7|0]=0;cR(a,e+15|0,e+12|0,e+7|0);g=w[e+7|0];f=x[e+12>>1];c=k;a:{b:{while(1){if(!(c&255)){break b}c:{h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!We(a,e+6|0)){break c}f=w[e+6|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}u[e+12>>1]=0;break a}u[e+12>>1]=f}c=1;h=g&255;e:{if(h>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;g=f-1^(g&254)>>>1;f=g+w[e+8|0]|0;t[e+7|0]=f;t[i|0]=f;v[e+8>>2]=((g>>1)-(j<<24>>24)|0)+(f<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=v[e+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}v[e+8>>2]=c}j=f;continue}break}l=l+1|0;continue}break}ab=e+16|0}function Bda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=ab-144|0;ab=g;Zn(a);a:{b:{if(!Qf(a,64)){break b}c:{d:{if(!Zk(a,60)){break d}if(!KP(a,14115)){break d}c=15;d=450;break c}Zn(a);if(!Qf(a,128)){break b}b=0;if(!Zk(a,124)){break a}if(!KP(a,15275)){break a}c=31;d=930}Zn(a);b=0;e:{while(1){if((b&65535)>>>0>=c>>>0){break e}b=b+1|0;if(IP(a)>>>0<=131072){continue}break}b=0;break a}Rc(a,4);if(!Qf(a,2)){break b}b=0;e=ab-16|0;ab=e;c=ab-16|0;ab=c;ll(c+8|0,e+8|0);f=v[c+12>>2];$c(c,a,v[c+8>>2],f);h=v[c+4>>2];if((f|0)==(h|0)){Rc(a,v[c+12>>2])}ab=c+16|0;if((f|0)==(h|0)){c=e+8|0;i=Ab(w[c|0]|w[c+1|0]<<8)}ab=e+16|0;if(i>>>0<178){break a}b=-1;if(!Qf(a,d)){break a}Rc(a,d);d=ab-16|0;ab=d;e=g+8|0;MQ(d+8|0,e);c=v[d+12>>2];$c(d,a,v[d+8>>2],c);f=v[d+4>>2];if((f|0)==(c|0)){Rc(a,v[d+12>>2])}ab=d+16|0;a=(c|0)==(f|0);if(!a){Iz(e)}if(!a){break a}b=JP(g+8|0);break a}b=-1}ab=g+144|0;return b|0}function wca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=ab-32|0;ab=f;g=ab-16|0;ab=g;c=a+33|0;e=c+206|0;v[b>>2]=w[e|0]|w[e+1|0]<<8;HK(c,b+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);HK(c,b+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);e=b+236|0;while(1){if((d|0)==96){if(w[c+208|0]){t[b+31|0]=w[c+209|0]+1;e=w[b+31|0];a:{b:{if(!e){d=1;break b}d=16;if(e>>>0<17){break a}}t[b+31|0]=d}d=c+210|0;u[g+14>>1]=w[d|0]|w[d+1|0]<<8;u[g+12>>1]=127;i=b,j=w[Lc(g+14|0,g+12|0)|0]+1|0,t[i+30|0]=j}t[b+33|0]=w[c+212|0];ab=g+16|0}else{i=Yb(e,d+12|0),j=w[c+d|0],u[i>>1]=j;d=d+1|0;continue}break}c=b+236|0;while(1){if((h|0)!=96){e=Yb(c,h+12|0);d=w[(a+h|0)+33|0];u[e>>1]=d>>>0<(w[a+27|0]|w[a+28|0]<<8)>>>0?d:0;h=h+1|0;continue}break}gl(f,3,a+4|0);c=f+16|0;tc(c,v[f>>2],v[f+4>>2],w[f+8|0]);sc(b+492|0,c);pb(c);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}ab=f+32|0}function ru(a){var b=0,c=0,d=0,e=0,f=0;d=ab-16|0;ab=d;a:{if(w[a+3|0]!=19){break a}t[a+3|0]=20;c=a+5|0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=w[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}t[a+3|0]=0;break a}t[a+3|0]=2;t[a+5|0]=b|240;break a}t[a+3|0]=3;t[a+5|0]=b|240;break a}t[c|0]=b&15|16;break a}t[c|0]=b&3|48;break a}t[c|0]=b&15|32;break a}t[c|0]=b&15|176;break a}t[c|0]=b&3|64;break a}t[a+3|0]=15;t[a+5|0]=b&15;break a}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;break a}t[a+3|0]=0;break a}if(b&15){t[a+3|0]=11;t[d+15|0]=14;e=a,f=w[Qb(c,d+15|0)|0]|240,t[e+5|0]=f;break a}t[a+3|0]=0;break a}if((b|0)!=192){break a}t[a|0]=254;t[a+3|0]=0;break a}if((b|0)!=208){break a}t[a+3|0]=0}ab=d+16|0}function naa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=ab-16|0;ab=g;v[g+12>>2]=1;a:{if(Mn(a)){c=v[a>>2];j=$f(c,v[a+4>>2]);v[g+8>>2]=j;k=v[zb(g+12|0,g+8|0)>>2];while(1){if(k){k=k-1|0;if((b|0)!=(c|0)){d=wb(v[b>>2]);h=wb(v[b+4>>2]);f=ab-16|0;ab=f;i=hB(d,h);b:{if(i>>>0<=um(c)>>>0){v[f+8>>2]=h;l=v[c>>2];e=wc(l,v[c+4>>2]);m=e>>>0>=i>>>0;if(m){e=h}else{v[f+8>>2]=d;cO(f+8|0,e);l=v[c>>2];e=v[f+8>>2]}d=Ci(d,e,l);if(!m){fO(c,v[f+8>>2],h,i-wc(v[c>>2],v[c+4>>2])|0);break b}Hd(c,d);break b}eO(c);Ez(c,rj(c,i));fO(c,d,h,i)}ab=f+16|0;wj(c+12|0,b+12|0);u[c+28>>1]=x[b+28>>1]}c=c+32|0;continue}break}if(!j){Zy(a,1-j|0,b);break a}WN(a,v[a>>2]+32|0);break a}if(v[a>>2]){YN(a);d=v[a>>2];Mn(a);xb(d);n=vb(a),o=0,v[n>>2]=o;v[a>>2]=0;v[a+4>>2]=0}e=Bp(a,1);if(TO()>>>0<e>>>0){hd();L()}d=RO(e);v[a>>2]=d;v[a+4>>2]=d;n=vb(a),o=d+(e<<5)|0,v[n>>2]=o;Zy(a,1,b)}ab=g+16|0}
function R9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;l=ab-16|0;ab=l;d=v[$b(l+8|0,wb(v[a+4>>2]))>>2];i=ab-32|0;ab=i;e=d;d=v[a>>2];h=(fm(e,wb(d))<<1)+d|0;g=Iy(b,c);a:{if((g|0)<=0){break a}e=v[vb(a)>>2];d=v[a+4>>2];if((g|0)<=e-d>>1){f=d-h|0;j=f>>1;b:{if((j|0)>=(g|0)){e=c;break b}v[i+8>>2]=b;v[i+8>>2]=v[i+8>>2]+(j<<1);e=v[i+8>>2];VN(a,e,c,g-j|0);if((f|0)<=0){break a}}m=ab-16|0;ab=m;j=v[a+4>>2];f=(j-((g<<1)+h|0)|0)+h|0;g=Ai(m,a,d-f>>1);k=v[g+4>>2];c=f;while(1){if(c>>>0>=d>>>0){dc(g);Wp(h,f,j);ab=m+16|0}else{wi(k,x[c>>1]);k=k+2|0;v[g+4>>2]=k;c=c+2|0;continue}break}zn(b,e,h);break a}f=vb(a);f=qj(i+8|0,rj(a,wc(v[a>>2],d)+g|0),h-v[a>>2]>>1,f);d=ab-16|0;ab=d;e=ho(d,f+8|0,Iy(b,c));c=v[e>>2];while(1){if(v[e+4>>2]!=(c|0)){wi(c,x[b>>1]);c=v[e>>2]+2|0;v[e>>2]=c;b=b+2|0;continue}break}xd(e);ab=d+16|0;h=$N(a,f,h);Bi(f)}wb(h);ab=i+32|0;ab=l+16|0;return a|0}function bF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=ab-32|0;ab=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;i=e;h=c&33554431;if(!(!e&(h|0)==16777216?!(a|b):!e&h>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(h^16777216|a|(b|i)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;zf(g+16|0,a,b,c,e,f-16129|0);Yl(g,a,b,c,e,16257-f|0);b=v[g+8>>2];e=(v[g+12>>2]&33554431)<<7|b>>>25;h=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;f=v[g+4>>2];a=0;b=b&33554431;if(!(!a&(b|0)==16777216?!(h|f):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|h|(a|f)){break a}e=(e&1)+e|0}ab=g+32|0;return l(2,d&-2147483648|e),q()}function e8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=v[a>>2];d=ck(e,v[a+4>>2]);if(d>>>0<b>>>0){h=ab-32|0;ab=h;a:{b:{e=b-d|0;b=v[vb(a)>>2];f=v[a+4>>2];c:{if(e>>>0<=(b-f|0)/52>>>0){yx(a,e,c);break c}d=vb(a);f=uK(a,ck(v[a>>2],f)+e|0);g=ck(v[a>>2],v[a+4>>2]);b=h+8|0;Ve(b+12|0,d);if(f){d=sK(f)}else{d=0}v[b>>2]=d;g=d+B(g,52)|0;v[b+8>>2]=g;v[b+4>>2]=g;i=ic(b),j=d+B(f,52)|0,v[i>>2]=j;v[22452]=0;U(856,b|0,e|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}f=v[a>>2];c=v[a+4>>2];e=b+4|0;while(1){if((c|0)!=(f|0)){d=v[e>>2]-52|0;c=c-52|0;Sj(d,c);v[d+20>>2]=v[c+20>>2];g=v[c+16>>2];v[d+12>>2]=v[c+12>>2];v[d+16>>2]=g;Sj(d+24|0,c+24|0);Ac(d+36|0,c+36|0);v[d+48>>2]=v[c+48>>2];v[e>>2]=v[e>>2]-52;continue}break}cc(a,e);cc(a+4|0,b+8|0);cc(vb(a),ic(b));v[b>>2]=v[b+4>>2];qK(b)}ab=h+32|0;break a}a=P()|0;O()|0;qK(b);S(a|0);L()}return}if(b>>>0<d>>>0){vK(a,e+B(b,52)|0)}}function rda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=ad(d,v[a+4>>2]);if(c>>>0<b>>>0){f=ab-32|0;ab=f;c=b-c|0;b=v[vb(a)>>2];d=v[a+4>>2];a:{if(c>>>0<=(b-d|0)/12>>>0){d=ab-16|0;ab=d;b=kt(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){dc(b);ab=d+16|0}else{lP(a);a=a+12|0;v[b+4>>2]=a;continue}break}break a}b=vb(a);b=ql(f+8|0,to(a,ad(v[a>>2],d)+c|0),ad(v[a>>2],v[a+4>>2]),b);e=ab-16|0;ab=e;d=mP(e,b+8|0,c);c=v[d>>2];while(1){if(v[d+4>>2]!=(c|0)){lP(c);c=v[d>>2]+12|0;v[d>>2]=c;continue}break}xd(d);ab=e+16|0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;Sj(v[d>>2]-12|0,c);v[d>>2]=v[d>>2]-12;continue}break}cc(a,d);cc(a+4|0,b+8|0);cc(vb(a),ic(b));v[b>>2]=v[b+4>>2];a=v[b+4>>2];while(1){c=v[b+8>>2];if((c|0)!=(a|0)){c=c-12|0;v[b+8>>2]=c;nP(c);continue}break}a=v[b>>2];if(a){Yq(b);xb(a)}}ab=f+32|0;return}if(b>>>0<c>>>0){oP(a,d+B(b,12)|0)}}function Vaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=ab-16|0;ab=f;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){g=v[f+8>>2];m=((((v[f+12>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+j|0;e=(((g>>>16|0)+4&131064)<<1)+b|0;n=u[e+38>>1];o=u[e+36>>1];p=u[e+34>>1];q=u[e+32>>1];r=u[e+30>>1];s=u[e+28>>1];t=u[e+26>>1];w=u[e+24>>1];g=0;while(1){if((g|0)!=2){e=(g<<1)+m|0;v[(g<<2)+f>>2]=(((((B(u[e+8>>1],p)+B(u[e+4>>1],q)|0)+B(u[e+12>>1],o)|0)+B(u[e+16>>1],n)|0)/2|0)+((((B(u[e-8>>1],t)+B(u[e-12>>1],w)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)/2|0)|0)/16384;g=g+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],h);Lb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function z7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=C(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0),x=C(0),y=0,A=0,B=C(0);i=v[a+4220>>2];if(i){g=a+44|0;j=Gd(g,0);k=Gd(g,1);l=dd(g,0);m=dd(g,1);n=d;while(1){if(n){f=v[a+4208>>2];o=v[a+4224>>2];e=o-v[a+4228>>2]|0;e=(e>>31&i)+e<<1;y=Fb(f,e);p=z[Fb(f,e|1)>>2];t=z[a+4244>>2];q=z[y>>2];u=z[a+4252>>2];r=z[k>>2];w=z[a+4248>>2];s=z[j>>2];x=z[a+4256>>2];h=C(C(p*t)+C(C(q*u)+C(C(r*w)+C(s*x))));e=o<<1;A=Fb(f,e),B=C(D(h))<C(1.0000000195414814e-24)?C(0):h,z[A>>2]=B;h=C(C(q*t)+C(C(p*u)+C(C(s*w)+C(r*x))));A=Fb(f,e|1),B=C(D(h))<C(1.0000000195414814e-24)?C(0):h,z[A>>2]=B;f=o+1|0;v[a+4224>>2]=(f|0)==(i|0)?0:f;z[l>>2]=C(s*z[a+4240>>2])+C(q*z[a+4236>>2]);z[m>>2]=C(r*z[a+4240>>2])+C(p*z[a+4236>>2]);n=n-1|0;m=m+4|0;l=l+4|0;k=k+4|0;j=j+4|0;continue}else{ai(a,b,c,dd(g,0),dd(g,1),d)}break}}}function Kv(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break a}f=0;t[b|0]=0;a=v[e>>2];v[e>>2]=a+1;t[a|0]=46;if(!ub(h)){break b}a=v[j>>2];if((a-i|0)>159){break b}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!ub(h)){break c}if(!w[b|0]){break a}f=0;a=v[j>>2];if((a-i|0)>159){break b}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b;v[k>>2]=0;return 0}f=-1;a=Mv(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=w[(a>>2)+79744|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=v[e>>2];if((a|0)!=(d|0)){f=-1;if((w[a-1|0]&95)!=(w[c|0]&127)){break b}}v[e>>2]=a+1;t[a|0]=g;return 0}t[c|0]=80;break d}d=t[c|0];if((d|0)!=(g&95)){break d}t[c|0]=d|128;if(!w[b|0]){break d}t[b|0]=0;if(!ub(h)){break d}b=v[j>>2];if((b-i|0)>159){break d}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c}b=v[e>>2];v[e>>2]=b+1;t[b|0]=g;f=0;if((a|0)>84){break b}v[k>>2]=v[k>>2]+1}return f}return-1}function sY(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=v[116320];c=nc(b,v[116321]);if(c>>>0<a>>>0){f=ab-32|0;ab=f;e=a-c|0;b=v[116321];a:{if(e>>>0<=v[116322]-b>>2>>>0){IE(e);break a}g=Ev(465280);c=f+8|0;d=nc(v[116320],b)+e|0;b=ab-16|0;ab=b;v[b+12>>2]=d;b:{a=Jn();if(d>>>0<=a>>>0){d=Ch(465280);if(d>>>0<a>>>1>>>0){v[b+8>>2]=d<<1;a=v[Pc(b+8|0,b+12|0)>>2]}ab=b+16|0;break b}hd();L()}d=nc(v[116320],v[116321]);Ve(c+12|0,g);if(a){b=FE(v[c+16>>2],a)}else{b=0}v[c>>2]=b;d=b+(d<<2)|0;v[c+8>>2]=d;v[c+4>>2]=d;h=ic(c),i=b+(a<<2)|0,v[h>>2]=i;d=ab-16|0;ab=d;a=jl(d,c+8|0,e);b=v[a>>2];while(1){if(v[a+4>>2]!=(b|0)){_s(b);b=v[a>>2]+4|0;v[a>>2]=b;continue}break}xd(a);ab=d+16|0;a=c+4|0;Gn(v[116320],v[116321],a);cc(465280,a);cc(465284,c+8|0);cc(465288,ic(c));v[c>>2]=v[c+4>>2];NO(c);a=v[c>>2];if(a){HE(v[c+16>>2],a,iz(c))}}ab=f+32|0;return}if(a>>>0<c>>>0){Qd(465280,b+(a<<2)|0)}}function Wo(a){a=a|0;var b=0,c=0,d=C(0),e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);b=v[a+36>>2];if(!b){uc(a+16|0);return}a:{b:{switch(x[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){uc(c);return}Ij(c,b);b=u[a+28>>1];d=C(Il(a,(b<<16)+65536>>16)/Il(a,b));a=v[a+36>>2];d=fe(d,C(C(1)/C(a+1>>>0)));b=1;while(1){if(a>>>0<b>>>0){break a}f=fe(d,C(b>>>0));m=Fb(v[c>>2],b-1|0),n=f,z[m>>2]=n;b=b+1|0;continue};case 1:c=a+16|0;g=x[a+30>>1];if(g>>>0>1e3/(b>>>0)>>>0){uc(c);return}Ij(c,B(b,g));j=x[a+30>>1];l=ln(u[a+28>>1],j);c:while(1){if((h&65535)>>>0>=g>>>0){break a}b=1;e=ln(h+l<<16>>16,j)<<16;k=e>>16;d=C(Il(a,e+65536>>16)/Il(a,k));e=v[a+36>>2];d=fe(d,C(C(1)/C(e+1>>>0)));while(1){i=b&65535;if(e>>>0<i>>>0){h=h+1|0;continue c}else{f=fe(d,C(i>>>0));m=Fb(v[c>>2],(B(e,k)+i|0)-1|0),n=f,z[m>>2]=n;b=b+1|0;continue}}};case 0:uc(a+16|0);return;default:break b}}uc(a+16|0);v[a+36>>2]=0}}function eW(){var a=0,b=0,c=0,d=0;c=ab-32|0;ab=c;a:{a=Mb(c+16|0,14944);if(!ub(a)){break a}b:{if((kg(a,14621)|0)!=-1){b=kg(a,14621);v[22452]=0;W(121,c|0,a|0,b+1|0,-1);b=v[22452];v[22452]=0;if((b|0)==1){break b}tb(a,c);pb(c)}if((kg(a,16743)|0)!=-1){b=kg(a,16743);v[22452]=0;W(121,c|0,a|0,b+1|0,-1);b=v[22452];v[22452]=0;if((b|0)==1){break b}tb(a,c);pb(c)}if((kg(a,13838)|0)!=-1){b=kg(a,13838);v[22452]=0;W(121,c|0,a|0,0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break b}tb(a,c);pb(c)}if((kg(a,13687)|0)!=-1){b=kg(a,13687);v[22452]=0;W(121,c|0,a|0,0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break b}tb(a,c);pb(c)}if((kg(a,13730)|0)!=-1){b=kg(a,13730);v[22452]=0;W(121,c|0,a|0,0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break b}tb(a,c);pb(c)}v[22452]=0;b=T(122,a|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;pb(a);S(c|0);L()}pb(a);ab=c+32|0;return b|0}function yB(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if((w[a|0]-16&255)>>>0>=241){f=a+1954|0;d=a+1698|0;a:{while(1){if((d|0)==(f|0)){d=0;f=0;while(1){if((d|0)==32){h=1;break a}b=B(d,13)+a|0;if(w[b+14|0]){break a}e=(d<<4)+a|0;c=e+418|0;if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break a}c=e+422|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if(w[b+942|0]|c>>>0>1048575){break a}b=B(d,11)+a|0;g=b+1346|0;if(w[g|0]>15|w[b+1351|0]>3|w[b+1356|0]>3){break a}b:{c:{d:{if(c){b=e+430|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(b>>>0<=1048574){if(b>>>0>c>>>0){break a}e=e+426|0;if(b>>>0<(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0){break a}}b=1;if(f){break b}if(c){break c}break d}b=1;if(f){break b}}if(Ib(g,26269,11)){break c}b=0;break b}b=1}f=b;d=d+1|0;continue}}e=t[d|0];d=d+1|0;if((e|0)>=-1){continue}break}return 0}a=f&h}else{a=0}return a}function rO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=ab-16|0;ab=g;c=v[a>>2];$b(g+8|0,c);a:{b:{c:{d:{e:{if(td(c+16|0)){while(1){if(b>>>0>31){break e}v[22452]=0;d=ha(43)|0;e=v[22452];v[22452]=0;if((e|0)!=1){f=f|d;b=b+32|0;continue}break}b=V(88980)|0;if((O()|0)!=(fa(88980)|0)){break c}_(b|0)|0;t[c+20|0]=0;v[22452]=0;Z(29,c|0);b=v[22452];v[22452]=0;if((b|0)==1){break d}$();break e}t[c+20|0]=0}if(!w[c+20|0]){c=v[c+24>>2];b=0;d=1;while(1){if(d){d=0;b=v[c+2496>>2];e=c+(b<<2)|0;i=v[c+((b+397>>>0)%624<<2)>>2];h=(b+1>>>0)%624|0;b=v[c+(h<<2)>>2];b=i^(b&2147483647|v[e>>2]&-2147483648)>>>1^B(b&1,-1727483681);v[e>>2]=b;v[c+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}ab=g+16|0;break a}b=P()|0;O()|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)==1){break b}}S(b|0);L()}V(0)|0;O()|0;Gb();L()}return v[a+28>>2]&f}function Al(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;Bk(a);a:{b:{c:{f=v[b+32>>2];d:{if(!f){e=v[b+2084>>2];if(e){break d}break b}c=v[b+4>>2];if((c|0)<9){break c}e=v[b+2084>>2];if(!e){break c}}h=v[a+1392>>2];j=zl(h);d=v[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=y[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}v[a+1392>>2]=h>>>b;b=d-b|0}v[a+1396>>2]=b;return c}if(w[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=w[v[b+8>>2]+d|0];if((c|0)==255){break f}g=v[a+1392>>2];if(v[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=v[a+1396>>2];if((e|0)>=(c|0)){v[a+1392>>2]=g>>>c;v[a+1396>>2]=e-w[v[b+8>>2]+d|0];return d}v[a+1396>>2]=0;break b}d=d+1|0;continue}break}Vb(a,21);v[a+1396>>2]=0}return-1}ca(11352,13164,1705,5406);L()}function j1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=ab-32|0;ab=c;d=v[a>>2];a=v[d>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];g=v[a+8>>2];d=v[a+4>>2];i=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=ab-32|0;ab=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(vf(c)>>>0<g>>>0){break b}j=b+12|0;c:while(1){b=0;if((e|0)==(g|0)){break a}while(1)if((b|0)==(d|0)){e=e+1|0;continue c}else{k=a,l=+(Sl(be(Xf(A[Hg(i,d,b,e)>>3])*134217728))+Wc(Or(j),21)|0)*7.450580596923828e-9,A[k+24>>3]=l;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;h=be(A[qg(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(h)<2147483648){f=~~h;break d}f=-2147483648}f=Jc(f);k=an(c,b,e),m=f,u[k>>1]=m;b=b+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}ab=a+32|0;ab=c+32|0}function _0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=ab-32|0;ab=c;d=v[a>>2];a=v[d>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];g=v[a+8>>2];d=v[a+4>>2];i=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=ab-32|0;ab=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(vf(c)>>>0<g>>>0){break b}j=b+12|0;c:while(1){b=0;if((e|0)==(g|0)){break a}while(1)if((b|0)==(d|0)){e=e+1|0;continue c}else{k=a,l=+(Sl(be(Xf(A[Hg(i,d,b,e)>>3])*134217728))+Wc(Or(j),21)|0)*7.450580596923828e-9,A[k+24>>3]=l;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;h=be(A[qg(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(h)<2147483648){f=~~h;break d}f=-2147483648}f=Jc(f);k=$m(c,b,e),m=f,u[k>>1]=m;b=b+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}ab=a+32|0;ab=c+32|0}function EI(a,b){var c=0,d=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){a:{v[22452]=0;Z(789,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){a=v[c+4>>2];if(v[a>>2]?a:0){d=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(d|0)){b=b-4|0;bg(b);continue}break}v[a+4>>2]=d;b=v[a>>2];Ch(a);xb(b)}xb(a);v[c+4>>2]=0;$x(c+1298408|0);zs(c+1298344|0);pb(c+1298332|0);pb(c+1298320|0);pb(c+1298308|0);ys(c+1298304|0);xs(c+1298300|0);ip(c+1298264|0);Es(c+1074376|0);b=c+946300|0;a=c+906300|0;while(1){b=ep(b-160|0);if((a|0)!=(b|0)){continue}break}ZN(c+484360|0);_x(c+484344|0);ec(c+480248|0);break a}V(0)|0;O()|0;$x(c+1298408|0);zs(c+1298344|0);pb(c+1298332|0);pb(c+1298320|0);pb(c+1298308|0);ys(c+1298304|0);xs(c+1298300|0);ip(c+1298264|0);Es(c+1074376|0);b=c+946300|0;a=c+906300|0;while(1){b=ep(b-160|0);if((a|0)!=(b|0)){continue}break}ZN(c+484360|0);_x(c+484344|0);ec(c+480248|0);Gb();L()}}xb(c)}}function Cl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab-16|0;ab=d;v[a+4>>2]=0;Pi(d+8|0,a,1);if(zd(w[d+8|0])){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22452]=0;b=T(94,b|0)|0;c=v[22452];v[22452]=0;d:{if((c|0)!=1){if(!jc(b,-1)){break d}break b}break c}v[a+4>>2]=v[a+4>>2]+1;continue}}c=v[a+4>>2];while(1){if((b|0)<=(c|0)){break a}c=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22452]=0;c=T(94,c|0)|0;f=v[22452];v[22452]=0;if((f|0)!=1){if(jc(c,-1)){break b}c=v[a+4>>2]+1|0;v[a+4>>2]=c;continue}break}}b=V(0)|0;O()|0;_(b|0)|0;e=1;Oi(v[v[a>>2]-12>>2]+a|0,1);e:{f:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22452]=0;X(95);a=v[22452];v[22452]=0;if((a|0)!=1){break e}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break f}S(a|0);L()}$();break a}V(0)|0;O()|0;Gb()}L()}e=2}Ug(v[v[a>>2]-12>>2]+a|0,e)}ab=d+16|0;return a|0}function Waa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;f=ab-16|0;ab=f;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){g=v[f+8>>2];m=(((v[f+12>>2]&2147483647)<<1|g>>>31)&-2)+j|0;e=(((g>>>16|0)+4&131064)<<1)+b|0;n=u[e+38>>1];o=u[e+36>>1];p=u[e+34>>1];q=u[e+32>>1];r=u[e+30>>1];s=u[e+28>>1];w=u[e+26>>1];x=u[e+24>>1];g=0;while(1){if((g|0)!=2){e=g+m|0;v[(g<<2)+f>>2]=(((((B(t[e+4|0],p)+B(t[e+2|0],q)|0)+B(t[e+6|0],o)|0)+B(t[e+8|0],n)<<8)/2|0)+((((B(t[e-4|0],w)+B(t[e-6|0],x)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)<<8)/2|0)|0)/16384;g=g+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],h);Lb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function $ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=ab-16|0;ab=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;o=v[a+8>>2];p=v[a+12>>2];while(1){b=e;if(d){q=v[a+72>>2];e=v[a+60>>2];g=e;i=e>>31;k=u[(v[h+12>>2]<<1)+n>>1]<<8;e=k;e=oia(g,i,e,e>>31);j=db;g=e;e=v[a+64>>2];i=e;r=e>>31;e=Sb(b,-16777216,16776704);i=oia(i,r,e,e>>31);g=g+i|0;e=db+j|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=v[a+68>>2];f=Sb(f,-16777216,16776704);j=oia(g,g>>31,f,f>>31);g=i+j|0;f=db+e|0;f=g>>>0<j>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Lb(h+8|0,o,p);e=f-(q&k)|0;c=c+8|0;d=d-1|0;f=b;continue}break}v[a+48>>2]=f;v[a+44>>2]=b;b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+16|0}function ZM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=ab-16|0;ab=d;e=Bb(a);g=d,h=kd(b),v[g+8>>2]=h;g=d,h=Ff(b),v[g>>2]=h;b=0;a=0;a:{while(1){b:{if(!aj(d+8|0,d)){if(!a){break b}v[22452]=0;R(49,e|0,65533);a=v[22452];v[22452]=0;if((a|0)!=1){break b}break a}c=w[v[d+8>>2]];c:{if(!a){if(!(c&128)){a=0;v[22452]=0;R(49,e|0,c|0);c=v[22452];v[22452]=0;if((c|0)!=1){break c}break a}if((c&224)==192){b=c&31;a=1;break c}if((c&240)==224){b=c&15;a=2;break c}if((c&248)==240){b=c&7;a=3;break c}b=0;v[22452]=0;R(49,e|0,65533);c=v[22452];v[22452]=0;a=0;if((c|0)==1){break a}break c}if((c&192)!=128){b=0;v[22452]=0;R(49,e|0,65533);f=v[22452];v[22452]=0;a=0;if((f|0)==1){break a}}c=c&63|b<<6;a=a-1|0;if(a){b=c;break c}b=0;v[22452]=0;R(49,e|0,c|0);c=v[22452];v[22452]=0;a=0;if((c|0)==1){break a}}Fe(d+8|0);continue}break}ab=d+16|0;return}a=P()|0;O()|0;Oc(e);S(a|0);L()}function gea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=ab+-64|0;ab=c;n=c,o=Ze(a)>>>5|0,u[n+32>>1]=o;u[c+16>>1]=3999;i=b+480190|0;d=x[Lc(c+32|0,c+16|0)>>1];u[i>>1]=d;j=c+58|0;k=c+56|0;l=c+62|0;g=c+52|0;m=c+60|0;h=1;while(1){f=h&65535;if(f>>>0<=d>>>0){d=Tj(b,f);e=c+32|0;rt(a,e);ed(d,0);lj(c,2,e);e=c+16|0;tc(e,v[c>>2],v[c+4>>2],w[c+8|0]);sc(((f<<5)+b|0)+946304|0,e);pb(e);v[d+24>>2]=8287;n=c,o=Ab(w[m|0]|w[m+1|0]<<8),u[n+16>>1]=o;u[c>>1]=64;n=d,o=x[Lc(e,c)>>1]<<2,u[n+30>>1]=o;n=d,o=Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))&-2,v[n>>2]=o;e=Ab(w[l|0]|w[l+1|0]<<8);n=Fb(d+68|0,0),o=e,v[n>>2]=o;e=Ab(w[k|0]|w[k+1|0]<<8);f=Ab(w[j|0]|w[j+1|0]<<8);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>y[d>>2]){break a}v[d+16>>2]=f;v[d+12>>2]=e<<1;u[d+34>>1]=x[d+34>>1]|8}h=h+1|0;d=x[i>>1];continue}break}ab=c- -64|0}function QC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=ab-32|0;ab=c;v[22452]=0;e=Q(12,c+24|0,462840)|0;d=v[22452];v[22452]=0;a:{b:{c:{if((d|0)!=1){d:{e:{if(!w[e|0]){break e}f=xi(c+8|0,462840);d=v[v[115710]-12>>2]+462840|0;g=v[d+4>>2];v[22452]=0;h=T(13,d|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break d}f=v[f>>2];v[22452]=0;b=a+b|0;a=la(14,f|0,a|0,((g&176)==32?b:a)|0,b|0,d|0,h|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break d}v[c+16>>2]=a;if(!Au(c+16|0)){break e}a=v[v[115710]-12>>2];v[22452]=0;R(15,a+462840|0,5);a=v[22452];v[22452]=0;if((a|0)!=1){break e}break d}dk(e);break b}a=V(0)|0;O()|0;dk(e);break c}a=V(0)|0;O()|0}_(a|0)|0;a=v[v[115710]-12>>2];v[22452]=0;Z(16,a+462840|0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$()}ab=c+32|0;return}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){V(0)|0;O()|0;Gb();L()}S(a|0);L()}function aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=ab-16|0;ab=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;o=v[a+8>>2];p=v[a+12>>2];while(1){b=e;if(d){q=v[a+72>>2];e=v[a+60>>2];g=e;i=e>>31;k=t[v[h+12>>2]+n|0]<<16;e=k;e=oia(g,i,e,e>>31);j=db;g=e;e=v[a+64>>2];i=e;r=e>>31;e=Sb(b,-16777216,16776704);i=oia(i,r,e,e>>31);g=g+i|0;e=db+j|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=v[a+68>>2];f=Sb(f,-16777216,16776704);j=oia(g,g>>31,f,f>>31);g=i+j|0;f=db+e|0;f=g>>>0<j>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Cc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Lb(h+8|0,o,p);e=f-(q&k)|0;c=c+8|0;d=d-1|0;f=b;continue}break}v[a+48>>2]=f;v[a+44>>2]=b;b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;ab=h+16|0}function P8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=ab-32|0;ab=d;e=Bb(d+16|0);a:{b:{c:{if(c>>>0<64){break c}v[22452]=0;c=T(180,b|0)|0;f=v[22452];v[22452]=0;d:{if((f|0)!=1){v[d+12>>2]=c;if((c|0)>0){break d}v[22452]=0;Q(55,a|0,21598)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break b}}break a}v[22452]=0;c=T(193,b|0)|0;f=v[22452];v[22452]=0;if((f|0)!=1){g=d,h=oi(c),v[g+8>>2]=h;c=v[jd(d+12|0,d+8|0)>>2];v[22452]=0;R(46,e|0,c|0);c=v[22452];v[22452]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{v[22452]=0;c=T(197,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break f}if(!c){break e}v[22452]=0;Y(824,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[22452];v[22452]=0;if((c|0)!=1){continue}}break}break a}v[22452]=0;Q(179,b|0,4)|0;b=v[22452];v[22452]=0;if((b|0)==1){break a}Ac(a,e)}pb(e);ab=d+32|0;return}a=P()|0;O()|0;pb(e);S(a|0);L()}function bp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=ab-16|0;ab=c;a:{b:{switch(w[a+480224|0]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;f=oia(b,d,5e4,0);e=db;b=v[Pc(c+8|0,c)>>2];b=vc(pia(f,e,b,b>>31),db);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=oia(v[a+1074420>>2],0,oia(v[a+1074408>>2],0,v[a+1074416>>2],0),db),v[g>>2]=h;v[c+4>>2]=db;b=oia(b,0,6e5,0);d=c+8|0;e=b;f=db;b=Iu(v[d>>2],v[d+4>>2],v[c>>2],v[c+4>>2])?c:d;b=ria(e,f,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];f=oia(b,d,1e4,0);e=db;b=v[Pc(c+8|0,c)>>2];b=vc(pia(f,e,b,b>>31),db);v[a+1074404>>2]=b}e=a+1074404|0;a=v[a+480244>>2];b=oia(a,a>>31,b,b>>31)+32768|0;a=db;a=vc(pia(b,b>>>0<32768?a+1|0:a,65536,0),db);v[e>>2]=a?a:1;ab=c+16|0}function x8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;ed(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;d=a+40|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+44|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=w[b+151|0];if(d>>>0<=4){t[c+38|0]=w[d+42874|0]}d=b+152|0;d=w[d|0]|w[d+1|0]<<8;t[c+39|0]=d;e=b+156|0;e=(w[e|0]|w[e+1|0]<<8)>>>4|0;t[c+41|0]=e;b=b+154|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if((b|e)&255){t[c+39|0]=d^-1}b=a+38|0;a=w[b|0]|w[b+1|0]<<8;if(a&4){u[c+34>>1]=x[c+34>>1]|1;a=w[b|0]|w[b+1|0]<<8}if(a&8){u[c+34>>1]=x[c+34>>1]|2;a=w[b|0]|w[b+1|0]<<8}if(a&16){u[c+34>>1]=x[c+34>>1]|4;a=w[b|0]|w[b+1|0]<<8}if(a&32){u[c+34>>1]=x[c+34>>1]|32}}function o3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-16|0;ab=d;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22452]=0;R(984,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break i}c=v[d>>2];e=ad(c,v[d+4>>2]);if(e>>>0<2147483647){break h}c=aa(8)|0;v[22452]=0;Q(978,c|0,7347)|0;b=v[22452];v[22452]=0;if((b|0)==1){break g}v[22452]=0;U(110,c|0,88756,159);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}if((b|0)<0|(b|0)>=(e|0)){a=21598}else{a=Eb(ld(c,b))}b=$d(a);Uc(d);break d}b=V(0)|0;O()|0;ba(c|0)}Uc(d)}_(b|0)|0;b=0;v[22452]=0;W(911,11756,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break c}$()}ab=d+16|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Gb()}L()}S(a|0);L()}function a3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-16|0;ab=d;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22452]=0;R(992,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break i}c=v[d>>2];e=ad(c,v[d+4>>2]);if(e>>>0<2147483647){break h}c=aa(8)|0;v[22452]=0;Q(978,c|0,7347)|0;b=v[22452];v[22452]=0;if((b|0)==1){break g}v[22452]=0;U(110,c|0,88756,159);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}if((b|0)<0|(b|0)>=(e|0)){a=21598}else{a=Eb(ld(c,b))}b=$d(a);Uc(d);break d}b=V(0)|0;O()|0;ba(c|0)}Uc(d)}_(b|0)|0;b=0;v[22452]=0;W(911,11791,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break c}$()}ab=d+16|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Gb()}L()}S(a|0);L()}function Z2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-16|0;ab=d;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22452]=0;R(994,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break i}c=v[d>>2];e=ad(c,v[d+4>>2]);if(e>>>0<2147483647){break h}c=aa(8)|0;v[22452]=0;Q(978,c|0,7347)|0;b=v[22452];v[22452]=0;if((b|0)==1){break g}v[22452]=0;U(110,c|0,88756,159);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}if((b|0)<0|(b|0)>=(e|0)){a=21598}else{a=Eb(ld(c,b))}b=$d(a);Uc(d);break d}b=V(0)|0;O()|0;ba(c|0)}Uc(d)}_(b|0)|0;b=0;v[22452]=0;W(911,11821,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break c}$()}ab=d+16|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Gb()}L()}S(a|0);L()}function Q2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-16|0;ab=d;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22452]=0;R(997,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break i}c=v[d>>2];e=ad(c,v[d+4>>2]);if(e>>>0<2147483647){break h}c=aa(8)|0;v[22452]=0;Q(978,c|0,7347)|0;b=v[22452];v[22452]=0;if((b|0)==1){break g}v[22452]=0;U(110,c|0,88756,159);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}if((b|0)<0|(b|0)>=(e|0)){a=21598}else{a=Eb(ld(c,b))}b=$d(a);Uc(d);break d}b=V(0)|0;O()|0;ba(c|0)}Uc(d)}_(b|0)|0;b=0;v[22452]=0;W(911,11917,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break c}$()}ab=d+16|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Gb()}L()}S(a|0);L()}function N2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-16|0;ab=d;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22452]=0;R(998,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break i}c=v[d>>2];e=ad(c,v[d+4>>2]);if(e>>>0<2147483647){break h}c=aa(8)|0;v[22452]=0;Q(978,c|0,7347)|0;b=v[22452];v[22452]=0;if((b|0)==1){break g}v[22452]=0;U(110,c|0,88756,159);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}if((b|0)<0|(b|0)>=(e|0)){a=21598}else{a=Eb(ld(c,b))}b=$d(a);Uc(d);break d}b=V(0)|0;O()|0;ba(c|0)}Uc(d)}_(b|0)|0;b=0;v[22452]=0;W(911,11885,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break c}$()}ab=d+16|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Gb()}L()}S(a|0);L()}function G3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-16|0;ab=d;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22452]=0;R(977,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break i}c=v[d>>2];e=ad(c,v[d+4>>2]);if(e>>>0<2147483647){break h}c=aa(8)|0;v[22452]=0;Q(978,c|0,7347)|0;b=v[22452];v[22452]=0;if((b|0)==1){break g}v[22452]=0;U(110,c|0,88756,159);b=v[22452];v[22452]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}if((b|0)<0|(b|0)>=(e|0)){a=21598}else{a=Eb(ld(c,b))}b=$d(a);Uc(d);break d}b=V(0)|0;O()|0;ba(c|0)}Uc(d)}_(b|0)|0;b=0;v[22452]=0;W(911,11853,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break c}$()}ab=d+16|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Gb()}L()}S(a|0);L()}function eU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=ab-16|0;ab=e;ed(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=oq(a+4|0,a);d=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=d;c=oq(a+8|0,a);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+8>>2]=f;c=a+15|0;g=(w[c|0]|w[c+1|0]<<8)<<1;v[b+24>>2]=g;c=w[c|0]|w[c+1|0]<<8?g:16726;v[b+24>>2]=c;g=a+14|0;h=b,i=(B(tu(t[a+17|0],w[g|0]<<28>>24),c)>>>0)/8363|0,v[h+24>>2]=i;t[e+15|0]=w[a+18|0];t[e+14|0]=127;h=b,i=(((w[Qb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[h+30>>1]=i;c=w[g|0];if(c>>>0>=16){u[b+34>>1]=32;u[b+28>>1]=c&240}c=a+19|0;a=w[c|0];if(a&4){u[b+34>>1]=x[b+34>>1]|1;a=w[c|0]}a:{if(!(a&8)|d>>>0>=f>>>0){break a}f=x[b+34>>1];d=f|2;u[b+34>>1]=d;a=w[c|0];if(a&16){d=f|6;u[b+34>>1]=d;a=w[c|0]}if(!(a&64)){break a}u[b+34>>1]=d|128}ab=e+16|0}function eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!w[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=w[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?(w[d-1|0]==13&(i|0)==10)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&w[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}Pe(a);rp(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=t[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}pp(a,e);c=c+1|0;continue}break}}function y4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=ab-32|0;ab=e;v[22452]=0;Z(924,a|0);d=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[22452]=0;Z(925,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break g}v[22452]=0;Z(925,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break g}f=v[a+24>>2];v[22452]=0;d=Q(55,e+16|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break g}v[22452]=0;c=Q(55,e|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break f}v[22452]=0;W(940,f|0,d|0,c|0,1);b=v[22452];v[22452]=0;if((b|0)==1){break e}pb(c);pb(d);b=1;break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;pb(c)}pb(d)}_(b|0)|0;b=0;v[22452]=0;W(911,6370,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$()}ab=e+32|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function $G(a,b,c,d){var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=0;e=ab-96|0;ab=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=z[g+4>>2];f=z[g+8>>2];z[i+4>>2]=h+f;k=d<<1;z[(8-k<<2)+e>>2]=h-f;h=z[g+16>>2];f=z[g+12>>2];z[(7-k<<2)+e>>2]=h-f;z[i+8>>2]=-C(h+f);d=d+1|0;continue}break}_G(e+48|0);_G(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=z[i>>2];f=z[d+(e+48|0)>>2];l=z[d+67168>>2];m=z[d+67204>>2];n=z[d+e>>2];z[i>>2]=C(f*l)-C(m*n);i=a+d|0;d=c+d|0;f=C(C(f*m)+C(n*l));z[i>>2]=C(h*z[d>>2])-C(z[d+36>>2]*f);z[(17-g<<2)+a>>2]=C(h*z[d+36>>2])+C(f*z[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}ab=e+96|0}function j9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=ab-880|0;ab=b;c=Jb(a,0,76);v[c+84>>2]=0;v[c+88>>2]=0;v[c+80>>2]=256;u[c+76>>1]=65535;v[c+92>>2]=0;v[c+96>>2]=0;t[c+100|0]=1;e=c+223848|0;d=c+616|0;a=d;while(1){a=VO(a)+872|0;if((e|0)!=(a|0)){continue}break}e=Pb(c+223848|0);f=c+223860|0;aM(f);g=b+8|0;Jb(g,0,108);oz(b+120|0,48e3);Jb(b+664|0,0,72);t[b+754|0]=0;u[b+752>>1]=65535;t[b+746|0]=0;u[b+744>>1]=65535;t[b+738|0]=0;u[b+736>>1]=65535;v[b+748>>2]=0;v[b+740>>2]=0;Jb(b+756|0,0,103);v[b+868>>2]=0;v[b+872>>2]=0;t[b+875|0]=0;t[b+876|0]=0;t[b+877|0]=0;t[b+878|0]=0;v[b+860>>2]=0;v[b+864>>2]=0;t[b+859|0]=w[b+859|0]&128;a=((d+223232|0)-d|0)/872|0;while(1){if((a|0)>0){a=a-1|0;d=hp(d,g)+872|0;continue}break}v[22452]=0;R(501,e|0,32);a=v[22452];v[22452]=0;if((a|0)!=1){ab=b+880|0;return c|0}a=P()|0;O()|0;jp(f);Xb(e);S(a|0);L()}function X7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=ab-32|0;ab=f;j=cf(a,c);Xd(f+8|0,v[a+28>>2]);c=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=c;k=a;a:{if(!j){c=0;if(Vc(a,5)){break a}}e=ab-48|0;ab=e;h=v[a+28>>2];qk(h,e+40|0);c=v[e+44>>2];if(!c&y[e+40>>2]>=257|c){v[e+40>>2]=256;v[e+44>>2]=0}l=v[e+40>>2];m=v[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!m&c>>>0>=l>>>0){break b}Kf(h,e+38|0);g=Bb(e+24|0);v[22452]=0;Q(444,h|0,g|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;U(11,e+8|0,d|0,g|0);a=v[22452];v[22452]=0;if((a|0)==1){break e}v[22452]=0;a=Q(865,b|0,e+38|0)|0;i=v[22452];v[22452]=0;if((i|0)==1){break d}i=a;a=e+8|0;tb(i,a);pb(a);pb(g);c=c+1|0;continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;pb(e+8|0)}pb(g);S(c|0);L()}ab=e+48|0;c=j}Te(k,c,f+24|0);ab=f+32|0}function iM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ab-16|0;ab=e;h=-1;a:{if(!Px(a,b,2)){break a}f=v[b+656>>2];g=a+1074312|0;rb(e+8|0,g,31);b:{if(sb(v[v[e+8>>2]>>2],v[e+12>>2])){d=v[b+740>>2];if(d){break b}break a}d=v[b+740>>2]}rb(e+8|0,g,31);g=d-sb(v[v[e+8>>2]>>2],v[e+12>>2])|0;i=v[a+480180>>2];d=(i|0)==4096;j=f+88|0;f=d?64:(i|0)==16384?192:512;d=wp(j,g,f,d?255:64)-(f>>>1|0)|0;if(w[b+746|0]&16){h=mp(a,b,!(v[b+88>>2]&32768),d);break a}if(hj(v[b+656>>2])){if((d|0)==u[b+772>>1]){break a}k=b,l=Jc(d),u[k+772>>1]=l;t[b+851|0]=w[b+851|0]|64;break a}a=_i(a);v[e+8>>2]=d;c:{if((d|0)<0){v[e+8>>2]=0-d;Jh(e+8|0,255);a=(v[e+8>>2]<<2)+(a?38320:37296)|0;break c}Jh(e+8|0,255);a=(v[e+8>>2]<<2)+(a?37296:38320)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];k=c,l=vc(pia(oia(b,d,a,a>>31),db,65536,0),db),v[k>>2]=l}ab=e+16|0;return h}function hy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=x[a+480188>>1];h=d>>>0>256?d:256;f=a+1298300|0;c=d;a:{while(1){if((c|0)!=(h|0)){e=B(c,872)+a|0;if(!v[e+1075068>>2]){if(!Kj(v[e+1075648>>2])|w[e+1075081|0]&24){break a}}if(w[e+1075081|0]&2){if(!td(f)){break a}if(!RL(v[f>>2],c&65535)){break a}}c=c+1|0;continue}break}e=0;f=65535;g=8388608;if(b>>>0<=255){b=B(b,872)+a|0;if(!v[b+1075688>>2]){c=65535;if(v[b+1075068>>2]){break a}}g=v[b+1075680>>2]|v[b+1075672>>2]<<9}while(1){if((d|0)==(h|0)){c=f;break a}b=B(d,872)+a|0;if(!(v[b+1075688>>2]?0:v[b+1075068>>2])){c=(v[b+1075680>>2]|v[b+1075672>>2]<<9)>>>(v[b+1075080>>2]>>>1&1)|0;b:{c:{if(c>>>0<g>>>0){b=v[(B(d,872)+a|0)+1075716>>2];break c}if((c|0)!=(g|0)){break b}b=v[(B(d,872)+a|0)+1075716>>2];if(e>>>0>=b>>>0){break b}}g=c;f=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function Vv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a:{if(b&3){while(1){c=w[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=v[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=v[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;d=w[b|0];if((d|0)!=61){b=c+1|0;if(d){continue}}break}b=c}f=b-a|0;if(!f){return 0}c:{if(w[a+f|0]){break c}e=v[115842];if(!e){break c}b=v[e>>2];if(!b){break c}while(1){d:{c=b;g=f;i=0;h=a;d=w[a|0];e:{if(!d){break e}while(1){f:{j=w[c|0];if(!j){break f}g=g-1|0;if(!g|(d|0)!=(j|0)){break f}c=c+1|0;d=w[h+1|0];h=h+1|0;if(d){continue}break e}break}i=d}if(w[c|0]==(i&255)){b=b+f|0;if(w[b|0]==61){break d}}b=v[e+4>>2];e=e+4|0;if(b){continue}break c}break}k=b+1|0}return k}function j5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0);i=ab-16|0;ab=i;j=a+44|0;if(Ih(j)){g=Gd(j,0);v[i+8>>2]=g;k=Gd(j,1);v[i+12>>2]=k;e=dd(j,0);v[i>>2]=e;h=dd(j,1);v[i+4>>2]=h;a:{if(z[a+4216>>2]!=C(.5)){g=d;b:while(1){k=0;if(!g){break a}while(1)if((k|0)==2){g=g-1|0;continue b}else{h=k<<2;e=h+(i+8|0)|0;f=v[e>>2];v[e>>2]=f+4;e=a+h|0;m=e+4248|0;p=z[m>>2];l=z[f>>2];q=z[a+4236>>2];r=z[a+4232>>2];s=z[a+4228>>2];t=z[a+4220>>2];u=z[a+4224>>2];f=e+4240|0;n=z[f>>2];z[m>>2]=n;z[f>>2]=l;f=e+4264|0;w=z[f>>2];e=e+4256|0;o=z[e>>2];z[f>>2]=o;l=C(C(C(C(s*p)+C(C(t*l)+C(u*n)))-C(r*o))-C(q*w));z[e>>2]=l;h=i+h|0;e=v[h>>2];v[h>>2]=e+4;z[e>>2]=l;k=k+1|0;continue}}}f=g;g=d<<2;gc(e,f,g);gc(h,k,g)}ai(a,b,c,dd(j,0),dd(j,1),d)}ab=i+16|0}function k3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=ab-48|0;ab=c;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;a:{b:{c:{if((b|0)!=1){d=Bb(c+32|0);v[22452]=0;Z(989,c+16|0);b=v[22452];v[22452]=0;d:{e:{if((b|0)!=1){g=c,h=wb(v[c+16>>2]),v[g+8>>2]=h;e=1;while(1){f=wb(v[c+20>>2]);b=v[c+8>>2];if(!Tb(b,f)){b=$d(Eb(d));Uc(c+16|0);pb(d);break b}if(!e){v[22452]=0;Q(913,d|0,14596)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}b=v[c+8>>2]}v[22452]=0;Q(776,d|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}Sn(c+8|0);e=0;continue}}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;Uc(c+16|0)}pb(d);break c}b=V(0)|0;O()|0}_(b|0)|0;b=0;v[22452]=0;W(911,6552,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$()}ab=c+48|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);c=v[22452];v[22452]=0;if((c|0)==1){V(0)|0;O()|0;Gb();L()}S(a|0);L()}function gd(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;a:{if(t[463652]&1){break a}if(!Jd(463652)){break a}b=ab-32|0;ab=b;b:{c:{while(1){e=(b+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=CF(a,d?14270:21598)}else{d=v[a<<2>>2]}v[e>>2]=d;if((d|0)!=-1){a=a+1|0;if((a|0)==6){break c}continue}break}break b}if(!BF(0)){c=85472;if(!Ib(b+8|0,85472,24)){break b}c=85496;if(!Ib(b+8|0,85496,24)){break b}a=0;if(!w[463424]){while(1){f=(a<<2)+463376|0,g=CF(a,21598),v[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}t[463424]=1;v[115850]=v[115844]}c=463376;if(!Ib(b+8|0,463376,24)){break b}c=463400;if(!Ib(b+8|0,463400,24)){break b}c=yd(24);if(!c){break b}}a=v[b+12>>2];v[c>>2]=v[b+8>>2];v[c+4>>2]=a;a=v[b+28>>2];v[c+16>>2]=v[b+24>>2];v[c+20>>2]=a;a=v[b+20>>2];v[c+8>>2]=v[b+16>>2];v[c+12>>2]=a}ab=b+32|0;v[115912]=c;Id(463652)}return v[115912]}function E3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=ab-48|0;ab=c;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;a:{b:{c:{if((b|0)!=1){d=Bb(c+32|0);v[22452]=0;Z(981,c+16|0);b=v[22452];v[22452]=0;d:{e:{if((b|0)!=1){g=c,h=wb(v[c+16>>2]),v[g+8>>2]=h;e=1;while(1){f=wb(v[c+20>>2]);b=v[c+8>>2];if(!Tb(b,f)){b=$d(Eb(d));Uc(c+16|0);pb(d);break b}if(!e){v[22452]=0;Q(913,d|0,14596)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}b=v[c+8>>2]}v[22452]=0;Q(776,d|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}Sn(c+8|0);e=0;continue}}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;Uc(c+16|0)}pb(d);break c}b=V(0)|0;O()|0}_(b|0)|0;b=0;v[22452]=0;W(911,7015,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$()}ab=c+48|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);c=v[22452];v[22452]=0;if((c|0)==1){V(0)|0;O()|0;Gb();L()}S(a|0);L()}function bP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;f=ab-16|0;ab=f;n=v[a+20>>2];e=x[a+34>>1]&65;v[f+8>>2]=e;v[f>>2]=e^65;h=a+24|0;o=d+1298224|0;e=d+1074992|0;i=_i(d);p=a+4|0;q=a+12|0;r=a+8|0;s=a+16|0;t=d+480180|0;while(1){if((e|0)!=(o|0)){if(v[e+104>>2]==(a|0)){if(v[e+16>>2]){v[e+16>>2]=b}if(y[e+4>>2]>c>>>0){v[e>>2]=0;v[e+4>>2]=0}if(v[e+76>>2]){mc(e+76|0,c)}d=RC(e);g=v[(d?q:p)>>2];v[e+84>>2]=v[(d?s:r)>>2];v[e+80>>2]=g;d=v[e+88>>2]|v[f+8>>2];v[e+88>>2]=d;v[e+88>>2]=d&(v[f>>2]^-1);d=e+704|0;j=v[a+24>>2];a:{if(!v[e+704>>2]|!j){break a}if(_l(v[t>>2])){break a}g=v[(i?d:h)>>2];k=oia(v[(i?h:d)>>2],0,v[e+700>>2],0);l=k+(g>>>1|0)|0;m=db;u=e,w=Fc(ria(l,k>>>0>l>>>0?m+1|0:m,g,0),db),v[u+700>>2]=w}v[d>>2]=j}e=e+872|0;continue}break}v[a>>2]=c;v[a+20>>2]=b;az(n);ab=f+16|0}function HK(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;l=ab-16|0;ab=l;t[l+15|0]=c;t[l+14|0]=12;Wg(b,w[Qb(l+15|0,l+14|0)|0]);m=v[b>>2];c=0;while(1){if(Td(b)>>>0<=c>>>0){c=0;t[b+12|0]=0;a:{if(!(d&1)){break a}if(jc(m,v[b+4>>2])){break a}c=1;t[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;t[b+12|0]=c}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=c|2}t[b+14|0]=g;t[b+13|0]=f}ab=l+16|0}else{b:{c:{d:{switch(h|0){case 0:i=Fb(m,c);j=(c<<2)+a|0;k=j+96|0;u[i>>1]=w[k|0]|w[k+1|0]<<8;j=j+98|0;break c;case 1:break d;default:break b}}i=Fb(m,c);j=(c<<2)+a|0;k=j+144|0;u[i>>1]=w[k|0]|w[k+1|0]<<8;j=j+146|0}t[i+2|0]=w[j|0]}e:{if(!c){break e}j=Fb(m,c);i=x[j>>1];k=Fb(m,c-1|0);n=x[k>>1];if(i>>>0>255|i>>>0>=n>>>0){break e}i=i|n&65280;u[j>>1]=i;if(i>>>0>=x[k>>1]){break e}u[j>>1]=i+256}c=c+1|0;continue}break}}function G7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{if((sj(v[a>>2],v[a+4>>2])|0)==2){if((sj(v[a+12>>2],v[a+16>>2])|0)==(b|0)){break a}}v[22452]=0;R(877,a|0,2);e=v[22452];v[22452]=0;b:{c:{d:{if((e|0)==1){break d}v[22452]=0;e=a;R(877,a+12|0,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break d}v[22452]=0;R(878,a+24|0,2);d=v[22452];v[22452]=0;if((d|0)==1){break d}v[22452]=0;d=a;R(878,a+36|0,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break d}c=0;break c}b=V(88408)|0;if((O()|0)!=(fa(88408)|0)){break b}_(b|0)|0;uc(a);bK(a);b=a+12|0;uc(b);bK(b);b=a+24|0;uc(b);aK(b);a=a+36|0;uc(a);aK(a);$();break a}while(1){if((c|0)!=2){f=io(v[a>>2],c);g=Fb(v[a+24>>2],c),h=f,v[g>>2]=h;c=c+1|0;continue}break}a=0;while(1){if((a|0)==(b|0)){break a}c=io(v[e+12>>2],a);g=Fb(v[d+36>>2],a),h=c,v[g>>2]=h;a=a+1|0;continue}}S(b|0);L()}}function uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=ab-32|0;ab=f;c=cf(a,c);Xd(f+8|0,v[a+28>>2]);e=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=e;a:{if(!c){if(Vc(a,5)){break a}}d=ab-32|0;ab=d;g=v[a+28>>2];Kf(g,d+30|0);b:{c:{d:{e:{e=x[d+30>>1];if(e>>>0>=4001){i=v[b+12>>2];e=ab-16|0;ab=e;h=Mb(e,15875);Ac(d,h);pb(h);ab=e+16|0;v[22452]=0;U(437,d+16|0,d|0,d+30|0);e=v[22452];v[22452]=0;if((e|0)==1){break e}e=v[i+1298464>>2];v[22452]=0;U(364,e|0,2,d+16|0);e=v[22452];v[22452]=0;if((e|0)==1){break d}pb(d+16|0);yb(d);e=4e3}mf(jj(b,0),e);b=jj(b,0);j=d,k=wb(v[b>>2]),v[j+16>>2]=k;b=wb(v[b+4>>2]);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;pb(d+16|0)}yb(d);S(a|0);L()}while(1){e=v[d+16>>2];if(Tb(e,b)){Kf(g,d);u[e>>1]=x[d>>1];Ke(d+16|0);continue}break}ab=d+32|0;d=c}Te(a,d,f+24|0);ab=f+32|0}function XG(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=v[a+32>>2];a:{b:{b=v[a+1380>>2];if((b|0)==-1){d=1;b=-1;break b}e=v[a+1116>>2];d=(b|0)>(e|0)?b:e;while(1){c:{if((b|0)!=(d|0)){f=w[(a+b|0)+1120|0];c=f+c|0;if((f|0)==255){break c}d=b}if(y[a+40>>2]<c>>>0){Vb(a,1);break a}b=(d|0)==(e|0)?-1:d;d=0;break b}b=b+1|0;continue}}while(1){if((b|0)!=-1){return 1}e=v[a+40>>2];if(e>>>0<=c+26>>>0){Vb(a,1);break a}if(Ib(c,89320,4)){Vb(a,21);break a}if(w[c+4|0]){Vb(a,21);break a}d:{if(d){if(!v[a+992>>2]|!(t[c+5|0]&1)){break d}Vb(a,21);break a}if(t[c+5|0]&1){break d}Vb(a,21);break a}b=0;f=c+27|0;d=w[c+26|0];c=f+d|0;if(e>>>0<c>>>0){Vb(a,1);break a}while(1){e:{if((b|0)==(d|0)){b=d;break e}g=w[b+f|0];c=g+c|0;if((g|0)!=255){break e}b=b+1|0;continue}break}b=(b|0)==(d|0)?-1:b;d=0;if(c>>>0<=e>>>0){continue}break}Vb(a,1)}return 0}function vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=ab-16|0;ab=b;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=((((v[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;m=u[e+39878>>1];n=u[e+39876>>1];o=u[e+39874>>1];p=u[e+39872>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+l|0;v[(e<<2)+b>>2]=(((B(u[f>>1],o)+B(u[f-4>>1],p)|0)+B(u[f+4>>1],n)|0)+B(u[f+8>>1],m)|0)/16384;e=e+1|0;continue}break}e=v[a+32>>2];h=v[a+28>>2]+h|0;v[c>>2]=v[c>>2]+B(v[b>>2],h>>12);g=e+g|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g>>12);Lb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=g;v[a+36>>2]=h;v[a+20>>2]=h>>12;v[a+24>>2]=g>>12;c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function gF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=ab-32|0;ab=h;a:{b:{c:{if((b|0)!=(c|0)){j=v[114934];v[114934]=0;g=ab-16|0;ab=g;gd();e=ab-16|0;ab=e;f=ab-16|0;ab=f;Tv(f,b,h+28|0,2);k=v[f>>2];i=v[f+4>>2];b=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=b;v[e>>2]=k;v[e+4>>2]=i;ab=f+16|0;i=v[e>>2];f=v[e+4>>2];b=v[e+12>>2];v[g+8>>2]=v[e+8>>2];v[g+12>>2]=b;v[g>>2]=i;v[g+4>>2]=f;ab=e+16|0;f=v[g>>2];e=v[g+4>>2];b=v[g+12>>2];v[h+16>>2]=v[g+8>>2];v[h+20>>2]=b;v[h+8>>2]=f;v[h+12>>2]=e;ab=g+16|0;i=v[h+16>>2];f=v[h+20>>2];g=v[h+8>>2];e=v[h+12>>2];b=v[114934];if(!b){break c}if(v[h+28>>2]!=(c|0)){break b}l=g;m=e;n=i;o=f;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[114934]=j;if(v[h+28>>2]==(c|0)){break a}}v[d>>2]=4;g=l;e=m;i=n;f=o}v[a>>2]=g;v[a+4>>2]=e;v[a+8>>2]=i;v[a+12>>2]=f;ab=h+32|0}function D1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=ab-32|0;ab=c;j=c,k=GI(),v[j+24>>2]=k;g=a+24|0;e=c+24|0;EI(g,Pd(e));Zh(e);u[a+28>>1]=0;xO();f=ab-16|0;ab=f;d=pc(144);v[22452]=0;h=Q(1038,d|0,4)|0;i=v[22452];v[22452]=0;a:{if((i|0)!=1){d=v[yf(f+8|0,h)>>2];ab=f+16|0;break a}a=P()|0;O()|0;xb(d);S(a|0);L()}v[c+24>>2]=d;DI(a+32|0,Pd(e));Lo(e);j=c,k=FI(v[a>>2]),v[j+24>>2]=k;d=a+4|0;CI(d,Pd(e));Yh(e);dn(v[g>>2],v[d>>2]);v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;t[a- -64|0]=0;j=c,k=al(b),v[j+24>>2]=k;j=c,k=Af(b),v[j+16>>2]=k;b:{while(1){if(!Qg(c+24|0,c+16|0)){break b}d=id(c+24|0);b=Rf(c,d);v[22452]=0;W(940,a|0,b|0,d+12|0,0);d=v[22452];v[22452]=0;if((d|0)!=1){pb(b);Uj(c+24|0);continue}break}a=P()|0;O()|0;pb(b);S(a|0);L()}ab=c+32|0}function cK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=ab-16|0;ab=d;a:{if(nc(v[a>>2],v[a+4>>2])>>>0>511){break a}if(!uh(v[v[b>>2]-12>>2]+b|0)){break a}g=ab-16|0;ab=g;e=pc(64);v[22452]=0;h=T(811,e|0)|0;f=v[22452];v[22452]=0;b:{c:{if((f|0)!=1){e=yf(g,h);f=v[e>>2];v[22452]=0;h=Y(872,f|0,b|0,c|0)|0;f=v[22452];v[22452]=0;d:{e:{if((f|0)!=1){if((h|0)==1){break e}of(g+8|0);break d}a=P()|0;O()|0;bg(e);break c}Oh(g+8|0,e)}bg(e);ab=g+16|0;f=v[g+8>>2];break b}a=P()|0;O()|0;xb(e)}S(a|0);L()}v[d+8>>2]=f;f:{g:{if(!td(d+8|0)){v[22452]=0;c=Q(871,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break g}v[d>>2]=c;fS(d+8|0,Pd(d));bg(d)}if(!td(d+8|0)){break f}b=d+8|0;i=v[b>>2];v[22452]=0;R(446,a|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){break f}}a=P()|0;O()|0;bg(d+8|0);S(a|0);L()}bg(d+8|0)}ab=d+16|0;return i}function uz(a,b){var c=0;c=ab-16|0;ab=c;a=by(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(Db(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:Xx(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Cf(a,107);break a;case 3:Xx(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Cf(a,4);break a;case 2:break b;case 0:break c}}Db(a,88,1);break a}Xx(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}ab=c+16|0}function bJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=ab-48|0;ab=j;k=v[a+4>>2];l=v[a>>2];a=v[a+8>>2];v[j+32>>2]=b;v[j+44>>2]=a;v[j+36>>2]=l;v[j+40>>2]=k;v[22452]=0;a=Q(904,(d?d:905)|0,e|0)|0;b=v[22452];v[22452]=0;a:{b:{c:{d:{if((b|0)!=1){v[j+16>>2]=a;a=v[Oo(j+24|0,j+16|0)>>2];b=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=b;v[22452]=0;b=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=b;c=+za(906,j|0,+c,a|0);a=v[22452];v[22452]=0;if((a|0)==1){break d}oe(j+16|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;oe(j+16|0)}_(a|0)|0;v[22452]=0;ja(907,15025,d|0,e|0,f|0,g|0,h|0,i|0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();c=0}ab=j+48|0;return+c}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=ab-16|0;ab=b;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=(((v[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;m=u[e+39878>>1];n=u[e+39876>>1];o=u[e+39874>>1];p=u[e+39872>>1];e=0;while(1){if((e|0)!=2){f=e+l|0;v[(e<<2)+b>>2]=(((B(t[f|0],o)+B(t[f-2|0],p)|0)+B(t[f+2|0],n)|0)+B(t[f+4|0],m)<<8)/16384;e=e+1|0;continue}break}e=v[a+32>>2];h=v[a+28>>2]+h|0;v[c>>2]=v[c>>2]+B(v[b>>2],h>>12);g=e+g|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g>>12);Lb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=g;v[a+36>>2]=h;v[a+20>>2]=h>>12;v[a+24>>2]=g>>12;c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function k1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=ab-32|0;ab=b;c=v[a>>2];a=v[c>>2];wf(b+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[c+4>>2];g=v[a+8>>2];f=v[a+4>>2];i=v[a>>2];a=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=a;a=v[b+20>>2];v[b>>2]=v[b+16>>2];v[b+4>>2]=a;a=ab-32|0;ab=a;a:{b:{if(y[b+4>>2]>=f>>>0){if(vf(b)>>>0<g>>>0){break b}c:while(1){c=0;if((d|0)==(g|0)){break a}while(1)if((c|0)==(f|0)){d=d+1|0;continue c}else{j=a,k=A[Hg(i,f,c,d)>>3],A[j+24>>3]=k;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;h=be(A[qg(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(h)<2147483648){e=~~h;break d}e=-2147483648}e=Jc(e);j=an(b,c,d),l=e,u[j>>1]=l;c=c+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}ab=a+32|0;ab=b+32|0}function $0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=ab-32|0;ab=b;c=v[a>>2];a=v[c>>2];wf(b+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[c+4>>2];g=v[a+8>>2];f=v[a+4>>2];i=v[a>>2];a=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=a;a=v[b+20>>2];v[b>>2]=v[b+16>>2];v[b+4>>2]=a;a=ab-32|0;ab=a;a:{b:{if(y[b+4>>2]>=f>>>0){if(vf(b)>>>0<g>>>0){break b}c:while(1){c=0;if((d|0)==(g|0)){break a}while(1)if((c|0)==(f|0)){d=d+1|0;continue c}else{j=a,k=A[Hg(i,f,c,d)>>3],A[j+24>>3]=k;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;h=be(A[qg(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(h)<2147483648){e=~~h;break d}e=-2147483648}e=Jc(e);j=$m(b,c,d),l=e,u[j>>1]=l;c=c+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}ab=a+32|0;ab=b+32|0}function T6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=ab-4112|0;ab=c;h=eb[v[v[a>>2]+116>>2]](a)|0;if(!h){eb[v[v[a>>2]+120>>2]](a)}v[c+12>>2]=0;f=ab-16|0;ab=f;while(1){d=v[a+44>>2];if(sj(d,v[a+48>>2])>>>0<=e>>>0){ab=f+16|0}else{v[f+12>>2]=0;d=io(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){z[d>>2]=z[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){v[c+8>>2]=b;mc(c+8|0,512);e=c+16|0;ay(e);d=v[c+8>>2];eb[v[v[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;z[c+4>>2]=D(z[g>>2]);i=c,j=z[gx(c+12|0,c+4|0)>>2],z[i+12>>2]=j;z[c+4>>2]=D(z[g+2048>>2]);i=c,j=z[gx(c+12|0,c+4|0)>>2],z[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){eb[v[v[a>>2]+124>>2]](a)}ab=c+4112|0;return C(z[c+12>>2])}function rB(a,b){var c=0,d=0;d=w[a|0];if(d>>>0>=36){t[a|0]=0;return}c=w[d+26304|0];t[a|0]=c;a:{b:{c:{switch(c-17|0){default:d:{if(c-6>>>0<2){break d}if((c|0)==31){break b}if((c|0)==11){break d}if(w[b|0]|(c|0)!=1){break a}t[a|0]=0;return}c=w[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}t[b|0]=a;return;case 6:a=w[b|0];if(a>>>0<=64){t[b|0]=a<<1;return}t[b|0]=128;return;case 2:e:{f:{g:{h:{c=w[b|0];switch((c&240)-48>>>4|0){case 4:break e;case 2:break f;case 1:break g;case 0:break h;default:break a}}t[a|0]=20;t[b|0]=159;return}t[a|0]=20;t[b|0]=192;return}if(c&14){break a}t[a|0]=21;t[b|0]=(w[b|0]!=80)<<6;return}t[a|0]=20;t[b|0]=w[b|0]&15|160;return;case 1:case 3:case 4:case 5:break a;case 0:break c}}if(w[b|0]>31){break a}t[a|0]=16;return}t[b|0]=(d<<5|w[b|0]<<24>>>27)^128}}function h2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ab+-64|0;ab=d;a:{b:{if((b|0)>=0){e=a+24|0;if(ej(Kb(v[e>>2]+484360|0))>>>0>b>>>0){break b}}a=a+16|0;break a}f=Yb(v[Kb(v[e>>2]+484360|0)>>2],b);c:{g=v[e>>2]+484344|0;f=x[f>>1];if(!lm(g,f)){break c}if((c|0)>=0){h=c;if(v[Rb(g,f)+12>>2]>(c|0)){break c}}a=a+16|0;break a}u[v[e>>2]+1074448>>1]=b;b=b&65535;gL(v[e>>2],b);v[v[e>>2]+1074428>>2]=h;v[v[e>>2]+1074392>>2]=-2;c=v[e>>2];e=w[a+64|0];u[d+28>>1]=0;t[d+30|0]=255;v[d+40>>2]=2;v[d+24>>2]=0;v[d+32>>2]=h;u[d+36>>1]=b;b=v[d+44>>2];v[d+16>>2]=v[d+40>>2];v[d+20>>2]=b;b=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=b;b=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=b;b=d+48|0;tt(b,c,e?7:1,d);i=a,j=A[$K(v[d+52>>2])>>3],A[i+16>>3]=j;ni(b);a=a+16|0}ab=d- -64|0;return+A[a>>3]}function Taa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=ab-16|0;ab=f;h=v[a+40>>2];i=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){m=v[a+32>>2];e=(v[f+12>>2]<<1)+j|0;g=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[g+34>>1])+B(u[e+2>>1],u[g+32>>1])|0)+B(u[e+6>>1],u[g+36>>1])|0)+B(u[e+8>>1],u[g+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+26>>1])+B(u[e-6>>1],u[g+24>>1])|0)+B(u[e-2>>1],u[g+28>>1])|0)+B(u[e>>1],u[g+30>>1])|0)/2|0)|0)/16384|0;i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(e,i>>12);h=h+m|0;v[c+4>>2]=v[c+4>>2]+B(e,h>>12);Lb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=h;v[a+36>>2]=i;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function cd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=v[a+112>>2];d=v[a+116>>2];e=!!(b|d);c=b;a:{i=e;f=v[a+4>>2];e=v[a+44>>2];b=f-e|0;h=b;g=b+v[a+120>>2]|0;b=v[a+124>>2]+(b>>31)|0;b=g>>>0<h>>>0?b+1|0:b;if(!(i&(c>>>0<=g>>>0&(b|0)>=(d|0)|(b|0)>(d|0)))){h=_v(a);if((h|0)>=0){break a}f=v[a+4>>2];e=v[a+44>>2]}v[a+112>>2]=-1;v[a+116>>2]=-1;v[a+104>>2]=f;c=e-f|0;d=c+g|0;b=(c>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<c>>>0?b+1|0:b;return-1}d=g+1|0;b=d?b:b+1|0;f=v[a+4>>2];e=v[a+8>>2];c=v[a+112>>2];g=v[a+116>>2];b:{if(!(c|g)){break b}i=c-d|0;c=g-(b+(d>>>0>c>>>0)|0)|0;j=e-f|0;g=j>>31;if((c|0)>=(g|0)&i>>>0>=j>>>0|(c|0)>(g|0)){break b}e=f+i|0}v[a+104>>2]=e;c=v[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){t[f-1|0]=h}return h}function Xi(a,b,c){var d=0,e=0,f=0,g=0;e=ab-48|0;ab=e;d=a+24|0;g=v[v[d>>2]+24620>>2];a:{if(!((g|0)!=(b|0)|v[v[d>>2]+24624>>2]!=(c|0))){if(w[a+29|0]){break a}ZK(v[d>>2],1);break a}f=e+8|0;gc(f,v[d>>2]+24604|0,40);v[e+28>>2]=c;v[e+24>>2]=b;c=v[e+44>>2];Vr(f,v[e+40>>2]);Bn(f,c);Tx(v[d>>2],f);if((b|0)==(g|0)){break a}b=v[d>>2];f=b+946300|0;c=b+906300|0;while(1){if((c|0)!=(f|0)){b=v[c>>2];b:{if(!b){break b}if(!(eb[v[v[b>>2]+116>>2]](b)|0)){break b}eb[v[v[b>>2]+108>>2]](b,0);eb[v[v[b>>2]+96>>2]](b);eb[v[v[b>>2]+124>>2]](b)}c=c+160|0;continue}break}b=v[d>>2];d=b+946300|0;c=b+906300|0;while(1){if((c|0)!=(d|0)){b=v[c>>2];c:{if(!b){break c}if(eb[v[v[b>>2]+116>>2]](b)|0){break c}eb[v[v[b>>2]+108>>2]](b,1);eb[v[v[b>>2]+120>>2]](b)}c=c+160|0;continue}break}}t[a+29|0]=1;ab=e+48|0}function tn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=v[b+88>>2];d=c|2048;v[b+88>>2]=d;f=v[b+656>>2];if(!(!f|t[b+730|0]&1)){d=c|6144;v[b+88>>2]=d}a:{if(!v[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=v[b+104>>2];if(!c){break b}e=x[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;v[b+88>>2]=d;e=v[c>>2];v[b+76>>2]=e;g=v[c+4>>2];v[b+80>>2]=g;c=v[c+8>>2];v[b+84>>2]=c;if(c>>>0<e>>>0){v[b+76>>2]=c;h=c}else{h=e}e=v[b+4>>2];if(h>>>0>=e>>>0){break b}v[b>>2]=0;v[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;v[b+88>>2]=d;v[b+76>>2]=v[c>>2]}if(!f){break a}if(!(!(v[a+480180>>2]&1064964?1:w[f+60|0]&2)|!v[f>>2])){v[b+88>>2]=d|4096}if(w[f+65|0]==255|x[b+728>>1]!=65535){break a}i=b,j=Jc(wp(f+48|0,v[b+724>>2],256,64)),u[i+728>>1]=j;i=b,j=x[Fb(v[f+48>>2],w[f+65|0])>>1],v[i+724>>2]=j}}function E1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ab-32|0;ab=c;v[c+28>>2]=0;Pi(c+24|0,a,0);if(zd(w[c+24|0])){d=c+16|0;zc(d,v[v[a>>2]-12>>2]+a|0);v[22452]=0;d=T(1077,d|0)|0;e=v[22452];v[22452]=0;a:{b:{if((e|0)!=1){e=xi(c+8|0,a);f=dh(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22452]=0;ka(1080,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=v[22452];v[22452]=0;if((d|0)!=1){break b}}b=V(0)|0;O()|0;Nb(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;Oi(v[v[a>>2]-12>>2]+a|0,b);c:{d:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22452]=0;X(95);a=v[22452];v[22452]=0;if((a|0)!=1){break c}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break d}S(a|0);L()}$();break a}V(0)|0;O()|0;Gb()}L()}Nb(c+16|0);v[b>>2]=v[c+20>>2]}Ug(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}ab=c+32|0;return a|0}function Po(a){var b=C(0),c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=Ph(+a);break a}if(d>>>0<=1081824209){f=+a;if(d>>>0>=1075235812){b=C(-Ph(((e|0)>=0?-3.141592653589793:3.141592653589793)+f));break a}if((e|0)<0){b=Qh(f+1.5707963267948966);break a}b=Qh(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=Ph(((e|0)>=0?-6.283185307179586:6.283185307179586)+ +a);break a}if((e|0)<0){b=Qh(-4.71238898038469-+a);break a}b=Qh(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(pw(a,c+8|0)&3){case 0:b=Ph(A[c+8>>3]);break a;case 1:b=Qh(-A[c+8>>3]);break a;case 2:b=C(-Ph(A[c+8>>3]));break a;default:break b}}b=Qh(A[c+8>>3])}a=b;ab=c+16|0;return a}function LQ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;d=b+20|0;while(1){if((b|0)!=(d|0)){f=c;c=t[b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;continue}break}d=c;a:{if(c>>>0>5){break a}while(1){if((g|0)!=15){c=0;e=B(g,30)+a|0;b=e+20|0;j=b+22|0;while(1){if((b|0)!=(j|0)){f=c;c=t[b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;continue}break}d=c+d|0;if(d>>>0>48){break a}b=w[e+45|0];if(w[e+44|0]|b>>>0>64){break a}c=Ab(w[e+42|0]|w[e+43|0]<<8);if(c>>>0>32768){break a}g=g+1|0;h=b|h;i=c+i|0;continue}break}if(!i|!(h&255)){break a}d=w[a+470|0];if(d>>>0>128){break a}e=w[a+471|0];if(e>>>0>220){break a}a=a+472|0;c=a+128|0;b:{if((a|0)==(c|0)){break b}b=a;while(1){b=b+1|0;if((c|0)==(b|0)){break b}a=w[a|0]<w[b|0]?b:a;continue}}a=w[a|0];if(a>>>0>63){break a}k=(e|(a|d))!=0}return k}function z1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ab-32|0;ab=c;v[c+28>>2]=0;Pi(c+24|0,a,0);a:{b:{c:{if(zd(w[c+24|0])){e=c+16|0;zc(e,v[v[a>>2]-12>>2]+a|0);v[22452]=0;e=T(1077,e|0)|0;d=v[22452];v[22452]=0;d:{e:{if((d|0)==1){break e}d=xi(c+8|0,a);f=dh(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[22452]=0;ka(1078,e|0,d|0,f|0,a+g|0,c+28|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break e}Nb(c+16|0);break d}b=V(0)|0;O()|0;Nb(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;Oi(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22452]=0;X(95);a=v[22452];v[22452]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break c}S(a|0);L()}$()}Ug(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}ab=c+32|0;break a}V(0)|0;O()|0;Gb()}L()}return a|0}function x1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ab-32|0;ab=c;v[c+28>>2]=0;Pi(c+24|0,a,0);a:{b:{c:{if(zd(w[c+24|0])){e=c+16|0;zc(e,v[v[a>>2]-12>>2]+a|0);v[22452]=0;e=T(1077,e|0)|0;d=v[22452];v[22452]=0;d:{e:{if((d|0)==1){break e}d=xi(c+8|0,a);f=dh(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[22452]=0;ka(1082,e|0,d|0,f|0,a+g|0,c+28|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break e}Nb(c+16|0);break d}b=V(0)|0;O()|0;Nb(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;Oi(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22452]=0;X(95);a=v[22452];v[22452]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break c}S(a|0);L()}$()}Ug(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}ab=c+32|0;break a}V(0)|0;O()|0;Gb()}L()}return a|0}function u1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ab-32|0;ab=c;v[c+28>>2]=0;Pi(c+24|0,a,0);a:{b:{c:{if(zd(w[c+24|0])){e=c+16|0;zc(e,v[v[a>>2]-12>>2]+a|0);v[22452]=0;e=T(1077,e|0)|0;d=v[22452];v[22452]=0;d:{e:{if((d|0)==1){break e}d=xi(c+8|0,a);f=dh(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[22452]=0;ka(1083,e|0,d|0,f|0,a+g|0,c+28|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break e}Nb(c+16|0);break d}b=V(0)|0;O()|0;Nb(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;Oi(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22452]=0;X(95);a=v[22452];v[22452]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break c}S(a|0);L()}$()}Ug(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}ab=c+32|0;break a}V(0)|0;O()|0;Gb()}L()}return a|0}function j2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ab-32|0;ab=c;v[c+28>>2]=0;Pi(c+24|0,a,0);a:{b:{c:{if(zd(w[c+24|0])){e=c+16|0;zc(e,v[v[a>>2]-12>>2]+a|0);v[22452]=0;e=T(1077,e|0)|0;d=v[22452];v[22452]=0;d:{e:{if((d|0)==1){break e}d=xi(c+8|0,a);f=dh(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[22452]=0;ka(1079,e|0,d|0,f|0,a+g|0,c+28|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break e}Nb(c+16|0);break d}b=V(0)|0;O()|0;Nb(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;Oi(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22452]=0;X(95);a=v[22452];v[22452]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break c}S(a|0);L()}$()}Ug(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}ab=c+32|0;break a}V(0)|0;O()|0;Gb()}L()}return a|0}function B1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ab-32|0;ab=c;v[c+28>>2]=0;Pi(c+24|0,a,0);a:{b:{c:{if(zd(w[c+24|0])){e=c+16|0;zc(e,v[v[a>>2]-12>>2]+a|0);v[22452]=0;e=T(1077,e|0)|0;d=v[22452];v[22452]=0;d:{e:{if((d|0)==1){break e}d=xi(c+8|0,a);f=dh(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[22452]=0;ka(1081,e|0,d|0,f|0,a+g|0,c+28|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break e}Nb(c+16|0);break d}b=V(0)|0;O()|0;Nb(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;Oi(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22452]=0;X(95);a=v[22452];v[22452]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break c}S(a|0);L()}$()}Ug(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}ab=c+32|0;break a}V(0)|0;O()|0;Gb()}L()}return a|0}function Uaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=ab-16|0;ab=f;h=v[a+40>>2];i=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){m=v[a+32>>2];e=v[f+12>>2]+j|0;g=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[g+34>>1])+B(t[e+1|0],u[g+32>>1])|0)+B(t[e+3|0],u[g+36>>1])|0)+B(t[e+4|0],u[g+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+26>>1])+B(t[e-3|0],u[g+24>>1])|0)+B(t[e-1|0],u[g+28>>1])|0)+B(t[e|0],u[g+30>>1])<<8)/2|0)|0)/16384|0;i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(e,i>>12);h=h+m|0;v[c+4>>2]=v[c+4>>2]+B(e,h>>12);Lb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=h;v[a+36>>2]=i;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function Mu(a,b,c,d){var e=0,f=0,g=0,h=0;g=ab-16|0;ab=g;a:{if(!c){break a}if(d){b=Zb(g+8|0,a,b);a=ab-16|0;ab=a;v[a+12>>2]=c;d=v[b+4>>2];b:{if(!d){d=v[b>>2];break b}e=32-d|0;v[a+8>>2]=e;c=v[b>>2];h=e;e=v[zb(a+8|0,a+12|0)>>2];v[c>>2]=-1<<d&-1>>>h-e|v[c>>2];f=v[a+12>>2];d=c+4|0;v[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Jb(e,255,d);c=c&31;v[a+12>>2]=c;if(c){e=b;b=d+v[b>>2]|0;v[e>>2]=b;v[b>>2]=v[b>>2]|-1>>>32-c}ab=a+16|0;break a}b=Zb(g,a,b);a=ab-16|0;ab=a;v[a+12>>2]=c;d=v[b+4>>2];c:{if(!d){d=v[b>>2];break c}e=32-d|0;v[a+8>>2]=e;c=v[b>>2];f=v[c>>2];h=e;e=v[zb(a+8|0,a+12|0)>>2];v[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=v[a+12>>2];d=c+4|0;v[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Jb(e,0,d);c=c&31;v[a+12>>2]=c;if(c){e=b;b=d+v[b>>2]|0;v[e>>2]=b;v[b>>2]=v[b>>2]&(-1>>>32-c^-1)}ab=a+16|0}ab=g+16|0}function a6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=0,q=0,r=0;g=ab-16|0;ab=g;i=a+44|0;if(Ih(i)){q=g,r=Gd(i,0),v[q+8>>2]=r;q=g,r=Gd(i,1),v[q+12>>2]=r;q=g,r=dd(i,0),v[q>>2]=r;q=g,r=dd(i,1),v[q+4>>2]=r;l=d;a:while(1){if(l){o=w[a+4273|0];p=w[a+4272|0];k=0;while(1)if((k|0)==2){l=l-1|0;continue a}else{j=k<<2;h=j+(g+8|0)|0;e=v[h>>2];v[h>>2]=e+4;f=C(z[e>>2]*z[a+4240>>2]);e=a+j|0;h=e+4228|0;f=C(f+C(z[h>>2]*z[a+4236>>2]));z[h>>2]=f;f=DJ(C(f*C(1073741824)),p,o);h=e+4244|0;e=e+4252|0;m=z[e>>2];n=z[a+4264>>2];f=C(C(C(f*z[a+4260>>2])-C(z[a+4268>>2]*z[h>>2]))-C(m*n));z[e>>2]=f;z[h>>2]=m+C(f*n);e=g+j|0;j=v[e>>2];v[e>>2]=j+4;z[j>>2]=f*C(9.313225746154785e-10);k=k+1|0;continue}}break}ai(a,b,c,dd(i,0),dd(i,1),d)}ab=g+16|0}function _G(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);f=z[a>>2];i=z[a+24>>2];c=C(f-i);d=z[a+16>>2];b=z[a+32>>2];g=z[a+8>>2];e=C(d+C(b-g));z[a+16>>2]=c+e;j=C(c-C(e*C(.5)));c=z[a+4>>2];e=z[a+20>>2];h=z[a+28>>2];k=C(C(C(c-e)-h)*C(.8660253882408142));z[a+4>>2]=j+k;l=C(C(d-b)*C(.1736481785774231));f=C(f+C(i*C(.5)));i=C(C(g+b)*C(.7660444378852844));m=C(l+C(f-i));n=C(C(c+e)*C(.9848077297210693));b=C(z[a+12>>2]*C(.8660253882408142));c=C(C(c+h)*C(.6427876353263855));o=C(C(n-b)-c);z[a+12>>2]=m+o;z[a+20>>2]=m-o;z[a+28>>2]=j-k;d=C(C(g+d)*C(.9396926164627075));g=C(C(f+d)-l);e=C(C(e-h)*C(.3420201539993286));h=C(C(e-b)-n);z[a+32>>2]=g+h;d=C(C(f-d)+i);b=C(C(b+e)-c);z[a+24>>2]=d+b;z[a+8>>2]=d-b;z[a>>2]=g-h}function FJ(a){var b=0,c=0,d=0,e=0;b=ab-16|0;ab=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=Qh(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=C(-Ph(d+1.5707963267948966));break a}a=Ph(d+-1.5707963267948966);break a}a=Qh(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((e|0)<0){a=Ph(d+4.71238898038469);break a}a=C(-Ph(d+-4.71238898038469));break a}a=Qh(((e|0)>=0?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(pw(a,b+8|0)&3){case 0:a=Qh(A[b+8>>3]);break a;case 1:a=Ph(A[b+8>>3]);break a;case 2:a=Qh(-A[b+8>>3]);break a;default:break b}}a=C(-Ph(A[b+8>>3]))}ab=b+16|0;return a}function _ca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=ab-16|0;ab=f;j=f,k=Wj(b),v[j>>2]=k;c=ab-16|0;ab=c;e=b;h=a;a=Kd(a);a:{b:{if(a){b=ac(h);while(1){c:{d=a+13|0;if(dt(e,d)){d=v[a>>2];if(!d){break b}break c}if(dt(d,e)){b=a+4|0;d=v[a+4>>2];if(d){a=b;break c}v[c+12>>2]=a;a=b;break a}v[c+12>>2]=a;a=b;break a}b=a;a=d;continue}}a=ac(h)}v[c+12>>2]=a}d=a;b=v[a>>2];if(!b){g=ab-16|0;ab=g;a=ac(h);i=hh(c,pc(20),ih(g+8|0,a));b=v[i>>2]+13|0;e=ab-16|0;ab=e;v[e+8>>2]=v[f>>2];a=v[e+8>>2];a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[b+4|0]=0;t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24;ab=e+16|0;j=ac(i),k=1,t[j+4|0]=k;ab=g+16|0;Pg(h,v[c+12>>2],d,v[c>>2]);b=Pd(c);$k(c);g=1}Og(f+8|0,$b(c,b),g);ab=c+16|0;ab=f+16|0;return v[f+8>>2]+17|0}function fW(a){a=a|0;var b=0,c=0,d=0,e=0;c=ab-192|0;ab=c;b=c+16|0;ch(b,a);v[22452]=0;R(79,c+32|0,b|0);a=v[22452];v[22452]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22452]=0;a=Q(80,c+48|0,c+32|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}pb(c+32|0);pb(c+16|0);b=v[v[a>>2]-12>>2];v[22452]=0;d=ha(62)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}v[22452]=0;U(63,c+8|0,b+(c+48|0)|0,d|0);b=v[22452];v[22452]=0;if((b|0)==1){break c}Nb(c+8|0);b=a+v[v[a>>2]-12>>2]|0;v[b+4>>2]=v[b+4>>2]&-75;v[b+4>>2]=v[b+4>>2]|8;v[22452]=0;Q(85,a|0,c+32|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break c}b=Fj(v[v[a>>2]-12>>2]+(c+48|0)|0);d=v[c+32>>2];ef(a);ab=c+192|0;a=b?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;pb(c+32|0)}pb(c+16|0);break b}b=P()|0;O()|0;ef(a)}S(b|0);L()}return a|0}function bZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=ab-16|0;ab=k;a:{if(a){a=OE(c);b:{if(b){ok(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;nk(k,a);break b}dr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;sh(k,a)}Fi(i,k);Oc(k);l=e,m=Ki(a),v[l>>2]=m;l=f,m=Li(a),v[l>>2]=m;Eg(k,a);tb(g,k);pb(k);th(k,a);Fi(h,k);Oc(k);a=mk(a);break a}a=NE(c);c:{if(b){ok(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;nk(k,a);break c}dr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;sh(k,a)}Fi(i,k);Oc(k);l=e,m=Ki(a),v[l>>2]=m;l=f,m=Li(a),v[l>>2]=m;Eg(k,a);tb(g,k);pb(k);th(k,a);Fi(h,k);Oc(k);a=mk(a)}v[j>>2]=a;ab=k+16|0}function gV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;h=ab-16|0;ab=h;e=c+32|0;Nc(b,w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));e=Pb(a);a=c+28|0;g=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[22452]=0;R(175,e|0,g|0);g=v[22452];v[22452]=0;if((g|0)!=1){a:{g=c+4|0;c=0;while(1){b:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<=c>>>0){break b}v[22452]=0;f=Q(147,b|0,4)|0;i=v[22452];v[22452]=0;if((i|0)==1){break a}if(!f){break b}f=w[g|0]|w[g+1|0]<<8;v[22452]=0;f=Q(176,b|0,f|0)|0;i=v[22452];v[22452]=0;c:{if((i|0)!=1){v[h+12>>2]=f;if(ad(v[d>>2],v[d+4>>2])>>>0<=f>>>0){break c}v[22452]=0;R(177,e|0,h+12|0);f=v[22452];v[22452]=0;if((f|0)!=1){break c}}break a}c=c+1|0;continue}break}ab=h+16|0;return}}a=P()|0;O()|0;ec(e);S(a|0);L()}function fZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=ab-16|0;ab=k;a:{if(a){a=RE(c);b:{if(b){ok(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;nk(k,a);break b}dr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;sh(k,a)}tb(i,k);pb(k);l=e,m=Ki(a),t[l|0]=m;l=f,m=Li(a),t[l|0]=m;Eg(k,a);tb(g,k);pb(k);th(k,a);tb(h,k);pb(k);a=mk(a);break a}a=QE(c);c:{if(b){ok(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;nk(k,a);break c}dr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;sh(k,a)}tb(i,k);pb(k);l=e,m=Ki(a),t[l|0]=m;l=f,m=Li(a),t[l|0]=m;Eg(k,a);tb(g,k);pb(k);th(k,a);tb(h,k);pb(k);a=mk(a)}v[j>>2]=a;ab=k+16|0}function efa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ab-16|0;ab=e;t[e+15|0]=0;u[e+12>>1]=0;n=B(c,d);j=4;while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){if(h>>>0<o>>>0){t[e+11|0]=0;cR(a,e+15|0,e+12|0,e+11|0);i=w[e+11|0];f=x[e+12>>1];c=j;a:{b:{while(1){if(!(c&255)){break b}c:{g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!We(a,e+10|0)){break c}f=w[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}u[e+12>>1]=0;break a}u[e+12>>1]=f}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;t[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;t[e+11|0]=l;t[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}break}k=k+1|0;continue}break}ab=e+16|0}function Gca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ab+-64|0;ab=c;a:{d=v[a+4>>2];b:{if(d>>>0<b>>>0){f=Vd(c+56|0);e=b-d|0;b=at(a);c:{if(!(e>>>0>b>>>0|d>>>0>b-e>>>0)){Yk(c+40|0,v[a>>2],v[a+4>>2]);Zb(f,v[c+40>>2],v[c+44>>2]);v[a+4>>2]=v[a+4>>2]+e;break c}b=Fn(c+40|0);d=v[a+4>>2];v[22452]=0;d=Q(700,a|0,d+e|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break a}v[22452]=0;R(701,b|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break a}v[b+4>>2]=v[a+4>>2]+e;Rj(c+24|0,v[a>>2]);Yk(c+16|0,v[a>>2],v[a+4>>2]);Rj(c+8|0,v[b>>2]);_P(c+32|0,v[c+24>>2],v[c+28>>2],v[c+16>>2],v[c+20>>2],v[c+8>>2],v[c+12>>2]);Zb(f,v[c+32>>2],v[c+36>>2]);gt(a,b);Be(b)}a=Zb(c,v[f>>2],v[f+4>>2]);Mu(v[a>>2],v[a+4>>2],e,0);break b}v[a+4>>2]=b}ab=c- -64|0;return}a=P()|0;O()|0;Be(b);S(a|0);L()}function UJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=ab-48|0;ab=c;v[c+8>>2]=542066252;f=c+8|0;d=f|4;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;d=c+16|0;e=v[b+4220>>2];t[d|0]=e;t[d+1|0]=e>>>8;t[d+2|0]=e>>>16;t[d+3|0]=e>>>24;d=c+20|0;e=v[b+4224>>2];t[d|0]=e;t[d+1|0]=e>>>8;t[d+2|0]=e>>>16;t[d+3|0]=e>>>24;d=c+24|0;e=v[b+4228>>2];t[d|0]=e;t[d+1|0]=e>>>8;t[d+2|0]=e>>>16;t[d+3|0]=e>>>24;d=c+28|0;e=v[b+4232>>2];t[d|0]=e;t[d+1|0]=e>>>8;t[d+2|0]=e>>>16;t[d+3|0]=e>>>24;d=c+32|0;e=v[b+4236>>2];t[d|0]=e;t[d+1|0]=e>>>8;t[d+2|0]=e>>>16;t[d+3|0]=e>>>24;t[c+36|0]=w[b+4240|0];t[c+37|0]=w[b+4241|0];t[c+38|0]=w[b+4242|0];t[c+39|0]=w[b+4243|0];t[c+40|0]=w[b+4244|0];d=b+4208|0;Ei(d,33);gc(v[d>>2],f,33);de(c,v[d>>2],v[b+4212>>2]);Zb(a,v[c>>2],v[c+4>>2]);ab=c+48|0}function ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=ab-16|0;ab=e;t[e+15|0]=0;u[e+12>>1]=0;j=8;n=B(c,d)<<1;while(1){if((d|0)!=(k|0)){g=(k<<1)+b|0;o=n+g|0;while(1){if(g>>>0<o>>>0){u[e+10>>1]=0;dR(a,e+15|0,e+12|0,j,e+10|0);h=x[e+10>>1];c=j;while(1){a:{if(!(c&255)){break a}f=x[e+12>>1]<<1;i=f&254;u[e+12>>1]=i;if(i){f=(f&65534)>>>0>255}else{if(!We(a,e+9|0)){break a}f=w[e+9|0];u[e+12>>1]=f<<1&254|1;f=f>>>7|0}c=c-1|0;h=f|h<<1;continue}break}c=1;i=h&65535;b:{if(i>>>0<4){break b}f=15;while(1){c=f;m=f&255;if(i>>>m&1){break b}f=c-1|0;if(m>>>0>1){continue}break}}f=h&1;t[e+15|0]=f;l=(f-1^(h&65534)>>>1)+l|0;u[e+10>>1]=l;u[g>>1]=l;g=(d<<1)+g|0;j=(c+j&254)>>>1|0;continue}break}k=k+1|0;continue}break}ab=e+16|0}function fy(a,b,c,d){var e=0,f=0,g=0,h=0;e=ab-16|0;ab=e;a:{if(!d){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}f=v[a+480180>>2];d=f&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=v[a+480208>>2]&4096;if(!d){break h}if(!a){break b}a=0-(d>>>2|0)|0;break d}a=v[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!(f&16777248)|!d){break c}break b}a=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}rb(e+8|0,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;if(!sb(v[v[e+8>>2]>>2],v[e+12>>2])){break d}a=(a|0)/4<<24>>24}c=a;if(!c){break b}}a=v[b+692>>2];u[b+784>>1]=0;g=b,h=Sb(a+c|0,0,256),v[g+692>>2]=h}ab=e+16|0}function Hda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=ab-32|0;ab=e;ed(c,2);t[e+16|0]=w[b+13|0];t[e|0]=64;d=e+16|0;h=c,i=w[Qb(d,e)|0]<<2,u[h+30>>1]=i;f=b+14|0;v[c+24>>2]=(w[f|0]|w[f+1|0]<<8)<<1;Zj(e,2,b+1|0);tc(d,v[e>>2],v[e+4>>2],w[e+8|0]);ke(c+43|0,d);pb(d);f=Gc(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}a=b;d=b+22|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+26|0;g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[c+4>>2]=g;d=b+30|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[c+8>>2]=d-(d>>>0>g>>>0);b=w[b|0];if(b&4){u[c+34>>1]=x[c+34>>1]|2;b=w[a|0]}if(b&8){u[c+34>>1]=x[c+34>>1]|4;b=w[a|0]}if(!(b&16)){break a}vh(f,16);nf(f,9);v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}ab=e+32|0}function So(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;d=j(0)|0;a:{b:{c:{d:{if((b|0)>0|(b|0)>=0){f=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(f>>>0>2146435071){break a}b=1072693248;g=-1023;if((f|0)!=1072693248){b=f;break b}if(d){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;d=j(0)|0;g=-1077}b=b+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,d|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function fga(){var a=0,b=0,c=0;b=ab-16|0;ab=b;Bb(89820);v[22458]=0;t[89836]=0;v[22460]=0;v[22452]=0;a=ha(27)|0;c=v[22452];v[22452]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[b+8>>2]=a;a=b+8|0;iA(89832,Pd(a));bl(a);t[89836]=0;break e}a=Ca(88408,88980)|0;c=O()|0;if((fa(88408)|0)==(c|0)){_(a|0)|0;v[22452]=0;X(28);a=v[22452];v[22452]=0;if((a|0)==1){break c}L()}if((fa(88980)|0)!=(c|0)){break b}_(a|0)|0;v[22452]=0;t[89836]=0;X(17);a=v[22452];v[22452]=0;if((a|0)==1){a=P()|0;O()|0;break b}if(w[89836]){break d}}v[22452]=0;Z(29,89816);a=v[22452];v[22452]=0;if((a|0)!=1){break d}a=P()|0;O()|0;break b}ab=b+16|0;return}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break a}}bl(89840);bl(89832);pb(89820);S(a|0);L()}V(0)|0;O()|0;Gb();L()}function RD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ab-48|0;ab=e;f=Eb(b);d=ub(b);i=Eb(c);g=ub(c);d=d+f|0;h=-1;a:{while(1){if((d|0)==(f|0)){break a}d=d-1|0;if(Qp(i,g,d)){continue}break}h=d-f|0}b:{c:{d=h;if((d|0)!=-1){k=e,l=kd(b),v[k+16>>2]=l;k=e,l=le(e+16|0,d),v[k+24>>2]=l;k=e,l=le(e+24|0,1),v[k+32>>2]=l;c=Yg(e+40|0,e+32|0);k=e,l=Ff(b),v[k>>2]=l;d=Yg(e+8|0,e);ZC(b,v[c>>2],v[d>>2]);break c}if(!ub(b)){break c}h=Eb(b);d=ub(b);i=Eb(c);g=ub(c);if(!d|!g){c=-1}else{c=h;f=d+c|0;g=g+i|0;while(1){d:{d=i;e:{if((c|0)!=(f|0)){while(1){if((d|0)==(g|0)){break e}j=t[d|0];d=d+1|0;if(!jc(t[c|0],j)){continue}break}}else{c=f}break d}c=c+1|0;continue}break}c=(c|0)==(f|0)?-1:c-h|0}if(c){break c}Bb(a);break b}Ac(a,b)}ab=e+48|0}function LT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=ab-48|0;ab=f;g=a+8|0;c=v[a+8>>2];j=ic(a);a:{if((c|0)!=v[j>>2]){break a}i=a+4|0;e=v[a+4>>2];d=v[a>>2];if(e>>>0>d>>>0){a=e;d=((a-d>>1)+1|0)/-2<<1;e=a+d|0;while(1){if((a|0)!=(c|0)){e=HT(e,a)+2|0;a=a+2|0;continue}break}c=e;v[g>>2]=c;v[i>>2]=d+v[i>>2];break a}v[f+24>>2]=c-d;v[f+44>>2]=1;e=f+24|0;c=v[Pc(e,f+44|0)>>2];c=qj(e,c,c>>>2|0,v[a+16>>2]);d=$b(f+16|0,v[a+4>>2]);h=v[$b(f+8|0,v[a+8>>2])>>2];e=ab-32|0;ab=e;d=v[d>>2];v[e+24>>2]=d;d=ho(e+8|0,c+8|0,hB(d,h));while(1){h=v[d>>2];if((h|0)!=v[d+4>>2]){eq(h,v[e+24>>2]);v[d>>2]=v[d>>2]+2;Ke(e+24|0);continue}break}xd(d);ab=e+32|0;cc(a,c);cc(i,c+4|0);cc(g,c+8|0);cc(j,ic(c));Bi(c);c=v[a+8>>2]}eq(c,b);v[g>>2]=v[g>>2]+2;ab=f+48|0}function t1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ab-80|0;ab=d;a=v[a+4>>2];nv(d+16|0,b);v[22452]=0;b=Q(1,d|0,17713)|0;e=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[22452]=0;U(2,d+32|0,d+16|0,b|0);e=v[22452];v[22452]=0;if((e|0)==1){break h}v[22452]=0;U(436,d+48|0,d+32|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break g}v[22452]=0;R(986,d- -64|0,d+48|0);c=v[22452];v[22452]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[22452]=0;R(c|0,a|0,d- -64|0);a=v[22452];v[22452]=0;if((a|0)==1){break e}pb(d- -64|0);pb(d+48|0);pb(d+32|0);pb(b);pb(d+16|0);ab=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;pb(d- -64|0)}pb(d+48|0)}pb(d+32|0)}pb(b)}pb(d+16|0);S(a|0);L()}function oL(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:Zo(a,C(1));nn(a,C(3.725290298461914e-9));Yo(a,C(268435456));Xo(a,0);break b;case 1:Zo(a,C(32));nn(a,C(4.656612873077393e-10));Yo(a,C(2147483648));Xo(a,0);break b;case 2:Zo(a,C(2));nn(a,C(7.450580596923828e-9));Yo(a,C(134217728));Xo(a,1);break b;default:Zo(a,C(1));nn(a,C(7.450580596923828e-9));Yo(a,C(134217728));Xo(a,1);Mx(a,0);Lx(a,1);Kx(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}Zo(a,C(.75));nn(a,C(7.450580596923828e-9));Yo(a,C(134217728));Xo(a,1);Mx(a,0);b=(b|0)==4;Lx(a,b?2:3);Kx(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}Mx(a,1);Lx(a,0);Kx(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function zG(a,b,c,d){a:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 6:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 8:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 9:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 16:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 17:eb[d|0](a,c);default:return;case 1:case 4:case 14:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function o8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=ab-32|0;ab=f;c=oj(v[v[a+48>>2]+12>>2]);if(b){c=B(b,c);a:{b:{if(v[a+12>>2]!=(b|0)){break b}if((Yj(v[a>>2],v[a+4>>2])|0)!=(c|0)){break b}b=ab-16|0;ab=b;d=wb(v[a>>2]);a=wb(v[a+4>>2]);kh(b+8|0);e=os(a,d);c=ab-16|0;ab=c;v[c+8>>2]=d;while(1){if((e|0)>0){a=v[c+8>>2];d=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;d=w[b+12|0]|w[b+13|0]<<8;t[a+4|0]=d;t[a+5|0]=d>>>8;e=e-1|0;ui(c+8|0);continue}break}ab=c+16|0;ab=b+16|0;break a}e=f+8|0;kh(e);c=oS(f+16|0,c,e);yK(a);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];e=vb(c);g=vb(a),h=v[e>>2],v[g>>2]=h;v[e>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Eh(c);v[a+12>>2]=b}a=1}else{a=0}ab=f+32|0;return a|0}function J4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ab-48|0;ab=f;v[f+40>>2]=d;d=Oh(a,f+40|0);g=of(a+4|0);h=of(a+24|0);i=of(a+32|0);j=Pb(a+36|0);v[a+56>>2]=3;k=Pb(a+68|0);v[22452]=0;R(920,a|0,e|0);l=v[22452];v[22452]=0;a:{b:{c:{d:{if((l|0)!=1){Ub(f+8|0,b,c);b=Vd(f);c=v[b+4>>2];b=v[b>>2];v[22452]=0;ga(921,f+16|0,v[f+8>>2],v[f+12>>2],b|0,c|0);b=v[22452];v[22452]=0;if((b|0)==1){break d}v[22452]=0;U(922,a|0,f+16|0,e|0);b=v[22452];v[22452]=0;if((b|0)==1){break c}qb(f+16|0);v[22452]=0;Z(923,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;qb(f+16|0)}Uc(k);Hf(j);Lo(i);Zh(h);Yh(g);oe(d);oe(f+40|0);S(a|0);L()}oe(f+40|0);ab=f+48|0;return a|0}function yj(a,b){var c=0,d=0,e=0,f=0;c=ab+-64|0;ab=c;d=v[v[a>>2]-12>>2]+a|0;e=v[d+16>>2]&-3;Im(d,e);Pi(c+56|0,a,1);a:{b:{if(zd(w[c+56|0])){d=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22452]=0;f=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=f;f=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=f;U(99,c+40|0,d|0,c+8|0);b=v[22452];v[22452]=0;c:{if((b|0)!=1){b=Zg(c+24|0,-1,-1);b=v[b+8>>2]==v[c+48>>2]&v[c+52>>2]==v[b+12>>2]?e|4:e;break c}b=V(0)|0;O()|0;_(b|0)|0;b=e|1;Oi(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22452]=0;X(95);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break b}S(a|0);L()}$()}Ug(v[v[a>>2]-12>>2]+a|0,b)}ab=c- -64|0;return a}V(0)|0;O()|0;Gb()}L()}function iaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=ab-32|0;ab=f;i=cf(a,c);c=f+8|0;Xd(c,v[a+28>>2]);d=v[c+12>>2];v[f+24>>2]=v[c+8>>2];v[f+28>>2]=d;a:{if(!i){b:{c=0;if(!Vc(a,5)){break b}break a}}g=v[a+28>>2];c=ab-16|0;ab=c;v[c+12>>2]=0;TH(g,c+12|0,1);d=v[c+12>>2];e=d>>>2&3;t[c+11|0]=e;if(e){t[c+4|0]=3;e=w[Qb(c+4|0,c+11|0)|0];t[c+4|0]=0;t[c|0]=0;t[c+10|0]=0;c:{if(!e){break c}Wh(g,c+4|0);if((e|0)==1){break c}Wh(g,c);if(e>>>0<3){break c}Wh(g,c+10|0);h=w[c+10|0]<<24}d=d&255|w[c+4|0]<<8|w[c|0]<<16|h;v[c+12>>2]=d}e=d>>>4|0;v[c+4>>2]=e;v[c>>2]=1e6;Cx(b,v[zb(c+4|0,c)>>2]);d=0;while(1){h=ub(b);if(h>>>0<=d>>>0){b=e-h|0;if(b){Cl(g,b)}ab=c+16|0}else{Ck(g,oc(b,d),1);d=d+1|0;continue}break}c=i}Te(a,c,f+24|0);ab=f+32|0}function kJ(a){var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);g=C(C(z[a+4220>>2]*C(.9980000257492065))+C(.0010000000474974513));c=-3e3/+C(C(C(z[a+4216>>2]*C(2999.9990234375))+C(.0010000000474974513))*C(y[v[a+16>>2]+24620>>2]));m=a,n=C(Gj(10,c*+y[a+4288>>2])),z[m+4232>>2]=n;m=a+4236|0,n=C(Gj(10,c*+y[a+4292>>2])),z[m>>2]=n;l=c*(1/+g+-1);h=a+4272|0;i=a+4232|0;while(1){if((d|0)==4){c=Gj(10,+iJ(z[a+4208>>2])*.05);b=Gj(10,+iJ(z[a+4212>>2])*.1);z[a+4228>>2]=4/K(j)*c*K(b);z[a+4224>>2]=c*K(1-b)}else{k=v[(d<<2)+h>>2];e=d<<1&-4;f=Gj(10,l*+(k+v[(e+h|0)+16>>2]>>>0));b=Gj(10,c*+(k>>>0));g=z[e+i>>2];e=(d<<3)+i|0;f=(1-f)*.5;z[e+12>>2]=b*f;z[e+8>>2]=b*(1-f);b=b*+g;b=b*(b*(b*(b+1)+1)+1)+1;j=b*b+j;d=d+1|0;continue}break}}function un(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=ab-16|0;ab=g;if(e){v[e>>2]=0}a:{h=a+484344|0;if(!he(h,b)){break a}d=Qc(Rb(h,b),c,d);f=w[d+5|0];b:{c:{d:{e:{i=w[d+3|0];switch(i-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(i-35>>>0>=2){break a}}v[g+12>>2]=1;j=0;if((i|0)!=17){break b}j=v[a+480180>>2]==4;break b}v[g+12>>2]=2;j=0}m=g,n=v[Rb(h,b)+12>>2]+(c^-1)|0,v[m+8>>2]=n;c=0;k=v[zb(g+8|0,g+12|0)>>2];a=k;while(1){f:{if(a){d=B(oj(v[v[Rb(h,b)+48>>2]+12>>2]),6)+d|0;if(w[d+3|0]==34){break f}k=c}f=(i-37&255)>>>0<254?f:k?f:f<<8;if(!e){break a}v[e>>2]=k;break a}l=f<<8;f=w[d+5|0]|(j?f>>>0<256?l+-8192|0:l:l);c=c+1|0;a=a-1|0;continue}}ab=g+16|0;return f}function fC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=ab-16|0;ab=g;e=v[b>>2];d=wc(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=ab-32|0;ab=i;d=c-d|0;f=v[vb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>1>>>0){f=ab-16|0;ab=f;e=Ai(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){dc(e);ab=f+16|0}else{qq(d);d=d+2|0;v[e+4>>2]=d;continue}break}break b}f=vb(b);e=qj(i+8|0,rj(b,wc(v[b>>2],e)+d|0),wc(v[b>>2],v[b+4>>2]),f);h=ab-16|0;ab=h;d=ho(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){qq(f);f=v[d>>2]+2|0;v[d>>2]=f;continue}break}xd(d);ab=h+16|0;rd(b,e);Bi(e)}ab=i+32|0;break a}if(c>>>0<d>>>0){Hd(b,e+(c<<1)|0)}}c=Hb(a,c<<1);if(c){d=v[b>>2];Ub(g+8|0,d,wc(d,v[b+4>>2])<<1);fd(g,a,v[g+8>>2],v[g+12>>2])}ab=g+16|0;return c|0}function IF(a,b,c,d,e,f){var g=0;g=ab-80|0;ab=g;a:{if((f|0)>=16384){wd(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}wd(g+16|0,b,c,d,e,0,0,0,2147352576);f=(f>>>0<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}wd(g- -64|0,b,c,d,e,0,0,0,7471104);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}wd(g+48|0,b,c,d,e,0,0,0,7471104);f=(f>>>0>4294918376?f:-48920)+32538|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}wd(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;ab=g+80|0}function rH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=ab-16|0;ab=f;a:{b:{c:{d:{e:{if((b|0)>=0){if((Mo(a+8|0)|0)>(b|0)){break e}}a=aa(8)|0;v[22452]=0;c=Q(55,f|0,10667)|0;b=v[22452];v[22452]=0;if((b|0)==1){break d}lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break b}b=P()|0;O()|0;pb(c);break c}d=a+32|0;a=(v[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;v[a>>2]=c|v[a>>2]&-134218753;a=(v[d>>2]+B(b,872)|0)+1075080|0;v[a>>2]=c|v[a>>2]&-134218753;a=x[v[d>>2]+480188>>1];g=a>>>0>256?a:256;b=b+1|0;while(1){if((a|0)==(g|0)){break a}e=B(a,872);if((b|0)==x[(e+v[d>>2]|0)+1075778>>1]){e=(e+v[d>>2]|0)+1075080|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;continue}}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}ab=f+16|0}function Q4(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=ab-48|0;ab=b;c=Bb(b+32|0);v[22452]=0;Z(912,b+16|0);a=v[22452];v[22452]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=wb(v[b+16>>2]),v[f+8>>2]=g;d=1;while(1){e=wb(v[b+20>>2]);a=v[b+8>>2];if(!Tb(a,e)){a=$d(Eb(c));Uc(b+16|0);pb(c);break b}if(!d){v[22452]=0;Q(913,c|0,14596)|0;a=v[22452];v[22452]=0;if((a|0)==1){break d}a=v[b+8>>2]}v[22452]=0;Q(776,c|0,a|0)|0;a=v[22452];v[22452]=0;if((a|0)==1){break d}Sn(b+8|0);d=0;continue}}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Uc(b+16|0)}pb(c);_(a|0)|0;a=0;v[22452]=0;W(911,6946,0,0,0);c=v[22452];v[22452]=0;if((c|0)==1){break a}$()}ab=b+48|0;return a|0}b=P()|0;O()|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)==1){V(0)|0;O()|0;Gb();L()}S(b|0);L()}function MM(a,b,c,d){var e=0,f=C(0),g=0,h=0,i=0,j=0;g=ab-16|0;ab=g;v[g+12>>2]=c>>>3;v[g+8>>2]=v[a>>2];a=v[a+20>>2];h=v[zb(g+12|0,g+8|0)>>2];c=h;while(1){if(c){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);f=xf((l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q()));f=kf(C(Ed(C((Yf(f)?f>=C(0)?C(1):C(-1):f)*d),C(-1))*C(32768)));a:{if(C(D(f))<C(2147483648)){e=~~f;break a}e=-2147483648}i=a,j=Jc(e),u[i>>1]=j;e=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);f=xf((l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q()));f=kf(C(Ed(C((Yf(f)?f>=C(0)?C(1):C(-1):f)*d),C(-1))*C(32768)));b:{if(C(D(f))<C(2147483648)){e=~~f;break b}e=-2147483648}i=a,j=Jc(e),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;continue}break}ab=g+16|0;return h<<3}function SQ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=v[b>>2];while(1){if((i|0)==128){mf(b,c);c=v[a+8>>2];d=c+d|0;i=x[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(jk(a)&-2)){break c}Nc(a,c+(f<<10)|0);if(!Nz(a,16,1)){break b}u[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((jk(a)|0)!=(d+B(f,i)|0)){break a}}Nc(a,c+B(f,x[e>>1])|0);h=Nz(a,64,1)?h:k}Nc(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(B(c,x[e>>1])<<8)|0)==(jk(a)|0)){break d}}if(c>>>0>=255){Mz(b,254,65534);Mz(b,255,65535)}l=h}a=l&65535}else{j=x[Yb(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function M4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ab-16|0;ab=e;i=e,j=Wj(b),v[i>>2]=j;c=ab-16|0;ab=c;f=b;g=a;a=Kd(a);a:{b:{if(a){b=ac(g);while(1){c:{d=a+16|0;if(Ks(f,d)){d=v[a>>2];if(!d){break b}break c}if(Ks(d,f)){b=a+4|0;d=v[a+4>>2];if(d){a=b;break c}v[c+12>>2]=a;a=b;break a}v[c+12>>2]=a;a=b;break a}b=a;a=d;continue}}a=ac(g)}v[c+12>>2]=a}b=v[a>>2];if(!b){d=ab-16|0;ab=d;b=ac(g);h=hh(c,pc(40),ih(d+8|0,b));f=v[h>>2]+16|0;b=ab-16|0;ab=b;v[b+8>>2]=v[e>>2];Ac(f,v[b+8>>2]);Bb(f+12|0);ab=b+16|0;i=ac(h),j=1,t[i+4|0]=j;ab=d+16|0;Pg(g,v[c+12>>2],a,v[c>>2]);b=Pd(c);a=v[c>>2];v[c>>2]=0;if(a){if(w[ac(c)+4|0]){Pl(a+16|0)}if(a){xb(a)}}h=1}a=e+8|0;Og(a,$b(c,b),h);ab=c+16|0;a=id(a);ab=e+16|0;return a+12|0}function xL(a){var b=0,c=0,d=0,e=0;e=a+128e3|0;while(1){if((a|0)!=(e|0)){d=ab-32|0;ab=d;Xs(d);b=v[d+28>>2];c=v[d+24>>2];t[a+24|0]=c;t[a+25|0]=c>>>8;t[a+26|0]=c>>>16;t[a+27|0]=c>>>24;t[a+28|0]=b;t[a+29|0]=b>>>8;t[a+30|0]=b>>>16;t[a+31|0]=b>>>24;b=v[d+20>>2];c=v[d+16>>2];t[a+16|0]=c;t[a+17|0]=c>>>8;t[a+18|0]=c>>>16;t[a+19|0]=c>>>24;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[d+12>>2];c=v[d+8>>2];t[a+8|0]=c;t[a+9|0]=c>>>8;t[a+10|0]=c>>>16;t[a+11|0]=c>>>24;t[a+12|0]=b;t[a+13|0]=b>>>8;t[a+14|0]=b>>>16;t[a+15|0]=b>>>24;b=v[d+4>>2];c=v[d>>2];t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24;ab=d+32|0;a=a+32|0;continue}break}}function pw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=ab-16|0;ab=e;g=(p(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;A[b>>3]=d;g=d<-.7853981852531433;if(D(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,i-(c<<23)|0),q());c=EG(e+8|0,e,c,1,0);d=A[e>>3];if((g|0)<0){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}ab=e+16|0;return c}function Tca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=ab-16|0;ab=g;e=v[b>>2];d=$f(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=ab-32|0;ab=i;d=c-d|0;f=v[vb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){f=ab-16|0;ab=f;e=kz(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){dc(e);ab=f+16|0}else{Dz(d);d=d+32|0;v[e+4>>2]=d;continue}break}break b}f=vb(b);e=bt(i+8|0,Bp(b,$f(v[b>>2],e)+d|0),$f(v[b>>2],v[b+4>>2]),f);h=ab-16|0;ab=h;d=SO(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){Dz(f);f=v[d>>2]+32|0;v[d>>2]=f;continue}break}xd(d);ab=h+16|0;rd(b,e);UO(e)}ab=i+32|0;break a}if(c>>>0<d>>>0){Hd(b,e+(c<<5)|0)}}if(Hb(a,c<<5)){c=v[b>>2];Ub(g+8|0,c,$f(c,v[b+4>>2])<<5);fd(g,a,v[g+8>>2],v[g+12>>2])}ab=g+16|0}function Rca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=ab-16|0;ab=g;e=v[b>>2];d=Cg(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=ab-32|0;ab=i;d=c-d|0;f=v[vb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>4>>>0){f=ab-16|0;ab=f;e=xo(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){dc(e);ab=f+16|0}else{Tt(d);d=d+16|0;v[e+4>>2]=d;continue}break}break b}f=vb(b);e=yv(i+8|0,Av(b,Cg(v[b>>2],e)+d|0),Cg(v[b>>2],v[b+4>>2]),f);h=ab-16|0;ab=h;d=nE(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){Tt(f);f=v[d>>2]+16|0;v[d>>2]=f;continue}break}xd(d);ab=h+16|0;rd(b,e);yE(e)}ab=i+32|0;break a}if(c>>>0<d>>>0){Hd(b,e+(c<<4)|0)}}if(Hb(a,c<<4)){c=v[b>>2];Ub(g+8|0,c,Cg(c,v[b+4>>2])<<4);fd(g,a,v[g+8>>2],v[g+12>>2])}ab=g+16|0}function u4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ab-32|0;ab=d;v[22452]=0;Z(924,a|0);e=v[22452];v[22452]=0;a:{b:{c:{if((e|0)==1){break c}v[22452]=0;Z(925,b|0);e=v[22452];v[22452]=0;if((e|0)==1){break c}v[22452]=0;Z(925,c|0);f=v[22452];v[22452]=0;e=1;if((f|0)==1){break c}f=v[a+24>>2];b=kc(d+24|0,b);c=kc(d+16|0,c);v[22452]=0;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;W(946,f|0,d+8|0,d|0,1);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,5468,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();e=0}ab=d+32|0;return e|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function f$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=v[b+44>>2];i=v[b+24>>2];if(h>>>0<i>>>0){v[b+44>>2]=i;h=i}l=-1;m=-1;n=f&24;a:{if(!n|(e|0)==1&(n|0)==24){break a}if(h){g=h-Eb(b+32|0)|0;o=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;j=e;k=e>>31;break b}e=i-v[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=o;k=g}d=d+k|0;c=c+j|0;d=j>>>0>c>>>0?d+1|0:d;e=c;c=d;if((g|0)<=(d|0)&e>>>0>o>>>0|(d|0)>(g|0)|(d|0)<0){break a}d=f&8;d:{if(!(c|e)){break d}if(v[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!i){break a}}if(d){d=v[b+8>>2];Rm(b,d,d+e|0,h)}if(f&16){dw(b,v[b+20>>2],v[b+28>>2]);sr(b,e)}l=e;m=c}Zg(a,l,m)}function ci(a,b,c,d){var e=0,f=0,g=0,h=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=44464;b=a+24|0;v[b>>2]=0;v[b+4>>2]=0;v[b+16>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;c=a+44|0;d=Pb(c);e=Pb(c+12|0);f=Pb(c+24|0);g=Pb(c+36|0);v[22452]=0;R(875,c|0,0);h=v[22452];v[22452]=0;if((h|0)==1){a=P()|0;O()|0;ec(g);ec(f);hx(e);hx(d);S(a|0);L()}v[a+4196>>2]=1065353216;v[a+4200>>2]=0;u[a+4204>>1]=0;d=v[a+16>>2];v[d+946300>>2]=v[d+946300>>2]+1;v[22452]=0;d=T(876,a+92|0)|0;e=v[22452];v[22452]=0;a:{if((e|0)!=1){c=a+4200|0;v[b>>2]=d;b=w[a+4200|0];d=v[a+16>>2];e=v[a+20>>2];while(1){if((e|0)==((d+B(b,160)|0)+906300|0)|b>>>0>248){break a}b=b+1|0;t[c|0]=b;continue}}a=P()|0;O()|0;RJ(c);S(a|0);L()}return a}function fI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=ab-32|0;ab=c;e=v[a>>2];a=v[e>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];g=v[a+8>>2];e=v[a+4>>2];i=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(y[c+4>>2]>=e>>>0){if(vf(c)>>>0<g>>>0){break b}j=b+12|0;c:while(1){a=0;if((f|0)==(g|0)){break a}while(1)if((a|0)==(e|0)){f=f+1|0;continue c}else{d=xh(i,e,a,f);h=Fb(v[b>>2],a);d=v[d>>2]+(v[h>>2]>>1)|0;k=d;d=Pr(j)+d&-4096;v[h>>2]=k-d;d=Wc(d|2048,12);d=(d|0)<32767?d:32767;l=an(c,a,f),m=(d|0)>-32768?d:-32768,u[l>>1]=m;a=a+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}ab=c+32|0}function _H(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=ab-32|0;ab=c;e=v[a>>2];a=v[e>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];g=v[a+8>>2];e=v[a+4>>2];i=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(y[c+4>>2]>=e>>>0){if(vf(c)>>>0<g>>>0){break b}j=b+12|0;c:while(1){a=0;if((f|0)==(g|0)){break a}while(1)if((a|0)==(e|0)){f=f+1|0;continue c}else{d=xh(i,e,a,f);h=Fb(v[b>>2],a);d=v[d>>2]+(v[h>>2]>>1)|0;k=d;d=Pr(j)+d&-4096;v[h>>2]=k-d;d=Wc(d|2048,12);d=(d|0)<32767?d:32767;l=$m(c,a,f),m=(d|0)>-32768?d:-32768,u[l>>1]=m;a=a+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}ab=c+32|0}function Mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=ab-528|0;ab=b;e=-1;a:{if(!Qf(a,1468)){break a}Zk(a,1464);c=b+524|0;_Q(a,c);if(!ae(c,26889)){e=0;if(!ae(b+524|0,15476)){break a}}Zk(a,20);c=1;while(1){if((c&65535)>>>0<=31){if(XQ(a,b)){c=c+1|0;d=Qz(b)+d|0;continue}else{e=-1;break a}}break}e=0;if(d>>>0>40){break a}d=b+520|0;c=ab-16|0;ab=c;b:{if(!Qf(a,2)){t[c|0]=0;XB(d,c);break b}ll(c+8|0,d);Pz(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0;if(w[b+520|0]>128){break a}d=Zc(b+520|0);c=ab-16|0;ab=c;c:{if(!Qf(a,512)){HQ(b);break c}eu(c+8|0,b);Pz(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0;a=b+512|0;c=b;e=1;d=w[d|0];while(1){if((a|0)==(c|0)){break a}f=w[c|0];c=c+1|0;if(d>>>0>=f>>>0){continue}break}e=0}ab=b+528|0;return e|0}function Om(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0,n=0;l=ab-16|0;ab=l;t[l+15|0]=a;a:{b:{c:{k=v[d>>2];if((k|0)!=(c|0)){break c}m=43;n=a&255;if((n|0)!=w[j+24|0]){m=45;if(w[j+25|0]!=(n|0)){break c}}v[d>>2]=c+1;t[c|0]=m;break b}if(!(!ub(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=fi(j,j+26|0,l+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}if((c|0)==(k|0)|(k-c|0)>2|w[k-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=k+1;t[k|0]=w[f+79744|0];break a}v[d>>2]=k+1;t[k|0]=w[f+79744|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}ab=l+16|0;return a}function CF(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=Vv(13840);if(w[b|0]?b:0){break a}b=Vv(B(a,12)+75584|0);if(w[b|0]?b:0){break a}b=Vv(14120);if(w[b|0]?b:0){break a}b=14729}b:{while(1){d=w[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14729;c:{d:{c=w[b|0];e:{f:{if(!(w[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!w[e+1|0]){break e}}if(!Zi(e,14729)){break e}if(Zi(e,13495)){break d}}if(!a){c=75656;if(w[e+1|0]==46){break c}}return 0}b=0;c=v[115843];if(c){while(1){if(!Zi(e,c+8|0)){break c}c=v[c+32>>2];if(c){continue}break}}c=yd(36);if(c){v[c+4>>2]=20;v[c>>2]=75552;b=c+8|0;gc(b,e,d);t[b+d|0]=0;v[c+32>>2]=v[115843];v[115843]=c;b=c}c=a|b?b:75656}return c}function zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=ab-16|0;ab=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=((((v[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;m=u[e+39878>>1];n=u[e+39876>>1];o=u[e+39874>>1];p=u[e+39872>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+l|0;v[(e<<2)+b>>2]=(((B(u[f>>1],o)+B(u[f-4>>1],p)|0)+B(u[f+4>>1],n)|0)+B(u[f+8>>1],m)|0)/16384;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g);Lb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function oU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ab-16|0;ab=d;ed(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=oq(a+4|0,a);e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=e;c=oq(a+8|0,a);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+8>>2]=f;t[d+15|0]=127;t[d+14|0]=w[a+15|0];i=b,j=(((w[Qb(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[i+30>>1]=j;g=a+12|0;c=w[g|0];if(c>>>0>=16){u[b+34>>1]=32;u[b+28>>1]=c&240}c=a+13|0;h=(w[c|0]|w[c+1|0]<<8)<<1;v[b+24>>2]=h;c=w[c|0]|w[c+1|0]<<8?h:16726;v[b+24>>2]=c;i=b,j=(B(tu(0,w[g|0]<<28>>24),c)>>>0)/8363|0,v[i+24>>2]=j;if(e>>>0<f>>>0){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}ab=d+16|0}function Mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=ab-16|0;ab=b;f=v[a+40>>2];g=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>18|0;n=((((v[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){h=(e<<1)+n|0;i=u[h>>1];v[(e<<2)+b>>2]=i+((B(u[h+4>>1]-i|0,m)|0)/16384|0);e=e+1|0;continue}break}e=v[a+32>>2];g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=e+f|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Lb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=f;v[a+36>>2]=g;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function Pda(a){a=a|0;var b=0,c=0,d=0,e=0;b=ab-192|0;ab=b;c=b+16|0;ch(c,a);v[22452]=0;R(79,b+32|0,c|0);a=v[22452];v[22452]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22452]=0;a=Q(80,b+48|0,b+32|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break e}pb(b+32|0);pb(b+16|0);c=v[v[a>>2]-12>>2];v[22452]=0;d=ha(62)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}v[22452]=0;U(63,b+8|0,c+(b+48|0)|0,d|0);c=v[22452];v[22452]=0;if((c|0)==1){break c}Nb(b+8|0);v[22452]=0;Q(81,a|0,b+32|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}c=Fj(v[v[a>>2]-12>>2]+(b+48|0)|0);d=x[b+32>>1];ef(a);ab=b+192|0;a=(c?0:d)&65535;break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;pb(b+32|0)}pb(b+16|0);break b}c=P()|0;O()|0;ef(a)}S(c|0);L()}return a|0}function bh(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0);f=oJ(z[a+4252>>2]);c=C(C(z[a+4224>>2]*C(1.899999976158142))+C(.10000000149011612));g=z[a+4268>>2];d=fe(C(10),C(C(C(C(C(v[((b<<2)+a|0)+4292>>2])/g)*C(-60))/C(C(z[a+4220>>2]*C(19.899999618530273))+C(.10000000149011612)))/C(20)));c=C(C(fe(d,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-Po(c>C(1)?C(3.1415927410125732):C(f*C(C(6.2831854820251465)/g)))));a:{if(c==C(0)){break a}if(!Hl(c)){break a}g=C(c+c);f=C(C(-2)-g);c=C(C(f*f)+C(C(c*c)*C(-4)));if(c>C(0)){e=C(K(c))}c=C(C(e-f)/g);if(C(D(c))>C(1)){c=C(C(C(-f)-e)/g)}e=xf(c)}b=(b<<3)+a|0;z[b+4404>>2]=e;z[b+4400>>2]=d;c=z[a+4272>>2];c=C(c*c);e=C(C(1)-c);d=C(d*d);return C(C(C(e*C(d/C(C(1)-C(c*d))))*e)+c)}function Tz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ab-16|0;ab=f;d=w[a|0];if(d&1){t[b+12|0]=w[b+12|0]|1;d=w[a|0]}if(d&2){t[b+12|0]=w[b+12|0]|4;d=w[a|0]}if(d&4){t[b+12|0]=w[b+12|0]|2;d=w[a|0]}if(d&16){t[b+12|0]=w[b+12|0]|16;d=w[a|0]}if(d&32){t[b+12|0]=w[b+12|0]|8}t[f+15|0]=w[a+1|0];t[f+14|0]=25;Wg(b,w[Qb(f+15|0,f+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];h=v[b>>2];d=0;while(1){if(Td(b)>>>0>d>>>0){g=Fb(h,d);i=(d<<2)+a|0;e=i+6|0;e=w[e|0]|w[e+1|0]<<8;u[g>>1]=e;a:{if(!d){break a}j=e;e=x[Fb(h,d-1|0)>>1];if(j>>>0>=e>>>0){break a}u[g>>1]=e+1}e=i+8|0;k=g,l=Sb((w[e|0]|w[e+1|0]<<8)<<16>>16>>c,0,64),t[k+2|0]=l;d=d+1|0;continue}break}ab=f+16|0}function Nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=ab-16|0;ab=b;f=v[a+40>>2];g=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>10&4194048;n=(((v[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){h=e+n|0;i=t[h|0];v[(e<<2)+b>>2]=((B(t[h+2|0]-i|0,m)|0)/16384|0)+(i<<8);e=e+1|0;continue}break}e=v[a+32>>2];g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=e+f|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Lb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=f;v[a+36>>2]=g;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function IQ(a,b){var c=0,d=0,e=0;c=ab-32|0;ab=c;a:{if(!Hb(a,1024)){v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;a=64;while(1){if(a){d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}Jz(c+8|0,b);fd(c+16|0,a,v[c+8>>2],v[c+12>>2])}ab=c+32|0}function cW(a){a=a|0;var b=0,c=0,d=0,e=0;b=ab-192|0;ab=b;c=b+16|0;ch(c,a);v[22452]=0;R(79,b+32|0,c|0);a=v[22452];v[22452]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22452]=0;a=Q(80,b+48|0,b+32|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break e}pb(b+32|0);pb(b+16|0);c=v[v[a>>2]-12>>2];v[22452]=0;d=ha(62)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}v[22452]=0;U(63,b+8|0,c+(b+48|0)|0,d|0);c=v[22452];v[22452]=0;if((c|0)==1){break c}Nb(b+8|0);v[22452]=0;Q(84,a|0,b+32|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}c=Fj(v[v[a>>2]-12>>2]+(b+48|0)|0);d=v[b+32>>2];ef(a);ab=b+192|0;a=c?0:d;break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;pb(b+32|0)}pb(b+16|0);break b}c=P()|0;O()|0;ef(a)}S(c|0);L()}return a|0}function I4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-32|0;ab=d;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[22452]=0;Z(925,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break f}e=v[a+24>>2];v[22452]=0;c=Q(55,d|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}v[22452]=0;W(926,d+16|0,e|0,c|0,1);b=v[22452];v[22452]=0;if((b|0)==1){break d}a=d+16|0;b=$d(Eb(a));pb(a);pb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;pb(c)}_(b|0)|0;b=0;v[22452]=0;W(911,6393,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$()}ab=d+32|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function z5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=ci(a,b,c,d);v[a+4260>>2]=0;v[a>>2]=46860;c=a+4960|0;e=a+4504|0;b=e;while(1){b=Ye(b)+24|0;if((c|0)!=(b|0)){continue}break}t[a+5046|0]=1;u[a+5044>>1]=0;v[a+4208>>2]=1063675494;v[a+4212>>2]=1065185444;v[a+4256>>2]=1059760811;b=a+4248|0;v[b>>2]=1065353216;v[b+4>>2]=1048525618;b=a+4240|0;v[b>>2]=1038174126;v[b+4>>2]=1065353216;b=a+4232|0;v[b>>2]=1047457519;v[b+4>>2]=1062836634;b=a+4224|0;v[b>>2]=1053079357;v[b+4>>2]=1059859440;b=a+4216|0;v[b>>2]=0;v[b+4>>2]=1032805417;v[22452]=0;R(875,a+44|0,2);b=v[22452];v[22452]=0;if((b|0)==1){a=P()|0;O()|0;while(1){c=c-24|0;ec(c);if((c|0)!=(e|0)){continue}break}ff(d);S(a|0);L()}bi(d);return a|0}function m3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-32|0;ab=d;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[22452]=0;Z(925,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break f}e=v[a+24>>2];v[22452]=0;c=Q(55,d|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break e}v[22452]=0;U(985,d+16|0,e|0,c|0);b=v[22452];v[22452]=0;if((b|0)==1){break d}a=d+16|0;b=$d(Eb(a));pb(a);pb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;pb(c)}_(b|0)|0;b=0;v[22452]=0;W(911,13273,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$()}ab=d+32|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function wp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=ab-16|0;ab=f;g=Td(a)-1|0;while(1){a:{if(Td(a)-1>>>0>e>>>0){if(x[xc(v[a>>2],v[a+4>>2],e)>>1]<(b|0)){break a}g=e}h=x[xc(v[a>>2],v[a+4>>2],g)>>1];v[f+12>>2]=0;b:{if((b|0)>=(h|0)){j=f,k=(w[xc(v[a>>2],v[a+4>>2],g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break b}e=0;if(g){e=g-1|0;i=(w[xc(v[a>>2],v[a+4>>2],e)+2|0]<<16)/(d|0)|0;v[f+12>>2]=i;e=x[xc(v[a>>2],v[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}a=((w[xc(v[a>>2],v[a+4>>2],g)+2|0]<<16)/(d|0)|0)-i|0;d=a;g=a>>31;a=b-e|0;b=oia(d,g,a,a>>31);a=h-e|0;j=f,k=vc(pia(b,db,a,a>>31),db)+i|0,v[j+12>>2]=k}ce(f+12|0,0,65536);ab=f+16|0;return(B(v[f+12>>2],c)+32768|0)/65536|0}e=e+1|0;continue}}function J$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ab-32|0;ab=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;e=b+c|0;f=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!qw(Ea(v[a+60>>2],b|0,f|0,d+12|0)|0)){g=v[d+12>>2];if((g|0)==(e|0)){break d}if((g|0)>=0){break c}break b}if((e|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}h=v[b+4>>2];i=h>>>0<g>>>0;j=(i<<3)+b|0;h=g-(i?h:0)|0;v[j>>2]=h+v[j>>2];j=(i?12:4)+b|0;v[j>>2]=v[j>>2]-h;b=i?b+8|0:b;e=e-g|0;f=f-i|0;continue}break}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((f|0)==2){break a}a=c-v[b+4>>2]|0}ab=d+32|0;return a|0}function qca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=ab-16|0;ab=g;ed(b,4);u[b+30>>1]=w[a+12|0]<<2;lg(b+30|0,256);c=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=c;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];e=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=e;c=a+4|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=c;d=a+8|0;d=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+c|0;v[b+8>>2]=d;f=a+14|0;a=w[f|0];if(a&16){d=d>>>1|0;v[b+8>>2]=d;c=c>>>1|0;v[b+4>>2]=c;e=e>>>1|0;v[b>>2]=e;a=w[f|0]}if(a&32){d=d>>>1|0;v[b+8>>2]=d;c=c>>>1|0;v[b+4>>2]=c;v[b>>2]=e>>>1;a=w[f|0]}if(!(!(a&3)|c>>>0>=d>>>0)){u[b+34>>1]=34;u[b+34>>1]=w[f|0]&2?38:34}a=Mb(g,21598);ke(b+43|0,a);pb(a);ab=g+16|0}function Q0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ab-80|0;ab=e;v[e+76>>2]=d;v[e+72>>2]=c;v[22452]=0;c=v[b+12>>2];v[e+16>>2]=v[b+8>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;c=T(1057,e+8|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){a:{b:{if(c){v[22452]=0;R(1058,e+48|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){d=e+56|0;$u(d,v[e+48>>2],v[e+52>>2]);b=Gf(e- -64|0,d);c=Gf(e+40|0,e+72|0);break b}break a}v[22452]=0;R(1059,e+48|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}d=e+56|0;$u(d,v[e+48>>2],v[e+52>>2]);b=Gf(e+32|0,d);c=Gf(e+24|0,e+72|0)}vD(a,v[b>>2],v[b+4>>2],v[c>>2],v[c+4>>2]);Cd(d);Cd(e+48|0);Cd(e+72|0);ab=e+80|0;return}}a=P()|0;O()|0;Cd(e+72|0);S(a|0);L()}function zfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ab-16|0;ab=e;j=e,k=Wj(b),v[j>>2]=k;f=x[b>>1];c=ab-16|0;ab=c;g=a;a=Kd(a);a:{b:{if(a){b=ac(g);while(1){c:{d=a+14|0;if(uA(f,d)){d=v[a>>2];if(!d){break b}break c}if(tA(d,f)){b=a+4|0;d=v[a+4>>2];if(d){a=b;break c}v[c+12>>2]=a;a=b;break a}v[c+12>>2]=a;a=b;break a}b=a;a=d;continue}}a=ac(g)}v[c+12>>2]=a}b=a;a=v[a>>2];if(!a){d=ab-16|0;ab=d;a=ac(g);h=hh(c,pc(20),ih(d+8|0,a));f=v[h>>2]+14|0;a=ab-16|0;ab=a;v[a+8>>2]=v[e>>2];i=x[v[a+8>>2]>>1];u[f+2>>1]=0;u[f>>1]=i;ab=a+16|0;j=ac(h),k=1,t[j+4|0]=k;ab=d+16|0;Pg(g,v[c+12>>2],b,v[c>>2]);a=Pd(c);$k(c);h=1}b=e+8|0;Og(b,$b(c,a),h);ab=c+16|0;a=Jp(b);ab=e+16|0;return a+2|0}function raa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=ab-48|0;ab=f;g=a+8|0;c=v[a+8>>2];j=ic(a);a:{if((c|0)!=v[j>>2]){break a}i=a+4|0;d=v[a+4>>2];e=v[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Ci(d,c,a+d|0);v[g>>2]=c;v[i>>2]=a+v[i>>2];break a}v[f+24>>2]=c-e>>1;v[f+44>>2]=1;d=f+24|0;c=v[Pc(d,f+44|0)>>2];c=_f(d,c,c>>>2|0,v[a+16>>2]);e=$b(f+16|0,v[a+4>>2]);h=v[$b(f+8|0,v[a+8>>2])>>2];d=ab-32|0;ab=d;e=v[e>>2];v[d+24>>2]=e;e=jl(d+8|0,c+8|0,yt(h,e));while(1){h=v[e>>2];if((h|0)!=v[e+4>>2]){Pn(h,v[d+24>>2]);v[e>>2]=v[e>>2]+4;te(d+24|0);continue}break}xd(e);ab=d+32|0;cc(a,c);cc(i,c+4|0);cc(g,c+8|0);cc(j,ic(c));Zf(c);c=v[a+8>>2]}Pn(c,b);v[g>>2]=v[g>>2]+4;ab=f+48|0}function Aba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=ab-16|0;ab=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=(((v[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;m=u[e+39878>>1];n=u[e+39876>>1];o=u[e+39874>>1];p=u[e+39872>>1];e=0;while(1){if((e|0)!=2){f=e+l|0;v[(e<<2)+b>>2]=(((B(t[f|0],o)+B(t[f-2|0],p)|0)+B(t[f+2|0],n)|0)+B(t[f+4|0],m)<<8)/16384;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g);Lb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function G9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab-80|0;ab=d;e=Bf(d+48|0);v[22452]=0;c=Q(769,b|0,e|0)|0;f=v[22452];v[22452]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22452]=0;T(770,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break b}}break a}c=e+4|0;c=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c=c?c:-1;v[22452]=0;U(181,d|0,b|0,c|0);f=v[22452];v[22452]=0;if((f|0)==1){break a}f=bc(d+24|0,d);Mc(e+8|0,f);qb(f);qb(d);d:{c=c&1;if(!c){break d}v[22452]=0;Q(179,b|0,2-c|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break d}break a}$j(a,e)}Tc(e);ab=d+80|0;return}a=P()|0;O()|0;Tc(e);S(a|0);L()}function HV(){var a=0,b=0,c=0,d=0;a=KC(v[v[115710]-12>>2]+462840|0,10);c=ab-16|0;ab=c;v[22452]=0;b=Q(12,c+8|0,462840)|0;d=v[22452];v[22452]=0;a:{b:{c:{d:{if((d|0)!=1){e:{if(!w[b|0]){break e}d=xi(c,462840);v[22452]=0;a=Q(20,d|0,a|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){if(!Au(a)){break e}a=v[v[115710]-12>>2];v[22452]=0;R(15,a+462840|0,1);a=v[22452];v[22452]=0;if((a|0)!=1){break e}}a=V(0)|0;O()|0;dk(b);break d}dk(b);break c}a=V(0)|0;O()|0}_(a|0)|0;b=v[v[115710]-12>>2];v[22452]=0;Z(16,b+462840|0);b=v[22452];v[22452]=0;if((b|0)==1){break b}$()}ab=c+16|0;break a}c=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(c|0);L()}V(0)|0;O()|0;Gb();L()}Ou(462840)}function Xaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ab-16|0;ab=f;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=(v[f+12>>2]<<1)+j|0;g=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[g+34>>1])+B(u[e+2>>1],u[g+32>>1])|0)+B(u[e+6>>1],u[g+36>>1])|0)+B(u[e+8>>1],u[g+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+26>>1])+B(u[e-6>>1],u[g+24>>1])|0)+B(u[e-2>>1],u[g+28>>1])|0)+B(u[e>>1],u[g+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Lb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function wI(a,b,c){var d=0,e=0,f=0,g=0;e=ab-16|0;ab=e;v[e+12>>2]=c;a:{b:{if(!b){a=a+120|0;cn(a);b=v[e+12>>2];c=sd(a);if(b){v[22452]=0;R(1045,a|0,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break a}qI(a,b)}t[a+20|0]=0;break b}d=ab-16|0;ab=d;v[d+12>>2]=c;c:{if((b|0)==1){b=a+120|0;cn(b);vI(b,a,v[d+12>>2]);t[b+20|0]=1;break c}f=ab-16|0;ab=f;v[f+12>>2]=c;d:{if((b|0)==2){a=a+120|0;cn(a);b=v[f+12>>2];c=sd(a);if(b){v[22452]=0;R(1044,a|0,b|0);g=v[22452];v[22452]=0;if((g|0)==1){break a}qI(a,b)}Vd(a+12|0);t[a+20|0]=2;break d}b=ab-16|0;ab=b;v[b+12>>2]=c;c=a+120|0;cn(c);vI(c,a,v[b+12>>2]);t[c+20|0]=3;ab=b+16|0}ab=f+16|0}ab=d+16|0}ab=e+16|0;return}a=P()|0;O()|0;Xb(c);S(a|0);L()}function Ou(a){var b=0,c=0,d=0,e=0;d=ab-16|0;ab=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[22452]=0;c=Q(12,d+8|0,a|0)|0;b=v[22452];v[22452]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22452]=0;b=T(21,b|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[22452]=0;R(15,a+b|0,1);b=v[22452];v[22452]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;dk(c);break c}dk(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[22452]=0;Z(16,a+c|0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$()}ab=d+16|0;return}a=P()|0;O()|0;v[22452]=0;X(17);c=v[22452];v[22452]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function zM(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=ab-112|0;ab=f;v[f+108>>2]=0;d=un(a,e&65535,d,c,f+108|0);c=w[b+790|0];if(!v[f+108>>2]){e=(c|0)==15;h=e&!w[b+792|0];d=d<<8;a:{if(d){v[b+664>>2]=d;break a}d=0;if(e){break a}d=v[b+664>>2]}h=h?0:w[b+836|0]<<16}if((c|0)==15){c=w[b+792|0];b:{if(!c){c=v[b+76>>2];v[f>>2]=1;e=v[Pc(f,f+108|0)>>2]<<3;g=oia(c,0,d,0);d=(256<<e>>>1|0)+g|0;c=db;c=d>>>0<g>>>0?c+1|0:c;g=d;e=e+8|0;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}d=Fc(c,e);break b}sP(f);if(c>>>0>9){break b}c=v[b+104>>2];if(!c){break b}d=v[Fb(c+68|0,w[b+792|0]-1|0)>>2]+d|0}v[b+664>>2]=d}yn(a,b,d+h|0);ab=f+112|0}function pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ab-32|0;ab=d;v[d+28>>2]=0;Xj(a,d+28|0);a:{b:{i=v[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Bb(d+16|0);v[22452]=0;u[d+14>>1]=0;e=Y(442,a|0,g|0,255)|0;h=v[22452];v[22452]=0;if((h|0)==1){break b}if(!e){break d}v[22452]=0;R(431,a|0,d+14|0);e=v[22452];v[22452]=0;if((e|0)==1){break b}v[22452]=0;U(11,d|0,c|0,g|0);e=v[22452];v[22452]=0;if((e|0)!=1){v[22452]=0;e=Q(443,b|0,d+14|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break e}tb(e,d);pb(d);pb(g);f=f+1|0;continue}break}f=P()|0;O()|0;break a}f=P()|0;O()|0;pb(d);break a}pb(g)}ab=d+32|0;return}f=P()|0;O()|0}pb(g);S(f|0);L()}function nK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=C(0),k=0,l=C(0);g=ab-16|0;ab=g;e=u[d>>1];f=u[d+2>>1];if(!(!x[b>>1]|(e|0)>(f|0)|(!(z[c>>2]>C(0))|(f-e|0)>32766))){u[a>>1]=3;f=a+4|0;uc(f);u[a+28>>1]=65472;v[g+12>>2]=1065353216;pK(f,g+12|0);v[a+32>>2]=0;u[a+30>>1]=0;uc(a+16|0);h=u[d>>1];u[a+28>>1]=h;e=ab-16|0;ab=e;u[e+14>>1]=x[b>>1];u[e+12>>1]=32767;b=u[Lc(e+14|0,e+12|0)>>1];ab=e+16|0;u[a+30>>1]=b;i=C(D(z[c>>2]));z[a+32>>2]=i;i=fe(i,C(C(1)/C(b|0)));Ij(f,(u[d+2>>1]-h|0)+1|0);b=u[d+2>>1];d=u[d>>1];while(1){if((b|0)<(d|0)){Wo(a)}else{j=fe(i,C(d|0));k=Fb(v[a+4>>2],d-u[a+28>>1]|0),l=j,z[k>>2]=l;d=d+1|0;continue}break}h=1}ab=g+16|0;return h|0}function Wx(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=ab-16|0;ab=e;b=v[a>>2];if(!jc(b,v[a+4>>2])){b=wb(b);v[e+8>>2]=b;c=wb(v[a+4>>2]);while(1){if(Tb(b,c)){jo(b,4194304,67108864);g=v[b>>2];f=g+f|0;b=d;b=f>>>0<g>>>0?b+1|0:b;d=b;te(e+8|0);b=v[e+8>>2];continue}else{c=v[a>>2];b=nc(c,v[a+4>>2]);l=e,m=wb(c),v[l>>2]=m;d=ria(f,d,b,0);h=d;g=((db&1)<<31|d>>>1)&2147483647;f=b<<24;d=0;i=wb(v[a+4>>2]);while(1){b=v[e>>2];if(Tb(b,i)){j=b;c=v[b>>2];b=c>>>8|0;c=g+(c<<24)|0;b=b+k|0;b=Fc(ria(c,c>>>0<g>>>0?b+1|0:b,h,k),db);v[j>>2]=b;c=f;f=c-b|0;d=d-(b>>>0>c>>>0)|0;te(e);continue}else{d=v[a>>2];if(!nc(d,v[a+4>>2])){Du();L()}v[d>>2]=f+v[d>>2]}break}}break}}ab=e+16|0}function rha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ab-32|0;ab=e;v[e+24>>2]=b;k=e,l=kd(a),v[k+8>>2]=l;g=am(e+24|0,e+8|0);a:{b:{h=hi(c,d);if(!h){break b}if(!rs(a,c)){b=ub(a);f=Ec(a);c:{if(f-b>>>0>=h>>>0){f=Eb(a);i=b-g|0;if(!i){break c}j=g+f|0;_j(j+h|0,j,i);break c}Kl(a,f,(b+h|0)-f|0,b,g,0,h);f=v[a>>2]}b=b+h|0;cg(a,b);t[e+8|0]=0;md(b+f|0,e+8|0);b=g+f|0;while(1){if((c|0)==(d|0)){break b}md(b,c);c=c+1|0;b=b+1|0;continue}}d=pg(e+8|0,c,d);c=Eb(d);g=ub(d);v[22452]=0;c=da(353,a|0,b|0,c|0,c+g|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){pb(d);break a}a=P()|0;O()|0;pb(d);S(a|0);L()}k=e,l=kd(a),v[k+8>>2]=l;c=le(e+8|0,g)}ab=e+32|0;return c|0}function oga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ab-32|0;ab=d;u[d+30>>1]=0;Kf(a,d+30|0);a:{b:{i=x[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Bb(d+16|0);v[22452]=0;u[d+14>>1]=0;e=Q(444,a|0,g|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break b}if(!e){break d}v[22452]=0;R(431,a|0,d+14|0);e=v[22452];v[22452]=0;if((e|0)==1){break b}v[22452]=0;U(11,d|0,c|0,g|0);e=v[22452];v[22452]=0;if((e|0)!=1){v[22452]=0;e=Q(443,b|0,d+14|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break e}tb(e,d);pb(d);pb(g);f=f+1|0;continue}break}f=P()|0;O()|0;break a}f=P()|0;O()|0;pb(d);break a}pb(g)}ab=d+32|0;return}f=P()|0;O()|0}pb(g);S(f|0);L()}function fK(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=ab-48|0;ab=e;d=Bb(e+32|0);v[22452]=0;R(866,b|0,e+24|0);f=v[22452];v[22452]=0;if((f|0)!=1){b:{g=v[e+28>>2];f=v[e+24>>2];Pe(d);v[22452]=0;f=!g&f>>>0<255?f:255;R(60,d|0,f|0);g=v[22452];v[22452]=0;if((g|0)==1){break b}c:{while(1){if((f|0)==(h|0)){b=IT(Eb(d),ub(d));if((b|0)==-1){break c}v[22452]=0;R(60,d|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break c}break b}g=oc(d,h);v[22452]=0;Q(867,b|0,g|0)|0;g=v[22452];v[22452]=0;if((g|0)!=1){h=h+1|0;continue}break}break b}v[22452]=0;U(11,e+8|0,a|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}a=e+8|0;tb(c,a);pb(a);pb(d);ab=e+48|0;break a}}a=P()|0;O()|0;pb(d);S(a|0);L()}}function Ow(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=C(0);g=ab-80|0;ab=g;h=a+24|0;$o(v[h>>2]);t[v[h>>2]+1298420|0]=v[a+52>>2]!=0;v[g+76>>2]=f;v[g+72>>2]=e;v[g+68>>2]=d;v[g+64>>2]=c;c=g- -64|0;c=ag(g+16|0,c,kI(c),b);d=v[c>>2];e=v[c+4>>2];f=v[c+8>>2];j=v[a+32>>2];k=z[a+48>>2];c=g+32|0;Rr(c);v[c+20>>2]=f;v[c+16>>2]=e;v[c+12>>2]=d;v[c+8>>2]=j;v[c+4>>2]=0;v[c>>2]=54752;z[c+24>>2]=k;v[c>>2]=53956;a:{if(b){while(1){b:{d=v[h>>2];v[g+8>>2]=b;v[g+12>>2]=0;v[g>>2]=134217727;v[g+4>>2]=0;d=Sr(d,v[il(g+8|0,g)>>2],c);i=d+i|0;if(!d){break b}b=b-d|0;if(b){continue}}break}if(i){break a}}i=0;if(v[a+52>>2]!=1){break a}a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}ab=g+80|0;return i}function Nw(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=C(0);g=ab-80|0;ab=g;h=a+24|0;$o(v[h>>2]);t[v[h>>2]+1298420|0]=v[a+52>>2]!=0;v[g+76>>2]=f;v[g+72>>2]=e;v[g+68>>2]=d;v[g+64>>2]=c;c=g- -64|0;c=ag(g+16|0,c,kI(c),b);d=v[c>>2];e=v[c+4>>2];f=v[c+8>>2];j=v[a+32>>2];k=z[a+48>>2];c=g+32|0;Rr(c);v[c+20>>2]=f;v[c+16>>2]=e;v[c+12>>2]=d;v[c+8>>2]=j;v[c+4>>2]=0;v[c>>2]=55596;z[c+24>>2]=k;v[c>>2]=54832;a:{if(b){while(1){b:{d=v[h>>2];v[g+8>>2]=b;v[g+12>>2]=0;v[g>>2]=134217727;v[g+4>>2]=0;d=Sr(d,v[il(g+8|0,g)>>2],c);i=d+i|0;if(!d){break b}b=b-d|0;if(b){continue}}break}if(i){break a}}i=0;if(v[a+52>>2]!=1){break a}a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}ab=g+80|0;return i}function gU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=ab-208|0;ab=d;if(!hu(c,a)){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0}BB(c,d+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}c=ab-16|0;ab=c;v[c+12>>2]=64;v[c+8>>2]=255;e=w[zb(c+12|0,c+8|0)|0];ab=c+16|0;t[d+12|0]=e;Wg(b,w[Qb(a+4|0,d+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;e=v[b>>2];a=0;while(1){if(Td(b)>>>0<=a>>>0){break a}b:{if(!a){c=w[d+18|0];f=Fb(e,0);break b}g=x[Fb(e,a-1|0)>>1];v[d+12>>2]=1;c=(d+16|0)+B(a,3)|0;v[d+8>>2]=(t[c+1|0]&1)<<8|w[c|0];h=Ee(d+12|0,d+8|0);f=Fb(e,a);u[f>>1]=x[h>>1]+g;c=w[c+2|0]}t[f+2|0]=c;a=a+1|0;continue}}ab=d+208|0}function xn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){t[b+809|0]=c;break a}c=w[b+809|0]}e=v[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=v[b+688>>2];b:{if(e&69206029){break b}f=d&240;g=d&15;c:{if((g|0)==15){if(f){wn(a,b,(d&240)>>>4|0,0);return}f=-60;if(t[b+851|0]&1){break c}break b}if((f|0)!=240){break b}if(g){vn(a,b,g,0);return}f=60;if(!(t[b+851|0]&1)){break b}}c=(w[a+480208|0]&2?0:f)+c|0}d:{if(!(!(t[b+851|0]&1)|w[a+480208|0]&2)&(v[a+1074416>>2]!=1|(e|0)!=524288)){break d}a=d&255;d=d&15;e:{if(d){if(a&240?e&16777248:0){break d}c=c-(d<<2)|0;break e}c=(a>>>2&60)+c|0}if((e|0)!=1){break d}v[b+88>>2]=v[b+88>>2]|2097152}h=b,i=Sb(c,0,256),v[h+688>>2]=i}function Yaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ab-16|0;ab=f;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[f+12>>2]+j|0;g=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[g+34>>1])+B(t[e+1|0],u[g+32>>1])|0)+B(t[e+3|0],u[g+36>>1])|0)+B(t[e+4|0],u[g+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+26>>1])+B(t[e-3|0],u[g+24>>1])|0)+B(t[e-1|0],u[g+28>>1])|0)+B(t[e|0],u[g+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Lb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;ab=f+16|0}function Vg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=ab+-64|0;ab=e;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}if(he(a,b)){break b}c:{d:{d=v[a>>2];if(ck(d,v[a+4>>2])>>>0<=b>>>0){d=zx(e+8|0,a);v[22452]=0;U(192,a|0,b+1|0,d|0);f=v[22452];v[22452]=0;if((f|0)==1){break d}Lk(d);d=v[a>>2]}v[22452]=0;Q(202,Nf(d,b)|0,c|0)|0;c=v[22452];v[22452]=0;e:{if((c|0)!=1){c=Nf(v[a>>2],b);v[c+16>>2]=0;v[c+20>>2]=0;c=v[a>>2];v[22452]=0;Z(203,Nf(c,b)|0);c=v[22452];v[22452]=0;if((c|0)!=1){break e}}b=V(88408)|0;a=O()|0;break c}g=Gh(Nf(v[a>>2],b));break b}b=V(88408)|0;a=O()|0;Lk(d)}if((fa(88408)|0)!=(a|0)){break a}_(b|0)|0;$()}ab=e- -64|0;return g|0}S(b|0);L()}function DK(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=ab-16|0;ab=h;t[h+15|0]=b;t[h+14|0]=10;Wg(g,w[Qb(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;k=v[g>>2];b=0;a:{while(1){if(Td(g)>>>0<=b>>>0){b:{b=w[g+12|0]&-2|a&1;t[g+12|0]=b;if(a&2){break b}b=b&251;break a}}else{m=Fb(k,b);l=B(b,3)+f|0;i=(w[l|0]|w[l+1|0]<<8)>>>4|0;u[m>>1]=i;c:{d:{if(!b){j=0;i=0;break d}j=x[Fb(k,b-1|0)>>1];if(i>>>0>=j>>>0){break c}j=j+1|0;i=b}n=Fb(k,i),o=j,u[n>>1]=o}n=m,o=Ld(w[l+2|0],0,64),t[n+2|0]=o;b=b+1|0;continue}break}b=b&-5|(Td(g)>>>0>=c>>>0)<<2}t[g+12|0]=b;if(d>>>0<=e>>>0?a&4:0){a=b&-3|(Td(g)>>>0>=d>>>0)<<1}else{a=b&253}t[g+12|0]=a;ab=h+16|0}function dv(a,b,c,d){var e=0,f=0,g=0;e=ab-48|0;ab=e;v[e+44>>2]=d;a:{f=v[b>>2];b:{if(!(eb[v[v[f>>2]+36>>2]](f,c,d)|0)){wD(a);break b}ol(e+24|0,v[b>>2],v[b+4>>2]);b=v[b>>2];d=v[v[b>>2]+24>>2];v[22452]=0;b=T(d|0,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}v[e+20>>2]=b-c;d=v[e+24>>2];f=v[e+28>>2];g=v[zb(e+44|0,e+20|0)>>2];b=ab-16|0;ab=b;v[b+12>>2]=f;v[b+8>>2]=d;d=ol(b,d,f);f=v[d+4>>2];d=v[d>>2];v[22452]=0;ga(163,e+32|0,d|0,f|0,c|0,g|0);c=v[22452];v[22452]=0;c:{if((c|0)!=1){Cd(b+8|0);ab=b+16|0;break c}a=P()|0;O()|0;Cd(b+8|0);S(a|0);L()}b=Vd(e+8|0);vD(a,v[e+32>>2],v[e+36>>2],v[b>>2],v[b+4>>2])}ab=e+48|0;return}a=P()|0;O()|0;Cd(e+24|0);S(a|0);L()}function s0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ab-32|0;ab=d;g=b+24|0;h=Bb(a);a=Bb(d+16|0);b=1;a:{b:{c:{while(1){c=b&65535;if(c>>>0>x[v[g>>2]+480192>>1]){if(!(i&1)){break c}v[22452]=0;R(241,h|0,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){break c}b=P()|0;O()|0;break a}c=dL(v[g>>2],c);v[22452]=0;c=Q(55,d|0,c|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break b}e=pd(c);v[22452]=0;f=Q(776,a|0,c|0)|0;j=v[22452];v[22452]=0;d:{if((j|0)==1){break d}v[22452]=0;Q(913,f|0,21568)|0;f=v[22452];v[22452]=0;if((f|0)==1){break d}i=e^1|i;pb(c);b=b+1|0;continue}break}b=P()|0;O()|0;pb(c);break a}pb(a);ab=d+32|0;return}b=P()|0;O()|0}pb(a);pb(h);S(b|0);L()}function r0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ab-32|0;ab=e;g=b+24|0;h=Bb(a);a=Bb(e+16|0);b=1;a:{b:{c:{while(1){c=b&65535;if(c>>>0>x[v[g>>2]+480190>>1]){if(!(i&1)){break c}v[22452]=0;R(241,h|0,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){break c}b=P()|0;O()|0;break a}d=v[g>>2];v[22452]=0;c=Q(55,e|0,eL(d,c)|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}d=pd(c);v[22452]=0;f=Q(776,a|0,c|0)|0;j=v[22452];v[22452]=0;d:{if((j|0)==1){break d}v[22452]=0;Q(913,f|0,21568)|0;f=v[22452];v[22452]=0;if((f|0)==1){break d}i=d^1|i;pb(c);b=b+1|0;continue}break}b=P()|0;O()|0;pb(c);break a}pb(a);ab=e+32|0;return}b=P()|0;O()|0}pb(a);pb(h);S(b|0);L()}function S8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=ab-16|0;ab=h;f=ab-16|0;ab=f;g=b;b=Kd(b);a:{b:{if(b){d=ac(g);while(1){c:{e=b+16|0;if(Ey(c,e)){e=v[b>>2];if(!e){break b}break c}if(Ey(e,c)){d=b+4|0;e=v[b+4>>2];if(e){b=d;break c}v[f+12>>2]=b;b=d;break a}v[f+12>>2]=b;b=d;break a}d=b;b=e;continue}}b=ac(g)}v[f+12>>2]=b}d=v[b>>2];if(!d){d=ab-16|0;ab=d;e=ac(g);e=hh(f,pc(28),ih(d+8|0,e));i=v[e>>2];v[22452]=0;R(822,i+16|0,c|0);c=v[22452];v[22452]=0;d:{if((c|0)!=1){j=ac(e),k=1,t[j+4|0]=k;ab=d+16|0;break d}a=P()|0;O()|0;MK(e);S(a|0);L()}Pg(g,v[f+12>>2],b,v[f>>2]);d=Pd(f);MK(f);i=1}b=h+8|0;Og(b,$b(f,d),i);ab=f+16|0;kO(a,b);ab=h+16|0}function h1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b;b=0;c=ab-32|0;ab=c;e=v[a>>2];a=v[e>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];f=v[a+8>>2];e=v[a+4>>2];g=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(e>>>0<=y[c+4>>2]){if(vf(c)>>>0<f>>>0){break b}h=d+12|0;c:while(1){a=0;if((b|0)==(f|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue c}else{d=Wc((v[xh(g,e,a,b)>>2]+Wc(Or(h),21)|0)+2048|0,12);d=(d|0)<32767?d:32767;i=an(c,a,b),j=(d|0)>-32768?d:-32768,u[i>>1]=j;a=a+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}ab=c+32|0}function Y0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b;b=0;c=ab-32|0;ab=c;e=v[a>>2];a=v[e>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];f=v[a+8>>2];e=v[a+4>>2];g=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(e>>>0<=y[c+4>>2]){if(vf(c)>>>0<f>>>0){break b}h=d+12|0;c:while(1){a=0;if((b|0)==(f|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue c}else{d=Wc((v[xh(g,e,a,b)>>2]+Wc(Or(h),21)|0)+2048|0,12);d=(d|0)<32767?d:32767;i=$m(c,a,b),j=(d|0)>-32768?d:-32768,u[i>>1]=j;a=a+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}ab=c+32|0}function Nm(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;a:{b:{k=v[d>>2];if((k|0)!=(c|0)){break b}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break b}}v[d>>2]=c+1;t[c|0]=l;break a}c:{if(!(!ub(g)|(a|0)!=(f|0))){g=0;a=v[i>>2];if((a-h|0)>159){break c}b=v[e>>2];v[i>>2]=a+4;v[a>>2]=b;break a}g=-1;f=Mv(j,j+104|0,a)-j|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(k|0)|(k-c|0)>2|w[k-1|0]!=48){break c}v[e>>2]=0;v[d>>2]=k+1;t[k|0]=w[a+79744|0];return 0}v[d>>2]=k+1;t[k|0]=w[a+79744|0];v[e>>2]=v[e>>2]+1;g=0}return g}v[e>>2]=0;return 0}function OD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ab-48|0;ab=e;f=Eb(b);d=ub(b);i=Eb(c);h=ub(c);g=-1;a:{if(!d){break a}j=d+f|0;d=f;while(1){if((d|0)==(j|0)){break a}if(Qp(i,h,d)){d=d+1|0;continue}break}g=d-f|0}b:{c:{d=g;if((d|0)!=-1){k=e,l=kd(b),v[k+32>>2]=l;c=Yg(e+40|0,e+32|0);k=e,l=kd(b),v[k+8>>2]=l;k=e,l=le(e+8|0,d),v[k+16>>2]=l;d=Yg(e+24|0,e+16|0);ZC(b,v[c>>2],v[d>>2]);break c}g=ub(b);if(!g){break c}d=Eb(b);f=ub(b);i=Eb(c);h=ub(c);c=-1;d:{if(!h){break d}c=d+f|0;f=-1;e:{while(1){if((c|0)==(d|0)){break e}c=c-1|0;if(!Qp(i,h,c)){continue}break}f=c-d|0}c=f}if((c|0)!=(g-1|0)){break c}Bb(a);break b}Ac(a,b)}ab=e+48|0}function Nl(a,b,c,d){var e=0,f=0;e=ab-16|0;ab=e;f=a+1074312|0;rb(e+8|0,f,84);a:{if(sb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){rb(e+8|0,f,10);if(!sb(v[v[e+8>>2]>>2],v[e+12>>2])){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+784>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;rb(e+8|0,f,10);if(!sb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}t[b+831|0]=0;u[b+778>>1]=0}ab=e+16|0}function Lda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=ab-32|0;ab=d;ed(b,0);Hh(d,1,a);e=d+16|0;tc(e,v[d>>2],v[d+4>>2],w[d+8|0]);ke(b+43|0,e);pb(e);c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;Tp(b,+((w[a+60|0]^8)-120|0)/192);t[d+16|0]=w[a+61|0];t[d|0]=64;g=b,h=w[Qb(e,d)|0]<<2,u[g+30>>1]=h;u[b+34>>1]=0;e=a+47|0;a=w[e|0];if(a&4){u[b+34>>1]=1;v[b>>2]=v[b>>2]>>>1;f=1;a=w[e|0]}if(a&32){f=f|4;u[b+34>>1]=f;a=w[e|0]}if(a<<24>>24<0){u[b+34>>1]=f|2}ab=d+32|0}function D$(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=ab-32|0;ab=e;if(Da(1,e+16|0)|0){yr(v[114934],12685);L()}c=xr(e+8|0,v[e+16>>2]);g=xr(e,v[e+20>>2]);d=ab-32|0;ab=d;b=ab-16|0;ab=b;a=ab-16|0;ab=a;h=a,i=oia(v[c>>2],v[c+4>>2],1e9,0),v[h>>2]=i;v[a+4>>2]=db;c=Zs(a+8|0,a);f=v[c+4>>2];c=v[c>>2];ab=a+16|0;v[b+8>>2]=c;v[b+12>>2]=f;a=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=a;ab=b+16|0;f=v[d+8>>2];c=v[d+12>>2];a=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=a;a=d;c=v[a+4>>2]+c|0;b=v[a>>2];f=f+b|0;v[a+16>>2]=f;v[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=Zs(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];ab=d+32|0;a=bn(e+24|0,a,b);b=v[a+4>>2];a=v[a>>2];ab=e+32|0;db=b;return a|0}function g$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=ab-16|0;ab=g;a:{b:{if(!jc(b,-1)){i=v[a+8>>2];j=v[a+12>>2];d=v[a+24>>2];if((d|0)==v[a+28>>2]){e=-1;if(!(w[a+48|0]&16)){break a}h=v[a+20>>2];k=v[a+44>>2];v[22452]=0;c=a+32|0;R(47,c|0,0);f=v[22452];v[22452]=0;if((f|0)==1){break b}f=Ec(c);v[22452]=0;R(60,c|0,f|0);f=v[22452];v[22452]=0;if((f|0)==1){break b}e=Eb(c);dw(a,e,ub(c)+e|0);sr(a,d-h|0);v[a+44>>2]=v[a+20>>2]+(k-h|0);d=v[a+24>>2]}v[g+12>>2]=d+1;d=v[Pc(g+12|0,a+44|0)>>2];v[a+44>>2]=d;if(w[a+48|0]&8){c=Eb(a+32|0);Rm(a,c,c+(j-i|0)|0,d)}e=hG(a,hn(b));break a}e=cw(b);break a}a=V(0)|0;O()|0;_(a|0)|0;$()}ab=g+16|0;return e|0}function tH(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=ab-16|0;ab=d;a:{b:{c:{d:{if((b|0)>=0){if((Mo(a+8|0)|0)>(b|0)){break d}}a=aa(8)|0;v[22452]=0;d=Q(55,d|0,10667)|0;b=v[22452];v[22452]=0;if((b|0)==1){break c}lc(a,d);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}b=P()|0;O()|0;pb(d);break b}if(c<0|c>1){a=aa(8)|0;v[22452]=0;d=Q(55,d|0,11726)|0;b=v[22452];v[22452]=0;if((b|0)!=1){lc(a,d);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}b=P()|0;O()|0;pb(d);break b}b=P()|0;O()|0;ba(a|0);break b}e=Tl(c*64);v[(v[a+32>>2]+B(b,872)|0)+1075740>>2]=e;ab=d+16|0;return}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function xba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=ab-16|0;ab=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){l=v[a+32>>2];e=(v[b+12>>2]<<1)+i|0;h=v[b+8>>2]>>>21&2040;e=(((B(u[e>>1],u[h+39874>>1])+B(u[e-2>>1],u[h+39872>>1])|0)+B(u[e+2>>1],u[h+39876>>1])|0)+B(u[e+4>>1],u[h+39878>>1])|0)/16384|0;g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+l|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Lb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=f;v[a+36>>2]=g;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function up(a,b,c){var d=0,e=0,f=0;d=Bb(a);a=ub(b);v[22452]=0;R(46,d|0,a|0);a=v[22452];v[22452]=0;if((a|0)!=1){a:{while(1){if(ub(b)>>>0>e>>>0){f=v[Mj(b,e)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if(v[(a<<2)+c>>2]==(f|0)){v[22452]=0;R(47,d|0,a<<24>>24);a=v[22452];v[22452]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}v[22452]=0;R(47,d|0,a<<24>>24);a=v[22452];v[22452]=0;if((a|0)!=1){break b}break a}v[22452]=0;R(47,d|0,63);a=v[22452];v[22452]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;pb(d);S(a|0);L()}function n3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ab-32|0;ab=d;f=Pb(a);g=b+24|0;a=x[v[g>>2]+480192>>1];v[22452]=0;R(172,f|0,a|0);a=v[22452];v[22452]=0;a:{if((a|0)!=1){a=1;b:{c:{d:{e:{while(1){c=a&65535;if(c>>>0>x[v[g>>2]+480192>>1]){break b}c=dL(v[g>>2],c);v[22452]=0;c=Q(55,d|0,c|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){v[22452]=0;U(980,d+16|0,b|0,c|0);e=v[22452];v[22452]=0;if((e|0)==1){break e}v[22452]=0;R(174,f|0,d+16|0);e=v[22452];v[22452]=0;if((e|0)==1){break d}pb(d+16|0);pb(c);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;pb(d+16|0)}pb(c);break a}ab=d+32|0;return}a=P()|0;O()|0}Uc(f);S(a|0);L()}function P2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ab-32|0;ab=c;f=Pb(a);g=b+24|0;a=x[v[g>>2]+480190>>1];v[22452]=0;R(172,f|0,a|0);a=v[22452];v[22452]=0;a:{if((a|0)!=1){a=1;b:{c:{d:{e:{while(1){e=a&65535;if(e>>>0>x[v[g>>2]+480190>>1]){break b}d=v[g>>2];v[22452]=0;e=Q(55,c|0,eL(d,e)|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){v[22452]=0;U(980,c+16|0,b|0,e|0);d=v[22452];v[22452]=0;if((d|0)==1){break e}v[22452]=0;R(174,f|0,c+16|0);d=v[22452];v[22452]=0;if((d|0)==1){break d}pb(c+16|0);pb(e);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;pb(c+16|0)}pb(e);break a}ab=c+32|0;return}a=P()|0;O()|0}Uc(f);S(a|0);L()}function $C(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if(Ib(a,3878,4)){break a}b=a+16|0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(c>>>0<36){break a}b=a+24|0;d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(d>>>0<36){break a}b=a+32|0;e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(e>>>0<36){break a}b=a+12|0;f=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(f-1>>>0>858993458){break a}b=a+20|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(b-1>>>0>536870910){break a}a=a+28|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);if(B(f,-5)-1>>>0<c>>>0|a-1>>>0>1073741822|(b<<3^-1)>>>0<d>>>0){break a}g=(a<<2^-1)>>>0>=e>>>0}return g}function Y2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-32|0;ab=c;e=Pb(a);f=b+24|0;a=Ps(v[f>>2]+484344|0);v[22452]=0;R(172,e|0,a|0);a=v[22452];v[22452]=0;a:{if((a|0)!=1){a=0;b:{c:{d:{e:{while(1){if(Ps(v[f>>2]+484344|0)>>>0<=a>>>0){break b}d=Rb(v[f>>2]+484344|0,a);v[22452]=0;R(993,c|0,d|0);d=v[22452];v[22452]=0;if((d|0)!=1){v[22452]=0;U(980,c+16|0,b|0,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break e}v[22452]=0;R(174,e|0,c+16|0);d=v[22452];v[22452]=0;if((d|0)==1){break d}a=a+1|0;pb(c+16|0);pb(c);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;pb(c+16|0)}pb(c);break a}ab=c+32|0;return}a=P()|0;O()|0}Uc(e);S(a|0);L()}function E9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ab-80|0;ab=d;e=Bf(d+48|0);v[22452]=0;g=Q(773,b|0,e|0)|0;f=v[22452];v[22452]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22452]=0;T(774,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break b}}break a}g=Wl(e);v[22452]=0;U(181,d|0,b|0,g|0);f=v[22452];v[22452]=0;if((f|0)==1){break a}f=bc(d+24|0,d);Mc(e+8|0,f);qb(f);qb(d);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}v[22452]=0;Q(179,b|0,2-c|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break d}break a}$j(a,e)}Tc(e);ab=d+80|0;return}a=P()|0;O()|0;Tc(e);S(a|0);L()}function yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=ab-16|0;ab=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){l=v[a+32>>2];e=v[b+12>>2]+i|0;h=v[b+8>>2]>>>21&2040;e=(((B(t[e|0],u[h+39874>>1])+B(t[e-1|0],u[h+39872>>1])|0)+B(t[e+1|0],u[h+39876>>1])|0)+B(t[e+2|0],u[h+39878>>1])<<8)/16384|0;g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+l|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Lb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=f;v[a+36>>2]=g;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function lr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=ab-16|0;ab=h;f=d?d:463364;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}if(!v[v[114936]>>2]){v[i>>2]=d&57343;e=1;break a}a=a-194|0;if(a>>>0>50){break c}d=v[(a<<2)+79536>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[114934]=25;e=-1;break a}v[f>>2]=d}ab=h+16|0;return e}function Wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=v[a>>2];d=Zp(c,v[a+4>>2]);if(d>>>0<b>>>0){f=ab-32|0;ab=f;c=b-d|0;b=v[vb(a)>>2];e=v[a+4>>2];a:{if(c>>>0<=(b-e|0)/48>>>0){d=ab-16|0;ab=d;b=kT(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){dc(b);ab=d+16|0}else{NR(a);a=a+48|0;v[b+4>>2]=a;continue}break}break a}b=vb(a);d=hT(f+8|0,iT(a,Zp(v[a>>2],e)+c|0),Zp(v[a>>2],v[a+4>>2]),b);b=ab-16|0;ab=b;v[b>>2]=v[d+8>>2];e=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=B(c,48)+e;c=v[b>>2];while(1){if(v[b+4>>2]!=(c|0)){NR(c);c=v[b>>2]+48|0;v[b>>2]=c;continue}break}xd(b);ab=b+16|0;gT(a,d);fT(d)}ab=f+32|0;return}if(b>>>0<d>>>0){Hd(a,c+B(b,48)|0)}}function h9(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){ws(a+484344|0);Pe(a+1298308|0);Pe(a+1298320|0);Pe(a+1298332|0);uc(a+1298408|0);c=a+900380|0;b=a+484380|0;while(1){if((b|0)==(c|0)){a:{d=a+901404|0;b=a+900380|0;while(1){if((b|0)==(d|0)){c=a+946300|0;b=a+906300|0;while(1){if((b|0)==(c|0)){break a}nB(b);b=b+160|0;continue}}c=v[b>>2];if(c){zt(c)}xb(c);v[b>>2]=0;b=b+4|0;continue}}}else{Xl(b);b=b+104|0;continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0}else{v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+872|0;continue}break}}function Pu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ab-16|0;ab=f;t[f+15|0]=d;t[b+12|0]=w[a|0]&15|w[b+12|0]&240;i=a+1|0;e=f+15|0;Wg(b,w[Qb(i,e)|0]);g=w[Qb(a+2|0,e)|0];t[b+13|0]=g;k=b,l=Ld(w[a+3|0],g,d),t[k+14|0]=l;e=w[Qb(a+4|0,e)|0];t[b+15|0]=e;k=b,l=Ld(w[a+5|0],e,d),t[k+16|0]=l;g=v[b>>2];b=0;while(1){t[f+14|0]=25;if(w[Qb(f+14|0,i)|0]>b>>>0){e=B(b,3)+a|0;h=Sb(w[e+6|0]+c<<24>>24,0,64);d=Fb(g,b);t[d+2|0]=h;e=e+7|0;e=w[e|0]|w[e+1|0]<<8;u[d>>1]=e;a:{if(!b){break a}h=Fb(g,b-1|0);j=x[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;u[d>>1]=e;if(x[h>>1]<=(e&65535)>>>0){break a}u[d>>1]=e+256}b=b+1|0;continue}break}ab=f+16|0}function NM(a,b,c,d){var e=C(0),f=0,g=0,h=0,i=0,j=0;f=ab-16|0;ab=f;v[f+12>>2]=c>>>3;v[f+8>>2]=v[a>>2];a=v[a+20>>2];h=v[zb(f+12|0,f+8|0)>>2];c=h;while(1){if(c){e=xf((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()));e=kf(C(Ed(C((Yf(e)?e>=C(0)?C(1):C(-1):e)*d),C(-1))*C(32768)));a:{if(C(D(e))<C(2147483648)){g=~~e;break a}g=-2147483648}i=a,j=Jc(g),u[i>>1]=j;e=xf((l(2,w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),q()));e=kf(C(Ed(C((Yf(e)?e>=C(0)?C(1):C(-1):e)*d),C(-1))*C(32768)));b:{if(C(D(e))<C(2147483648)){g=~~e;break b}g=-2147483648}i=a,j=Jc(g),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;continue}break}ab=f+16|0;return h<<3}function bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=ab-16|0;ab=b;f=v[a+40>>2];g=v[a+36>>2];h=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;i=v[a+8>>2];j=v[a+12>>2];while(1){if(d){k=((((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&2147483646)<<1)+h|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=u[(e<<1)+k>>1];e=e+1|0;continue}break}e=v[a+32>>2];g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=e+f|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Lb(b+8|0,i,j);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=f;v[a+36>>2]=g;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function nO(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+798|0]=0;return}t[a+798|0]=1;return}t[a+798|0]=2;return}t[a+798|0]=3;return}t[a+730|0]=w[a+730|0]&254;return}t[a+730|0]=w[a+730|0]|1;return}t[a+738|0]=w[a+738|0]&254;return}t[a+738|0]=w[a+738|0]|1;return}t[a+746|0]=w[a+746|0]&254;return}t[a+746|0]=w[a+746|0]|1;return}if(v[c+480180>>2]!=16777216){break a}c=a;a=w[a+746|0];t[c+746|0]=(b|0)==13?a&238|1:a|17}}function oT(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{if(!d){break a}i=w[e|0];if(!i){break a}g=d-6|0;j=35>>>g&(g&255)>>>0<6;l=d-2|0;m=0-c|0;while(1){if(!b){break a}k=(l&255)>>>0>2;h=B(m,6);c=a;a=h+c|0;f=w[a+3|0];b:{if(!(k|(f-2&255)>>>0>2)){g=1;if(w[(c+h|0)+5|0]<224){break b}break a}g=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}g=1}c:{if(k){break c}f=c+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=c+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}b=b-1|0;if(!g){continue}c=w[(c+h|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}t[e|0]=0}}function s8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ab-80|0;ab=d;e=Bf(d+48|0);v[22452]=0;g=Q(845,b|0,e|0)|0;f=v[22452];v[22452]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22452]=0;T(846,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break b}}break a}g=Wl(e);v[22452]=0;U(181,d|0,b|0,g|0);f=v[22452];v[22452]=0;if((f|0)==1){break a}f=bc(d+24|0,d);Mc(e+8|0,f);qb(f);qb(d);d:{if(!(g&1)|c>>>0<2){break d}v[22452]=0;Q(179,b|0,1)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break d}break a}$j(a,e)}Tc(e);ab=d+80|0;return}a=P()|0;O()|0;Tc(e);S(a|0);L()}function yR(a){var b=0,c=0,d=0,e=0,f=0;b=ab-32|0;ab=b;e=b,f=Wb(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788|0,v[e>>2]=f;v[b+4>>2]=0;e=b,f=Wb(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24)),v[e+8>>2]=f;v[b+12>>2]=0;c=Wb(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24));v[b+16>>2]=c?c:52;v[b+20>>2]=0;e=b,f=Wb(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))+80|0,v[e+24>>2]=f;v[b+28>>2]=0;a=b;d=He(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=Iu(v[a>>2],v[a+4>>2],v[c>>2],v[c+4>>2])?c:a;continue}}ab=b+32|0;c=v[a>>2];b=c-52|0;db=v[a+4>>2]-(c>>>0<52)|0;return b}function CG(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=ab-208|0;ab=f;v[f+204>>2]=c;c=f+160|0;Jb(c,0,40);v[f+200>>2]=v[f+204>>2];a:{if((BG(0,b,f+200|0,f+80|0,c,d,e)|0)<0){b=-1;break a}i=v[a+76>>2]>=0;g=v[a>>2];if(v[a+72>>2]<=0){v[a>>2]=g&-33}b:{c:{d:{if(!v[a+48>>2]){v[a+48>>2]=80;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;h=v[a+44>>2];v[a+44>>2]=f;break d}if(v[a+16>>2]){break c}}c=-1;if(mC(a)){break b}}c=BG(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){eb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=h;v[a+28>>2]=0;b=v[a+20>>2];v[a+16>>2]=0;v[a+20>>2]=0;c=b?c:-1}b=a;a=v[a>>2];v[b>>2]=a|g&32;b=a&32?-1:c;if(!i){break a}}ab=f+208|0;return b}function i1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=0;c=ab-32|0;ab=c;d=v[a>>2];a=v[d>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];f=v[a+8>>2];d=v[a+4>>2];g=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(vf(c)>>>0<f>>>0){break b}c:while(1){a=0;if((b|0)==(f|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{e=Wc(v[xh(g,d,a,b)>>2]+2048|0,12);e=(e|0)<32767?e:32767;h=an(c,a,b),i=(e|0)>-32768?e:-32768,u[h>>1]=i;a=a+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}ab=c+32|0}function a_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=ab-48|0;ab=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=eb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;zc(a,c);v[22452]=0;a=T(1094,a|0)|0;b=v[22452];v[22452]=0;b:{if((b|0)!=1){Nb(f+24|0);c:{if(e){th(f+24|0,a);break c}sh(f+24|0,a)}g=f,h=kd(f+24|0),v[g+16>>2]=h;while(1){g=f,h=Ff(f+24|0),v[g+8>>2]=h;if(!aj(f+16|0,f+8|0)){c=v[f+40>>2];pb(f+24|0);break a}a=t[v[f+16>>2]];v[22452]=0;Q(20,f+40|0,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){Fe(f+16|0);continue}break}c=P()|0;O()|0;pb(f+24|0);break b}c=P()|0;O()|0;Nb(f+24|0)}S(c|0);L()}ab=f+48|0;return c|0}function Z0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=0;c=ab-32|0;ab=c;d=v[a>>2];a=v[d>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];f=v[a+8>>2];d=v[a+4>>2];g=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(vf(c)>>>0<f>>>0){break b}c:while(1){a=0;if((b|0)==(f|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{e=Wc(v[xh(g,d,a,b)>>2]+2048|0,12);e=(e|0)<32767?e:32767;h=$m(c,a,b),i=(e|0)>-32768?e:-32768,u[h>>1]=i;a=a+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}ab=c+32|0}function N7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{e=ab+-64|0;ab=e;d=v[a+28>>2];Im(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){g=v[a+28>>2];f=v[a+12>>2];h=d;d=v[a+8>>2]+d|0;f=h>>>0>d>>>0?f+1|0:f;d=Zg(e+48|0,d,f);f=v[d+12>>2];v[e+16>>2]=v[d+8>>2];v[e+20>>2]=f;f=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=f;yj(g,e+8|0)}d=e+24|0;Xd(d,v[a+28>>2]);f=v[d+12>>2];v[e+40>>2]=v[d+8>>2];v[e+44>>2]=f;Wy(v[a+28>>2],c,v[v[b>>2]+8>>2]);b=v[b>>2];c=Mm(d,Cb(v[a+32>>2],v[b>>2]),x[b+12>>1]);v[22452]=0;Y(870,a|0,b|0,e+40|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){yb(c);ab=e- -64|0;break a}a=P()|0;O()|0;yb(c);S(a|0);L()}}function Mw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=ab-32|0;ab=c;d=v[a>>2];a=v[d>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(vf(c)>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=Sl(be(Xf(A[Hg(f,d,a,b)>>3])*134217728));h=Lw(c,a,b),i=C(+(g|0)*7.450580596923828e-9),z[h>>2]=i;a=a+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}ab=c+32|0}function Kw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=ab-32|0;ab=c;d=v[a>>2];a=v[d>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(vf(c)>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=Sl(be(Xf(A[Hg(f,d,a,b)>>3])*134217728));h=Jw(c,a,b),i=C(+(g|0)*7.450580596923828e-9),z[h>>2]=i;a=a+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}ab=c+32|0}function rD(a,b){var c=0,d=0,e=0,f=0;c=v[a>>2];d=Ag(c,v[a+4>>2]);if(d>>>0<b>>>0){f=ab-32|0;ab=f;c=b-d|0;b=v[vb(a)>>2];e=v[a+4>>2];a:{if(c>>>0<=b-e>>3>>>0){d=ab-16|0;ab=d;b=Hq(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){dc(b);ab=d+16|0}else{nl(a);a=a+8|0;v[b+4>>2]=a;continue}break}break a}b=vb(a);d=Jq(f+8|0,Kq(a,Ag(v[a>>2],e)+c|0),Ag(v[a>>2],v[a+4>>2]),b);b=ab-16|0;ab=b;v[b>>2]=v[d+8>>2];e=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=(c<<3)+e;c=v[b>>2];while(1){if(v[b+4>>2]!=(c|0)){nl(c);c=v[b>>2]+8|0;v[b>>2]=c;continue}break}xd(b);ab=b+16|0;rd(a,d);Iq(d)}ab=f+32|0;return}if(b>>>0<d>>>0){Hd(a,c+(b<<3)|0)}}function cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=ab-16|0;ab=b;f=v[a+40>>2];g=v[a+36>>2];h=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;i=v[a+8>>2];j=v[a+12>>2];while(1){if(d){k=(((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&-2)+h|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=t[e+k|0]<<8;e=e+1|0;continue}break}e=v[a+32>>2];g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=e+f|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Lb(b+8|0,i,j);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=f;v[a+36>>2]=g;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function RA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=ab-16|0;ab=e;f=ab-32|0;ab=f;c=ze(f+16|0,1,0);b:{c:{d:{while(1){d=Eb(c);wx(f+8|0,d,ub(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break d}d=If(ub(c));v[22452]=0;R(59,c|0,d|0);d=v[22452];v[22452]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=Eb(c);v[22452]=0;R(60,c|0,b-d|0);b=v[22452];v[22452]=0;e:{if((b|0)!=1){v[22452]=0;R(73,e|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){break e}break c}break c}pb(c);ab=f+32|0;break b}a=P()|0;O()|0;pb(c);S(a|0);L()}v[22452]=0;R(72,a|0,e|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(e);ab=e+16|0;break a}a=P()|0;O()|0;pb(e);S(a|0);L()}}function J9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-80|0;ab=c;e=Bf(c+48|0);v[22452]=0;d=Q(765,b|0,e|0)|0;f=v[22452];v[22452]=0;a:{b:{c:{if((f|0)!=1){if(d){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22452]=0;T(766,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break b}}break a}d=gB(e);v[22452]=0;U(181,c|0,b|0,d|0);f=v[22452];v[22452]=0;if((f|0)==1){break a}f=bc(c+24|0,c);Mc(e+8|0,f);qb(f);qb(c);d:{d=d&1;if(!d){break d}v[22452]=0;Q(179,b|0,2-d|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break d}break a}$j(a,e)}Tc(e);ab=c+80|0;return}a=P()|0;O()|0;Tc(e);S(a|0);L()}function Hm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=ab-16|0;ab=e;f=ab-32|0;ab=f;c=ze(f+16|0,1,0);b:{c:{d:{while(1){d=Eb(c);Ex(f+8|0,d,ub(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break d}d=If(ub(c));v[22452]=0;R(59,c|0,d|0);d=v[22452];v[22452]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=Eb(c);v[22452]=0;R(60,c|0,b-d|0);b=v[22452];v[22452]=0;e:{if((b|0)!=1){v[22452]=0;R(73,e|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){break e}break c}break c}pb(c);ab=f+32|0;break b}a=P()|0;O()|0;pb(c);S(a|0);L()}v[22452]=0;R(72,a|0,e|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(e);ab=e+16|0;break a}a=P()|0;O()|0;pb(e);S(a|0);L()}}function Sy(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=ab-16|0;ab=g;i=Rk(a,b);a:{if((i|0)==255){break a}if(Oj(a)){break a}b:{if(c>>>0>6208431){f=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}c=oia(1<<20-f,0,c,0)+24858e3|0;h=db;c=Fc(ria(c,c>>>0<24858e3?h+1|0:h,49716e3,0),db)}if(e){u[g+14>>1]=(b&3)+c;u[g+12>>1]=1023;c=x[Lc(g+14|0,g+12|0)>>1]}h=Ts(i);e=Cb(a+8|0,i);t[e|0]=(f<<10|c)>>>8|(d?0:32);Mg(a,b,h|160,c&255);Mg(a,b,h|176,w[e|0]);t[a+534|0]=1}ab=g+16|0}function Pg(a,b,c,d){v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;b=v[v[a>>2]>>2];if(b){v[a>>2]=b;d=v[c>>2]}c=v[ac(a)>>2];t[d+12|0]=(c|0)==(d|0);while(1){a:{if(w[v[d+8>>2]+12|0]|(c|0)==(d|0)){break a}b:{b=v[d+8>>2];if(gh(b)){b=v[v[b+8>>2]+4>>2];if(!(!b|w[b+12|0])){break b}if(!gh(d)){d=v[d+8>>2];Lp(d)}b=v[d+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=0;Kp(b);break a}b=v[v[b+8>>2]>>2];if(!(!b|w[b+12|0])){break b}if(gh(d)){d=v[d+8>>2];Kp(d)}b=v[d+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=0;Lp(b);break a}d=v[d+8>>2];t[d+12|0]=1;d=v[d+8>>2];t[d+12|0]=(c|0)==(d|0);t[b+12|0]=1;continue}break}a=vb(a);v[a>>2]=v[a>>2]+1}function BW(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=ab-32|0;ab=k;m=v[c>>2];l=v[c+8>>2];c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=l;v[k+24>>2]=c;v[k+28>>2]=l;v[k+20>>2]=m;v[k+16>>2]=d;v[22452]=0;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=Ja(1020,a|0,b|0,k|0)|0;b=v[22452];v[22452]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[22452]=0;ja(907,10376,e|0,f|0,g|0,h|0,i|0,j|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}$();a=-255}ab=k+32|0;break a}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}return a|0}function Uo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=ab-16|0;ab=e;f=ab-32|0;ab=f;c=ze(f+16|0,1,0);a:{b:{c:{while(1){d=Eb(c);Ex(f+8|0,d,ub(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break c}d=If(ub(c));v[22452]=0;R(59,c|0,d|0);d=v[22452];v[22452]=0;if((d|0)!=1){continue}break}break b}b=v[f+8>>2];d=Eb(c);v[22452]=0;R(60,c|0,b-d|0);b=v[22452];v[22452]=0;d:{if((b|0)!=1){v[22452]=0;R(61,e|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){break d}break b}break b}pb(c);ab=f+32|0;break a}a=P()|0;O()|0;pb(c);S(a|0);L()}v[22452]=0;R(58,a|0,e|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(e);ab=e+16|0;return}a=P()|0;O()|0;pb(e);S(a|0);L()}function aea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=ab-32|0;ab=e;a:{c=v[a+12>>2];b:{if((c|0)==(b|0)){break b}d=b>>>0>c>>>0;c=B(oj(v[v[a+48>>2]+12>>2]),d?b-c|0:c-b|0);c:{if(d){d=$b(e+24|0,wb(v[a+4>>2]));f=e+16|0;kh(f);d=v[d>>2];v[22452]=0;W(604,a|0,d|0,c|0,f|0);c=v[22452];v[22452]=0;if((c|0)!=1){break c}a=V(88408)|0;if((O()|0)!=(fa(88408)|0)){break a}_(a|0)|0;$();break b}g=e,h=wb(v[a+4>>2]),v[g+16>>2]=h;c=$b(e+8|0,JA(e+16|0,c));d=v[$b(e,wb(v[a+4>>2]))>>2];f=v[c>>2];c=v[a>>2];c=B(os(f,wb(c)),6)+c|0;if(Tb(f,d)){Hd(a,zK(c+B(os(d,f),6)|0,v[a+4>>2],c))}wb(c)}v[a+12>>2]=b}ab=e+32|0;return}S(a|0);L()}function R8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=ab-16|0;ab=e;f=ab-32|0;ab=f;c=ze(f+16|0,1,0);a:{b:{c:{while(1){d=Eb(c);Ex(f+8|0,d,ub(c)+d|0,w[b|0]);if(!v[f+12>>2]){break c}d=If(ub(c));v[22452]=0;R(59,c|0,d|0);d=v[22452];v[22452]=0;if((d|0)!=1){continue}break}break b}b=v[f+8>>2];d=Eb(c);v[22452]=0;R(60,c|0,b-d|0);b=v[22452];v[22452]=0;d:{if((b|0)!=1){v[22452]=0;R(61,e|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){break d}break b}break b}pb(c);ab=f+32|0;break a}a=P()|0;O()|0;pb(c);S(a|0);L()}v[22452]=0;R(58,a|0,e|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(e);ab=e+16|0;return}a=P()|0;O()|0;pb(e);S(a|0);L()}function bW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ab-32|0;ab=c;a:{b:{c:{d:{if(h=pd(b),i=1,j=v[b+12>>2],j?h:i){Bb(a);break d}e=Bb(c+16|0);d=ub(b);f=Pf(14291);g=Eb(b);v[22452]=0;W(92,e|0,g|0,d|0,d+f|0);d=v[22452];v[22452]=0;e:{if((d|0)!=1){v[22452]=0;Y(93,e|0,14291,f|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;pb(e);S(a|0);L()}v[22452]=0;R(123,c|0,b+12|0);b=v[22452];v[22452]=0;if((b|0)==1){break c}v[22452]=0;U(2,a|0,c+16|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}pb(c);pb(c+16|0)}ab=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;pb(c)}pb(c+16|0);S(b|0);L()}function C1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=ab+-64|0;ab=c;e=c+16|0;i=ab-16|0;ab=i;j=tO(i+8|0);while(1){if((k|0)==12){ab=i+16|0}else{g=ab+-64|0;ab=g;f=v[j>>2];d=v[j+4>>2]-f|0;a:{if(!d){break a}h=d+1|0;if(!h){f=lI(mI(g+8|0,32));break a}d=E(h);f=mI(g+8|0,(h<<d+1?32:31)-d|0);while(1){d=lI(f);if(h>>>0<=d>>>0){continue}break}f=v[j>>2]+d|0}ab=g- -64|0;l=Fb(e,k),m=f,v[l>>2]=m;k=k+1|0;continue}break}e=vO(c,e,wO(e));uO(a,e);ec(e);ab=c- -64|0;c=a+120|0;tI(c,a,b);t[c+20|0]=1;v[22452]=0;R(1046,a|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){a=P()|0;O()|0;cn(c);S(a|0);L()}return a|0}function Xd(a,b){var c=0,d=0,e=0;c=ab-32|0;ab=c;a=Zg(a,-1,-1);Pi(c+24|0,b,1);a:{b:{if(zd(w[c+24|0])){d=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[22452]=0;R(98,c+8|0,d|0);d=v[22452];v[22452]=0;c:{if((d|0)!=1){d=v[c+12>>2];v[a>>2]=v[c+8>>2];v[a+4>>2]=d;d=v[c+20>>2];v[a+8>>2]=v[c+16>>2];v[a+12>>2]=d;break c}a=V(0)|0;O()|0;_(a|0)|0;e=1;Oi(v[v[b>>2]-12>>2]+b|0,1);if(v[(v[v[b>>2]-12>>2]+b|0)+20>>2]&1){v[22452]=0;X(95);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break b}S(a|0);L()}$()}Ug(v[v[b>>2]-12>>2]+b|0,e)}ab=c+32|0;return}V(0)|0;O()|0;Gb()}L()}function O7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=ab+-64|0;ab=f;e=v[a+28>>2];Im(v[v[e>>2]-12>>2]+e|0,0);e=v[v[b>>2]+4>>2];if(e){h=v[a+28>>2];g=v[a+12>>2];i=e;e=v[a+8>>2]+e|0;g=i>>>0>e>>>0?g+1|0:g;e=Zg(f+48|0,e,g);g=v[e+12>>2];v[f+16>>2]=v[e+8>>2];v[f+20>>2]=g;g=v[e+4>>2];v[f+8>>2]=v[e>>2];v[f+12>>2]=g;yj(h,f+8|0)}e=f+24|0;Xd(e,v[a+28>>2]);g=v[e+12>>2];v[f+40>>2]=v[e+8>>2];v[f+44>>2]=g;fK(d,v[a+28>>2],c);b=v[b>>2];c=Mm(e,Cb(v[a+32>>2],v[b>>2]),x[b+12>>1]);v[22452]=0;Y(870,a|0,b|0,f+40|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){yb(c);ab=f- -64|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function M7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=ab+-64|0;ab=f;e=v[a+28>>2];Im(v[v[e>>2]-12>>2]+e|0,0);e=v[v[b>>2]+4>>2];if(e){h=v[a+28>>2];g=v[a+12>>2];i=e;e=v[a+8>>2]+e|0;g=i>>>0>e>>>0?g+1|0:g;e=Zg(f+48|0,e,g);g=v[e+12>>2];v[f+16>>2]=v[e+8>>2];v[f+20>>2]=g;g=v[e+4>>2];v[f+8>>2]=v[e>>2];v[f+12>>2]=g;yj(h,f+8|0)}e=f+24|0;Xd(e,v[a+28>>2]);g=v[e+12>>2];v[f+40>>2]=v[e+8>>2];v[f+44>>2]=g;cK(c,v[a+28>>2],d);b=v[b>>2];c=Mm(e,Cb(v[a+32>>2],v[b>>2]),x[b+12>>1]);v[22452]=0;Y(870,a|0,b|0,f+40|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){yb(c);ab=f- -64|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function K9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(v[a+4>>2]!=v[vb(a)>>2]){c=ab-16|0;ab=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+7;SM(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+7;dc(c);ab=c+16|0;return}f=ab-32|0;ab=f;h=vb(a);i=f+8|0;c=a;g=Hy(v[a>>2],v[a+4>>2])+1|0;e=ab-16|0;ab=e;v[e+12>>2]=g;d=ab-16|0;ab=d;v[d+12>>2]=613566756;v[d+8>>2]=2147483647;a=v[zb(d+12|0,d+8|0)>>2];ab=d+16|0;a:{if(a>>>0>=g>>>0){d=Gy(c);if(d>>>0<a>>>1>>>0){v[e+8>>2]=d<<1;a=v[Pc(e+8|0,e+12|0)>>2]}ab=e+16|0;break a}hd();L()}a=WM(i,a,Hy(v[c>>2],v[c+4>>2]),h);SM(v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+7;VM(c,a);UM(a);ab=f+32|0}function lZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=ab-16|0;ab=k;a:{if(a){a=OE(b);ok(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;nk(k,a);Fi(i,k);Oc(k);sh(k,a);Fi(h,k);Oc(k);l=d,m=Ki(a),v[l>>2]=m;l=e,m=Li(a),v[l>>2]=m;Eg(k,a);tb(f,k);pb(k);th(k,a);Fi(g,k);Oc(k);a=mk(a);break a}a=NE(b);ok(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;nk(k,a);Fi(i,k);Oc(k);sh(k,a);Fi(h,k);Oc(k);l=d,m=Ki(a),v[l>>2]=m;l=e,m=Li(a),v[l>>2]=m;Eg(k,a);tb(f,k);pb(k);th(k,a);Fi(g,k);Oc(k);a=mk(a)}v[j>>2]=a;ab=k+16|0}function A4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-32|0;ab=c;v[22452]=0;Z(924,a|0);d=v[22452];v[22452]=0;a:{b:{c:{if((d|0)==1){break c}v[22452]=0;Z(925,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break c}d=v[a+24>>2];b=kc(c+8|0,b);v[22452]=0;e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;W(937,c+16|0,d|0,c|0,1);b=v[22452];v[22452]=0;if((b|0)==1){break c}a=c+16|0;b=$d(Eb(a));pb(a);break b}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[22452]=0;W(911,5496,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$()}ab=c+32|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function zW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ab-16|0;ab=e;v[22452]=0;Z(924,a|0);f=v[22452];v[22452]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[22452]=0;Z(925,b|0);f=v[22452];v[22452]=0;if((f|0)==1){break d}f=v[a+24>>2];b=kc(e+8|0,b);v[22452]=0;g=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=g;La(945,f|0,e|0,c|0,d|0,1);c=v[22452];v[22452]=0;b=1;if((c|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,8613,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break b}$();b=0}ab=e+16|0;break a}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}return b|0}function cI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);e=ab+-64|0;ab=e;f=a+24|0;$o(v[f>>2]);t[v[f>>2]+1298420|0]=v[a+52>>2]!=0;c=ag(e+16|0,d,c,b);d=v[c>>2];h=v[c+4>>2];i=v[c+8>>2];j=v[a+32>>2];k=z[a+48>>2];c=e+32|0;Rr(c);v[c+20>>2]=i;v[c+16>>2]=h;v[c+12>>2]=d;v[c+8>>2]=j;v[c+4>>2]=0;v[c>>2]=56424;z[c+24>>2]=k;v[c>>2]=55652;a:{if(b){while(1){b:{d=v[f>>2];v[e+8>>2]=b;v[e+12>>2]=0;v[e>>2]=134217727;v[e+4>>2]=0;d=Sr(d,v[il(e+8|0,e)>>2],c);g=d+g|0;if(!d){break b}b=b-d|0;if(b){continue}}break}if(g){break a}}g=0;if(v[a+52>>2]!=1){break a}a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}ab=e- -64|0;return g}function ZH(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);e=ab+-64|0;ab=e;f=a+24|0;$o(v[f>>2]);t[v[f>>2]+1298420|0]=v[a+52>>2]!=0;c=ag(e+16|0,d,c,b);d=v[c>>2];h=v[c+4>>2];i=v[c+8>>2];j=v[a+32>>2];k=z[a+48>>2];c=e+32|0;Rr(c);v[c+20>>2]=i;v[c+16>>2]=h;v[c+12>>2]=d;v[c+8>>2]=j;v[c+4>>2]=0;v[c>>2]=57252;z[c+24>>2]=k;v[c>>2]=56480;a:{if(b){while(1){b:{d=v[f>>2];v[e+8>>2]=b;v[e+12>>2]=0;v[e>>2]=134217727;v[e+4>>2]=0;d=Sr(d,v[il(e+8|0,e)>>2],c);g=d+g|0;if(!d){break b}b=b-d|0;if(b){continue}}break}if(g){break a}}g=0;if(v[a+52>>2]!=1){break a}a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}ab=e- -64|0;return g}function Rga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=b;c=ab-48|0;ab=c;h=a;a:{if(Dt(a)){v[f>>2]=0;break a}SR(c+16|0,c+32|0);_b(c+24|0,h,v[c+16>>2],v[c+20>>2]);g=v[c+28>>2];i=w[c+32|0];e=i&127;v[f>>2]=e;a=e;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;d=1;while(1){b=(B(g,7)+a|0)+B(d,-7)|0;b:{while(1){if(i<<24>>24>=0|d>>>0>=g>>>0){break b}i=w[(c+32|0)+d|0];e=i&127|e<<7;v[f>>2]=e;a=a+7|0;d=d+1|0;if((g|0)!=(d|0)){continue}break}Ob(h,g);SR(c+8|0,c+32|0);_b(c+24|0,h,v[c+8>>2],v[c+12>>2]);g=v[c+28>>2];e=v[f>>2];d=0;a=b;continue}break}Ob(h,d);if(a>>>0<33){break a}v[f>>2]=-1}ab=c+48|0}function HA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ab-16|0;ab=e;d=(c<<3)+a|0;g=w[d+356|0];t[b+12|0]=w[b+12|0]&248|g&1|g<<1&4|g>>>1&2;Wg(b,Ld(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;g=((c|0)!=0)<<1;j=v[b>>2];a=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if(Td(b)>>>0<=d>>>0){GA(b,32);ab=e+16|0}else{h=a+(d<<2)|0;f=h+160|0;u[e+12>>1]=w[f|0]|w[f+1|0]<<8;f=Ne(e+14|0,e+12|0);i=Fb(j,d);f=x[f>>1];u[i>>1]=f;u[e+14>>1]=f+1;t[e+11|0]=(c^w[h+162|0])>>>g;t[e+10|0]=64;k=i,l=w[Qb(e+11|0,e+10|0)|0],t[k+2|0]=l;d=d+1|0;continue}break}}function ZI(a,b){var c=0,d=0,e=0,f=0;a:{e=ab-16|0;ab=e;f=ab-32|0;ab=f;c=ze(f+16|0,1,0);b:{c:{d:{while(1){d=Eb(c);_w(f+8|0,d,ub(c)+d|0,x[b>>1]);if(!v[f+12>>2]){break d}d=If(ub(c));v[22452]=0;R(59,c|0,d|0);d=v[22452];v[22452]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=Eb(c);v[22452]=0;R(60,c|0,b-d|0);b=v[22452];v[22452]=0;e:{if((b|0)!=1){v[22452]=0;R(73,e|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){break e}break c}break c}pb(c);ab=f+32|0;break b}a=P()|0;O()|0;pb(c);S(a|0);L()}v[22452]=0;R(72,a|0,e|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(e);ab=e+16|0;break a}a=P()|0;O()|0;pb(e);S(a|0);L()}}function QJ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=ab-16|0;ab=f;qh(f+8|0,b);g=ab-16|0;ab=g;Gg(g+8|0,v[f+8>>2],v[f+12>>2]);j=v[g+8>>2];e=v[g+12>>2];h=ab-16|0;ab=h;k=h,l=wb(a),v[k+8>>2]=l;b=ab-16|0;ab=b;i=v[h+8>>2];d=i;a=v[d+12>>2];d=v[d+8>>2];a:{if((a|0)<0){break a}c=v[i+4>>2];if(!a&c>>>0<d>>>0|a){break a}v[b+8>>2]=c-d;v[b+12>>2]=0-(a+(d>>>0>c>>>0)|0);a=e;v[b>>2]=a;v[b+4>>2]=0;c=iu(b+8|0,b);if((Dy(v[c>>2],v[c+4>>2])|0)!=(a|0)){break a}Ci(j,e+j|0,d+v[i>>2]|0);e=v[h+8>>2];c=e;d=a+v[c+8>>2]|0;e=v[c+12>>2];v[c+8>>2]=d;v[c+12>>2]=a>>>0>d>>>0?e+1|0:e}ab=b+16|0;ab=h+16|0;ab=g+16|0;ab=f+16|0}function sZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=ab-16|0;ab=k;a:{if(a){a=RE(b);ok(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;nk(k,a);tb(i,k);pb(k);sh(k,a);tb(h,k);pb(k);l=d,m=Ki(a),t[l|0]=m;l=e,m=Li(a),t[l|0]=m;Eg(k,a);tb(f,k);pb(k);th(k,a);tb(g,k);pb(k);a=mk(a);break a}a=QE(b);ok(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;nk(k,a);tb(i,k);pb(k);sh(k,a);tb(h,k);pb(k);l=d,m=Ki(a),t[l|0]=m;l=e,m=Li(a),t[l|0]=m;Eg(k,a);tb(f,k);pb(k);th(k,a);tb(g,k);pb(k);a=mk(a)}v[j>>2]=a;ab=k+16|0}function rJ(a,b){var c=0,d=0,e=0,f=0;a:{e=ab-16|0;ab=e;f=ab-32|0;ab=f;c=ze(f+16|0,1,0);b:{c:{d:{while(1){d=Eb(c);lJ(f+8|0,d,ub(c)+d|0,w[b|0]);if(!v[f+12>>2]){break d}d=If(ub(c));v[22452]=0;R(59,c|0,d|0);d=v[22452];v[22452]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=Eb(c);v[22452]=0;R(60,c|0,b-d|0);b=v[22452];v[22452]=0;e:{if((b|0)!=1){v[22452]=0;R(73,e|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){break e}break c}break c}pb(c);ab=f+32|0;break b}a=P()|0;O()|0;pb(c);S(a|0);L()}v[22452]=0;R(72,a|0,e|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(e);ab=e+16|0;break a}a=P()|0;O()|0;pb(e);S(a|0);L()}}function Ir(a,b,c){var d=0,e=0;d=a,e=Ti(C(C(z[c+1792>>2]*C(75038))+C(C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489))+C(C(C(z[c+1280>>2]+z[c+2304>>2])*C(6574))+C(C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153))+C(C(C(z[c+768>>2]+z[c+2816>>2])*C(2037))+C(C(C(z[c+3072>>2]-z[c+512>>2])*C(459))+C(C(C(z[c+256>>2]+z[c+3328>>2])*C(213))+C(C(z[c+3584>>2]-z[c>>2])*C(29)))))))))),u[d>>1]=e;d=(b<<5)+a|0,e=Ti(C(C(z[c+8>>2]*C(-5))+C(C(z[c+520>>2]*C(146))+C(C(z[c+1032>>2]*C(-45))+C(C(z[c+1544>>2]*C(-9975))+C(C(z[c+2056>>2]*C(64019))+C(C(z[c+2568>>2]*C(9727))+C(C(z[c+3080>>2]*C(1567))+C(z[c+3592>>2]*C(104)))))))))),u[d>>1]=e}function L1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[vb(a)>>2]){c=ab-16|0;ab=c;a=xo(c,a,1);Sw(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+16;dc(a);ab=c+16|0;return}e=ab-32|0;ab=e;c=vb(a);c=yv(e+8|0,Av(a,Cg(v[a>>2],v[a+4>>2])+1|0),Cg(v[a>>2],v[a+4>>2]),c);Sw(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+16;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-16|0;Sw(v[b>>2]-16|0,d);v[b>>2]=v[b>>2]-16;continue}break}cc(a,b);cc(a+4|0,c+8|0);cc(vb(a),ic(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];while(1){b=v[c+8>>2];if((b|0)!=(a|0)){b=b-16|0;v[c+8>>2]=b;cl(b);continue}break}a=v[c>>2];if(a){Yq(c);xb(a)}ab=e+32|0}function oM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=ab-16|0;ab=c;a:{if(w[b+791|0]!=27){a=t[b+831|0];break a}d=c+8|0;f=a+1074312|0;rb(d,f,21);e=a;a=w[b+821|0];a=Rx(e,w[b+828|0],sb(v[v[c+8>>2]>>2],v[c+12>>2])?a:a+16>>>2|0);rb(d,f,45);b:{if(!(!sb(v[v[c+8>>2]>>2],v[c+12>>2])|w[b+828|0]!=3)){d=w[b+821|0];c:{if(!(!d|d>>>0>=w[b+829|0])){a=w[b+832|0];e=d+1|0;break c}t[b+832|0]=a;e=1}t[b+821|0]=e;a=a<<24>>24;break b}t[b+821|0]=w[b+821|0]+w[b+829|0]}rb(c+8|0,f,47);if(!sb(v[v[c+8>>2]>>2],v[c+12>>2])){break a}t[b+831|0]=a}if(a){g=b,h=Sb(v[b+684>>2]+((B(w[b+830|0],a)+2|0)/8|0)|0,0,256),v[g+684>>2]=h}ab=c+16|0}function nW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=ab+-64|0;ab=g;ph(g+16|0,c);v[22452]=0;c=g+28|0;R(104,c|0,d|0);d=v[22452];v[22452]=0;b:{c:{d:{if((d|0)==1){break d}v[22452]=0;c=g+40|0;R(104,c|0,e|0);d=v[22452];v[22452]=0;if((d|0)==1){break d}v[22452]=0;c=g+52|0;R(104,c|0,f|0);d=v[22452];v[22452]=0;if((d|0)==1){break d}ov(g+8|0,g+16|0);v[22452]=0;W(105,a|0,b|0,v[g+8>>2],v[g+12>>2]);a=v[22452];v[22452]=0;if((a|0)==1){break c}$D(g+16|0);ab=g- -64|0;break a}a=P()|0;O()|0;while(1){c=pb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=P()|0;O()|0;$D(g+16|0)}S(a|0);L()}}function ik(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=ab-16|0;ab=e;f=a+36|0;c=v[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=v[a+20>>2];if(d>>>0>=y[a+24>>2]){Zm(e,f,f+1024|0);fd(e+8|0,a,v[e>>2],v[e+4>>2]);c=v[e+12>>2];v[a+24>>2]=c;v[a+20>>2]=0;if(!c){break c}d=0;c=v[a+32>>2]}v[a+20>>2]=d+1;g=w[(a+d|0)+36|0];d=c+8|0;v[a+32>>2]=d;v[a+28>>2]=v[a+28>>2]|g<<c;c=d;continue}break}a=aa(8)|0;v[22452]=0;T(158,a|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ba(a|0);S(b|0);L()}v[a+32>>2]=c-b;d=a;a=v[a+28>>2];v[d+28>>2]=a>>>b;ab=e+16|0;return a&(-1<<b^-1)}ia(a|0,30480,159);L()}function WG(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(De(a)){Vb(a,31);return 0}g=a,h=De(a),t[g+1375|0]=h;d=Si(a);b=Si(a);Si(a);g=a,h=Si(a),v[g+1112>>2]=h;Si(a);c=De(a);v[a+1116>>2]=c;if(!ww(a,a+1120|0,c)){Vb(a,10);return 0}v[a+1404>>2]=-2;a:{if((d|0)==-1&(b|0)==-1){break a}b=v[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=d;v[a+1404>>2]=b}if(w[a+1377|0]){b=0;e=v[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}v[a- -64>>2]=d;v[a+60>>2]=(v[a+56>>2]+(c+e|0)|0)+27}v[a+1380>>2]=0;return 1}function Nr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=ab-32|0;ab=c;d=v[a>>2];a=v[d>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(vf(c)>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=xh(f,d,a,b);h=Lw(c,a,b),i=C(C(v[g>>2])*C(7.450580596923828e-9)),z[h>>2]=i;a=a+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}ab=c+32|0}function Lr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=ab-32|0;ab=c;d=v[a>>2];a=v[d>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(vf(c)>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=xh(f,d,a,b);h=Jw(c,a,b),i=C(C(v[g>>2])*C(7.450580596923828e-9)),z[h>>2]=i;a=a+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}ab=c+32|0}function a5(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=ab-80|0;ab=d;v[d+72>>2]=c;c=v[a>>2];e=v[a+4>>2];f=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=f;v[d+32>>2]=c;v[d+36>>2]=e;a=Vd(d+24|0);c=v[a+4>>2];a=v[a>>2];e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;v[22452]=0;e=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=e;W(908,d+48|0,d|0,a|0,c|0);a=v[22452];v[22452]=0;a:{b:{if((a|0)!=1){a=v[Oh(d+16|0,d+72|0)>>2];v[22452]=0;b=+za(909,d+48|0,+b,a|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}qb(d+48|0);oe(d+72|0);ab=d+80|0;return+b}a=P()|0;O()|0;break a}a=P()|0;O()|0;qb(d+48|0)}oe(d+72|0);S(a|0);L()}function Qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=ab-16|0;ab=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>18|0;n=((((v[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;g=u[f>>1];v[(e<<2)+b>>2]=g+((B(u[f+4>>1]-g|0,m)|0)/16384|0);e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],h);Lb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function pH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-16|0;ab=d;a:{b:{c:{e=a+8|0;f=Yr(e);d:{if(!f){if(Xr(e)>>>0<=b>>>0){break d}a=Tj(v[a+32>>2],b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<f>>>0){break c}}a=aa(8)|0;v[22452]=0;b=Q(55,d|0,5961)|0;c=v[22452];v[22452]=0;e:{if((c|0)!=1){lc(a,b);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}c=P()|0;O()|0;pb(b);break e}c=P()|0;O()|0;ba(a|0)}S(c|0);L()}b=b+1<<2;a=a+32|0;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}a=v[(b+v[a>>2]|0)+900380>>2];t[a+15|0]=w[a+15|0]&253|(c?2:0)}ab=d+16|0;return}L()}function E$(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;d=ab-32|0;ab=d;if(Da(0,d+16|0)|0){yr(v[114934],12648);L()}b=xr(d+8|0,v[d+16>>2]);e=xr(d,v[d+20>>2]/1e3|0);c=ab-32|0;ab=c;a=ab-16|0;ab=a;f=ab-16|0;ab=f;b=bn(f+8|0,oia(v[b>>2],v[b+4>>2],1e6,0),db);g=v[b+4>>2];b=v[b>>2];ab=f+16|0;v[a+8>>2]=b;v[a+12>>2]=g;b=v[a+12>>2];v[c+16>>2]=v[a+8>>2];v[c+20>>2]=b;ab=a+16|0;a=v[c+16>>2];f=v[c+20>>2];b=v[e+4>>2];v[c+8>>2]=v[e>>2];v[c+12>>2]=b;e=v[c+8>>2];b=a+e|0;a=v[c+12>>2]+f|0;a=bn(c+24|0,b,b>>>0<e>>>0?a+1|0:a);b=v[a+4>>2];a=v[a>>2];ab=c+32|0;c=bn(d+24|0,a,b);a=v[c+4>>2];c=v[c>>2];ab=d+32|0;db=a;return c|0}function K7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[vb(a)>>2]){c=ab-16|0;ab=c;a=fz(c,a);rx(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;dc(a);ab=c+16|0;return}e=ab-32|0;ab=e;c=vb(a);c=_f(e+8|0,fh(a,nc(v[a>>2],v[a+4>>2])+1|0),nc(v[a>>2],v[a+4>>2]),c);rx(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-4|0;rx(v[b>>2]-4|0,d);v[b>>2]=v[b>>2]-4;continue}break}cc(a,b);cc(a+4|0,c+8|0);cc(vb(a),ic(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];while(1){b=v[c+8>>2];if((b|0)!=(a|0)){b=b-4|0;v[c+8>>2]=b;bg(b);continue}break}a=v[c>>2];if(a){iz(c);xb(a)}ab=e+32|0}function AW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-16|0;ab=d;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22452]=0;Z(925,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break d}c=v[a+24>>2];e=kc(d+8|0,b);v[22452]=0;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;b=eE(c,d,1);e=v[22452];v[22452]=0;c=db;if((e|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,8644,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break b}$();b=0;c=0}ab=d+16|0;a=c;break a}b=P()|0;O()|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Gb();L()}ua(a|0);return b|0}function $l(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function w4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-16|0;ab=d;v[22452]=0;Z(924,a|0);e=v[22452];v[22452]=0;a:{b:{c:{if((e|0)==1){break c}v[22452]=0;Z(925,b|0);e=v[22452];v[22452]=0;if((e|0)==1){break c}e=v[a+24>>2];b=kc(d+8|0,b);v[22452]=0;f=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=f;W(942,e|0,d|0,(c|0)!=0|0,1);c=v[22452];v[22452]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,9966,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}ab=d+16|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function paa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=ab-16|0;ab=g;h=x[c>>1];i=c;e=ab-16|0;ab=e;f=b;b=Kd(b);a:{b:{if(b){c=ac(f);while(1){c:{d=x[b+14>>1];if(wm(h,d)){d=v[b>>2];if(!d){break b}break c}if(wm(d,h)){c=b+4|0;d=v[b+4>>2];if(d){b=c;break c}v[e+12>>2]=b;b=c;break a}v[e+12>>2]=b;b=c;break a}c=b;b=d;continue}}b=ac(f)}v[e+12>>2]=b}c=v[b>>2];if(!c){c=ab-16|0;ab=c;d=ac(f);d=hh(e,pc(16),ih(c+8|0,d));wi(v[d>>2]+14|0,x[i>>1]);k=ac(d),l=1,t[k+4|0]=l;ab=c+16|0;Pg(f,v[e+12>>2],b,v[e>>2]);c=Pd(e);$k(e);j=1}b=g+8|0;Og(b,$b(e,c),j);ab=e+16|0;kO(a,b);ab=g+16|0}function Rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=ab-16|0;ab=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>10&4194048;n=(((v[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){f=e+n|0;g=t[f|0];v[(e<<2)+b>>2]=((B(t[f+2|0]-g|0,m)|0)/16384|0)+(g<<8);e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],h);Lb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function Lv(a,b,c,d,e){var f=0,g=0;f=ab-16|0;ab=f;g=f+8|0;zc(g,b);v[22452]=0;b=T(1111,g|0)|0;g=v[22452];v[22452]=0;a:{if((g|0)==1){break a}v[22452]=0;W(1123,b|0,79744,79776,c|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}v[22452]=0;b=T(1112,f+8|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}v[22452]=0;c=T(1124,b|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break a}v[d>>2]=c;v[22452]=0;c=T(1121,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}v[e>>2]=c;v[22452]=0;R(1122,a|0,b|0);a=v[22452];v[22452]=0;if((a|0)==1){break a}Nb(f+8|0);ab=f+16|0;return}a=P()|0;O()|0;Nb(f+8|0);S(a|0);L()}function MW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(Bg(a,v[b+8>>2],f)){tv(b,c,d,e);return}h=w[b+53|0];g=v[a+12>>2];t[b+53|0]=0;i=w[b+52|0];t[b+52|0]=0;j=a+16|0;pv(j,b,c,d,e,f);k=w[b+53|0];h=h|k;l=w[b+52|0];i=i|l;a:{if((g|0)<2){break a}j=j+(g<<3)|0;g=a+24|0;while(1){if(w[b+54|0]){break a}b:{if(l){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!k){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;pv(g,b,c,d,e,f);k=w[b+53|0];h=k|h;l=w[b+52|0];i=l|i;g=g+8|0;if(j>>>0>g>>>0){continue}break}}t[b+53|0]=(h&255)!=0;t[b+52|0]=(i&255)!=0}function SZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=ab-32|0;ab=f;v[f+24>>2]=b;a:{if(!(v[c+4>>2]&1)){c=eb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+8|0;zc(a,c);v[22452]=0;a=T(1112,a|0)|0;b=v[22452];v[22452]=0;b:{if((b|0)!=1){Nb(f+8|0);c:{if(e){th(f+8|0,a);break c}sh(f+8|0,a)}g=f,h=kd(f+8|0),v[g>>2]=h;while(1){a=rk(f+8|0);b=v[f>>2];if(!Tb(b,a)){c=v[f+24>>2];Oc(f+8|0);break a}a=v[b>>2];v[22452]=0;Q(1127,f+24|0,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){te(f);continue}break}c=P()|0;O()|0;Oc(f+8|0);break b}c=P()|0;O()|0;Nb(f+8|0)}S(c|0);L()}ab=f+32|0;return c|0}function Pv(a,b,c,d,e){var f=0,g=0;f=ab-16|0;ab=f;g=f+8|0;zc(g,b);v[22452]=0;b=T(18,g|0)|0;g=v[22452];v[22452]=0;a:{if((g|0)==1){break a}v[22452]=0;W(1109,b|0,79744,79776,c|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}v[22452]=0;b=T(1094,f+8|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}v[22452]=0;c=T(1110,b|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break a}t[d|0]=c;v[22452]=0;c=T(1107,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}t[e|0]=c;v[22452]=0;R(1108,a|0,b|0);a=v[22452];v[22452]=0;if((a|0)==1){break a}Nb(f+8|0);ab=f+16|0;return}a=P()|0;O()|0;Nb(f+8|0);S(a|0);L()}function v4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=ab-16|0;ab=e;v[22452]=0;Z(924,a|0);d=v[22452];v[22452]=0;a:{b:{c:{if((d|0)==1){break c}v[22452]=0;Z(925,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break c}d=v[a+24>>2];b=kc(e+8|0,b);v[22452]=0;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;Ta(944,d|0,e|0,+c,1);d=v[22452];v[22452]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,5887,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}ab=e+16|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function Wg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=nc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=ab-32|0;ab=e;b=b-c|0;c=v[vb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=ab-16|0;ab=c;b=li(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){dc(b);ab=c+16|0}else{Nu(a);a=a+4|0;v[b+4>>2]=a;continue}break}break a}c=vb(a);c=_f(e+8|0,fh(a,nc(v[a>>2],d)+b|0),nc(v[a>>2],v[a+4>>2]),c);f=ab-16|0;ab=f;b=jl(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){Nu(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}xd(b);ab=f+16|0;rd(a,c);Zf(c)}ab=e+32|0;return}if(b>>>0<c>>>0){Hd(a,d+(b<<2)|0)}}function _C(a){var b=0,c=0,d=0;b=ab-16|0;ab=b;v[b+4>>2]=B(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),5)+(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24));v[b+8>>2]=(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))+((w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))<<3);v[b+12>>2]=(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))+((w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24))<<2);a=b+4|0;d=Fb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=Kt(v[a>>2],v[c>>2])?c:a;continue}}ab=b+16|0;return v[a>>2]-36|0}function ada(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=sd(a);a:{if(b){v[22452]=0;R(679,a|0,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break a}d=ab-16|0;ab=d;v[d>>2]=a;c=v[a+4>>2];v[d+4>>2]=c;v[d+8>>2]=c+B(b,36);b=v[d+4>>2];e=v[d+8>>2];while(1){if((b|0)==(e|0)){dc(d);ab=d+16|0}else{c=Jb(b,0,36);v[c>>2]=0;v[c+4>>2]=0;u[c+22>>1]=0;u[c+24>>1]=0;u[c+26>>1]=0;u[c+28>>1]=0;t[c+21|0]=64;t[c+19|0]=64;t[c+20|0]=100;t[c+15|0]=0;t[c+16|0]=0;t[c+17|0]=0;t[c+18|0]=0;v[c+8>>2]=0;v[c+12>>2]=0;u[c+30>>1]=0;u[c+32>>1]=0;b=b+36|0;v[d+4>>2]=b;continue}break}}return a|0}a=P()|0;O()|0;rz(c);S(a|0);L()}function tQ(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1196314451){break a}b=a+4|0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|c>>>0>262144){break a}b=a+1094|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+1096|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-5>>>0<4294967292){break a}if(!qt(a+8|0)){break a}b=a+1094|0;a=a+40|0;while(1){if((a|0)==(b|0)){return 1}if(w[a+32|0]>15|w[a+33|0]>64){break a}c=qt(a);a=a+34|0;if(c){continue}break}}return 0}function Zea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=C(0),i=0,j=0,k=0,l=0,m=0;g=ab-16|0;ab=g;a:{b:{if((c|0)==(f|0)){if((b|0)!=(e|0)){break b}v[g+12>>2]=f;v[g+8>>2]=f;c=v[zb(g+12|0,g+8|0)>>2];v[g+12>>2]=e;v[g+8>>2]=e;j=v[zb(g+12|0,g+8|0)>>2];e=0;c:while(1){f=0;if((c|0)==(e|0)){break a}while(1)if((f|0)==(j|0)){e=e+1|0;continue c}else{k=(B(b,e)+f|0)+a|0;h=kf(C(Ed(z[Gp(d,f,e)>>2],C(-1))*C(128)));d:{if(C(D(h))<C(2147483648)){i=~~h;break d}i=-2147483648}l=k,m=aR(i),t[l|0]=m;f=f+1|0;continue}}}ca(17280,8954,27,9481);L()}ca(17230,8954,28,9481);L()}ab=g+16|0}function N_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=ab-32|0;ab=c;a:{b:{c:{if(jc(b,-1)){break c}i=c,j=hn(b),t[i+23|0]=j;if(w[a+44|0]){d=-1;if((bk(c+23|0,1,1,v[a+32>>2])|0)==1){break c}break a}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=qr(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((bk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((bk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}d=cw(b);break a}d=-1}ab=c+32|0;return d|0}function kea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab-80|0;ab=d;e=Bf(d+48|0);v[22452]=0;c=Q(591,b|0,e|0)|0;f=v[22452];v[22452]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22452]=0;T(592,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break a}}break c}c=e+4|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22452]=0;U(181,d|0,b|0,(c>>>0<9?0:c-8|0)|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Tc(e);S(a|0);L()}b=bc(d+24|0,d);Mc(e+8|0,b);qb(b);qb(d);$j(a,e)}Tc(e);ab=d+80|0}function Pi(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=ab-32|0;ab=e;t[a|0]=0;a:{d=v[v[b>>2]-12>>2]+b|0;b:{if(uh(d)){d=v[d+72>>2];if(d){Ou(d)}c:{if(c){break c}c=v[v[b>>2]-12>>2]+b|0;if(!(v[c+4>>2]&4096)){break c}d=e+24|0;zc(d,c);v[22452]=0;f=T(18,d|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}Nb(e+24|0);c=xi(e+16|0,b);d=dh(e+8|0);while(1){d:{if(!Eo(c,d)){break d}if(!_g(f,8192,Ak(v[c>>2]))){break d}vl(c);continue}break}if(!Cj(c,d)){break c}Ug(v[v[b>>2]-12>>2]+b|0,6)}g=a,h=uh(v[v[b>>2]-12>>2]+b|0),t[g|0]=h;break b}Ug(d,4)}ab=e+32|0;return}a=P()|0;O()|0;Nb(e+24|0);S(a|0);L()}function F_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-32|0;ab=c;d=w[a+52|0];a:{if(jc(b,-1)){if(d){break a}b=v[a+48>>2];e=a,f=jc(b,-1)^1,t[e+52|0]=f;break a}b:{if(!d){break b}e=c,f=hn(v[a+48>>2]),t[e+19|0]=f;c:{d:{e:{d=c+20|0;switch(qr(v[a+36>>2],v[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((nr(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}ab=c+32|0;return b|0}function E4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;v[22452]=0;Z(924,a|0);d=v[22452];v[22452]=0;a:{b:{c:{if((d|0)==1){break c}v[22452]=0;Z(925,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break c}d=v[a+24>>2];b=kc(c+8|0,b);v[22452]=0;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;e=+ra(935,d|0,c|0,1);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,5924,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();e=0}ab=c+16|0;return+e}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function _ea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=C(0),i=0,j=0,k=0,l=0;g=ab-16|0;ab=g;a:{b:{if((c|0)==(f|0)){if((b|0)!=(e|0)){break b}v[g+12>>2]=f;v[g+8>>2]=f;i=v[zb(g+12|0,g+8|0)>>2];v[g+12>>2]=e;v[g+8>>2]=e;j=v[zb(g+12|0,g+8|0)>>2];e=0;c:while(1){f=0;if((e|0)==(i|0)){break a}while(1)if((f|0)==(j|0)){e=e+1|0;continue c}else{h=kf(C(Ed(z[Gp(d,f,e)>>2],C(-1))*C(32768)));d:{if(C(D(h))<C(2147483648)){c=~~h;break d}c=-2147483648}c=Jc(c);k=bR(a,b,f,e),l=c,u[k>>1]=l;f=f+1|0;continue}}}ca(17280,8954,27,9481);L()}ca(17230,8954,28,9481);L()}ab=g+16|0}function FN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=Rs(b);d=sd(a);v[22452]=0;R(739,a|0,2048);e=v[22452];v[22452]=0;a:{if((e|0)!=1){g=ab-16|0;ab=g;e=Hq(g,a,2048);d=v[e+4>>2];i=v[e+8>>2];while(1){if((d|0)==(i|0)){dc(e);ab=g+16|0}else{v[d>>2]=0;v[d+4>>2]=0;d=d+8|0;v[e+4>>2]=d;continue}break}break a}a=P()|0;O()|0;Ud(d);S(a|0);L()}while(1){b:{c=1;if((f|0)!=1024){if((f|0)==2048){break b}c=+(f-1024|0);j=Rs(K(c*c*-9.5367431640625e-7+1)*b);c=c*.0372006759294457;c=j*ki(c)/(h*c)}k=He(v[a>>2],f),l=c*.011841342921061943,A[k>>3]=l;f=f+1|0;continue}break}}function d1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=ab-32|0;ab=c;d=v[a>>2];a=v[d>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(vf(c)>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=Hg(f,d,a,b);h=Lw(c,a,b),i=C(A[g>>3]),z[h>>2]=i;a=a+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}ab=c+32|0}function V0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=ab-32|0;ab=c;d=v[a>>2];a=v[d>>2];wf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(vf(c)>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=Hg(f,d,a,b);h=Jw(c,a,b),i=C(A[g>>3]),z[h>>2]=i;a=a+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}ab=c+32|0}function G4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-16|0;ab=d;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;a:{b:{c:{if((c|0)==1){break c}v[22452]=0;Z(925,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break c}c=v[a+24>>2];b=kc(d+8|0,b);v[22452]=0;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=Y(931,c|0,d|0,1)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,9997,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}ab=d+16|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function W4(a){a=a|0;var b=0;b=8003;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=21598;break a}b=8036;break a}b=17498;break a;case 0:b=4972;break a;case 9:b=8059;break a;case 10:b=8073;break a;case 11:b=5349;break a;case 12:b=5369;break a;case 19:b=8085;break a;case 20:b=8017;break a;case 21:b=12804;break a;case 22:b=12127;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=5980;break a}b=7970}return $d(b)|0}function DU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=ab-32|0;ab=e;ed(b,0);Hh(e,1,a+33|0);d=e+16|0;tc(d,v[e>>2],v[e+4>>2],w[e+8|0]);ke(b+43|0,d);pb(d);f=a+50|0;f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[b>>2]=f;g=a+54|0;v[b+24>>2]=w[g|0]|w[g+1|0]<<8;t[e+16|0]=w[a+56|0];t[e|0]=64;h=b,i=w[Qb(d,e)|0]<<2,u[h+30>>1]=i;d=a+57|0;g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[b+4>>2]=g;d=a+61|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);c=c?g?f:d:d;v[b+8>>2]=c;if(!(!w[a|0]|c>>>0<=g+2>>>0|c>>>0>f>>>0)){u[b+34>>1]=x[b+34>>1]|2}ab=e+32|0}function Pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=ab-16|0;ab=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){l=v[a+32>>2];h=v[b+12>>2]+i|0;e=t[h|0];e=((B(t[h+1|0]-e|0,v[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+l|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Lb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=f;v[a+36>>2]=g;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function zw(a,b,c){var d=0,e=0,f=C(0),g=0,h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0);e=ab-32|0;ab=e;ZG(C(-z[a>>2]),C(z[a+24>>2]+z[a+12>>2]),C(z[a+48>>2]+z[a+36>>2]),e+20|0);ZG(z[a+60>>2],C(z[a+48>>2]-z[a+36>>2]),C(z[a+24>>2]-z[a+12>>2]),e+8|0);z[e+12>>2]=-z[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;g=d+c|0;h=z[g>>2];f=z[d+(e+20|0)>>2];i=z[d+67248>>2];j=z[d+67260>>2];k=z[d+(e+8|0)>>2];z[g>>2]=C(f*i)-C(j*k);g=b+d|0;l=z[(0-a<<2)+67256>>2];d=5-a<<2;m=z[d+67248>>2];f=C(C(f*j)+C(k*i));z[g>>2]=C(h*l)-C(m*f);z[b+d>>2]=C(h*m)+C(f*l);a=a+1|0;continue}break}ab=e+32|0}function Ck(a,b,c){var d=0,e=0;e=ab-16|0;ab=e;v[a+4>>2]=0;Pi(e+8|0,a,1);d=4;a:{b:{c:{if(!zd(w[e+8|0])){break c}d=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22452]=0;b=Y(96,d|0,b|0,c|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;_(b|0)|0;d=1;Oi(v[v[a>>2]-12>>2]+a|0,1);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22452]=0;X(95);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)==1){break b}S(a|0);L()}$()}Ug(v[v[a>>2]-12>>2]+a|0,d);ab=e+16|0;return a}V(0)|0;O()|0;Gb()}L()}function t6(a){a=a|0;var b=0,c=0;c=ab-16|0;ab=c;b=v[v[a+16>>2]+24620>>2];b=vc(pia(oia(b,b>>31,3840,0),db,1e3,0),db);v[a+4316>>2]=b;v[22452]=0;v[c+12>>2]=0;U(881,a+4264|0,b|0,c+12|0);b=v[22452];v[22452]=0;a:{b:{c:{if((b|0)!=1){d:{if(!w[a+4260|0]){break d}b=v[a+4316>>2];v[22452]=0;v[c+12>>2]=0;U(881,a+4276|0,b|0,c+12|0);b=v[22452];v[22452]=0;if((b|0)!=1){break d}b=V(88408)|0;break c}v[c+12>>2]=0;b=c+12|0;KJ(a+4288|0,b);v[c+12>>2]=0;KJ(a+4300|0,b);break b}b=V(88408)|0}if((O()|0)!=(fa(88408)|0)){break a}_(b|0)|0;v[a+4316>>2]=0;$()}ab=c+16|0;return}S(b|0);L()}function Oba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=ab-16|0;ab=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){l=v[a+32>>2];h=(v[b+12>>2]<<1)+i|0;e=u[h>>1];e=e+((B(u[h+2>>1]-e|0,v[b+8>>2]>>>18|0)|0)/16384|0)|0;g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+l|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Lb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=f;v[a+36>>2]=g;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function oH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-16|0;ab=d;a:{b:{c:{c=a+8|0;e=Yr(c);d:{if(!e){if(Xr(c)>>>0<=b>>>0){break d}c=(w[Tj(v[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<e>>>0){break c}}a=aa(8)|0;v[22452]=0;b=Q(55,d|0,5961)|0;c=v[22452];v[22452]=0;e:{if((c|0)!=1){lc(a,b);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}c=P()|0;O()|0;pb(b);break e}c=P()|0;O()|0;ba(a|0)}S(c|0);L()}b=b+1<<2;a=a+32|0;c=1;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}c=(w[v[(b+v[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}ab=d+16|0;return c|0}L()}function Sq(a,b){a=a|0;b=b|0;var c=0,d=0;d=ab-16|0;ab=d;a=Bb(a);a:{b:{c:{switch(b|0){case 0:v[22452]=0;b=Q(1,d|0,15805)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}tb(a,b);pb(b);break b;case 1:v[22452]=0;b=Q(1,d|0,15830)|0;c=v[22452];v[22452]=0;if((c|0)!=1){tb(a,b);pb(b);break b}break a;case 2:v[22452]=0;b=Q(1,d|0,15778)|0;c=v[22452];v[22452]=0;if((c|0)!=1){tb(a,b);pb(b);break b}break a;case 3:break c;default:break b}}v[22452]=0;b=Q(1,d|0,15752)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}tb(a,b);pb(b)}ab=d+16|0;return}b=P()|0;O()|0;pb(a);S(b|0);L()}function Q_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=ab-32|0;ab=c;a:{b:{c:{if(Tm(b)){break c}v[c+20>>2]=b;if(w[a+44|0]){d=-1;if((bk(c+20|0,4,1,v[a+32>>2])|0)==1){break c}break a}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=qr(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((bk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((bk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}d=Tm(b)?0:b;break a}d=-1}ab=c+32|0;return d|0}function oY(){var a=0;a:{if(t[464880]&1){break a}if(!Jd(464880)){break a}a=464592;while(1){a=Bb(a)+12|0;if((a|0)!=464880){continue}break}Id(464880)}bd(464592,84744);bd(464604,84776);bd(464616,84812);bd(464628,84836);bd(464640,84860);bd(464652,84876);bd(464664,84896);bd(464676,84916);bd(464688,84944);bd(464700,84984);bd(464712,85016);bd(464724,85052);bd(464736,85088);bd(464748,85104);bd(464760,85120);bd(464772,85136);bd(464784,84860);bd(464796,85152);bd(464808,85168);bd(464820,85184);bd(464832,85200);bd(464844,85216);bd(464856,85232);bd(464868,85248)}function Yfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=ab-48|0;ab=e;v[22452]=0;d=Q(147,a|0,1)|0;c=v[22452];v[22452]=0;a:{if((c|0)==1){break a}b:{if(!d){break b}v[22452]=0;Z(463,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break a}v[22452]=0;d=T(197,a|0)|0;c=v[22452];v[22452]=0;c:{if((c|0)!=1){while(1){if(!(d&255)){break b}v[22452]=0;c=Q(464,a|0,e+8|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break c}d:{if(!c){break d}c=w[e+8|0];if(c>>>0>63){break d}gc(HR(v[b>>2],c),e+8|0,33)}d=d-1|0;continue}}break a}break a}qb(a);ab=e+48|0;return}b=P()|0;O()|0;qb(a);S(b|0);L()}function Lfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab-80|0;ab=d;e=Bf(d+48|0);v[22452]=0;c=Q(468,b|0,e|0)|0;f=v[22452];v[22452]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22452]=0;T(469,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break a}}break c}c=e+2|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22452]=0;U(181,d|0,b|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Tc(e);S(a|0);L()}b=bc(d+24|0,d);Mc(e+8|0,b);qb(b);qb(d);AR(a,e)}Tc(e);ab=d+80|0}function PL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=ab-16|0;ab=e;a:{if(v[a+480180>>2]!=1){break a}c=w[b+846|0];if(!c){break a}d=v[b+104>>2];if(!d){break a}if(!Fd(d)){break a}f=x[d+34>>1];if(!(f&10)){break a}c=w[b+847|0]+w[(c&15)+33392|0]|0;t[b+847|0]=c;if(c<<24>>24>=0){break a}t[b+847|0]=0;h=f&2;c=v[(h?4:12)+d>>2];g=b;b=v[b+760>>2]+1|0;b=b>>>0<v[(h?8:16)+d>>2]-c>>>0?b:0;v[g+760>>2]=b;g=v[d+20>>2];c=b+c|0;b=hk(f);Ub(e+8|0,g+B(c,b)|0,b);b=v[e+8>>2];f=Cb(b,v[e+12>>2]);while(1){if((b|0)==(f|0)){ii(d,a)}else{t[b|0]=w[b|0]^-1;b=b+1|0;continue}break}}ab=e+16|0}function J_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-32|0;ab=c;d=w[a+52|0];a:{if(Tm(b)){if(d){break a}b=v[a+48>>2];e=a,f=Tm(b)^1,t[e+52|0]=f;break a}b:{if(!d){break b}v[c+16>>2]=v[a+48>>2];c:{d:{e:{d=c+20|0;switch(qr(v[a+36>>2],v[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((nr(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}ab=c+32|0;return b|0}function BA(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=w[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!w[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=w[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=B(c>>>3|0,b);b=((d|0)==10)<<4}c=b+B(Np(w[a+1|0]),c)|0}return c}function lO(a,b){var c=0,d=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;bz(a+48|0);bz(a+68|0);bz(a+88|0);Xs(a+492|0);Xs(a+524|0);rm(a,0,0);qm(a,0,0);v[a+40>>2]=0;v[a+44>>2]=0;At(a,b);c=a+108|0;b=0;while(1){if((b|0)!=128){d=Cb(c,b);b=b+1|0;t[d|0]=b;continue}break}return a}function Qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ab-32|0;ab=d;ed(b,0);Hh(d,1,a);e=d+16|0;tc(e,v[d>>2],v[d+4>>2],w[d+8|0]);ke(b+43|0,e);pb(e);c=a+32|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+13|0;u[b+34>>1]=x[b+34>>1]&65533|(w[c|0]|w[c+1|0]<<8)<<1&2;c=a+16|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+20|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+24|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+16|0]=w[a+15|0];t[d|0]=64;f=b,g=w[Qb(e,d)|0]<<2,u[f+30>>1]=g;ab=d+32|0}function uC(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=ab-16|0;ab=f;v[f+8>>2]=e;v[f+12>>2]=d;Pe(a);rp(a,c);e=0;d=0;a:while(1){if(c>>>0>e>>>0){i=c-e|0;v[f+4>>2]=i;g=v[zb(f+12|0,f+4|0)>>2];h=g+d|0;l=d>>>0>h>>>0?d:h;j=$t(Op(a,b+e|0,g),1,13);while(1)if((d|0)==(l|0)){v[f+4>>2]=i-g;d=h+1|0;e=v[zb(f+8|0,f+4|0)>>2]+(e+g|0)|0;continue a}else{b:{c:{d:{k=t[oc(j,d)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=oc(j,d),n=32,t[m|0]=n}d=d+1|0;continue}}break}ab=f+16|0}function Wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;ed(b,0);g=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=g;c=a+4|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+12>>2]=e;c=a+8|0;f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+16>>2]=f;c=a+12|0;c=w[c|0]|w[c+1|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;c=a+14|0;d=w[c|0];u[b+30>>1]=d?d+1|0:256;c=x[b+34>>1]&32767|!w[c|0]<<15;u[b+34>>1]=c;d=a+15|0;a=w[d|0];if(!(!(a&1)|e>>>0>=f>>>0)){c=c|8;u[b+34>>1]=c;a=w[d|0]}if(a&2){v[b+16>>2]=f>>>1;v[b+12>>2]=e>>>1;v[b>>2]=g>>>1;u[b+34>>1]=c|1}}function B3(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=C(0);v[22452]=0;Z(924,a|0);d=v[22452];v[22452]=0;if((d|0)!=1){a=v[a+24>>2];a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125));e=C(c*c);c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125));c=C(K(C(e+C(c*c))))}return C(c)}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,9348,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function HL(a,b,c,d){var e=0;e=ab-16|0;ab=e;a:{b:{c:{if(!d){break c}d=c>>31;d=d+c^d;if(d>>>0<224){break c}rb(e+8|0,a+1074312|0,3);if(sb(v[v[e+8>>2]>>2],v[e+12>>2])){break c}if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,872)+a|0)+1075843|0]&1){rb(e+8|0,a+1074312|0,3);if(!sb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}}c=c<<2}if(!c){break a}d=B(b,872)+a|0;a=Bs(a,d+1074992|0);if(!a){break a}d=v[d+1075648>>2];if(d){d=w[d+33|0]}else{d=13}eb[v[v[a>>2]+84>>2]](a,c,d<<24>>24,b)}ab=e+16|0}function g8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=sd(a);b:{c:{d=Yj(v[b>>2],v[b+4>>2]);if(d){v[22452]=0;R(407,a|0,d|0);e=v[22452];v[22452]=0;if((e|0)==1){break c}Bx(a,v[b>>2],v[b+4>>2],d)}break b}a=P()|0;O()|0;Eh(c);S(a|0);L()}d=a;v[a+20>>2]=v[b+20>>2];c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;v[22452]=0;c=Q(855,a+24|0,b+24|0)|0;e=v[22452];v[22452]=0;d:{e:{if((e|0)!=1){v[22452]=0;Q(54,a+36|0,b+36|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break e}v[a+48>>2]=v[b+48>>2];break a}a=P()|0;O()|0;break d}a=P()|0;O()|0;ec(c)}Eh(d);S(a|0);L()}}function yP(a){var b=0,c=0;a:{if(Ib(a+60|0,13799,4)){break a}b=a+28|0;b=w[b|0]|w[b+1|0]<<8;if(b>>>0<64&(b|0)!=26|b>>>0>2112){break a}b=w[a+42|0];if(b>>>0>=65&(b|0)!=88){break a}b=a+48|0;if((w[b|0]|w[b+1|0]<<8)>>>0>64){break a}b=a+50|0;if((w[b|0]|w[b+1|0]<<8)>>>0>96){break a}b=a+52|0;b=w[b|0]|w[b+1|0]<<8;if(b>>>0>=130&(b|0)!=257){break a}b=a+30|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+38|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break a}b=a+44|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=1){break a}c=BP(a+20|0)}return c}function f9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=ab-208|0;ab=e;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;xL(a+946304|0);d=e+48|0;Jb(d,0,160);d=CL(d);v[22452]=0;f=a+906300|0;U(796,f|0,f+4e4|0,d|0);f=v[22452];v[22452]=0;a:{if((f|0)!=1){ep(d);d=_d(e+24|0,b);v[22452]=0;f=v[d+12>>2];v[e+8>>2]=v[d+8>>2];v[e+12>>2]=f;v[e+16>>2]=v[d+16>>2];f=v[d+4>>2];v[e>>2]=v[d>>2];v[e+4>>2]=f;a=Y(797,a|0,e|0,c|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){a=P()|0;O()|0;break a}qb(b);ab=e+208|0;return a|0}a=P()|0;O()|0;ep(d)}qb(b);S(a|0);L()}function Z8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=ab-16|0;ab=d;e=x[a+30>>1];if(e){b=ln(b<<16>>16,e<<16>>16)}u[d+14>>1]=b;a:{if(!pd(c)){wj(kK(a+52|0,d+14|0),c);break a}f=a+52|0;a=vx(f,d+14|0);v[d+8>>2]=a;j=d,k=Af(f),v[j>>2]=k;if(!Qg(d+8|0,d)){break a}g=ab-16|0;ab=g;a=v[$b(g,a)>>2];h=ab-16|0;ab=h;v[h+8>>2]=a;e=ab-16|0;ab=e;b=h+8|0;i=v[b>>2];c=On($b(e+8|0,i));if((i|0)==v[f>>2]){v[f>>2]=v[c>>2]}a=vb(f);v[a>>2]=v[a>>2]-1;jK(v[ac(f)>>2],i);a=v[c>>2];ab=e+16|0;cl(id(b));xb(i);ab=h+16|0;$b(g+8|0,a);ab=g+16|0}ab=d+16|0}function eY(){var a=0;a:{if(t[464576]&1){break a}if(!Jd(464576)){break a}a=464288;while(1){a=Bb(a)+12|0;if((a|0)!=464576){continue}break}Id(464576)}Xc(464288,4995);Xc(464300,4986);Xc(464312,10782);Xc(464324,10551);Xc(464336,5222);Xc(464348,11626);Xc(464360,5079);Xc(464372,5570);Xc(464384,8857);Xc(464396,8840);Xc(464408,8848);Xc(464420,8867);Xc(464432,10034);Xc(464444,13229);Xc(464456,8930);Xc(464468,7632);Xc(464480,5222);Xc(464492,9723);Xc(464504,10439);Xc(464516,10794);Xc(464528,9220);Xc(464540,6424);Xc(464552,5453);Xc(464564,13138)}function Cn(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0;d=x[a+24>>1];b=c+(d<<2)|0;v[a+40>>2]=((b&3)<<4)+27824;e=b>>>2|0;b=b>>>0<48;f=b?12-e|0:0;u[a+32>>1]=f;u[a+36>>1]=b?1:1<<e-12;u[a+34>>1]=-1<<f^-1;if((d|0)==15){u[a+36>>1]=4095}b=c+(x[a+26>>1]<<2)|0;v[a+52>>2]=((b&3)<<4)+27824;d=b>>>2|0;b=b>>>0<48;e=b?12-d|0:0;u[a+44>>1]=e;c=c+(x[a+30>>1]<<2)|0;v[a+64>>2]=((c&3)<<4)+27824;f=c>>>2|0;c=c>>>0<48;g=c?12-f|0:0;u[a+56>>1]=g;u[a+48>>1]=b?1:1<<d-12;u[a+60>>1]=c?1:1<<f-12;u[a+46>>1]=-1<<e^-1;u[a+58>>1]=-1<<g^-1}function zP(a,b,c,d,e){var f=0;f=w[(w[a+3|0]&15)+27024|0];t[a+3|0]=f;a:{b:{switch(f-11|0){case 0:b=w[a+5|0];c=b&15;if(c){t[a+5|0]=c;return}t[a+5|0]=b&240;return;case 3:c=w[a+5|0];c=B(c&240,10)|c&15;t[a+5|0]=c;f=c&255;c=x[d>>1];if(!(f|(c|0)==65535)){t[a+5|0]=c;t[a+3|0]=12;u[d>>1]=65535}mc(e,b);return;case 1:u[d>>1]=w[a+5|0];v[e>>2]=63;t[a+3|0]=0;return;case 5:b=w[a+5|0];if(c>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|B(c,-10)+b;t[a+5|0]=b}if(b&255){break a}t[a+3|0]=0;return;case 7:break a;default:break b}}if(w[a+5|0]){break a}t[a+3|0]=0}}function W7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);e=ab-32|0;ab=e;c=cf(a,c);d=e+8|0;Xd(d,v[a+28>>2]);f=v[d+12>>2];v[e+24>>2]=v[d+8>>2];v[e+28>>2]=f;a:{if(!c){b:{d=0;if(!Vc(a,5)){break b}break a}}d=ab-32|0;ab=d;h=v[a+28>>2];qk(h,d+24|0);i=d,j=Fc(v[d+24>>2],v[d+28>>2]),v[i+16>>2]=j;v[d+12>>2]=256;Ij(b,v[zb(d+16|0,d+12|0)>>2]);f=v[b>>2];while(1){if(nc(f,v[b+4>>2])>>>0<=g>>>0){ab=d+32|0}else{v[d+16>>2]=0;Vo(h,d+16|0);f=v[b>>2];i=Fb(f,g),k=z[d+16>>2],z[i>>2]=k;g=g+1|0;continue}break}d=c}Te(a,d,e+24|0);ab=e+32|0}function Cr(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=ab-240|0;ab=h;v[h+236>>2]=d;v[h>>2]=a;v[h+232>>2]=c;a:{b:{c:{d:{if((c|0)!=1){i=a;j=1;break d}i=a;j=1;if(d){break d}c=a;break c}while(1){c=i-v[(e<<2)+g>>2]|0;if((eb[b|0](c,a)|0)<=0){c=i;break c}e:{if(!((e|0)<2|f)){d=v[((e<<2)+g|0)-8>>2];f=i-4|0;if((eb[b|0](f,c)|0)>=0){break e}if((eb[b|0](f-d|0,c)|0)>=0){break e}}v[(j<<2)+h>>2]=c;f=h+232|0;d=JG(f);Dr(f,d);j=j+1|0;e=d+e|0;f=0;i=c;if(v[h+236>>2]|v[h+232>>2]!=1){continue}break b}break}c=i;break b}if(f){break a}}IG(h,j);sw(c,b,e,g)}ab=h+240|0}function m4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=ab-16|0;ab=e;f=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;b=ab-32|0;ab=b;v[b+24>>2]=c;c=v[Oh(b+16|0,b+24|0)>>2];v[22452]=0;f=v[e+12>>2];v[b+8>>2]=v[e+8>>2];v[b+12>>2]=f;f=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=f;da(1067,a+8|0,b|0,c|0,d|0)|0;c=v[22452];v[22452]=0;a:{if((c|0)!=1){EH(a);c=DH(a+88|0);d=CH(a+92|0);v[a>>2]=58536;v[c>>2]=58648;v[d>>2]=58728;oe(b+24|0);ab=b+32|0;break a}a=P()|0;O()|0;oe(b+24|0);S(a|0);L()}ab=e+16|0;return a|0}function Bba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=ab-16|0;ab=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){e=(v[b+12>>2]<<1)+i|0;f=v[b+8>>2]>>>21&2040;e=(((B(u[e>>1],u[f+39874>>1])+B(u[e-2>>1],u[f+39872>>1])|0)+B(u[e+2>>1],u[f+39876>>1])|0)+B(u[e+4>>1],u[f+39878>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Lb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function VJ(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0;kx(a);c=Ed(c,C(0));a:{switch(b|0){case 0:z[a+4220>>2]=c;return;case 1:z[a+4224>>2]=c;return;case 2:z[a+4228>>2]=c;ks(a);return;case 3:t[a+4240|0]=c>=C(.5);ks(a);return;case 4:b=ab-16|0;ab=b;e=b,f=Ah(C(c*C(32))),v[e+12>>2]=f;v[b+8>>2]=0;v[b+4>>2]=5;d=v[nj(b+12|0,b+8|0,b+4|0)>>2];ab=b+16|0;v[a+4232>>2]=d;return;case 5:t[a+4241|0]=c>=C(.5);return;case 6:t[a+4242|0]=c>=C(.5);return;case 7:t[a+4244|0]=c>=C(.5);return;case 8:if(c==C(0)){ix(a)}A[a+4256>>3]=c;break;default:break a}}}function K8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-48|0;ab=d;c=d+24|0;kj(c,b,1819307379);Mc(a+40|0,c);qb(c);kj(c,b,1953721961);Mc(a+60|0,c);qb(c);kj(c,b,543520099);Mc(a+120|0,c);qb(c);kj(c,b,1414744396);v[22452]=0;c=Q(359,c|0,13744)|0;e=v[22452];v[22452]=0;a:{if((e|0)!=1){b:{if(c){v[22452]=0;U(746,d|0,d+24|0,2);c=v[22452];v[22452]=0;if((c|0)==1){break b}ot(a+140|0,d);Rd(d)}v[22452]=0;U(747,d|0,b|0,1634890872);b=v[22452];v[22452]=0;if((b|0)!=1){break a}}}a=P()|0;O()|0;qb(d+24|0);S(a|0);L()}Mc(a+80|0,d);qb(d);qb(d+24|0);ab=d+48|0}function _U(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;v[c+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[c+8>>2]=16384;d=v[zb(c+12|0,c+8|0)>>2];v[a+1072>>2]=d;v[c+4>>2]=17;while(1){a:{if(!d){break a}e=v[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=ik(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Bq(c+4|0,ik(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}Bq(c+4|0,d-e|0);break b}NC(a,d,f,b);break b}e=d&(f^-1);if(d&f){v[c+4>>2]=e+1;break b}NC(a,e,0,b)}d=v[a+1072>>2];continue}break}ab=c+16|0}function Sda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-32|0;ab=d;ed(b,0);KA(d,a+1|0);c=d+16|0;tc(c,v[d>>2],v[d+4>>2],w[d+8|0]);ke(b+43|0,c);pb(c);c=a+73|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+54|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b>>2]=e;c=a+58|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if(c){v[b+8>>2]=c+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;mc(b+8|0,e);mc(b+4|0,v[b+8>>2]);ab=d+32|0}function py(a,b,c){var d=0,e=0,f=0;d=ab+-64|0;ab=d;f=v[a>>2];e=v[f-4>>2];f=v[f-8>>2];v[d+20>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;b=0;Jb(d+24|0,0,39);a=a+f|0;a:{if(Bg(e,c,0)){v[d+56>>2]=1;eb[v[v[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=v[d+32>>2]==1?a:0;break a}eb[v[v[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:b=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}b=v[d+24>>2]}ab=d- -64|0;return b}function mL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=ab-16|0;ab=e;v[e+12>>2]=16777216;h=e+12|0;d=v[a>>2];c=nc(d,v[a+4>>2]);a:{if(c>>>0<b>>>0){f=ab-32|0;ab=f;b=b-c|0;c=v[vb(a)>>2];d=v[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){eC(a,b,h);break b}c=vb(a);c=_f(f+8|0,fh(a,nc(v[a>>2],d)+b|0),nc(v[a>>2],v[a+4>>2]),c);g=ab-16|0;ab=g;b=jl(g,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){Dp(d,v[h>>2]);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}xd(b);ab=g+16|0;rd(a,c);Zf(c)}ab=f+32|0;break a}if(b>>>0<c>>>0){Hd(a,d+(b<<2)|0)}}Wx(a);ab=e+16|0}function vZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=ab-416|0;ab=h;d=h+416|0;v[h+12>>2]=d;c=ab-144|0;ab=c;v[c+28>>2]=c+132;i=c+32|0;VE(a+8|0,i,c+28|0,e,f,g);v[c+16>>2]=0;v[c+20>>2]=0;v[c+12>>2]=i;e=h+16|0;g=nc(e,v[h+12>>2]);f=ab-16|0;ab=f;i=Sh(f+8|0,v[a+8>>2]);a=xF(e,c+12|0,g,c+16|0);Rh(i);ab=f+16|0;if((a|0)==-1){mr(12567);L()}v[h+12>>2]=(a<<2)+e;ab=c+144|0;c=v[h+12>>2];a=ab-16|0;ab=a;v[a+8>>2]=b;while(1){if((c|0)!=(e|0)){aG(a+8|0,v[e>>2]);e=e+4|0;continue}break}ab=a+16|0;ab=d;return v[a+8>>2]}function ZU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;v[c+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[c+8>>2]=32768;d=v[zb(c+12|0,c+8|0)>>2];v[a+1072>>2]=d;v[c+4>>2]=9;while(1){a:{if(!d){break a}e=v[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=ik(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Bq(c+4|0,ik(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}Bq(c+4|0,d-e|0);break b}MC(a,d,f,b);break b}e=d&(f^-1);if(d&f){v[c+4>>2]=e+1;break b}MC(a,e,0,b)}d=v[a+1072>>2];continue}break}ab=c+16|0}function D8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{e=ab-32|0;ab=e;a=Ye(a);b:{c:{d:{e:{while(1){v[22452]=0;f=Q(147,b|0,8)|0;g=v[22452];v[22452]=0;if((g|0)==1){break c}if(f){v[22452]=0;U(843,e|0,b|0,c|0);f=v[22452];v[22452]=0;if((f|0)==1){break e}v[22452]=0;R(844,a|0,e|0);f=v[22452];v[22452]=0;if((f|0)==1){break d}Tc(e);qi(e,YP(v[a+4>>2]));if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=(d|0)){continue}}break}ab=e+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;Tc(e);break b}b=P()|0;O()|0}Rd(a);S(b|0);L()}}function F3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-32|0;ab=c;e=b+24|0;f=Pb(a);a=0;a:{b:{c:{d:{e:{while(1){if(x[v[e>>2]+480188>>1]<=a>>>0){break a}d=v[e>>2];v[22452]=0;R(979,c|0,(d+(a<<5)|0)+480289|0);d=v[22452];v[22452]=0;if((d|0)!=1){v[22452]=0;U(980,c+16|0,b|0,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break e}v[22452]=0;R(174,f|0,c+16|0);d=v[22452];v[22452]=0;if((d|0)==1){break d}a=a+1|0;pb(c+16|0);pb(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;pb(c+16|0)}pb(c)}Uc(f);S(a|0);L()}ab=c+32|0}function Dba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=ab-16|0;ab=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){e=v[b+12>>2]+i|0;f=v[b+8>>2]>>>21&2040;e=(((B(t[e|0],u[f+39874>>1])+B(t[e-1|0],u[f+39872>>1])|0)+B(t[e+1|0],u[f+39876>>1])|0)+B(t[e+2|0],u[f+39878>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Lb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function _r(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;g=ab-16|0;ab=g;d=ab-16|0;ab=d;c=Kd(a);f=ac(a);e=ab-16|0;ab=e;while(1){if(c){h=Ks(c+16|0,b);f=h?f:c;c=v[(h?4:0)+c>>2];continue}break}c=v[$b(e+8|0,f)>>2];ab=e+16|0;v[d+8>>2]=c;a:{if(Tb(c,Jf(a))){if(!Ks(b,id(d+8|0))){break a}}c=Jf(a)}ab=d+16|0;if(!jc(c,Jf(a))){c=v[$b(g+8|0,c)>>2];b=ab-16|0;ab=b;v[b+8>>2]=c;d=ab-16|0;ab=d;f=b+8|0;c=v[f>>2];e=On($b(d+8|0,c));if((c|0)==v[a>>2]){v[a>>2]=v[e>>2]}e=vb(a);v[e>>2]=v[e>>2]-1;jK(v[ac(a)>>2],c);ab=d+16|0;Pl(id(f));xb(c);ab=b+16|0}ab=g+16|0}function Ni(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=ab-16|0;ab=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?E(c):E(d)+32|0;zf(f,d,e,0,0,c+49|0);i=v[f>>2];h=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=i;v[a+4>>2]=h;v[a+8>>2]=c;v[a+12>>2]=g&-2147483648|d;ab=f+16|0}function fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=ab-16|0;ab=b;f=v[a+24>>2];g=v[a+20>>2];h=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;i=v[a+8>>2];j=v[a+12>>2];while(1){if(d){k=((((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&2147483646)<<1)+h|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=u[(e<<1)+k>>1];e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],g);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f);Lb(b+8|0,i,j);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function Rx(a,b,c){var d=0,e=0;e=ab-16|0;ab=e;rb(e+8|0,a+1074312|0,21);a:{if(sb(v[v[e+8>>2]>>2],v[e+12>>2])){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+33600|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=UK(sn(a))+-64|0;break a}d=t[(c>>>1&31)+32112|0];if(x[a+480182>>1]&1032){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+33472|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+33536|0]}a=d;ab=e+16|0;return a}function L9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=ab-16|0;ab=d;v[d+12>>2]=b;if(b>>>0<1073741808){h=d,i=ub(a),v[h+8>>2]=i;e=sl(v[Pc(d+12|0,d+8|0)>>2]);if((e|0)!=(yo(a)|0)){a:{f=1;c=yo(a);g=ub(a);b:{if((e|0)==1){b=a;c=v[a>>2];break b}b=e+1|0;c:{if(c>>>0<e>>>0){b=ji(b);break c}v[22452]=0;b=T(1193,b|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}f=me(a);c=Eb(a)}Uh(b,c,ub(a)+1|0);if(f){xb(c)}if((e|0)!=1){Lf(a,e+1|0);Qd(a,g);nd(a,b);break a}ye(a,g)}}ab=d+16|0;return}Df();L()}function A9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=ab-16|0;ab=e;f=Bb(a);a=0;a:{b:{c:{d:{while(1){d=v[b>>2];if(ad(d,v[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=ld(d,0);break e}v[22452]=0;Q(776,f|0,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}d=ld(v[b>>2],a)}v[22452]=0;R(777,e|0,d|0);d=v[22452];v[22452]=0;if((d|0)!=1){v[22452]=0;Q(776,f|0,e|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break d}a=a+1|0;pb(e);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;pb(e);break a}ab=e+16|0;return}a=P()|0;O()|0}pb(f);S(a|0);L()}function rp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=ab-16|0;ab=d;v[d+12>>2]=b;if(b>>>0<4294967280){h=d,i=ub(a),v[h+8>>2]=i;b=ri(v[Pc(d+12|0,d+8|0)>>2]);if((Ec(a)|0)!=(b|0)){a:{g=ub(a);b:{if((b|0)==10){e=1;c=a;f=v[a>>2];break b}c=b+1|0;c:{if(Ec(a)>>>0<b>>>0){c=pc(c);break c}v[22452]=0;c=T(52,c|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}e=me(a);f=Eb(a)}c=dg(c,f,ub(a)+1|0);if(e){xb(f)}if((b|0)!=10){Lf(a,b+1|0);Qd(a,g);nd(a,c);break a}ye(a,g)}}ab=d+16|0;return}Df();L()}function VV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=ab-16|0;ab=e;f=Bb(a);a=0;a:{b:{c:{d:{while(1){d=v[b>>2];if(ad(d,v[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=ld(d,0);break e}v[22452]=0;Q(89,f|0,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break b}d=ld(v[b>>2],a)}v[22452]=0;R(144,e|0,d|0);d=v[22452];v[22452]=0;if((d|0)!=1){v[22452]=0;Q(89,f|0,e|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break d}a=a+1|0;pb(e);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;pb(e);break a}ab=e+16|0;return}a=P()|0;O()|0}pb(f);S(a|0);L()}function T4(a){a=a|0;var b=0,c=0,d=0;b=ab-32|0;ab=b;a:{b:{if(!a){a=$d(21598);break b}v[22452]=0;c=Q(55,b|0,a|0)|0;a=v[22452];v[22452]=0;c:{d:{if((a|0)!=1){v[22452]=0;R(910,b+16|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break d}d=b+16|0;a=$d(Eb(d));pb(d);pb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;pb(c)}_(a|0)|0;a=0;v[22452]=0;W(911,10922,0,0,0);c=v[22452];v[22452]=0;if((c|0)==1){break a}$()}ab=b+32|0;return a|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function lha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ab-16|0;ab=e;g=x[yi(v[a>>2],v[a+4>>2],b)>>1];a:{b:{if(!aq(a,b)){break b}c=v[a+24>>2]+484360|0;d=vg(c);v[e+8>>2]=d;h=ug(c);while(1){if(!Tb(d,h)){break b}f=0;i=el(d);c:{while(1){if((f|0)!=(i|0)){if(!(!((a|0)!=(d|0)|(b|0)!=(f|0))|x[Yb(v[d>>2],f)>>1]!=(g|0))){c=BQ(v[a+24>>2]+484344|0,g,0);if((c|0)!=65535){break c}}f=f+1|0;continue}break}_y(e+8|0);d=v[e+8>>2];continue}break}j=yi(v[a>>2],v[a+4>>2],b),k=c,u[j>>1]=k;break a}c=g}ab=e+16|0;return c&65535}function Od(a){var b=0,c=0,d=0;b=ab-16|0;ab=b;v[b+4>>2]=1105;v[b>>2]=a;v[b+8>>2]=0;c=ab-16|0;ab=c;if(v[a>>2]!=-1){$b(c,yf(c+8|0,b));while(1){if(v[a>>2]==1){continue}break}a:{b:{if(!v[a>>2]){nd(a,1);v[22452]=0;Z(1106,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break b}v[a>>2]=-1}break a}b=V(0)|0;O()|0;_(b|0)|0;nd(a,0);v[22452]=0;X(95);a=v[22452];v[22452]=0;c:{if((a|0)==1){a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){break c}V(0)|0;O()|0;Gb()}L()}S(a|0);L()}}ab=c+16|0;ab=b+16|0;return v[a+4>>2]-1|0}function L2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=ab-16|0;ab=g;v[22452]=0;Z(924,a|0);h=v[22452];v[22452]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[22452]=0;ja(1001,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[22452];v[22452]=0;if((b|0)==1){break c}b=$d(Eb(g));pb(g);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[22452]=0;W(911,10580,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$()}ab=g+16|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function K3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=ab-16|0;ab=g;v[22452]=0;Z(924,a|0);h=v[22452];v[22452]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[22452]=0;ja(975,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[22452];v[22452]=0;if((b|0)==1){break c}b=$d(Eb(g));pb(g);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[22452]=0;W(911,10625,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$()}ab=g+16|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function T8(a){a=a|0;var b=0,c=0;b=32208;a=Pb(a);a:{b:{while(1){c:{if((b|0)==32784){b=32784;break c}d:{c=v[a+4>>2];if(!jc(v[a>>2],c)){if(!Zi(v[b+8>>2],v[on(c)>>2])){break d}}v[22452]=0;R(820,a|0,b+8|0);c=v[22452];v[22452]=0;if((c|0)!=1){break d}break b}b=b+12|0;continue}break}while(1){if((b|0)==32832){break a}e:{c=v[a+4>>2];f:{if(!jc(v[a>>2],c)){if(!Zi(v[b+8>>2],v[on(c)>>2])){break f}}v[22452]=0;R(820,a|0,b+8|0);c=v[22452];v[22452]=0;if((c|0)==1){break e}}b=b+12|0;continue}break}}b=P()|0;O()|0;ec(a);S(b|0);L()}}function FU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=ab-32|0;ab=d;ed(b,0);Hh(d,1,a+33|0);c=d+16|0;tc(c,v[d>>2],v[d+4>>2],w[d+8|0]);ke(b+43|0,c);pb(c);e=a+50|0;e=w[e|0]|w[e+1|0]<<8;v[b>>2]=e;f=a+52|0;v[b+24>>2]=w[f|0]|w[f+1|0]<<8;t[d+16|0]=w[a+54|0];t[d|0]=64;g=b,h=w[Qb(c,d)|0]<<2,u[g+30>>1]=h;c=a+55|0;f=w[c|0]|w[c+1|0]<<8;v[b+4>>2]=f;c=a+57|0;c=w[c|0]|w[c+1|0]<<8;v[b+8>>2]=c;a:{if((c|0)==65535){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(!w[a|0]|c>>>0<=f+2>>>0|c>>>0>e>>>0){break a}u[b+34>>1]=x[b+34>>1]|2}ab=d+32|0}function SC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=ab-16|0;ab=e;g=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=g;a:{if(!g){break a}c=b+80|0;d=v[b+84>>2];if(d>>>0<=15){c=v[c>>2]}else{v[e+12>>2]=d-16;c=v[Pc(c,e+12|0)>>2]}v[a+8>>2]=c;if(!(w[b+88|0]&2)|!w[b+794|0]){break a}b:{c:{if(!RC(b)){c=v[b+104>>2];break c}c=v[b+104>>2];if(v[b+80>>2]!=v[c+12>>2]){break c}d=1;f=v[b+84>>2];if((f|0)==v[c+16>>2]){break b}}d=0;f=v[b+84>>2];if((f|0)!=v[c+8>>2]){break a}}h=a,i=B((v[c>>2]-f|0)+(d?112:48)|0,hk(x[c+34>>1]))+g|0,v[h+4>>2]=i}ab=e+16|0}function Yda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=ab-32|0;ab=c;a=Ye(a);b:{c:{d:{e:{while(1){v[22452]=0;d=Q(147,b|0,8)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}if(d){v[22452]=0;R(621,c|0,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break e}v[22452]=0;R(622,a|0,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break d}Tc(c);qi(c,YP(v[a+4>>2]));if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1413891155){continue}}break}ab=c+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;Tc(c);break b}b=P()|0;O()|0}Rd(a);S(b|0);L()}}function y8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ab-32|0;ab=d;dl(d,2,a+2|0);e=d+16|0;tc(e,v[d>>2],v[d+4>>2],w[d+8|0]);sc(b+492|0,e);f=b+236|0;g=c+1|0;pb(e);c=0;while(1){if((c|0)==120){v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;c=a+1|0;e=a+2|0;f=a+3|0;g=a+4|0;DK(w[a|0]&15,w[c|0]&15,w[e|0]&15,w[f|0]&15,w[g|0]&15,a+5|0,b+48|0);DK(w[a|0]>>>4|0,w[c|0]>>>4|0,w[e|0]>>>4|0,w[f|0]>>>4|0,w[g|0]>>>4|0,a+35|0,b+68|0);ab=d+32|0}else{h=Yb(f,c),i=g+w[(a+c|0)+31|0]|0,u[h>>1]=i;c=c+1|0;continue}break}}function kga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a+4>>2]!=v[vb(a)>>2]){c=ab-16|0;ab=c;a=lv(c,a);d=v[a+4>>2];v[22452]=0;R(447,d|0,b|0);b=v[22452];v[22452]=0;a:{if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+12;dc(a);ab=c+16|0;break a}b=P()|0;O()|0;dc(a);S(b|0);L()}return}d=ab-32|0;ab=d;c=vb(a);c=ql(d+8|0,to(a,ad(v[a>>2],v[a+4>>2])+1|0),ad(v[a>>2],v[a+4>>2]),c);e=v[c+8>>2];v[22452]=0;R(447,e|0,b|0);b=v[22452];v[22452]=0;b:{if((b|0)!=1){v[c+8>>2]=v[c+8>>2]+12;kv(a,c);Zq(c);ab=d+32|0;break b}a=P()|0;O()|0;Zq(c);S(a|0);L()}}function SW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Bg(a,v[b+8>>2],e)){sv(b,c,d);return}a:{if(Bg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];eb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];eb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function LL(a,b,c){var d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}e=v[a+480180>>2];b=e&1048580?(b&240?-16:15)&b:b;c=b&240;f=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=f>>>3&30;break d}g=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!g){break b}b=0-(b<<1)|0;break c}if(g){break b}if(c){if(b?e&59314208:0){break b}b=f>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}a=a+1074456|0;v[d+12>>2]=v[a>>2]+(b<<!(e&59314208));ce(d+12|0,0,256);v[a>>2]=v[d+12>>2]}ab=d+16|0}function qF(a,b,c,d){var e=0,f=0,g=0;f=ab-16|0;ab=f;a:{b:{if((a|0)!=(b|0)){c:{g=v[114934];v[114934]=0;gd();d=vF(a,f+12|0,d);e=db;d:{a=v[114934];if(a){if(v[f+12>>2]!=(b|0)){break c}if((a|0)!=68){break d}v[c>>2]=4;a=2147483647;if(!!d&(e|0)>=0|(e|0)>0){break a}break b}v[114934]=g;if(v[f+12>>2]==(b|0)){break d}break c}if((e|0)<0&d>>>0<=2147483647|(e|0)<-1){v[c>>2]=4;break b}if((e|0)>=0&d>>>0>=2147483648|(e|0)>0){v[c>>2]=4;a=2147483647;break a}a=d;break a}}v[c>>2]=4;a=0;break a}a=-2147483648}ab=f+16|0;return a}function h8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=ab-16|0;ab=f;v[f+12>>2]=b;a:{if(vs(a)>>>0>=b>>>0){d=v[a>>2];g=ck(d,v[a+4>>2]);v[f+8>>2]=g;e=v[zb(f+12|0,f+8|0)>>2];while(1){if(e){xK(d,c);e=e-1|0;d=d+52|0;continue}break}if(b>>>0>g>>>0){yx(a,b-g|0,c);break a}vK(a,v[a>>2]+B(b,52)|0);break a}if(v[a>>2]){ws(a);d=v[a>>2];vs(a);xb(d);h=vb(a),i=0,v[h>>2]=i;v[a>>2]=0;v[a+4>>2]=0}d=uK(a,b);if(tK()>>>0<d>>>0){hd();L()}e=sK(d);v[a>>2]=e;v[a+4>>2]=e;h=vb(a),i=e+B(d,52)|0,v[h>>2]=i;yx(a,b,c)}ab=f+16|0}function D3(a){a=a|0;var b=0,c=0,d=0,e=0;c=ab-32|0;ab=c;d=Pb(a);Dd(c+24|0);a=v[c+28>>2];b=v[c+24>>2];v[22452]=0;R(172,d|0,FH(b,a)|0);a=v[22452];v[22452]=0;a:{if((a|0)!=1){a=0;b:{while(1){b=v[c+24>>2];if((FH(b,v[c+28>>2])|0)<=(a|0)){ab=c+32|0;return}b=v[b+(a<<3)>>2];v[22452]=0;b=Q(55,c+8|0,b|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){v[22452]=0;R(174,d|0,b|0);e=v[22452];v[22452]=0;if((e|0)==1){break b}pb(b);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;pb(b);break a}a=P()|0;O()|0}Uc(d);S(a|0);L()}function z3(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;if((c|0)!=1){a=v[a+24>>2];a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);if(!(t[(b+v[a>>2]|0)+1075081|0]&1)){break a}d=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125))}return C(d)}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,6135,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=ab-16|0;ab=b;f=v[a+24>>2];g=v[a+20>>2];h=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;i=v[a+8>>2];j=v[a+12>>2];while(1){if(d){k=(((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&-2)+h|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=t[e+k|0]<<8;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],g);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f);Lb(b+8|0,i,j);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function Wda(a){a=a|0;var b=0,c=0,d=0,e=0;b=ab-16|0;ab=b;t[b+15|0]=128;d=Vt(a,127,b+15|0);v[22452]=0;t[b+14|0]=64;e=Y(543,a+12|0,127,b+14|0)|0;c=v[22452];v[22452]=0;a:{b:{if((c|0)!=1){v[22452]=0;t[b+13|0]=0;Q(620,a+24|0,b+13|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;t[a+44|0]=0;t[a+45|0]=0;t[a+46|0]=0;t[a+47|0]=0;t[a+48|0]=0;t[a+49|0]=0;t[a+50|0]=0;t[a+51|0]=0;t[a+52|0]=0;t[a+53|0]=0;ab=b+16|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;Xb(e)}Xb(d);S(a|0);L()}function A3(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;if((c|0)!=1){a=v[a+24>>2];a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);if(!(t[(b+v[a>>2]|0)+1075081|0]&1)){break a}d=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125))}return C(d)}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,6233,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-80|0;ab=c;d=Bf(c+48|0);v[22452]=0;e=Q(354,b|0,d|0)|0;f=v[22452];v[22452]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22452]=0;T(355,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break a}}break c}e=gB(d);v[22452]=0;U(181,c|0,b|0,e|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Tc(d);S(a|0);L()}b=bc(c+24|0,c);Mc(d+8|0,b);qb(b);qb(c);$j(a,d)}Tc(d);ab=c+80|0}function jia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-80|0;ab=c;d=Bf(c+48|0);v[22452]=0;e=Q(293,b|0,d|0)|0;f=v[22452];v[22452]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22452]=0;T(294,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break a}}break c}e=gB(d);v[22452]=0;U(181,c|0,b|0,e|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Tc(d);S(a|0);L()}b=bc(c+24|0,c);Mc(d+8|0,b);qb(b);qb(c);$j(a,d)}Tc(d);ab=c+80|0}function Oda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-80|0;ab=c;d=Bf(c+48|0);v[22452]=0;e=Q(627,b|0,d|0)|0;f=v[22452];v[22452]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22452]=0;T(628,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break a}}break c}e=Wl(d);v[22452]=0;U(181,c|0,b|0,e|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Tc(d);S(a|0);L()}b=bc(c+24|0,c);Mc(d+8|0,b);qb(b);qb(c);$j(a,d)}Tc(d);ab=c+80|0}function It(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=ab-16|0;ab=g;v[g+12>>2]=0;v[g+8>>2]=a;h=ab-16|0;ab=h;c=Zb(h+8|0,v[g+8>>2],v[g+12>>2]);f=ab-16|0;ab=f;b=117;v[f+12>>2]=117;d=v[c+4>>2];a:{if(!d){d=v[c>>2];break a}e=32-d|0;v[f+8>>2]=e;b=v[c>>2];i=v[b>>2];j=e;e=v[zb(f+8|0,f+12|0)>>2];v[b>>2]=(-1<<d&-1>>>j-e^-1)&i;i=v[f+12>>2];d=b+4|0;v[c>>2]=d;b=i-e|0}e=d;d=b>>>5<<2;Jb(e,0,d);b=b&31;v[f+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]&(-1>>>32-b^-1)}ab=f+16|0;ab=h+16|0;ab=g+16|0;return a}function IC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=w[a+8|0];h=v[a>>2];e=v[a+4>>2];f=Eb(b);a=ub(b);b=ab-16|0;ab=b;v[b+8>>2]=a;v[b+12>>2]=e;a=h;g=v[zb(b+12|0,b+8|0)>>2];c=g;while(1){a:{if(!c){c=0;break a}i=w[f|0];t[a|0]=i;if(!i){break a}f=f+1|0;a=a+1|0;c=c-1|0;continue}break}b:{if((d-1&255)>>>0<=1){t[b+7|0]=0;Jl(a,((a+e|0)-g|0)+c|0,b+7|0);break b}if((d-3&255)>>>0>1){break b}t[b+6|0]=32;Jl(a,((a+e|0)-g|0)+c|0,b+6|0)}c:{switch(d-1|0){case 0:case 3:t[(v[b+12>>2]+h|0)-1|0]=0;break;default:break c}}ab=b+16|0}function jH(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=ab-32|0;ab=d;A[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22452]=0;d=Q(55,d+8|0,10667)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}lc(b,d);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(d);break b}a=v[a+32>>2];v[d+8>>2]=0;v[d+12>>2]=-1074790400;v[d>>2]=0;v[d+4>>2]=1072693248;e=(a+B(b,872)|0)+1075684|0,f=Tl(A[qg(d+24|0,d+8|0,d)>>3]*128+128),v[e>>2]=f;ab=d+32|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function iga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ab-16|0;ab=e;i=e,j=Wj(b),v[i>>2]=j;g=x[b>>1];c=ab-16|0;ab=c;f=a;a=Kd(a);a:{b:{if(a){b=ac(f);while(1){c:{d=a+16|0;if(uA(g,d)){d=v[a>>2];if(!d){break b}break c}if(tA(d,g)){b=a+4|0;d=v[a+4>>2];if(d){a=b;break c}v[c+12>>2]=a;a=b;break a}v[c+12>>2]=a;a=b;break a}b=a;a=d;continue}}a=ac(f)}v[c+12>>2]=a}b=a;a=v[a>>2];if(!a){dS(c,f,e);Pg(f,v[c+12>>2],b,v[c>>2]);a=Pd(c);cS(c);h=1}b=e+8|0;Og(b,$b(c,a),h);ab=c+16|0;a=id(b);ab=e+16|0;return a+4|0}function Oea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=ab-608|0;ab=f;b=ab-16|0;ab=b;d=f+8|0;KQ(b+8|0,d);c=v[b+12>>2];$c(b,a,v[b+8>>2],c);e=v[b+4>>2];if((e|0)==(c|0)){Rc(a,v[b+12>>2])}ab=b+16|0;c=(c|0)==(e|0);if(!c){JQ(d)}b=-1;a:{if(!c){break a}b=0;if(!LQ(f+8|0)){break a}b=-1;if(!Qf(a,1024)){break a}b=0;d=ab-1024|0;ab=d;c=ab-16|0;ab=c;Jz(c+8|0,d);e=v[c+12>>2];$c(c,a,v[c+8>>2],e);g=v[c+4>>2];if((e|0)==(g|0)){Rc(a,v[c+12>>2])}ab=c+16|0;if((e|0)==(g|0)){b=Lz(d,0)>>>0<17}ab=d+1024|0}ab=f+608|0;return b|0}function y3(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;if((c|0)!=1){a=v[a+24>>2];a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);if(t[(b+v[a>>2]|0)+1075081|0]&1){break a}d=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125))}return C(d)}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,6091,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function wj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){if(!me(a)){if(!me(b)){v[a+8>>2]=v[b+8>>2];c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return}d=Eb(b);b=ub(b);c=ab-16|0;ab=c;a:{if(b>>>0<=10){ye(a,b);a=dg(a,d,b);t[c+15|0]=0;md(a+b|0,c+15|0);break a}f=a;a=w[a+11|0];Un(f,10,b-10|0,a,0,a,b,d)}ab=c+16|0;return}d=Eb(b);b=ub(b);c=ab-16|0;ab=c;e=gk(a);b:{if(e>>>0>b>>>0){e=v[a>>2];Qd(a,b);a=dg(e,d,b);t[c+15|0]=0;md(a+b|0,c+15|0);break b}f=a;a=v[a+4>>2];Un(f,e-1|0,(b-e|0)+1|0,a,0,a,b,d)}ab=c+16|0}}function kK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ab-16|0;ab=e;i=e,j=Wj(b),v[i>>2]=j;g=x[b>>1];c=ab-16|0;ab=c;f=a;a=Kd(a);a:{b:{if(a){b=ac(f);while(1){c:{d=a+16|0;if(mK(g,d)){d=v[a>>2];if(!d){break b}break c}if(lK(d,g)){b=a+4|0;d=v[a+4>>2];if(d){a=b;break c}v[c+12>>2]=a;a=b;break a}v[c+12>>2]=a;a=b;break a}b=a;a=d;continue}}a=ac(f)}v[c+12>>2]=a}b=a;a=v[a>>2];if(!a){dS(c,f,e);Pg(f,v[c+12>>2],b,v[c>>2]);a=Pd(c);cS(c);h=1}b=e+8|0;Og(b,$b(c,a),h);ab=c+16|0;a=id(b);ab=e+16|0;return a+4|0}function iZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;h=ab-16|0;ab=h;d=ub(a);e=yo(a);g=$z(b,c);a:{if(!g){break a}b:{f=Eb(a);if(f>>>0<=b>>>0){f=(ub(a)<<2)+f>>>0>=b>>>0}else{f=0}if(!f){if(e-d>>>0<g>>>0){ME(a,e,(d+g|0)-e|0,d,d)}e=Eb(a)+(d<<2)|0;while(1){if((b|0)==(c|0)){break b}nd(e,v[b>>2]);b=b+4|0;e=e+4|0;continue}}b=uF(h,b,c);c=Eb(b);d=ub(b);v[22452]=0;Y(1147,a|0,c|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){Oc(b);break a}a=P()|0;O()|0;Oc(b);S(a|0);L()}nd(e,0);cg(a,d+g|0)}ab=h+16|0;return a|0}function C3(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;if((c|0)!=1){a=v[a+24>>2];a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);if(t[(b+v[a>>2]|0)+1075081|0]&1){break a}d=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125))}return C(d)}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,6190,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function Yl(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function fl(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(w[a+35|0]&2)){break a}fo(a)}d=x[a+34>>1]&-513|d;u[a+34>>1]=d;if(b){v[a>>2]=4;u[a+34>>1]=d&65470;sg(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}}function UC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{d=ab-16|0;ab=d;b:{c:{if(!b){b=Eb(c);g=b+ub(c)|0;f=ab-16|0;ab=f;d:{e=hi(b,g);if(e>>>0<4294967280){e:{if(e>>>0<=10){ye(a,e);c=a;break e}h=ri(e)+1|0;c=pc(h);nd(a,c);Lf(a,h);Qd(a,e)}while(1){if((b|0)!=(g|0)){md(c,b);c=c+1|0;b=b+1|0;continue}break}t[f+15|0]=0;md(c,f+15|0);ab=f+16|0;break d}Df();L()}break c}dO(d,b,c);v[22452]=0;R(50,a|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}Oc(d)}ab=d+16|0;break a}a=P()|0;O()|0;Oc(d);S(a|0);L()}}function J2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=ab-16|0;ab=f;v[22452]=0;Z(924,a|0);g=v[22452];v[22452]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[22452]=0;ka(1002,f|0,g|0,b|0,c|0,d|0,e|0);b=v[22452];v[22452]=0;if((b|0)==1){break c}b=$d(Eb(f));pb(f);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[22452]=0;W(911,12339,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$()}ab=f+16|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function MJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;b=ci(a,b,c,d);t[a+4260|0]=e;v[a>>2]=46404;c=Pb(a+4264|0);d=Pb(a+4276|0);v[a+4232>>2]=1061997773;e=a+4224|0;v[e>>2]=1061158912;v[e+4>>2]=1059082943;e=a+4216|0;v[e>>2]=1038174126;v[e+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1036831949;v[a+4328>>2]=0;e=a+4320|0;v[e>>2]=0;v[e+4>>2]=0;v[a+4312>>2]=0;v[a+4316>>2]=0;v[22452]=0;R(875,a+44|0,2);e=v[22452];v[22452]=0;if((e|0)!=1){bi(b);return a|0}a=P()|0;O()|0;ec(d);ec(c);ff(b);S(a|0);L()}function I3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=ab-16|0;ab=f;v[22452]=0;Z(924,a|0);g=v[22452];v[22452]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[22452]=0;ka(976,f|0,g|0,b|0,c|0,d|0,e|0);b=v[22452];v[22452]=0;if((b|0)==1){break c}b=$d(Eb(f));pb(f);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[22452]=0;W(911,12439,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$()}ab=f+16|0;return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function dha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=ab-48|0;ab=f;ph(f+8|0,c);v[22452]=0;c=f+20|0;R(104,c|0,d|0);d=v[22452];v[22452]=0;b:{c:{d:{if((d|0)==1){break d}v[22452]=0;c=f+32|0;R(104,c|0,e|0);d=v[22452];v[22452]=0;if((d|0)==1){break d}Tq(f,f+8|0);v[22452]=0;W(105,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[22452];v[22452]=0;if((a|0)==1){break c}kk(f+8|0);ab=f+48|0;break a}a=P()|0;O()|0;while(1){c=pb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;kk(f+8|0)}S(a|0);L()}}function aQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=ab-16|0;ab=c;v[a>>2]=0;v[a+4>>2]=0;mi(a+8|0,0);d=v[b+4>>2];if(d){vq(a,d);Rj(c+8|0,v[b>>2]);Yk(c,v[b>>2],v[b+4>>2]);b=ab-16|0;ab=b;d=v[a+4>>2];h=v[c+8>>2];i=v[c+12>>2];j=v[c>>2];k=v[c+4>>2];e=$P(h,i,j,k)+d|0;v[a+4>>2]=e;a:{b:{if(!d){f=e-1|0;break b}f=e-1|0;if((f^d-1)>>>0>31){break b}g=v[a>>2];break a}g=v[a>>2];v[g+((e>>>0<33?0:f>>>5|0)<<2)>>2]=0}go(b+8|0,g,d);_P(b,h,i,j,k,v[b+8>>2],v[b+12>>2]);ab=b+16|0}ab=c+16|0;return a|0}function Mca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=ab-48|0;ab=f;ph(f+8|0,c);v[22452]=0;c=f+20|0;R(541,c|0,d|0);d=v[22452];v[22452]=0;b:{c:{d:{if((d|0)==1){break d}v[22452]=0;c=f+32|0;R(541,c|0,e|0);d=v[22452];v[22452]=0;if((d|0)==1){break d}Tq(f,f+8|0);v[22452]=0;W(289,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[22452];v[22452]=0;if((a|0)==1){break c}kk(f+8|0);ab=f+48|0;break a}a=P()|0;O()|0;while(1){c=pb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;kk(f+8|0)}S(a|0);L()}}function JZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=ab-208|0;ab=a;u[a+204>>1]=w[79787]|w[79788]<<8;v[a+200>>2]=w[79783]|w[79784]<<8|(w[79785]<<16|w[79786]<<24);f=gd();v[a>>2]=e;g=a+176|0;i=sf(g,20,f,a+200|0,a);e=i+g|0;g=Dg(g,e,c);f=a+8|0;zc(f,c);v[22452]=0;f=T(1111,f|0)|0;h=v[22452];v[22452]=0;if((h|0)!=1){Nb(a+8|0);h=f;f=a+16|0;eF(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=Lm(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);ab=a+208|0;return b|0}b=P()|0;O()|0;Nb(a+8|0);S(b|0);L()}function Dda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=ab-48|0;ab=f;ph(f+8|0,c);v[22452]=0;c=f+20|0;R(130,c|0,d|0);d=v[22452];v[22452]=0;b:{c:{d:{if((d|0)==1){break d}v[22452]=0;c=f+32|0;R(104,c|0,e|0);d=v[22452];v[22452]=0;if((d|0)==1){break d}Tq(f,f+8|0);v[22452]=0;W(105,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[22452];v[22452]=0;if((a|0)==1){break c}kk(f+8|0);ab=f+48|0;break a}a=P()|0;O()|0;while(1){c=pb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;kk(f+8|0)}S(a|0);L()}}function ida(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=ab-4112|0;ab=d;Vl(a,b);a:while(1){if(Ic(v[a>>2],v[a+4>>2])>>>12>>>0>e>>>0){f=e<<12;b=0;c=0;while(1)if((b|0)==2048){g=f|2048;b=0;while(1){if((b|0)!=2048){h=Cb(v[a>>2],b+g|0);i=Cb(d+16|0,b<<1);c=w[h|0]+c|0;t[i|0]=c;b=b+1|0;continue}break}b=d+16|0;c=gP(b);j=d,k=wb(v[a>>2]),v[j+8>>2]=k;it(b,c,le(d+8|0,f));e=e+1|0;continue a}else{g=Cb(v[a>>2],b+f|0);h=Cb(d+16|0,b<<1|1);c=w[g|0]+c|0;t[h|0]=c;b=b+1|0;continue}}break}ab=d+4112|0}function ZV(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=ab-48|0;ab=f;Hm(f+8|0,c);v[22452]=0;c=f+20|0;R(130,c|0,d|0);d=v[22452];v[22452]=0;b:{c:{d:{if((d|0)==1){break d}v[22452]=0;c=f+32|0;R(130,c|0,e|0);d=v[22452];v[22452]=0;if((d|0)==1){break d}Tq(f,f+8|0);v[22452]=0;W(105,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[22452];v[22452]=0;if((a|0)==1){break c}kk(f+8|0);ab=f+48|0;break a}a=P()|0;O()|0;while(1){c=pb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;kk(f+8|0)}S(a|0);L()}}function dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=ab-16|0;ab=b;e=v[a+40>>2];f=v[a+36>>2];i=v[a+16>>2];g=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=g;g=v[a+8>>2];j=v[a+12>>2];while(1){if(d){k=v[a+32>>2];h=u[(v[b+12>>2]<<1)+i>>1];f=v[a+28>>2]+f|0;v[c>>2]=v[c>>2]+B(h,f>>12);e=e+k|0;v[c+4>>2]=v[c+4>>2]+B(e>>12,h);Lb(b+8|0,g,j);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=e;v[a+36>>2]=f;v[a+20>>2]=f>>12;v[a+24>>2]=e>>12;c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function Aga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ab-32|0;ab=c;e=c+8|0;f=Pb(e+8|0);v[22452]=0;d=T(193,b|0)|0;g=v[22452];v[22452]=0;a:{b:{if((g|0)==1){break b}v[22452]=0;U(238,e|0,b|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break b}d=v[e>>2];v[22452]=0;Q(179,b|0,d|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Xb(f);S(a|0);L()}pu(c,e);v[22452]=0;U(422,a|0,v[c>>2],v[c+4>>2]);a=v[22452];v[22452]=0;if((a|0)!=1){rc(c+8|0);ab=c+32|0;return}a=P()|0;O()|0;rc(c+8|0);S(a|0);L()}function hO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;j=b?33:32;c=v[a+8>>2]-1|0;e=v[a+12>>2];f=v[a>>2]+B(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(j|0)){break b}while(1)if((b|0)>=(e|0)){b=B(e,g);i=v[a+8>>2]-1|0;c:{if(!((i|0)!=(c|0)|(d|0)<=0)){if(!w[a+16|0]){d=1;c=0;break c}d=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=w[a+16|0];d=c?1:-1;c=c?0:i;break c}c=c+d|0}f=b+f|0;h=h+1|0;continue a}else{t[b+f|0]=w[v[a+4>>2]+(B(c,e)+b|0)|0];b=b+1|0;e=v[a+12>>2];continue}}break}}function dk(a){var b=0,c=0;a:{b=v[a+4>>2];b=v[v[b>>2]-12>>2]+b|0;b:{if(!v[b+24>>2]){break b}if(!uh(b)|!(v[b+4>>2]&8192)){break b}if(($a()|0)>0){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[22452]=0;b=T(21,b|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[22452]=0;R(15,a+b|0,1);a=v[22452];v[22452]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Gb();L()}function RZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=ab-160|0;ab=a;u[a+156>>1]=w[79781]|w[79782]<<8;v[a+152>>2]=w[79777]|w[79778]<<8|(w[79779]<<16|w[79780]<<24);f=a+152|0;sk(f|1,10715,1,v[c+4>>2]);g=gd();v[a>>2]=e;e=a+139|0;f=sf(e,13,g,f,a)+e|0;g=Dg(e,f,c);h=a+16|0;zc(h,c);v[22452]=0;ja(1128,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22452];v[22452]=0;if((e|0)!=1){Nb(a+16|0);b=Lm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);ab=a+160|0;return b|0}b=P()|0;O()|0;Nb(a+16|0);S(b|0);L()}function OZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=ab-160|0;ab=a;u[a+156>>1]=w[79781]|w[79782]<<8;v[a+152>>2]=w[79777]|w[79778]<<8|(w[79779]<<16|w[79780]<<24);f=a+152|0;sk(f|1,10715,0,v[c+4>>2]);g=gd();v[a>>2]=e;e=a+139|0;f=sf(e,13,g,f,a)+e|0;g=Dg(e,f,c);h=a+16|0;zc(h,c);v[22452]=0;ja(1128,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22452];v[22452]=0;if((e|0)!=1){Nb(a+16|0);b=Lm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);ab=a+160|0;return b|0}b=P()|0;O()|0;Nb(a+16|0);S(b|0);L()}function EM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ab-16|0;ab=e;k=e,l=Wj(b),v[k>>2]=l;c=ab-16|0;ab=c;h=ky(a,c+12|0,w[b|0],v[b+4>>2]);b=v[h>>2];if(!b){g=ab-16|0;ab=g;b=ac(a);i=hh(c,pc(28),ih(g+8|0,b));b=v[i>>2];d=ab-16|0;ab=d;v[d+8>>2]=v[e>>2];f=v[d+8>>2];j=v[f+4>>2];f=v[f>>2];v[b+24>>2]=0;v[b+16>>2]=f;v[b+20>>2]=j;ab=d+16|0;k=ac(i),l=1,t[k+4|0]=l;ab=g+16|0;Pg(a,v[c+12>>2],h,v[c>>2]);b=Pd(c);$k(c);d=1}a=e+8|0;Og(a,$b(c,b),d);ab=c+16|0;a=id(a);ab=e+16|0;return a+8|0}function eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=ab-16|0;ab=b;e=v[a+40>>2];f=v[a+36>>2];i=v[a+16>>2];g=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=g;g=v[a+8>>2];j=v[a+12>>2];while(1){if(d){k=v[a+32>>2];h=t[v[b+12>>2]+i|0]<<8;f=v[a+28>>2]+f|0;v[c>>2]=v[c>>2]+B(h,f>>12);e=e+k|0;v[c+4>>2]=v[c+4>>2]+B(e>>12,h);Lb(b+8|0,g,j);c=c+8|0;d=d-1|0;continue}break}v[a+40>>2]=e;v[a+36>>2]=f;v[a+20>>2]=f>>12;v[a+24>>2]=e>>12;c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function Rda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-32|0;ab=d;ed(b,0);KA(d,a+1|0);c=d+16|0;tc(c,v[d>>2],v[d+4>>2],w[d+8|0]);ke(b+43|0,c);pb(c);c=a+78|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;c=a+58|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b>>2]=e;c=a+62|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+66|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;mc(b+8|0,e);mc(b+4|0,v[b+8>>2]);ab=d+32|0}function gO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=b?33:32;e=v[a+12>>2];j=(e|0)>0?e:0;g=v[a>>2]+B(e,62)|0;d=b?1:-1;k=B(e,d)<<1;f=v[a+8>>2]-1|0;c=f;a:while(1){if((h|0)!=(i|0)){l=B(c,e);b=0;while(1)if((b|0)==(j|0)){b:{if(!((c|0)!=(f|0)|(d|0)<=0)){if(!w[a+16|0]){d=1;c=0;break b}d=-1;c=f-(w[a+17|0]!=0&(f|0)!=0)|0;break b}if(!((d|0)>=0|c)){b=w[a+16|0];d=b?1:-1;c=b?0:f;break b}c=d+c|0}g=g+k|0;h=h+1|0;continue a}else{u[(b<<1)+g>>1]=x[v[a+4>>2]+(b+l<<1)>>1];b=b+1|0;continue}}break}}function Z9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=ab-48|0;ab=d;DN(a,1<<b-1);v[a+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);f=1;g=b>>>2|0;b=g;while(1){if(b){e=v[10505];c=d+16|0;v[c+8>>2]=v[10504];v[c+12>>2]=e;e=v[10503];v[c>>2]=v[10502];v[c+4>>2]=e;Oy(c,h*+(b>>>0));xN(d+32|0,c);c=Hc(v[a>>2],f);e=v[d+44>>2];v[c+8>>2]=v[d+40>>2];v[c+12>>2]=e;e=v[d+36>>2];v[c>>2]=v[d+32>>2];v[c+4>>2]=e;b=b>>>1|0;f=f<<1;continue}break}b=Rl(d,1,0);Gx(a,0,g,A[b>>3],A[b+8>>3]);ab=d+48|0;return a|0}function hv(a){var b=0,c=0,d=0;if(y[a+4>>2]<y[vb(a)>>2]){b=ab-16|0;ab=b;a=lD(b,a);c=v[a+4>>2];v[22452]=0;Z(161,c|0);c=v[22452];v[22452]=0;a:{if((c|0)!=1){v[a+4>>2]=v[a+4>>2]+36;dc(a);ab=b+16|0;break a}b=P()|0;O()|0;dc(a);S(b|0);L()}return}c=ab-32|0;ab=c;b=vb(a);b=jD(c+8|0,kD(a,Gq(v[a>>2],v[a+4>>2])+1|0),Gq(v[a>>2],v[a+4>>2]),b);d=v[b+8>>2];v[22452]=0;Z(161,d|0);d=v[22452];v[22452]=0;b:{if((d|0)!=1){v[b+8>>2]=v[b+8>>2]+36;iD(a,b);_u(b);ab=c+32|0;break b}a=P()|0;O()|0;_u(b);S(a|0);L()}}function YZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=ab-80|0;ab=a;u[a+76>>1]=w[79781]|w[79782]<<8;v[a+72>>2]=w[79777]|w[79778]<<8|(w[79779]<<16|w[79780]<<24);f=a+72|0;sk(f|1,10715,0,v[c+4>>2]);g=gd();v[a>>2]=e;e=a+59|0;f=sf(e,13,g,f,a)+e|0;g=Dg(e,f,c);h=a+16|0;zc(h,c);v[22452]=0;ja(1125,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22452];v[22452]=0;if((e|0)!=1){Nb(a+16|0);b=mm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);ab=a+80|0;return b|0}b=P()|0;O()|0;Nb(a+16|0);S(b|0);L()}function A0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ab-48|0;ab=e;a:{if(w[b+8|0]){f=v[b+12>>2];j=e,k=Ic(f,v[b+16>>2])-c|0,v[j+40>>2]=k;v[e+32>>2]=v[d+4>>2];h=e+40|0;i=e+32|0;g=v[zb(h,i)>>2];j=e,k=wb(f),v[j+40>>2]=k;f=le(h,c);j=e,k=wb(v[b+12>>2]),v[j+24>>2]=k;j=e,k=le(e+24|0,c),v[j+32>>2]=k;c=le(i,g);b=v[d>>2];fk(f,c,b);Ub(a,b,g);break a}g=v[d+4>>2];d=v[d>>2];v[e+16>>2]=d;v[e+20>>2]=g;f=v[v[b>>2]+40>>2];v[e+8>>2]=d;v[e+12>>2]=g;eb[f|0](a,b,c,e+8|0)}ab=e+48|0}function $Z(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=ab-80|0;ab=a;u[a+76>>1]=w[79781]|w[79782]<<8;v[a+72>>2]=w[79777]|w[79778]<<8|(w[79779]<<16|w[79780]<<24);f=a+72|0;sk(f|1,10715,1,v[c+4>>2]);g=gd();v[a>>2]=e;e=a+59|0;f=sf(e,13,g,f,a)+e|0;g=Dg(e,f,c);h=a+16|0;zc(h,c);v[22452]=0;ja(1125,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22452];v[22452]=0;if((e|0)!=1){Nb(a+16|0);b=mm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);ab=a+80|0;return b|0}b=P()|0;O()|0;Nb(a+16|0);S(b|0);L()}function v3(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){a=v[a+24>>2]+24|0;b=x[v[a>>2]+1074448>>1];a:{if(ej(Kb(v[a>>2]+484360|0))>>>0<=b>>>0){a=x[v[a>>2]+1074446>>1];break a}b=x[Yb(v[Kb(v[a>>2]+484360|0)>>2],b)>>1];a=lm(v[a>>2]+484344|0,b)?b:-1}return a|0}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,9727,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function lI(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=v[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(y[a+12>>2]<=d>>>0)){while(1){e=Zx(v[a>>2]);c=db;f=v[a+36>>2];if((c|0)==(f|0)&y[a+32>>2]<=e>>>0|c>>>0>f>>>0){continue}break}c=b;b=v[a+8>>2];b=(e&v[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){d=Zx(v[a>>2]);c=db;f=v[a+28>>2];if((c|0)==(f|0)&y[a+24>>2]<=d>>>0|c>>>0>f>>>0){continue}break}c=b;b=v[a+8>>2];b=(d&v[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function TZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=ab-96|0;ab=a;u[a+92>>1]=w[79787]|w[79788]<<8;v[a+88>>2]=w[79783]|w[79784]<<8|(w[79785]<<16|w[79786]<<24);f=gd();v[a>>2]=e;g=a- -64|0;i=sf(g,20,f,a+88|0,a);e=i+g|0;g=Dg(g,e,c);f=a+8|0;zc(f,c);v[22452]=0;f=T(18,f|0)|0;h=v[22452];v[22452]=0;if((h|0)!=1){Nb(a+8|0);h=f;f=a+16|0;iF(h,a- -64|0,e,f);h=b;b=f+i|0;b=mm(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);ab=a+96|0;return b|0}b=P()|0;O()|0;Nb(a+8|0);S(b|0);L()}function T2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22452]=0;Z(924,a|0);d=v[22452];v[22452]=0;a:{if((d|0)==1){break a}v[22452]=0;Z(995,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break a}d=v[a+24>>2];v[22452]=0;b=Q(996,d|0,b|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,10314,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function Kfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[vb(a)>>2]){c=ab-16|0;ab=c;a=FT(c,a);jA(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;dc(a);ab=c+16|0;return}e=ab-32|0;ab=e;c=vb(a);c=DT(e+8|0,ET(a,fq(v[a>>2],v[a+4>>2])+1|0),fq(v[a>>2],v[a+4>>2]),c);jA(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;jA(v[b>>2]-28|0,d);v[b>>2]=v[b>>2]-28;continue}break}cc(a,b);cc(a+4|0,c+8|0);cc(vb(a),ic(c));v[c>>2]=v[c+4>>2];CT(c);ab=e+32|0}function n7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=ci(a,b,c,d);v[a>>2]=44232;c=Pb(a+4208|0);v[a+4236>>2]=2147483647;v[a+4240>>2]=0;v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;t[a+4244|0]=0;Jb(a+4248|0,0,48);v[22452]=0;X(786);d=v[22452];v[22452]=0;a:{if((d|0)==1){break a}e=a,f=yL(),v[e+4296>>2]=f;ks(a);js(a);v[22452]=0;R(875,a+44|0,2);d=v[22452];v[22452]=0;if((d|0)==1){break a}bi(b);return a|0}a=P()|0;O()|0;Xb(c);ff(b);S(a|0);L()}function ak(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[vb(a)>>2]){c=ab-16|0;ab=c;a=FT(c,a);fB(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;dc(a);ab=c+16|0;return}e=ab-32|0;ab=e;c=vb(a);c=DT(e+8|0,ET(a,fq(v[a>>2],v[a+4>>2])+1|0),fq(v[a>>2],v[a+4>>2]),c);fB(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;fB(v[b>>2]-28|0,d);v[b>>2]=v[b>>2]-28;continue}break}cc(a,b);cc(a+4|0,c+8|0);cc(vb(a),ic(c));v[c>>2]=v[c+4>>2];CT(c);ab=e+32|0}function xK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)!=(b|0)){c=ab-16|0;ab=c;d=v[b>>2];f=v[b+4>>2];e=Yj(d,f);a:{if(e>>>0<=St(a)>>>0){g=f;h=v[a>>2];i=Yj(h,v[a+4>>2]);j=i>>>0>=e>>>0;if(!j){v[c+12>>2]=d;v[c+12>>2]=v[c+12>>2]+B(i,6);h=v[a>>2];g=v[c+12>>2]}d=zK(d,g,h);if(!j){Bx(a,g,f,e-Yj(v[a>>2],v[a+4>>2])|0);break a}Hd(a,d);break a}yK(a);jS(a,rA(a,e));Bx(a,d,f,e)}ab=c+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];wK(a+24|0,b+24|0);wj(a+36|0,b+36|0)}function vea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,26);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function jea(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;b=-1;a:{if(!Qf(a,8)){break a}b=ab-32|0;ab=b;v[b+24>>2]=0;v[b+28>>2]=0;d=Zb(b+8|0,b+24|0,8);$c(b+16|0,a,v[d>>2],v[d+4>>2]);d=0;b:{if(v[b+20>>2]!=8){break b}if(Ib(b+24|0,14111,8)){break b}Rc(a,8);d=1}ab=b+32|0;b=0;if(!d){break a}b=-1;if(!tj(a,c+8|0)){break a}a=c+8|4;b=0;if(!Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}b=!(Wb(w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24))&-2139062144)}ab=c+16|0;return b|0}function QI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==10){wx(a,b,c,d);return}g=d;i=B(e,e);k=B(i,e);j=B(i,i);a:{while(1){h=f|1;if(e>>>0>g>>>0){break a}h=f|2;if(g>>>0<i>>>0){break a}h=f|3;if(g>>>0<k>>>0){break a}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){v[a+4>>2]=61;v[a>>2]=c;return}f=b+f|0;b=f;while(1){b=b-1|0;c=(d>>>0)/(e>>>0)|0;t[b|0]=w[(d-B(c,e)|0)+4856|0];g=d>>>0>=e>>>0;d=c;if(g){continue}break}v[a+4>>2]=0;v[a>>2]=f}function zf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function Lm(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=ab-16|0;ab=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>2;if((km(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if(b){f=cF(i,b,f);h=Eb(f);v[22452]=0;h=Y(1130,a|0,h|0,b|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break a}Oc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>2;if((km(a,c,b)|0)!=(b|0)){break b}}Zn(e);j=a}ab=i+16|0;return j|0}a=P()|0;O()|0;Oc(f);S(a|0);L()}function E0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;oo(a);v[a>>2]=57308;d=b;b=v[b+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=b;b=c;c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;c=ic(a);d=ab-16|0;ab=d;e=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;e=OH(d);Cm(c);t[c+8|0]=0;v[c+4>>2]=e;v[c>>2]=57708;Pb(c+12|0);v[c>>2]=57472;e=v[b+4>>2];v[c+24>>2]=v[b>>2];v[c+28>>2]=e;e=v[b+12>>2];v[c+32>>2]=v[b+8>>2];v[c+36>>2]=e;ab=d+16|0;ab=b+16|0;return a|0}function $ha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=sd(a);a:{b:{if(b){v[22452]=0;R(311,a|0,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break b}d=ab-16|0;ab=d;c=_p(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){dc(c);ab=d+16|0}else{t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+4|0]=6;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=8;t[b+3|0]=4;b=b+6|0;v[c+4>>2]=b;continue}break}}break a}a=P()|0;O()|0;Eh(c);S(a|0);L()}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function p3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=ab-32|0;ab=b;a:{b:{if(Vi(a)){of(b+24|0);break b}c=b+8|0;fn(c,a);v[22452]=0;c=T(983,c|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break a}v[b+24>>2]=c;Hf(b+8|0)}if(Vi(a)){c=a+36|0}else{c=v[b+24>>2]}a=v[a+8>>2];c:{if((a|0)==-1){f=b,g=wb(v[c>>2]),v[f+8>>2]=g;a=wb(v[c+4>>2]);while(1){c=v[b+8>>2];if(!Tb(c,a)){break c}d=d+A[c>>3];KH(b+8|0);continue}}d=A[_k(v[c>>2],a)>>3]}Ek(b+24|0);ab=b+32|0;return+d}a=P()|0;O()|0;Hf(b+8|0);S(a|0);L()}function U7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=ab-32|0;ab=e;f=cf(a,c);c=e+8|0;Xd(c,v[a+28>>2]);d=v[c+12>>2];v[e+24>>2]=v[c+8>>2];v[e+28>>2]=d;a:{b:{if(!f){c=0;d=-1;if(!Vc(a,5)){break b}break a}d=v[f+8>>2]}g=v[a+28>>2];c:{if(!((d|0)!=4&(d|0)!=-1)){c=ab-16|0;ab=c;v[c+8>>2]=0;Vo(g,c+8|0);z[b>>2]=z[c+8>>2];ab=c+16|0;break c}c=ab-32|0;ab=c;v[c+28>>2]=0;v[c+24>>2]=d;v[c+20>>2]=4;Er(c+8|0,g,c+28|0,v[zb(c+24|0,c+20|0)>>2]);v[b>>2]=0;ab=c+32|0}c=f}Te(a,c,e+24|0);ab=e+32|0}function sL(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;db=v[e+4>>2];return v[e>>2]}function n1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=ab-16|0;ab=c;a:{d=Ah(C(z[a+24>>2]*C(65536)));if((d|0)==65536){break a}i=v[b+4>>2];j=v[b+8>>2];k=d>>31;b:while(1){if((f|0)==(j|0)){break a}l=v[b+4>>2];m=v[b>>2];e=0;while(1)if((e|0)==(i|0)){f=f+1|0;continue b}else{g=xh(m,l,e,f);h=v[g>>2];n=g,o=vc(pia(oia(h,h>>31,d,k),db,65536,0),db),v[n>>2]=o;e=e+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;iI(a,c);ab=c+16|0}function c1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=ab-16|0;ab=c;a:{d=Ah(C(z[a+24>>2]*C(65536)));if((d|0)==65536){break a}i=v[b+4>>2];j=v[b+8>>2];k=d>>31;b:while(1){if((f|0)==(j|0)){break a}l=v[b+4>>2];m=v[b>>2];e=0;while(1)if((e|0)==(i|0)){f=f+1|0;continue b}else{g=xh(m,l,e,f);h=v[g>>2];n=g,o=vc(pia(oia(h,h>>31,d,k),db,65536,0),db),v[n>>2]=o;e=e+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;bI(a,c);ab=c+16|0}function eN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ab-16|0;ab=e;k=e,l=Wj(b),v[k>>2]=l;c=ab-16|0;ab=c;g=Ly(a,c+12|0,x[b>>1],v[b+4>>2]);b=v[g>>2];if(!b){f=ab-16|0;ab=f;b=ac(a);h=hh(c,pc(36),ih(f+8|0,b));b=v[h>>2]+16|0;d=ab-16|0;ab=d;v[d+8>>2]=v[e>>2];i=v[d+8>>2];j=v[i+4>>2];v[b>>2]=v[i>>2];v[b+4>>2]=j;Pb(b+8|0);ab=d+16|0;k=ac(h),l=1,t[k+4|0]=l;ab=f+16|0;Pg(a,v[c+12>>2],g,v[c>>2]);b=Pd(c);jN(c);d=1}a=e+8|0;Og(a,$b(c,b),d);ab=c+16|0;a=id(a);ab=e+16|0;return a+8|0}function O0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=ab-16|0;ab=d;v[d+4>>2]=1;g=d,h=pc(56),v[g+8>>2]=h;c=ab-16|0;ab=c;e=v[d+8>>2];oo(e);v[e>>2]=57808;f=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=f;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;b=ic(e);Cm(b);v[b>>2]=58172;Pb(b+4|0);t[b+20|0]=0;v[b+16>>2]=0;v[b>>2]=57972;e=v[c+4>>2];v[b+24>>2]=v[c>>2];v[b+28>>2]=e;e=v[c+12>>2];v[b+32>>2]=v[c+8>>2];v[b+36>>2]=e;t[b+40|0]=0;ab=c+16|0;b=a;a=qo(d);po(b,ic(a),a);Dm(d);ab=d+16|0}function oF(a,b,c,d){var e=0,f=0,g=0,h=0;e=ab-16|0;ab=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[114934];v[114934]=0;gd();a=Uv(a,e+12|0,d);d=db;g=v[114934];e:{if(g){if(v[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}v[114934]=h;if((b|0)!=v[e+12>>2]){break c}if(!d&a>>>0<65536){break b}}v[c>>2]=4;a=65535;break a}}v[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}ab=e+16|0;return a&65535}function hf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=oia(b,c,h,i);i=db;j=h;h=oia(d,e,f,g);e=j+h|0;d=db+i|0;i=e;h=i>>>0<h>>>0?d+1|0:d;j=i;k=g;e=0;l=c;d=0;i=oia(g,e,c,d);g=j+i|0;c=db+h|0;j=g;g=g>>>0<i>>>0?c+1|0:c;h=f;i=b;f=oia(h,0,i,0);b=db;c=0;d=oia(h,c,l,d);b=b+d|0;c=db+c|0;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+j|0;d=g;d=c>>>0<h>>>0?d+1|0:d;h=c;c=d;d=oia(i,m,k,e)+b|0;e=db;e=b>>>0>d>>>0?e+1|0:e;g=a;i=e;h=i+h|0;v[g+8>>2]=h;v[g+12>>2]=h>>>0<i>>>0?c+1|0:c;v[g>>2]=f;v[g+4>>2]=d}function cy(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;e=v[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=w[b+813|0];if(c){t[b+813|0]=e&240|c&15;break a}c=e&15;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}Jj(a,b,b+700|0,0-(c<<2)|0,0);if(v[b+700>>2]<65536){break b}rb(d+8|0,a+1074312|0,7);if(sb(v[v[d+8>>2]>>2],v[d+12>>2])|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}ab=d+16|0}function cR(a,b,c,d){var e=0,f=0;f=ab-16|0;ab=f;e=x[c>>1];while(1){a:{e=e<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!We(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!We(a,f+14|0)){break a}e=w[f+14|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;e=w[c|0];u[c>>1]=e;if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}ab=f+16|0}function Cba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=ab+-64|0;ab=d;j=a;f=d+16|0;a=0;g=ab-16|0;ab=g;h=tO(g+8|0);while(1){if((a|0)==12){ab=g+16|0}else{e=ab-48|0;ab=e;b=v[h>>2];c=v[h+4>>2]-b|0;a:{if(!c){break a}b=c+1|0;if(!b){b=rO(sO(e+8|0,32));break a}c=E(b);c=sO(e+8|0,(b<<c+1?32:31)-c|0);while(1){i=rO(c);if(i>>>0>=b>>>0){continue}break}b=i+v[h>>2]|0}ab=e+48|0;k=Fb(f,a),l=b,v[k>>2]=l;a=a+1|0;continue}break}a=vO(d,f,wO(f));uO(j,a);ec(a);ab=d- -64|0}function cz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=ab-16|0;ab=c;a:{d=v[a>>2];if(jc(d,v[a+4>>2])){break a}u[d>>1]=0;jf(d+2|0,b);h=c,i=wb(v[a>>2]),v[h>>2]=i;h=c,i=Wk(c,1),v[h+8>>2]=i;while(1){d=wb(v[a+4>>2]);e=v[c+8>>2];if(!Tb(e,d)){break a}d=c+8|0;g=Wk(d,-1);f=v[c+8>>2];h=f,i=x[Ne(e,g)>>1],u[h>>1]=i;jf(f+2|0,b);hP(d);continue}}jf(a+14|0,Td(a)-1&255);jf(a+13|0,w[a+14|0]);jf(a+16|0,Td(a)-1&255);jf(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){jf(a+17|0,Td(a)-1&255)}ab=c+16|0}function OM(a,b,c,d){var e=0,f=0,g=C(0),h=0,i=0,j=0;f=ab-16|0;ab=f;v[f+12>>2]=c>>>2;v[f+8>>2]=v[a>>2];a=v[a+20>>2];h=v[zb(f+12|0,f+8|0)>>2];c=h;while(1){if(c){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);g=xf((l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q()));g=kf(C(Ed(C((Yf(g)?g>=C(0)?C(1):C(-1):g)*d),C(-1))*C(32768)));a:{if(C(D(g))<C(2147483648)){e=~~g;break a}e=-2147483648}i=a,j=Jc(e),u[i>>1]=j;a=a+2|0;b=b+4|0;c=c-1|0;continue}break}ab=f+16|0;return h<<2}function Jt(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==w[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}if(w[a|0]==(b&255)|c>>>0<4){break b}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}b=b&255;while(1){if((b|0)==w[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function q2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[22452]=0;Z(924,a|0);h=v[22452];v[22452]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[22452]=0;b=qa(1011,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,12951,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function F2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[22452]=0;Z(924,a|0);h=v[22452];v[22452]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[22452]=0;b=qa(1004,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,12883,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function JL(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;e=v[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=w[b+814|0];if(c){t[b+814|0]=e&240|c&15;break a}c=e&15;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}Jj(a,b,b+700|0,0-c|0,0);if(v[b+700>>2]<65536){break b}rb(d+8|0,a+1074312|0,7);if(sb(v[v[d+8>>2]>>2],v[d+12>>2])|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}ab=d+16|0}function mm(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=ab-16|0;ab=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>0){if((km(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if(b){f=ze(i,b,f);g=Eb(f);v[22452]=0;g=Y(22,a|0,g|0,b|0)|0;h=v[22452];v[22452]=0;if((h|0)==1){break a}pb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((km(a,c,b)|0)!=(b|0)){break b}}Zn(e);j=a}ab=i+16|0;return j|0}a=P()|0;O()|0;pb(f);S(a|0);L()}function Xw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ab-32|0;ab=e;v[e+24>>2]=b;k=e,l=kd(a),v[k+16>>2]=l;b=am(e+24|0,e+16|0);h=ab-16|0;ab=h;a:{g=ub(a);if(b>>>0<=g>>>0){if(c){f=Ec(a);b:{if(f-g>>>0>=c>>>0){f=Eb(a);i=g-b|0;if(!i){break b}j=b+f|0;_j(j+c|0,j,i);break b}Kl(a,f,(c+g|0)-f|0,g,b,0,c);f=v[a>>2]}dq(b+f|0,c,d);c=c+g|0;cg(a,c);t[h+15|0]=0;md(c+f|0,h+15|0)}ab=h+16|0;break a}Vp();L()}k=e,l=kd(a),v[k+8>>2]=l;le(e+8|0,b);ab=e+32|0}function bL(a,b){var c=0,d=0,e=0,f=0,g=0;c=ab-32|0;ab=c;a:{if((b-4e3&65535)>>>0<61537){break a}f=1;e=(B(b,104)+a|0)+484380|0;if(!Fd(e)){break a}g=a+1298224|0;d=a+1074992|0;while(1){if((d|0)==(g|0)){Xl(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[c+24>>2]=0;v[c+8>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c>>2]=0;v[c+4>>2]=0;fl(e,0,c);break a}if(v[d+104>>2]==(e|0)){v[d+76>>2]=0;v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0}d=d+872|0;continue}}ab=c+32|0;return f}function DW(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;v[22452]=0;m=a;a=b;b=0;a=Ka(1019,m|b,a|0,c|0,d|0,b|e,f|0)|0;b=v[22452];v[22452]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[22452]=0;ja(907,8814,g|0,h|0,i|0,j|0,k|0,l|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}return a|0}function zO(a,b){var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;a=Bb(a);d=ub(b);v[22452]=0;R(46,a|0,d|0);d=v[22452];v[22452]=0;if((d|0)!=1){a:{e=c,f=kd(b),v[e+8>>2]=f;e=c,f=Ff(b),v[e>>2]=f;while(1){if(!aj(c+8|0,c)){ab=c+16|0;return}b:{b=w[v[c+8>>2]];if((b|0)!=13){v[22452]=0;R(47,a|0,b<<24>>24);b=v[22452];v[22452]=0;if((b|0)==1){break a}break b}v[22452]=0;R(47,a|0,10);b=v[22452];v[22452]=0;if((b|0)!=1){break b}break a}Fe(c+8|0);continue}}}b=P()|0;O()|0;pb(a);S(b|0);L()}function e4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[22452]=0;Z(949,a|0);f=v[22452];v[22452]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[22452]=0;b=Pa(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,11272,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function pK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=v[a>>2];c=nc(d,v[a+4>>2]);if(c>>>0<=127){f=ab-32|0;ab=f;c=128-c|0;e=v[vb(a)>>2];d=v[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){xx(a,c,b);break a}e=vb(a);d=_f(f+8|0,fh(a,nc(v[a>>2],d)+c|0),nc(v[a>>2],v[a+4>>2]),e);g=ab-16|0;ab=g;c=jl(g,d+8|0,c);e=v[c>>2];while(1){if(v[c+4>>2]!=(e|0)){ns(e,z[b>>2]);e=v[c>>2]+4|0;v[c>>2]=e;continue}break}xd(c);ab=g+16|0;rd(a,d);Zf(d)}ab=f+32|0;return}if((c|0)!=128){Hd(a,d+512|0)}}function kF(a,b,c,d){var e=0,f=0,g=0,h=0;e=ab-16|0;ab=e;a:{if((a|0)!=(b|0)){b:{c:{f=w[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=v[114934];v[114934]=0;gd();a=Uv(a,e+12|0,d);d=db;d:{g=v[114934];if(g){if(v[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}v[c>>2]=4;b=-1;a=-1;break a}v[114934]=h;if(v[e+12>>2]==(b|0)){break d}break b}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d;break a}}v[c>>2]=4;b=0;a=0}ab=e+16|0;db=a;return b}function K0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=ab-16|0;ab=e;g=v[d+4>>2];Iw(b,c,g);f=v[b+16>>2];a:{if(f>>>0<=c>>>0){Ub(a,v[d>>2],0);break a}v[e+12>>2]=f-c;v[e+8>>2]=g;f=v[d>>2];h=v[zb(e+12|0,e+8|0)>>2];Xp(e,f,g,0,h);i=v[e>>2];j=v[e+4>>2];d=ab-32|0;ab=d;l=d,m=wb(v[b+4>>2]),v[l+24>>2]=m;k=le(d+24|0,c);l=d,m=wb(v[b+4>>2]),v[l+8>>2]=m;l=d,m=le(d+8|0,c),v[l+16>>2]=m;fk(k,le(d+16|0,j),i);ab=d+32|0;Xp(a,f,g,0,h)}ab=e+16|0}function oZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=ab-16|0;ab=f;d=ub(a);e=Ec(a);g=hi(b,c);a:{if(!g){break a}b:{if(!rs(a,b)){if(e-d>>>0<g>>>0){Kl(a,e,(d+g|0)-e|0,d,d,0,0)}e=Eb(a)+d|0;while(1){if((b|0)==(c|0)){break b}md(e,b);b=b+1|0;e=e+1|0;continue}}b=pg(f,b,c);c=Eb(b);d=ub(b);v[22452]=0;Y(1040,a|0,c|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){pb(b);break a}a=P()|0;O()|0;pb(b);S(a|0);L()}t[f+15|0]=0;md(e,f+15|0);cg(a,d+g|0)}ab=f+16|0;return a|0}function ZC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=ab-32|0;ab=d;v[d+16>>2]=c;v[d+24>>2]=b;k=d,l=kd(a),v[k+8>>2]=l;c=d+24|0;g=d+8|0;b=am(c,g);e=am(d+16|0,c);a:{if(ub(a)>>>0>=b>>>0){if((e|0)==-1){RS(a,b);break a}c=ab-16|0;ab=c;v[c+12>>2]=e;if(e){h=ub(a);i=Eb(a);f=h-b|0;v[c+8>>2]=f;e=v[zb(c+12|0,c+8|0)>>2];v[c+12>>2]=e;f=f-e|0;if(f){j=b+i|0;_j(j,e+j|0,f)}f=a;a=h-e|0;cg(f,a);t[c+7|0]=0;md(a+i|0,c+7|0)}ab=c+16|0;break a}Vp();L()}le(g,b);ab=d+32|0}function kda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab+-64|0;ab=c;Vl(c+48|0,b);de(c+16|0,v[c+48>>2],v[c+52>>2]);b=Vd(c+8|0);d=v[b+4>>2];b=v[b>>2];v[22452]=0;b=ea(157,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[22452];v[22452]=0;a:{if((d|0)!=1){d=Pb(a);a=v[c+52>>2];e=v[c+48>>2];v[22452]=0;U(672,b|0,d|0,Ic(e,a)>>>5|0);a=v[22452];v[22452]=0;if((a|0)==1){a=P()|0;O()|0;ni(d);qb(b);break a}qb(b);Xb(c+48|0);ab=c- -64|0;return}a=P()|0;O()|0}Xb(c+48|0);S(a|0);L()}function hda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab+-64|0;ab=c;Vl(c+48|0,b);de(c+16|0,v[c+48>>2],v[c+52>>2]);b=Vd(c+8|0);d=v[b+4>>2];b=v[b>>2];v[22452]=0;b=ea(157,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[22452];v[22452]=0;a:{if((d|0)!=1){d=Pb(a);a=v[c+52>>2];e=v[c+48>>2];v[22452]=0;U(673,b|0,d|0,Ic(e,a)>>>2|0);a=v[22452];v[22452]=0;if((a|0)==1){a=P()|0;O()|0;ec(d);qb(b);break a}qb(b);Xb(c+48|0);ab=c- -64|0;return}a=P()|0;O()|0}Xb(c+48|0);S(a|0);L()}function gda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab+-64|0;ab=c;Vl(c+48|0,b);de(c+16|0,v[c+48>>2],v[c+52>>2]);b=Vd(c+8|0);d=v[b+4>>2];b=v[b>>2];v[22452]=0;b=ea(157,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[22452];v[22452]=0;a:{if((d|0)!=1){d=Pb(a);a=v[c+52>>2];e=v[c+48>>2];v[22452]=0;U(674,b|0,d|0,Ic(e,a)>>>8|0);a=v[22452];v[22452]=0;if((a|0)==1){a=P()|0;O()|0;ht(d);qb(b);break a}qb(b);Xb(c+48|0);ab=c- -64|0;return}a=P()|0;O()|0}Xb(c+48|0);S(a|0);L()}function fda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab+-64|0;ab=c;Vl(c+48|0,b);de(c+16|0,v[c+48>>2],v[c+52>>2]);b=Vd(c+8|0);d=v[b+4>>2];b=v[b>>2];v[22452]=0;b=ea(157,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[22452];v[22452]=0;a:{if((d|0)!=1){d=Pb(a);a=v[c+52>>2];e=v[c+48>>2];v[22452]=0;U(675,b|0,d|0,Ic(e,a)>>>4|0);a=v[22452];v[22452]=0;if((a|0)==1){a=P()|0;O()|0;Vj(d);qb(b);break a}qb(b);Xb(c+48|0);ab=c- -64|0;return}a=P()|0;O()|0}Xb(c+48|0);S(a|0);L()}function IK(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;j=ab-16|0;ab=j;v[j+12>>2]=d;i=a+12|0;a:{if(!(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))){break a}k=a+8|0;v[j+8>>2]=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);k=b;b=v[zb(j+8|0,j+12|0)>>2];v[k>>2]=b;b=Ld(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24),b,d);v[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=x[e>>1]|f;u[e>>1]=b;a=a+4|0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1){break a}u[e>>1]=b|g}ab=j+16|0}function h4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22452]=0;Z(949,a|0);e=v[22452];v[22452]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[22452]=0;b=da(f|0,e|0,b|0,c|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,11417,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=ab-16|0;ab=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+12>>2]+i|0;e=t[f|0];e=((B(t[f+1|0]-e|0,v[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Lb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function g4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22452]=0;Z(949,a|0);e=v[22452];v[22452]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[22452]=0;b=da(f|0,e|0,b|0,c|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,11453,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-32|0;ab=d;f=cf(a,c);Xd(d+8|0,v[a+28>>2]);c=v[d+20>>2];v[d+24>>2]=v[d+16>>2];v[d+28>>2]=c;a:{b:{if(!f){c=0;e=-1;if(!Vc(a,5)){break b}break a}e=v[f+8>>2]}c=e;e=v[a+28>>2];c:{d:{switch(c+1|0){case 0:case 2:c=ab-32|0;ab=c;t[c+24|0]=0;Ui(c+8|0,c+24|0);_m(c+16|0,e,v[c+8>>2],v[c+12>>2]);t[c+16|0]=w[c+24|0];t[b|0]=w[c+16|0];ab=c+32|0;break c;default:break d}}aS(e,b,c)}c=f}Te(a,c,d+24|0);ab=d+32|0}function Nx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{if((c|0)<2){break a}j=c-2>>>1|0;g=d-a|0;if((j|0)<g>>1){break a}h=g+1|0;e=(h<<1)+a|0;g=g+2|0;if((g|0)<(c|0)){f=_o(b,x[e>>1],x[e+2>>1]);e=f?e+2|0:e;h=f?g:h}f=x[e>>1];i=x[d>>1];if(_o(b,f,i)){break a}while(1){b:{g=e;u[d>>1]=f;if((h|0)>(j|0)){break b}d=h<<1;h=d|1;e=(h<<1)+a|0;d=d+2|0;if((d|0)<(c|0)){f=_o(b,x[e>>1],x[e+2>>1]);e=f?e+2|0:e;h=f?d:h}d=g;f=x[e>>1];if(!_o(b,f,i)){continue}}break}u[g>>1]=i}}function C$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ab-32|0;ab=d;v[d+16>>2]=b;e=v[a+48>>2];v[d+20>>2]=c-((e|0)!=0);g=v[a+44>>2];v[d+28>>2]=e;v[d+24>>2]=g;a:{b:{if(qw(_a(v[a+60>>2],d+16|0,2,d+12|0)|0)){b=32}else{e=v[d+12>>2];if((e|0)>0){break b}b=e?32:16}v[a>>2]=b|v[a>>2];break a}g=v[d+20>>2];if(g>>>0>=e>>>0){f=e;break a}f=v[a+44>>2];v[a+4>>2]=f;v[a+8>>2]=f+(e-g|0);if(v[a+48>>2]){v[a+4>>2]=f+1;t[(b+c|0)-1|0]=w[f|0]}f=c}ab=d+32|0;return f|0}function t4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ab-32|0;ab=d;a:{f=v[c+12>>2];if(!f){break a}e=ub(b);g=e-1|0;h=t[c+16|0];c=0;while(1){if((c|0)==(e|0)){break a}b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(g|0)){if(w[oc(b,0)|0]==(Sf(43)&255)){break b}if(w[oc(b,0)|0]==(Sf(45)&255)){break b}}i=d,j=kd(b),v[i+8>>2]=j;i=d,j=le(d+8|0,e-c|0),v[i+16>>2]=j;Yg(d+24|0,d+16|0);Xw(b,v[d+24>>2],1,Sf(h))}c=c+1|0;continue}}Ac(a,b);ab=d+32|0}function c4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[22452]=0;Z(949,a|0);d=v[22452];v[22452]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[22452]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,6621,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function a4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[22452]=0;Z(949,a|0);d=v[22452];v[22452]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[22452]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,6675,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function Sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=ab-16|0;ab=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=(v[b+12>>2]<<1)+i|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,v[b+8>>2]>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Lb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function tI(a,b,c){var d=0,e=0,f=0;e=sd(a);a:{b:{if(c){v[22452]=0;R(1043,a|0,c|0);d=v[22452];v[22452]=0;if((d|0)==1){break b}d=ab-16|0;ab=d;e=li(d,a,c);c=v[e+4>>2];f=v[e+8>>2];while(1){if((c|0)==(f|0)){dc(e);ab=d+16|0}else{v[c>>2]=0;dh(c);c=c+4|0;v[e+4>>2]=c;continue}break}}break a}a=P()|0;O()|0;ec(e);S(a|0);L()}e=a;a=0;c=0;d=ab-16|0;ab=d;f=d+8|0;while(1){if(a>>>0<32){a=a+48|0;c=tL(b);continue}break}v[f>>2]=c;qn(f);ab=d+16|0;v[e+12>>2]=v[f>>2]}function gC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=wc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=ab-32|0;ab=e;b=b-c|0;c=v[vb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){ZB(a,b);break a}c=vb(a);c=qj(e+8|0,rj(a,wc(v[a>>2],d)+b|0),wc(v[a>>2],v[a+4>>2]),c);f=ab-16|0;ab=f;b=ho(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){YB(d);d=v[b>>2]+2|0;v[b>>2]=d;continue}break}xd(b);ab=f+16|0;rd(a,c);Bi(c)}ab=e+32|0;return}if(b>>>0<c>>>0){Hd(a,d+(b<<1)|0)}}function Ij(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=nc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=ab-32|0;ab=e;b=b-c|0;c=v[vb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){FO(a,b);break a}c=vb(a);c=_f(e+8|0,fh(a,nc(v[a>>2],d)+b|0),nc(v[a>>2],v[a+4>>2]),c);f=ab-16|0;ab=f;b=jl(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){_s(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}xd(b);ab=f+16|0;rd(a,c);Zf(c)}ab=e+32|0;return}if(b>>>0<c>>>0){Hd(a,d+(b<<2)|0)}}function nL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=ab-16|0;ab=e;d=Ec(a);a:{b:{c:{f=hi(b,c);if(d>>>0<f>>>0){if(rs(a,b)){break c}g=d;h=f-d|0;d=ub(a);Kl(a,g,h,d,0,d,0)}d=Eb(a);while(1){if((b|0)==(c|0)){break b}md(d,b);d=d+1|0;b=b+1|0;continue}}b=pg(e,b,c);c=Eb(b);d=ub(b);v[22452]=0;Y(57,a|0,c|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){pb(b);break a}a=P()|0;O()|0;pb(b);S(a|0);L()}t[e+15|0]=0;md(d,e+15|0);cg(a,f)}ab=e+16|0;return a|0}function _2(a,b){a=a|0;b=b|0;var c=0;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;if((c|0)!=1){c=v[a+24>>2];a=-1;a:{if((b|0)<0){break a}c=c+24|0;if(ej(Kb(v[c>>2]+484360|0))>>>0<=b>>>0){break a}a=x[Yb(v[Kb(v[c>>2]+484360|0)>>2],b)>>1]}return a|0}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,9762,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function qk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ab-16|0;ab=e;v[b>>2]=0;v[b+4>>2]=0;t[e+15|0]=0;wh(a,e+15|0);c=w[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){v[b>>2]=f;v[b+4>>2]=d;if(!g&(h|0)==(i|0)){ab=e+16|0}else{t[e+15|0]=0;wh(a,e+15|0);c=v[b>>2];j=v[b+4>>2];f=w[e+15|0];d=g;g=h+1|0;d=g?d:d+1|0;h=g;g=d;k=c;d=(h<<3)-2|0;c=d&31;if((d&63)>>>0>=32){d=f<<c;c=0}else{d=(1<<c)-1&f>>>32-c;c=f<<c}f=k|c;d=d|j;continue}break}}function hc(a,b){var c=0,d=0,e=0;c=v[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return hc(a,24)+(hc(a,b-24|0)<<24)|0}if(!c){v[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=Hr(a);d=0;if((e|0)==-1){break a}d=v[a+1396>>2];c=d+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){ca(10038,13164,1632,6791);L()}d=v[a+1392>>2];v[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}v[a+1396>>2]=c}return d}function PZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=ab-256|0;ab=a;v[a+248>>2]=37;v[a+252>>2]=0;g=a+248|0;sk(g|1,10548,1,v[c+4>>2]);h=gd();v[a>>2]=e;v[a+4>>2]=f;e=a+224|0;f=sf(e,24,h,g,a)+e|0;g=Dg(e,f,c);h=a+16|0;zc(h,c);v[22452]=0;ja(1128,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22452];v[22452]=0;if((e|0)!=1){Nb(a+16|0);b=Lm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);ab=a+256|0;return b|0}b=P()|0;O()|0;Nb(a+16|0);S(b|0);L()}function NZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=ab-256|0;ab=a;v[a+248>>2]=37;v[a+252>>2]=0;g=a+248|0;sk(g|1,10548,0,v[c+4>>2]);h=gd();v[a>>2]=e;v[a+4>>2]=f;e=a+224|0;f=sf(e,24,h,g,a)+e|0;g=Dg(e,f,c);h=a+16|0;zc(h,c);v[22452]=0;ja(1128,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22452];v[22452]=0;if((e|0)!=1){Nb(a+16|0);b=Lm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);ab=a+256|0;return b|0}b=P()|0;O()|0;Nb(a+16|0);S(b|0);L()}function $r(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(v[22446]){b=$r(v[22446])}if(!v[22370]){break a}c=b|c;a=v[22370];continue}break}d=v[a+76>>2]>=0;b:{c:{if(v[a+20>>2]==v[a+28>>2]){break c}eb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break c}b=-1;if(d){break b}break a}b=v[a+8>>2];e=v[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;eb[v[a+40>>2]](a,b,b>>31,1)|0}b=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;if(!d){break a}}}return b|c}function ZZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=ab-112|0;ab=a;v[a+104>>2]=37;v[a+108>>2]=0;g=a+104|0;sk(g|1,10548,1,v[c+4>>2]);h=gd();v[a>>2]=e;v[a+4>>2]=f;e=a+80|0;f=sf(e,24,h,g,a)+e|0;g=Dg(e,f,c);h=a+16|0;zc(h,c);v[22452]=0;ja(1125,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22452];v[22452]=0;if((e|0)!=1){Nb(a+16|0);b=mm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);ab=a+112|0;return b|0}b=P()|0;O()|0;Nb(a+16|0);S(b|0);L()}function XZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=ab-112|0;ab=a;v[a+104>>2]=37;v[a+108>>2]=0;g=a+104|0;sk(g|1,10548,0,v[c+4>>2]);h=gd();v[a>>2]=e;v[a+4>>2]=f;e=a+80|0;f=sf(e,24,h,g,a)+e|0;g=Dg(e,f,c);h=a+16|0;zc(h,c);v[22452]=0;ja(1125,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22452];v[22452]=0;if((e|0)!=1){Nb(a+16|0);b=mm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);ab=a+112|0;return b|0}b=P()|0;O()|0;Nb(a+16|0);S(b|0);L()}function ow(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[114936]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[114934]=25;a=-1}else{a=1}return a}t[a|0]=b;return 1}function oda(a,b){a=a|0;b=b|0;var c=0,d=0;d=sd(a);a:{if(b){v[22452]=0;R(650,a|0,b|0);c=v[22452];v[22452]=0;if((c|0)==1){break a}c=ab-16|0;ab=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+B(b,9);b=v[c+4>>2];d=v[c+8>>2];while(1){if((b|0)==(d|0)){dc(c);ab=c+16|0}else{t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=b+9|0;v[c+4>>2]=b;continue}break}}return a|0}a=P()|0;O()|0;Cp(d);S(a|0);L()}function _3(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[22452]=0;Z(949,a|0);d=v[22452];v[22452]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[22452]=0;wa(f|0,d|0,b|0,+c);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,11652,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function Q3(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[22452]=0;Z(949,a|0);d=v[22452];v[22452]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+96>>2];v[22452]=0;wa(f|0,d|0,b|0,+c);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,11590,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function O3(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[22452]=0;Z(949,a|0);d=v[22452];v[22452]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+88>>2];v[22452]=0;wa(f|0,d|0,b|0,+c);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,10973,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function uU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;v[d+12>>2]=-1;if(hg(a,d+8|0)){v[d+4>>2]=w[d+8|0];f=v[zb(d+4|0,d+12|0)>>2];c=ab+-64|0;ab=c;e=c+40|0;Je(e,a,f);g=v[c+40>>2];Se(c+8|0,3,Sd(e),g);v[22452]=0;W(213,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22452];v[22452]=0;a:{if((a|0)!=1){Zb(c,b,11);a=c+24|0;pj(c,a);pb(a);rc(c+40|0);ab=c- -64|0;e=!f|(g|0)!=0;break a}a=P()|0;O()|0;rc(c+40|0);S(a|0);L()}}ab=d+16|0;return e|0}function o2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22452]=0;Z(924,a|0);f=v[22452];v[22452]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22452]=0;b=ea(1012,f|0,b|0,c|0,d|0,e|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,9659,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function eaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=$f(e,v[a+4>>2]);if(d>>>0<b>>>0){e=ab-32|0;ab=e;a:{b:{d=b-d|0;b=v[vb(a)>>2];f=v[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){Zy(a,d,c);break c}b=vb(a);b=bt(e+8|0,Bp(a,$f(v[a>>2],f)+d|0),$f(v[a>>2],v[a+4>>2]),b);v[22452]=0;U(731,b|0,d|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}UN(a,b);Xy(b)}ab=e+32|0;break a}a=P()|0;O()|0;Xy(b);S(a|0);L()}return}if(b>>>0<d>>>0){WN(a,e+(b<<5)|0)}}function X2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ab-32|0;ab=d;a:{g=v[c+12>>2];if(!g){break a}f=ub(b);h=f-1|0;c=t[c+16|0];while(1){if((e|0)==(f|0)){break a}b:{if(!e|(e>>>0)%(g>>>0)){break b}if((e|0)==(h|0)){if(w[Eb(b)|0]==(Sf(43)&255)){break b}if(w[Eb(b)|0]==(Sf(45)&255)){break b}}i=d,j=kd(b),v[i+8>>2]=j;i=d,j=le(d+8|0,f-e|0),v[i+16>>2]=j;Yg(d+24|0,d+16|0);NI(b,v[d+24>>2],1,Sf(c))}e=e+1|0;continue}}Ac(a,b);ab=d+32|0}function F9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=ab-32|0;ab=d;e=Ye(a);b:{c:{d:{e:{while(1){v[22452]=0;a=Q(147,b|0,8)|0;f=v[22452];v[22452]=0;if((f|0)==1){break c}if(!a){break d}v[22452]=0;U(771,d|0,b|0,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;R(772,e|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break e}Tc(d);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Tc(d);break b}ab=d+32|0;break a}a=P()|0;O()|0}Rd(e);S(a|0);L()}}function D2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22452]=0;Z(924,a|0);f=v[22452];v[22452]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22452]=0;b=ea(1005,f|0,b|0,c|0,d|0,e|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,9587,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function C8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=ab-32|0;ab=d;e=Ye(a);b:{c:{d:{e:{while(1){v[22452]=0;a=Q(147,b|0,8)|0;f=v[22452];v[22452]=0;if((f|0)==1){break c}if(!a){break d}v[22452]=0;U(843,d|0,b|0,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;R(844,e|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break e}Tc(d);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Tc(d);break b}ab=d+32|0;break a}a=P()|0;O()|0}Rd(e);S(a|0);L()}}function Ei(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=Ic(d,v[a+4>>2]);if(c>>>0<b>>>0){e=ab-32|0;ab=e;b=b-c|0;c=v[vb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>>0){Gv(a,b);break a}c=vb(a);c=xl(e+8|0,ul(a,Ic(v[a>>2],d)+b|0),Ic(v[a>>2],v[a+4>>2]),c);f=ab-16|0;ab=f;b=Dv(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){rf(d);d=v[b>>2]+1|0;v[b>>2]=d;continue}break}xd(b);ab=f+16|0;rd(a,c);wl(c)}ab=e+32|0;return}if(b>>>0<c>>>0){Hd(a,b+d|0)}}function $d(a){var b=0,c=0,d=0;d=No(Pf(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}b=w[a|0];t[c|0]=b;if(!b){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function NI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ab-32|0;ab=e;v[e+24>>2]=b;k=e,l=kd(a),v[k+16>>2]=l;b=am(e+24|0,e+16|0);h=ab-16|0;ab=h;a:{g=ub(a);if(b>>>0<=g>>>0){if(c){f=Ec(a);b:{if(f-g>>>0>=c>>>0){f=Eb(a);i=g-b|0;if(!i){break b}j=b+f|0;_j(j+c|0,j,i);break b}sy(a,f,(c+g|0)-f|0,g,b,c);f=v[a>>2]}dq(b+f|0,c,d);c=c+g|0;cg(a,c);t[h+15|0]=0;md(c+f|0,h+15|0)}ab=h+16|0;break a}Vp();L()}k=e,l=kd(a),v[k+8>>2]=l;le(e+8|0,b);ab=e+32|0}function Uca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=ab-16|0;ab=c;d=Gc(c+8|0,16,1,1,0);v[c+4>>2]=0;ed(a,0);qc(b);a:{b:{if(pq(b,13736)){Nc(b,12);if(!hm(b)){eo(d,2)}Nc(b,24);break b}if(oh(b,13608)){qc(b);v[c+4>>2]=4;e=1;break a}vh(d,8)}e=0}f=a,g=(Ze(b)>>>0)/(B(w[c+8|0],Np(w[d+1|0]))>>>3>>>0)|0,v[f>>2]=g;b=eg(d,a,b);if(!(!b|!e)){d=v[a+20>>2];f=c,g=mj(v[a>>2],x[a+34>>1]),v[f>>2]=g;Jb(d,0,v[zb(c+4|0,c)>>2])}ab=c+16|0;return(b|0)!=0|0}function MR(a,b){var c=0,d=0,e=0,f=0;d=v[a>>2];c=nc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=ab-32|0;ab=e;b=b-c|0;c=v[vb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){mA(a,b);break a}c=vb(a);c=_f(e+8|0,fh(a,nc(v[a>>2],d)+b|0),nc(v[a>>2],v[a+4>>2]),c);f=ab-16|0;ab=f;b=jl(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){im(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}xd(b);ab=f+16|0;rd(a,c);Zf(c)}ab=e+32|0;return}if(b>>>0<c>>>0){Hd(a,d+(b<<2)|0)}}function p2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=ab-16|0;ab=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=aa(8)|0;v[22452]=0;b=Q(55,h|0,8187)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}lc(a,b);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}e=P()|0;O()|0;pb(b);break b}Xi(a,b,4);c=Ow(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);ab=h+16|0;return c|0}e=P()|0;O()|0;ba(a|0)}S(e|0)}L()}function E2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=ab-16|0;ab=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=aa(8)|0;v[22452]=0;b=Q(55,h|0,8187)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}lc(a,b);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}e=P()|0;O()|0;pb(b);break b}Xi(a,b,4);c=Nw(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);ab=h+16|0;return c|0}e=P()|0;O()|0;ba(a|0)}S(e|0)}L()}function lF(a,b,c,d){var e=0,f=0,g=0,h=0;e=ab-16|0;ab=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[114934];v[114934]=0;gd();a=Uv(a,e+12|0,d);d=db;g=v[114934];e:{if(g){if(v[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}v[114934]=h;if((b|0)!=v[e+12>>2]){break c}if(!d){break b}}v[c>>2]=4;a=-1;break a}}v[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}ab=e+16|0;return a}function b5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;t[a+4202|0]=1;b=gj(C(C(y[v[a+16>>2]+24620>>2])*C(.04500000178813934)));c=gj(C(C(b>>>0)*C(1.1892070770263672)));d=gj(C(C(c>>>0)*C(1.1892070770263672)));g=gj(C(C(d>>>0)*C(1.1892070770263672)));e=gj(C(C(b+d>>>0)*C(.11546666920185089)));f=gj(C(C(c+g>>>0)*C(.11546666920185089)));v[a+4292>>2]=f;v[a+4288>>2]=e;v[a+4276>>2]=d-e;v[a+4272>>2]=b-e;v[a+4284>>2]=g-f;v[a+4280>>2]=c-f;kJ(a);jJ(a)}function aW(a,b){a=a|0;b=b|0;var c=0;a=Bb(a);a:{if(w[b+16|0]){v[22452]=0;Q(124,a|0,4906)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[22452]=0;Q(124,a|0,12514)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}}if(pd(a)){v[22452]=0;Q(124,a|0,10028)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[22452]=0;Q(124,a|0,11039)|0;b=v[22452];v[22452]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;pb(a);S(b|0);L()}function KT(){var a=0,b=0,c=0;a=ab-16|0;ab=a;a:{if(Za(a+12|0,a+8|0)|0){break a}b=yd((v[a+12>>2]<<2)+4|0);v[115842]=b;if(!b){break a}b=yd(v[a+8>>2]);if(b){c=v[115842];v[c+(v[a+12>>2]<<2)>>2]=0;if(!(Ya(c|0,b|0)|0)){break a}}v[115842]=0}ab=a+16|0;b:{if(t[463360]&1){break b}if(!Jd(463360)){break b}v[22452]=0;X(1089);a=v[22452];v[22452]=0;if((a|0)!=1){Id(463360);break b}a=P()|0;O()|0;Xe(463360);S(a|0);L()}t[459740]=1;v[114936]=463460}function cT(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(B(b,6)+a|0)+1072|0,g=ik(a,7),t[f|0]=g;d=ik(a,1);e=ik(a,1);c=v[a+1060>>2];if((c|0)>255){break a}b=v[a+1064>>2]+1|0;v[a+1060>>2]=b;v[a+1064>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1068>>1]=b;cT(a);b=v[a+1064>>2];break b}u[(B(c,6)+a|0)+1068>>1]=65535}v[a+1060>>2]=b;if(e){u[(B(c,6)+a|0)+1070>>1]=b;continue}break}u[(B(c,6)+a|0)+1070>>1]=65535}}function Xea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ab-80|0;ab=d;Pe(b);e=d+56|0;Je(e,a,c);a=v[d+56>>2];Se(d+8|0,3,Sd(e),a);v[22452]=0;W(213,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22452];v[22452]=0;b:{c:{if((a|0)!=1){v[22452]=0;U(11,d+40|0,5,d+24|0);a=v[22452];v[22452]=0;if((a|0)==1){break c}a=d+40|0;tb(b,a);pb(a);pb(d+24|0);rc(d+56|0);ab=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;pb(d+24|0)}rc(d+56|0);S(a|0);L()}}function Vfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=v[a>>2];c=Ef(d,v[a+4>>2]);if(c>>>0<b>>>0){d=ab-32|0;ab=d;a:{b:{c=b-c|0;b=v[vb(a)>>2];e=v[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){dC(a,c);break c}b=vb(a);b=NA(d+8|0,OA(a,Ef(v[a>>2],e)+c|0),Ef(v[a>>2],v[a+4>>2]),b);v[22452]=0;R(467,b|0,c|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}MA(a,b);Mt(b)}ab=d+32|0;break a}a=P()|0;O()|0;Mt(b);S(a|0);L()}return}if(b>>>0<c>>>0){bC(a,d+B(b,20)|0)}}function Hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ab-80|0;ab=d;Pe(b);e=d+56|0;Je(e,a,c);a=v[d+56>>2];Se(d+8|0,2,Sd(e),a);v[22452]=0;W(213,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22452];v[22452]=0;b:{c:{if((a|0)!=1){v[22452]=0;U(11,d+40|0,2,d+24|0);a=v[22452];v[22452]=0;if((a|0)==1){break c}a=d+40|0;tb(b,a);pb(a);pb(d+24|0);rc(d+56|0);ab=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;pb(d+24|0)}rc(d+56|0);S(a|0);L()}}function lca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;a:{c=v[b+4>>2];if(!c){break a}f=a+480190|0;u[d>>1]=x[f>>1];u[d+14>>1]=c-1;c=x[Lc(d,d+14|0)>>1];while(1){if(!c){break a}rb(d,v[b>>2],c);b:{if(sb(v[v[d>>2]>>2],v[d+4>>2])){break b}if(bL(a,c&65535)){e=Mb(d,21598);sc(((c<<5)+a|0)+946304|0,e);pb(e);g=g+1|0}if(c>>>0<2){break b}e=x[f>>1];if((e|0)!=(c|0)){break b}u[f>>1]=e-1}c=c-1|0;continue}}ab=d+16|0;return g&65535}function lU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=ab-16|0;ab=e;a:{b:{if(!Qf(a,7)){break b}c=0;if(!VB(a,17771)){break a}if(!Qf(a,1)){break b}c=-1;if(!Rc(a,kq(a))){break a}c=ab-16|0;ab=c;f=e+8|0;_n(c+8|0,f);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;d=(d|0)==(g|0);if(!d){mu(f)}c=-1;if(!d){break a}c=0;if(!IB(e+8|0)){break a}c=we(a,b,HB(e+8|0),db);break a}c=-1}ab=e+16|0;return c|0}function f4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22452]=0;Z(949,a|0);c=v[22452];v[22452]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[22452]=0;R(e|0,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,11282,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function S3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22452]=0;Z(949,a|0);c=v[22452];v[22452]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[22452]=0;R(e|0,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,12753,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function N3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22452]=0;Z(949,a|0);c=v[22452];v[22452]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+84>>2];v[22452]=0;R(e|0,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,12236,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function M3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22452]=0;Z(949,a|0);c=v[22452];v[22452]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+80>>2];v[22452]=0;R(e|0,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,11063,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function x2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22452]=0;Z(924,a|0);e=v[22452];v[22452]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22452]=0;b=da(1008,e|0,b|0,c|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,12914,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function v8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ab-32|0;ab=d;Qe(d,2,a+6|0);e=d+16|0;tc(e,v[d>>2],v[d+4>>2],w[d+8|0]);sc(b+492|0,e);f=b+236|0;g=c+1|0;pb(e);c=0;while(1){if((c|0)==128){c=a+226|0;v[b>>2]=(w[c|0]|w[c+1|0]<<8)<<5;Dx(a+180|0,b+48|0,0);Dx(a+228|0,b+88|0,2);Dx(a+276|0,b+68|0,1);a=a+324|0;if(!(w[a|0]|w[a+1|0]<<8)){lz(f)}ab=d+32|0}else{h=Yb(f,c),i=w[(a+c|0)+38|0]+g|0,u[h>>1]=i;c=c+1|0;continue}break}}function nea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=ab-32|0;ab=c;d=Ye(a);b:{c:{d:{e:{while(1){v[22452]=0;a=Q(147,b|0,8)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}if(!a){break d}v[22452]=0;R(589,c|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;R(590,d|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break e}Tc(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Tc(c);break b}ab=c+32|0;break a}a=P()|0;O()|0}Rd(d);S(a|0);L()}}function Y3(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22452]=0;Z(949,a|0);c=v[22452];v[22452]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[22452]=0;sa(e|0,c|0,+b);c=v[22452];v[22452]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[22452]=0;W(911,11690,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22452]=0;X(17);d=v[22452];v[22452]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function Xda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=ab-32|0;ab=c;d=Ye(a);b:{c:{d:{e:{while(1){v[22452]=0;a=Q(147,b|0,8)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}if(!a){break d}v[22452]=0;R(621,c|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;R(622,d|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break e}Tc(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Tc(c);break b}ab=c+32|0;break a}a=P()|0;O()|0}Rd(d);S(a|0);L()}}function T3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22452]=0;Z(949,a|0);c=v[22452];v[22452]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[22452]=0;R(e|0,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,9283,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function R3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22452]=0;Z(949,a|0);c=v[22452];v[22452]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+100>>2];v[22452]=0;d=+va(e|0,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,11608,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function Cha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=ab-32|0;ab=c;d=Ye(a);b:{c:{d:{e:{while(1){v[22452]=0;a=Q(147,b|0,8)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}if(!a){break d}v[22452]=0;R(350,c|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;R(351,d|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break e}Tc(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Tc(c);break b}ab=c+32|0;break a}a=P()|0;O()|0}Rd(d);S(a|0);L()}}function B2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22452]=0;Z(924,a|0);e=v[22452];v[22452]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22452]=0;b=da(1006,e|0,b|0,c|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,12840,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function A$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=ab-16|0;ab=e;while(1){a:{if((c|0)<=(f|0)){break a}g=v[a+16>>2];d=v[a+12>>2];b:{if(g>>>0>d>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=g-d;v[e+4>>2]=c-f;g=d;d=v[jd(e+12|0,jd(e+8|0,e+4|0))>>2];b=dg(b,g,d);v[a+12>>2]=v[a+12>>2]+d;b=b+d|0;break b}d=eb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=hn(d),t[h|0]=i;d=1;b=b+1|0}f=d+f|0;continue}break}ab=e+16|0;return f|0}function $fa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=ab-32|0;ab=c;d=Ye(a);b:{c:{d:{e:{while(1){v[22452]=0;a=Q(147,b|0,6)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}if(!a){break d}v[22452]=0;R(465,c|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;R(466,d|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break e}Tc(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Tc(c);break b}ab=c+32|0;break a}a=P()|0;O()|0}Rd(d);S(a|0);L()}}function z2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22452]=0;Z(924,a|0);e=v[22452];v[22452]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22452]=0;b=da(1007,e|0,b|0,c|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,9542,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function v2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22452]=0;Z(924,a|0);e=v[22452];v[22452]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22452]=0;b=da(1009,e|0,b|0,c|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,9620,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function s2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22452]=0;Z(924,a|0);e=v[22452];v[22452]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22452]=0;b=da(1010,e|0,b|0,c|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,9422,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function jW(a){a=a|0;var b=0,c=0,d=0,e=0;c=ab-32|0;ab=c;b=Mb(c,16715);v[22452]=0;U(111,c+16|0,a|0,b|0);a=v[22452];v[22452]=0;a:{if((a|0)!=1){pb(b);a=0;b=0;while(1){d=v[c+16>>2];if(!(b>>>0<=3&ad(d,v[c+20>>2])>>>0>b>>>0)){Uc(c+16|0);ab=c+32|0;return a|0}v[22452]=0;d=T(112,ld(d,b)|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=P()|0;O()|0;Uc(c+16|0);break a}a=P()|0;O()|0;pb(b)}S(a|0);L()}function _T(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=ab-32|0;ab=c;d=Ye(a);b:{c:{d:{e:{while(1){v[22452]=0;a=Q(147,b|0,8)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}if(!a){break d}v[22452]=0;R(287,c|0,b|0);a=v[22452];v[22452]=0;if((a|0)!=1){v[22452]=0;R(288,d|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break e}Tc(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Tc(c);break b}ab=c+32|0;break a}a=P()|0;O()|0}Rd(d);S(a|0);L()}}function Yea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=ab-32|0;ab=g;a:{if(x[a+480192>>1]<b>>>0){break a}h=v[((b<<2)+a|0)+900380>>2];if(!h){break a}b=g+16|0;tR(b,h);i=g,j=Ip(b),v[i+8>>2]=j;h=Jf(b);while(1){if(Tb(v[g+8>>2],h)){b=x[Jp(g+8|0)>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}On(g+8|0);continue}else{dA(g+16|0)}break}}ab=g+32|0}function W3(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22452]=0;Z(949,a|0);c=v[22452];v[22452]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[22452]=0;sa(e|0,c|0,+b);c=v[22452];v[22452]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[22452]=0;W(911,7695,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22452]=0;X(17);d=v[22452];v[22452]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function U3(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22452]=0;Z(949,a|0);c=v[22452];v[22452]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[22452]=0;sa(e|0,c|0,+b);c=v[22452];v[22452]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[22452]=0;W(911,7643,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22452]=0;X(17);d=v[22452];v[22452]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function P3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22452]=0;Z(949,a|0);c=v[22452];v[22452]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+92>>2];v[22452]=0;d=+va(e|0,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,10993,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function H2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22452]=0;Z(924,a|0);e=v[22452];v[22452]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22452]=0;b=da(1003,e|0,b|0,c|0,d|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,9391,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function $3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22452]=0;Z(949,a|0);c=v[22452];v[22452]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[22452]=0;d=+va(e|0,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,11671,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function yV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=ab-16|0;ab=f;v[f+4>>2]=1;j=f,k=pc(32),v[j+8>>2]=k;h=ab-16|0;ab=h;e=v[f+8>>2];oo(e);v[e>>2]=43128;e=ic(e);g=ol(h+8|0,v[b>>2],v[b+4>>2]);i=v[g>>2];c=v[c>>2];d=v[d>>2];b=ab-16|0;ab=b;g=v[g+4>>2];v[b+12>>2]=g;v[b+8>>2]=i;Cm(e);v[e>>2]=43264;ol(e+4|0,i,g);v[e+16>>2]=d;v[e+12>>2]=c;Cd(b+8|0);ab=b+16|0;ab=h+16|0;b=a;a=qo(f);po(b,ic(a),a);Dm(f);ab=f+16|0}function xP(a){var b=0,c=0,d=0;b=ab-16|0;ab=b;v[b+4>>2]=((w[a+48|0]|w[a+49|0]<<8)<<1)+((w[a+32|0]|w[a+33|0]<<8)<<4);v[b+8>>2]=((w[a+50|0]|w[a+51|0]<<8)<<1)+((w[a+34|0]|w[a+35|0]<<8)<<4);v[b+12>>2]=(B(w[a+52|0]|w[a+53|0]<<8,5)+((w[a+36|0]|w[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=Fb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=Io(v[a>>2],v[c>>2])?c:a;continue}}ab=b+16|0;a=v[a>>2];db=a>>31;return a}function O4(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=ab-16|0;ab=d;if(a){c=kc(d+8|0,a);f=v[c>>2];b=ab-16|0;ab=b;e=v[c+4>>2];a=0;a:{if(!e){break a}a=32208;while(1){if((a|0)==32784){c=32784;while(1){a=c;if((a|0)!=32832){kc(b,v[a+8>>2]);c=a+12|0;if(!OK(f,e,v[b>>2],v[b+4>>2])){continue}}break}a=(a|0)!=32832;break a}kc(b+8|0,v[a+8>>2]);a=a+12|0;if(!OK(f,e,v[b+8>>2],v[b+12>>2])){continue}break}a=1}ab=b+16|0}else{a=0}ab=d+16|0;return a|0}function d4(a,b){a=a|0;b=b|0;var c=0,d=0;v[22452]=0;Z(949,a|0);c=v[22452];v[22452]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[22452]=0;b=Q(d|0,c|0,b|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,6648,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function b4(a,b){a=a|0;b=b|0;var c=0,d=0;v[22452]=0;Z(949,a|0);c=v[22452];v[22452]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[22452]=0;b=Q(d|0,c|0,b|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,6699,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function wA(a,b,c,d,e){var f=0,g=0,h=0,i=0;h=-1;f=d&2147483647;i=f;g=(f|0)==2147418112;a:{if(g&!c?a|b:g&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;g=(f|0)==2147418112;if(g?0:g&0|f>>>0>2147418112){break a}if(!(a|c|(f|i|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function mf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[Lc(43116,d+14|0)>>1];e=v[a>>2];c=wc(e,v[a+4>>2]);a:{if(b>>>0>c>>>0){e=ab-32|0;ab=e;b=b-c|0;c=v[vb(a)>>2];g=v[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){ao(a,b,f);break b}c=vb(a);c=qj(e+8|0,rj(a,wc(v[a>>2],g)+b|0),wc(v[a>>2],v[a+4>>2]),c);rC(c,b,f);rd(a,c);Bi(c)}ab=e+32|0;break a}if(b>>>0<c>>>0){Hd(a,e+(b<<1)|0)}}ab=d+16|0}function PM(a,b,c,d){var e=0,f=C(0),g=0,h=0,i=0,j=0;e=ab-16|0;ab=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];c=v[a+20>>2];g=v[zb(e+12|0,e+8|0)>>2];a=g;while(1){if(a){f=xf((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()));f=kf(C(Ed(C((Yf(f)?f>=C(0)?C(1):C(-1):f)*d),C(-1))*C(32768)));a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}i=c,j=Jc(h),u[i>>1]=j;c=c+2|0;b=b+4|0;a=a-1|0;continue}break}ab=e+16|0;return g<<2}function AA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Hb(a,b)){break a}if(b>>>0<=3){c=ab-16|0;ab=c;if(Hb(a,b)){while(1){if((d|0)==4){v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}else{t[c+11|0]=0;b:{if(b>>>0>d>>>0){hg(a,c+11|0);e=t[c+11|0];g=e>>>31|0;break b}e=0-g|0}t[(c+12|0)+d|0]=e;d=d+1|0;continue}break}}ab=c+16|0;c=d;break a}c=jg(a);Ob(a,b-4|0)}t[f|0]=c}function XF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ab-48|0;ab=e;v[e+44>>2]=c;v[e+40>>2]=b;b=Mb(e+8|0,d);v[22452]=0;U(1085,e+24|0,e+40|0,b|0);c=v[22452];v[22452]=0;a:{b:{if((c|0)!=1){v[22452]=0;Q(1086,a|0,e+24|0)|0;c=v[22452];v[22452]=0;if((c|0)==1){break b}pb(e+24|0);pb(b);v[a>>2]=87724;b=v[e+44>>2];v[a+8>>2]=v[e+40>>2];v[a+12>>2]=b;ab=e+48|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;pb(e+24|0)}pb(b);S(a|0);L()}function SG(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;c=z[a>>2];i=a-16|0;d=z[i>>2];e=C(c+d);b=a-8|0;f=z[b>>2];j=a-24|0;g=z[j>>2];h=C(f+g);z[a>>2]=e+h;z[b>>2]=e-h;b=a-12|0;h=z[b>>2];k=a-28|0;l=z[k>>2];e=C(h+l);p=b;b=a-4|0;m=z[b>>2];a=a-20|0;n=z[a>>2];o=C(m+n);z[p>>2]=o-e;f=C(f-g);g=C(m-n);z[k>>2]=f+g;c=C(c-d);d=C(h-l);z[i>>2]=c+d;z[j>>2]=c-d;z[b>>2]=e+o;z[a>>2]=g-f}function e2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[22452]=0;Z(924,a|0);d=v[22452];v[22452]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[22452]=0;U(1018,d|0,b|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,10282,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function we(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=ab-16|0;ab=e;g=cp(a);a:{b:{if(!b){i=e,j=cp(a),v[i+8>>2]=j;v[e+12>>2]=0;break b}f=v[b+4>>2];h=v[b>>2];v[e+8>>2]=h;v[e+12>>2]=f;a=v[a+12>>2];v[e>>2]=2048;v[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=il(e+8|0,e);c=v[a>>2];a=v[a+4>>2];if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break b}break a}a=0;if((d|0)==(f|0)&b>>>0>h>>>0|d>>>0>f>>>0){break a}}a=1}ab=e+16|0;return a}function w$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=ab-16|0;ab=e;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+12>>2];f=v[a+16>>2];b:{if(d>>>0<f>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=f-d>>2;v[e+4>>2]=c-g;f=d;d=v[jd(e+12|0,jd(e+8|0,e+4|0))>>2];Uh(b,f,d);f=d<<2;v[a+12>>2]=f+v[a+12>>2];b=b+f|0;break b}d=eb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}ab=e+16|0;return g|0}function CW(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[22452]=0;a=Ia(1021,a|0,b|0,c|0,d|0)|0;b=v[22452];v[22452]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[22452]=0;ja(907,11086,e|0,f|0,g|0,h|0,i|0,j|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}return a|0}function qN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ab-32|0;ab=d;v[a+4>>2]=0;a:{if(b){b:{if(at(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}e=Fn(d+16|0);v[22452]=0;f=Q(700,a|0,b|0)|0;g=v[22452];v[22452]=0;if((g|0)==1){break a}v[22452]=0;R(701,e|0,f|0);f=v[22452];v[22452]=0;if((f|0)==1){break a}v[e+4>>2]=b;gt(a,e);Be(e)}Rj(d+8|0,v[a>>2]);Mu(v[d+8>>2],v[d+12>>2],b,w[c|0])}ab=d+32|0;return}a=P()|0;O()|0;Be(e);S(a|0);L()}function i2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[22452]=0;Z(924,a|0);d=v[22452];v[22452]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[22452]=0;e=+ra(1014,d|0,b|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,5311,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function Iga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=Yj(e,v[a+4>>2]);if(d>>>0<b>>>0){e=ab-32|0;ab=e;d=b-d|0;b=v[vb(a)>>2];f=v[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){yA(a,d,c);break a}b=vb(a);b=ZR(e+8|0,rA(a,Yj(v[a>>2],f)+d|0),Yj(v[a>>2],v[a+4>>2]),b);YR(b,d,c);c=b+4|0;WR(v[a>>2],v[a+4>>2],c);cc(a,c);cc(a+4|0,b+8|0);cc(vb(a),ic(b));v[b>>2]=v[b+4>>2];XR(b)}ab=e+32|0;return}if(b>>>0<d>>>0){Hd(a,e+B(b,6)|0)}}function Z3(a){a=a|0;var b=0,c=0,d=0;v[22452]=0;Z(949,a|0);b=v[22452];v[22452]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[22452]=0;c=+na(d|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,11708,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function X3(a){a=a|0;var b=0,c=0,d=0;v[22452]=0;Z(949,a|0);b=v[22452];v[22452]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[22452]=0;c=+na(d|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,7712,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function V3(a){a=a|0;var b=0,c=0,d=0;v[22452]=0;Z(949,a|0);b=v[22452];v[22452]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[22452]=0;c=+na(d|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,7660,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function xw(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!Gr(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}Vb(a,32);return 0}ca(15700,13164,1564,5997);L()}function W2(a,b){a=a|0;b=b|0;var c=0;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;if((c|0)!=1){c=v[a+24>>2];a=0;a:{if(!Kr(b)){break a}c=v[c+24>>2]+484344|0;if(!he(c,b&65535)){break a}a=v[Rb(c,b)+12>>2]}return a|0}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,6585,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function rE(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=ab-16|0;ab=i;if(1073741806-b>>>0>=c>>>0){j=Eb(a);k=1073741807;if(b>>>0<=536870886){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=sl(v[Pc(i+12|0,i+8|0)>>2])+1|0}c=ji(k);if(e){Uh(c,j,e)}if(g){Uh(c+(e<<2)|0,h,g)}d=d-(e+f|0)|0;if(d){h=e<<2;Uh((h+c|0)+(g<<2)|0,(h+j|0)+(f<<2)|0,d)}if((b|0)!=1){xb(j)}nd(a,c);Lf(a,k);b=a;a=d+(e+g|0)|0;Qd(b,a);nd(c+(a<<2)|0,0);ab=i+16|0;return}Df();L()}function pq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-32|0;ab=c;a:{if(!w[b+7|0]){while(1){if((d|0)==7){d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=Zb(c+8|0,c+24|0,7);_b(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=7){break b}if(Ib(c+24|0,b,7)){break b}Ob(a,7);d=1}ab=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17409,9050,413,13128);L()}ca(17388,9050,411,13128);L()}return d|0}function n2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=ab-16|0;ab=f;a:{b:{c:{if(!(e?d:0)){a=aa(8)|0;v[22452]=0;b=Q(55,f|0,8187)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}lc(a,b);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}e=P()|0;O()|0;pb(b);break b}Xi(a,b,2);c=Ow(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);ab=f+16|0;return c|0}e=P()|0;O()|0;ba(a|0)}S(e|0)}L()}function C2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=ab-16|0;ab=f;a:{b:{c:{if(!(e?d:0)){a=aa(8)|0;v[22452]=0;b=Q(55,f|0,8187)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}lc(a,b);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}e=P()|0;O()|0;pb(b);break b}Xi(a,b,2);c=Nw(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);ab=f+16|0;return c|0}e=P()|0;O()|0;ba(a|0)}S(e|0)}L()}function zR(a){var b=0,c=0;a:{if(Ib(a,14252,3)|(w[a+3|0]-52&255)>>>0<252){break a}b=a+8|0;if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+788>>>0<840){break a}b=a+16|0;if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}b=a+24|0;if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-1>>>0<51){break a}a=a+32|0;c=Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<4294967216}return c}function Nt(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=Cb(a,0);e=(w[f|0]&15)<<8|w[Cb(a,1)|0];c=0;a:{if(!e|(e|0)==4095){break a}while(1){c=108;if((d|0)==84){break a}b:{c=x[(d<<1)+32832>>1];if(c>>>0<=e>>>0){if(!d|(e|0)==(c|0)|(x[(d<<1)+32830>>1]-e|0)>=(e-c|0)){break b}c=d+24|0;break a}d=d+1|0;continue}break}c=d+25|0}t[b|0]=c;e=w[f|0]&16;d=Cb(a,2);t[b+1|0]=e|w[d|0]>>>4;t[b+3|0]=w[d|0]&15;g=b,h=w[Cb(a,3)|0],t[g+5|0]=h}function nB(a){a=a|0;var b=0,c=0,d=0;b=v[a>>2];if(b){eb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;uc(a);b=ab-32|0;ab=b;a:{b:{d=Do(a);c=Ic(v[a>>2],v[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}v[22452]=0;c=da(884,b+8|0,c|0,c|0,vb(a)|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){rd(a,c);wl(c);break c}a=V(0)|0;O()|0;_(a|0)|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)==1){break b}}ab=b+32|0;break a}V(0)|0;O()|0;Gb();L()}}function m2(a,b){a=a|0;b=b|0;var c=0,d=0;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22452]=0;R(1013,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,10807,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function dt(a,b){var c=0,d=0;c=ab-32|0;ab=c;d=c+16|0;ZO(d,a,a+1|0,a+2|0,a+3|0);ZO(c,b,b+1|0,b+2|0,b+3|0);ab=c+32|0;a=1;a:{if(w[v[d>>2]]<w[v[c>>2]]){break a}a=0;if(w[v[c>>2]]<w[v[d>>2]]){break a}a=1;b:{if(t[v[d+4>>2]]<t[v[c+4>>2]]){break b}a=0;if(t[v[c+4>>2]]<t[v[d+4>>2]]){break b}a=1;c:{if(w[v[d+8>>2]]<w[v[c+8>>2]]){break c}a=0;if(w[v[c+8>>2]]<w[v[d+8>>2]]){break c}a=w[v[d+12>>2]]<w[v[c+12>>2]]}}}return a}function UV(a){a=a|0;var b=0;a=Bb(a);v[22452]=0;R(74,a|0,4);b=v[22452];v[22452]=0;a:{b:{if((b|0)==1){break b}v[22452]=0;R(51,a|0,32);b=v[22452];v[22452]=0;if((b|0)==1){break b}v[22452]=0;R(51,a|0,10);b=v[22452];v[22452]=0;if((b|0)==1){break b}v[22452]=0;R(51,a|0,13);b=v[22452];v[22452]=0;if((b|0)==1){break b}v[22452]=0;R(51,a|0,9);b=v[22452];v[22452]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;pb(a);S(b|0);L()}}function B9(a){a=a|0;var b=0;a=Bb(a);v[22452]=0;R(46,a|0,4);b=v[22452];v[22452]=0;a:{b:{if((b|0)==1){break b}v[22452]=0;R(47,a|0,32);b=v[22452];v[22452]=0;if((b|0)==1){break b}v[22452]=0;R(47,a|0,10);b=v[22452];v[22452]=0;if((b|0)==1){break b}v[22452]=0;R(47,a|0,13);b=v[22452];v[22452]=0;if((b|0)==1){break b}v[22452]=0;R(47,a|0,9);b=v[22452];v[22452]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;pb(a);S(b|0);L()}}function j4(a){a=a|0;var b=0;v[22452]=0;Z(949,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){eb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){xb(b);v[a+20>>2]=0}xb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,5012,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function Yx(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;t[a+1074368|0]=b;oL(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){if((a|0)!=(f|0)){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;if(eb[v[v[b>>2]+136>>2]](b)|0){d=v[b+16>>2];e=d+1074332|0;c=C(C(c/z[e+8>>2])*C(C(y[d+480232>>2])/z[e+20>>2]))}z[b+4196>>2]=c}a=a+160|0;continue}break}}function y$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=ab-16|0;ab=e;while(1){a:{if((c|0)<=(f|0)){break a}g=v[a+28>>2];d=v[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=rg(t[b|0]),h=v[v[a>>2]+52>>2],eb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{v[e+12>>2]=g-d;v[e+8>>2]=c-f;g=d;d=v[jd(e+12|0,e+8|0)>>2];dg(g,b,d);v[a+24>>2]=d+v[a+24>>2];f=f+d|0;b=b+d|0}continue}break}ab=e+16|0;return f|0}function sH(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{b:{c:{d:{if((b|0)>=0){if((Mo(a+8|0)|0)>(b|0)){break d}}a=aa(8)|0;v[22452]=0;b=Q(55,c|0,10667)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}lc(a,b);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}c=P()|0;O()|0;pb(b);break b}ab=c+16|0;return+(+v[(v[a+32>>2]+B(b,872)|0)+1075740>>2]*.015625)}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function Ss(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=ab-16|0;ab=e;v[b+40>>2]=0;v[b+44>>2]=0;f=b- -64|0;v[f>>2]=0;v[f+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=wb(v[c>>2]);v[e+8>>2]=d;f=wb(v[c+4>>2]);while(1){if(!Tb(d,f)){break a}g=d,h=uN(b,A[d>>3]),A[g>>3]=h;Qs(e+8|0);d=v[e+8>>2];continue}}}else{uN(b,A[He(v[c>>2],0)>>3]);d=d+1|0;continue}break}Sj(a,c);ab=e+16|0}function RG(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){Vb(a,21);return-1}if(v[a+1396>>2]<=9){Bk(a)}c=v[a+1392>>2];e=u[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=w[e+v[b+8>>2]|0];v[a+1392>>2]=d>>>c;c=v[a+1396>>2]-c|0;d=(c|0)<0;v[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=Al(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>=0)){Vb(a,21)}return c}ca(7484,13164,1793,5711);L()}function Ge(a){var b=0,c=0,d=0;b=ab-16|0;ab=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=vo(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(iE(a,b)&3){case 0:c=vo(A[b>>3],A[b+8>>3]);break a;case 1:c=-wo(A[b>>3],A[b+8>>3],1);break a;case 2:c=-vo(A[b>>3],A[b+8>>3]);break a;default:break b}}c=wo(A[b>>3],A[b+8>>3],1)}a=c;ab=b+16|0;return a}function zca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;u[d+12>>1]=c;u[d+14>>1]=b;lg(d+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);e=d+12|0;c=ab-16|0;ab=c;b=x[d+14>>1];v[c+12>>2]=b;a:{if(um(a)>>>0>=b>>>0){g=v[a>>2];f=wc(g,v[a+4>>2]);v[c+8>>2]=f;wt(g,v[zb(c+12|0,c+8|0)>>2],e);if(b>>>0>f>>>0){ao(a,b-f|0,e);break a}Hd(a,v[a>>2]+(b<<1)|0);break a}eO(a);Ez(a,rj(a,b));ao(a,b,e)}ab=c+16|0;ab=d+16|0}function sU(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=ab-16|0;ab=f;v[f+12>>2]=c;a:{g=Hb(b,c<<1);if(!g){break a}mc(f+12|0,65535);mf(a,x[f+12>>1]);c=wb(v[a>>2]);v[f>>2]=c;i=wb(v[a+4>>2]);while(1){if(!Tb(c,i)){break a}a=f+8|0;su(b,a);a=w[a|0]|w[a+1|0]<<8;u[c>>1]=a;h=65535;b:{if((a|0)!=(d|0)){h=65534;if((a|0)!=(e|0)){break b}}u[c>>1]=h}Ke(f);c=v[f>>2];continue}}ab=f+16|0;return g|0}function Vn(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=ab-16|0;ab=f;v[f+12>>2]=c;a:{g=Hb(b,c);if(!g){break a}mc(f+12|0,65535);mf(a,x[f+12>>1]);c=wb(v[a>>2]);v[f>>2]=c;i=wb(v[a+4>>2]);while(1){if(!Tb(c,i)){break a}a=f+11|0;if(!hg(b,a)){rf(a)}a=w[f+11|0];u[c>>1]=a;h=65535;b:{if((a|0)!=(d|0)){h=65534;if((a|0)!=(e|0)){break b}}u[c>>1]=h}Ke(f);c=v[f>>2];continue}}ab=f+16|0;return g|0}function qH(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{b:{c:{d:{if((b|0)>=0){if((Mo(a+8|0)|0)>(b|0)){break d}}a=aa(8)|0;v[22452]=0;b=Q(55,c|0,10667)|0;c=v[22452];v[22452]=0;if((c|0)==1){break c}lc(a,b);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}c=P()|0;O()|0;pb(b);break b}ab=c+16|0;return(w[(v[a+32>>2]+B(b,872)|0)+1075081|0]&4)>>>2|0}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function ls(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function g2(a,b){a=a|0;b=+b;var c=0;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22452]=0;b=+Sa(1015,c|0,+b);c=v[22452];v[22452]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;_(c|0)|0;v[22452]=0;W(911,7524,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[22452]=0;X(17);c=v[22452];v[22452]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function cP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=ab-16|0;ab=d;v[d+12>>2]=6553600;e=b+4|0;i=d,j=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[i+8>>2]=j;f=+(c>>>0)/6553600;g=d+12|0;e=d+8|0;h=Up(f*+y[zb(g,e)>>2]);v[d+8>>2]=6553600;b=b+8|0;i=d,j=Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),v[i+4>>2]=j;i=d,j=Up(f*+y[zb(e,d+4|0)>>2]),v[i+12>>2]=j;v[d+8>>2]=c-h;Hn(a,h,zb(e,g));ab=d+16|0}function Z5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=ci(a,b,c,d);v[a>>2]=45904;d=Pb(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=v[c+24620>>2];v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;e=a+4228|0;v[e>>2]=1048576e3;v[e+4>>2]=1048576e3;v[a+4236>>2]=0;v[a+4260>>2]=0;v[a+4256>>2]=c;v[22452]=0;R(875,a+44|0,2);c=v[22452];v[22452]=0;if((c|0)!=1){bi(b);return a|0}a=P()|0;O()|0;ec(d);ff(b);S(a|0);L()}function wL(a,b){var c=0,d=0,e=0,f=0;d=v[a>>2];v[a>>2]=b;if(d){if(d){a=ab-16|0;ab=a;b=wb(v[d>>2]);v[a+8>>2]=b;f=wb(v[d+4>>2]);while(1){if(Tb(b,f)){a:{while(1){c=v[b>>2];e=v[c>>2];if(!e){break a}c=v[v[e>>2]+8>>2];v[22452]=0;Z(c|0,e|0);c=v[22452];v[22452]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;ec(d);Gb();L()}yb(c+20|0);yb(c+8|0);xb(c);te(a+8|0);b=v[a+8>>2];continue}break}ec(d);ab=a+16|0}xb(d)}}function r2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ab-16|0;ab=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22452]=0;c=Q(55,e|0,8187)|0;b=v[22452];v[22452]=0;if((b|0)==1){break c}lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}b=P()|0;O()|0;pb(c);break b}Xi(a,b,1);c=Ow(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);ab=e+16|0;return c|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function Ww(a,b,c,d,e){var f=0,g=0;a:{if(!Kr(b)){break a}f=a+24|0;a=v[f>>2]+484344|0;if(!he(a,b&65535)){break a}a=Rb(a,b);if((c|d)<0|v[a+12>>2]<=(c|0)|(x[v[f>>2]+480188>>1]<=d>>>0|e>>>0>5)){break a}b=Qc(a,c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=w[b|0]}return g}function VB(a,b){var c=0,d=0,e=0;c=ab-32|0;ab=c;a:{if(!w[b+7|0]){while(1){if((d|0)==7){d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=Zb(c+8|0,c+24|0,7);$c(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=7){break b}if(Ib(c+24|0,b,7)){break b}Rc(a,7);d=1}ab=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17409,9050,413,13128);L()}ca(17388,9050,411,13128);L()}return d}function Qda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=yz(a,b);v[22452]=0;e=Q(625,a+12|0,b+12|0)|0;d=v[22452];v[22452]=0;b:{c:{if((d|0)!=1){v[22452]=0;Q(626,a+24|0,b+24|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}c=v[b+40>>2];v[a+36>>2]=v[b+36>>2];v[a+40>>2]=c;u[a+52>>1]=x[b+52>>1];c=v[b+48>>2];v[a+44>>2]=v[b+44>>2];v[a+48>>2]=c;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;Xb(e)}Xb(c);S(a|0);L()}}function G2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ab-16|0;ab=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22452]=0;c=Q(55,e|0,8187)|0;b=v[22452];v[22452]=0;if((b|0)==1){break c}lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}b=P()|0;O()|0;pb(c);break b}Xi(a,b,1);c=Nw(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);ab=e+16|0;return c|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function X0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=ab-16|0;ab=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;YH(a,c);a:{if(z[a+24>>2]==C(1)){break a}d=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=xh(v[a+12>>2],v[a+16>>2],b,i);z[f>>2]=z[a+24>>2]*z[f>>2];b=b+1|0;continue}}}ab=c+16|0}function Wq(a){var b=0,c=0;Gm(a,1,15322);v[22452]=0;b=ha(117)|0;c=v[22452];v[22452]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[22452]=0;b=ha(118)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}t[a+16|0]=b;v[22452]=0;b=ha(119)|0;c=v[22452];v[22452]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[22452]=0;Z(120,a+20|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;pb(a);S(b|0);L()}function hH(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=ab-16|0;ab=d;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22452]=0;d=Q(55,d|0,10667)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}lc(b,d);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(d);break b}e=(v[a+32>>2]+B(b,872)|0)+1075766|0,f=sz(c*32768),u[e>>1]=f;ab=d+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function y2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ab-16|0;ab=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22452]=0;c=Q(55,e|0,8187)|0;b=v[22452];v[22452]=0;if((b|0)==1){break c}lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}b=P()|0;O()|0;pb(c);break b}Xi(a,b,2);c=ZH(a,c,2,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);ab=e+16|0;return c|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function w2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ab-16|0;ab=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22452]=0;c=Q(55,e|0,8187)|0;b=v[22452];v[22452]=0;if((b|0)==1){break c}lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}b=P()|0;O()|0;pb(c);break b}Xi(a,b,4);c=cI(a,c,4,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);ab=e+16|0;return c|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function u2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ab-16|0;ab=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22452]=0;c=Q(55,e|0,8187)|0;b=v[22452];v[22452]=0;if((b|0)==1){break c}lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}b=P()|0;O()|0;pb(c);break b}Xi(a,b,2);c=cI(a,c,2,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);ab=e+16|0;return c|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function c3(a){a=a|0;var b=0,c=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22452]=0;b=T(991,b|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,7196,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function A2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ab-16|0;ab=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22452]=0;c=Q(55,e|0,8187)|0;b=v[22452];v[22452]=0;if((b|0)==1){break c}lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}b=P()|0;O()|0;pb(c);break b}Xi(a,b,4);c=ZH(a,c,4,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);ab=e+16|0;return c|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function bd(a,b){var c=0,d=0,e=0,f=0,g=0;a:{e=zF(b);c=yo(a);if(e>>>0<=c>>>0){f=Eb(a);d=f;c=e;if(c){b:{if((b|0)==(d|0)){break b}if(d-b>>>0>=c<<2>>>0){if(!c){break b}while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}break b}if(!c){break b}while(1){c=c-1|0;g=c<<2;v[g+d>>2]=v[b+g>>2];if(c){continue}break}}}nd((e<<2)+f|0,0);cg(a,e);break a}d=a;a=ub(a);rE(d,c,e-c|0,a,0,a,e,b)}}function q3(a){a=a|0;var b=0,c=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22452]=0;c=+na(982,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,7596,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function ki(a){var b=0,c=0;b=ab-16|0;ab=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=wo(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(iE(a,b)&3){case 0:a=wo(A[b>>3],A[b+8>>3],1);break a;case 1:a=vo(A[b>>3],A[b+8>>3]);break a;case 2:a=-wo(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-vo(A[b>>3],A[b+8>>3])}ab=b+16|0;return a}function DL(a,b){a=a|0;b=b|0;AL(a);AL(a+368680|0);if(b){zL(a,1);return a|0}a:{if(t[458680]&1){break a}if(!Jd(458680)){break a}v[22452]=0;Q(823,89976,1)|0;b=v[22452];v[22452]=0;if((b|0)!=1){Id(458680);break a}a=P()|0;O()|0;Xe(458680);S(a|0);L()}zn(221088,286624,a+131112|0);zn(286624,352160,a+196648|0);zn(352160,417696,a+262184|0);zn(9e4,221088,a+24|0);gc(a+327720|0,417696,40960);return a|0}function jF(a,b,c){var d=0,e=0,f=C(0),g=0,h=C(0);e=ab-16|0;ab=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[114934];v[114934]=0;gd();d=ab-16|0;ab=d;Tv(d,a,e+12|0,0);f=bF(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);ab=d+16|0;a=v[114934];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[114934]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}ab=e+16|0;return f}function Iw(a,b,c){var d=0,e=0;d=ab-32|0;ab=d;a:{if(w[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=v[a+16>>2];if(b>>>0<=c>>>0){break a}b=RH(b,4096);QH(a,b-c|0);c=v[a+16>>2];b=Zb(d+16|0,Cb(v[a+4>>2],c),b-c|0);c=v[v[a>>2]+44>>2];e=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=e;eb[c|0](d+24|0,a,d+8|0);v[a+16>>2]=v[a+16>>2]+v[d+28>>2];if(!(eb[v[v[a>>2]+40>>2]](a)|0)){break a}t[a+20|0]=1}ab=d+32|0}function wga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=ab-32|0;ab=f;c=cf(a,c);Xd(f+8|0,v[a+28>>2]);e=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=e;a:{if(!c){e=0;if(Vc(a,5)){break a}}h=v[a+28>>2];g=ab-16|0;ab=g;e=Bb(g);v[22452]=0;da(416,b|0,h|0,e|0,d|0)|0;b=v[22452];v[22452]=0;b:{if((b|0)!=1){pb(e);ab=g+16|0;break b}a=P()|0;O()|0;pb(e);S(a|0);L()}e=c}Te(a,e,f+24|0);ab=f+32|0}function ou(a,b,c){var d=0,e=0,f=0;d=v[c+16>>2];a:{if(!d){if(mC(c)){break a}d=v[c+16>>2]}f=v[c+20>>2];if(d-f>>>0<b>>>0){return eb[v[c+36>>2]](c,a,b)|0}b:{if(v[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(w[e+a|0]!=10){continue}break}e=eb[v[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=v[c+20>>2]}gc(f,a,b);v[c+20>>2]=v[c+20>>2]+b;e=b+d|0}return e}function Un(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=ab-16|0;ab=i;if(-18-b>>>0>=c>>>0){j=Eb(a);k=-17;if(b>>>0<=2147483622){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=ri(v[Pc(i+12|0,i+8|0)>>2])+1|0}c=pc(k);if(e){dg(c,j,e)}if(g){dg(c+e|0,h,g)}d=d-(e+f|0)|0;if(d){dg((c+e|0)+g|0,(e+j|0)+f|0,d)}if((b|0)!=10){xb(j)}nd(a,c);Lf(a,k);b=a;a=d+(e+g|0)|0;Qd(b,a);t[i+7|0]=0;md(a+c|0,i+7|0);ab=i+16|0;return}Df();L()}function l1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0;c=ab-16|0;ab=c;a:{f=z[a+24>>2];if(f==C(1)){break a}h=v[b+4>>2];i=v[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=v[b+4>>2];k=v[b>>2];d=0;while(1)if((d|0)==(h|0)){e=e+1|0;continue b}else{g=Hg(k,j,d,e);A[g>>3]=A[g>>3]*+f;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;hI(a,c);ab=c+16|0}function e1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0;c=ab-16|0;ab=c;a:{f=z[a+24>>2];if(f==C(1)){break a}h=v[b+4>>2];i=v[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=v[b+4>>2];k=v[b>>2];d=0;while(1)if((d|0)==(h|0)){e=e+1|0;continue b}else{g=Hg(k,j,d,e);A[g>>3]=A[g>>3]*+f;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;dI(a,c);ab=c+16|0}function b1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0;c=ab-16|0;ab=c;a:{f=z[a+24>>2];if(f==C(1)){break a}h=v[b+4>>2];i=v[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=v[b+4>>2];k=v[b>>2];d=0;while(1)if((d|0)==(h|0)){e=e+1|0;continue b}else{g=Hg(k,j,d,e);A[g>>3]=A[g>>3]*+f;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;aI(a,c);ab=c+16|0}function W0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0;c=ab-16|0;ab=c;a:{f=z[a+24>>2];if(f==C(1)){break a}h=v[b+4>>2];i=v[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=v[b+4>>2];k=v[b>>2];d=0;while(1)if((d|0)==(h|0)){e=e+1|0;continue b}else{g=Hg(k,j,d,e);A[g>>3]=A[g>>3]*+f;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;XH(a,c);ab=c+16|0}function VQ(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Dz(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+30|0]=0;t[a+31|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function qY(){var a=0;a:{if(t[464280]&1){break a}if(!Jd(464280)){break a}a=464112;while(1){a=Bb(a)+12|0;if((a|0)!=464280){continue}break}Id(464280)}bd(464112,84404);bd(464124,84432);bd(464136,84460);bd(464148,84492);bd(464160,84532);bd(464172,84568);bd(464184,84596);bd(464196,84632);bd(464208,84648);bd(464220,84664);bd(464232,84680);bd(464244,84696);bd(464256,84712);bd(464268,84728)}function g1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=ab-16|0;ab=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;eI(a,c);a:{if(z[a+24>>2]==C(1)){break a}d=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=Gp(v[a+12>>2],b,i);z[f>>2]=z[a+24>>2]*z[f>>2];b=b+1|0;continue}}}ab=c+16|0}function hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=ab-16|0;ab=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;e=v[a+8>>2];j=v[a+12>>2];while(1){if(d){f=u[(v[b+12>>2]<<1)+i>>1];v[c>>2]=v[c>>2]+B(f,h);v[c+4>>2]=v[c+4>>2]+B(g,f);Lb(b+8|0,e,j);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function hF(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=ab-16|0;ab=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[114934];v[114934]=0;gd();d=ab-16|0;ab=d;Tv(d,a,e+12|0,1);f=Ew(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);ab=d+16|0;a=v[114934];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[114934]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}ab=e+16|0;return f}function B7(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[22452]=0;R(279,b+4|0,8);b=v[22452];v[22452]=0;if((b|0)!=1){b=v[a+4264>>2];c=v[v[a+20>>2]+4>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(88408)|0;if((O()|0)==(fa(88408)|0)){_(b|0)|0;uc(v[a+20>>2]+4|0);$();return}S(b|0);L()}function Cz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ab-32|0;ab=d;e=Pb(a);a=wb(v[b>>2]);v[d+24>>2]=a;b=wb(v[b+4>>2]);a:{while(1){if(Tb(a,b)){qi(d,a);if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==(c|0)){gm(d,a);v[22452]=0;R(349,e|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break a}qb(d)}em(d+24|0);a=v[d+24>>2];continue}break}ab=d+32|0;return}a=P()|0;O()|0;qb(d);Yc(e);S(a|0);L()}function laa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=sd(a);b:{c:{c=wc(v[b>>2],v[b+4>>2]);if(c){v[22452]=0;R(584,a|0,c|0);e=v[22452];v[22452]=0;if((e|0)==1){break c}VN(a,v[b>>2],v[b+4>>2],c)}break b}a=P()|0;O()|0;_c(d);S(a|0);L()}c=a;v[22452]=0;Q(3,a+12|0,b+12|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){v[a+24>>2]=v[b+24>>2];u[a+28>>1]=x[b+28>>1];break a}a=P()|0;O()|0;_c(c);S(a|0);L()}}function ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=ab-16|0;ab=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;e=v[a+8>>2];j=v[a+12>>2];while(1){if(d){f=t[v[b+12>>2]+i|0]<<8;v[c>>2]=v[c>>2]+B(f,h);v[c+4>>2]=v[c+4>>2]+B(g,f);Lb(b+8|0,e,j);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;ab=b+16|0}function s4(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Zr(b)}xb(b);v[a+24>>2]=0;b=v[a+20>>2];if(b){xb(b);v[a+20>>2]=0}xb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,5039,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function mH(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22452]=0;c=Q(55,c|0,10667)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}lc(b,c);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(c);break b}a=v[a+32>>2]+B(b,872)|0;v[a+1075008>>2]=0;v[a+1075068>>2]=0;ab=c+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function I1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;wj(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){b=Eb(c)+ub(c)|0;v[a+44>>2]=b;d=Eb(c);Rm(a,d,d,b);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=ub(c);e=a,f=b+Eb(c)|0,v[e+44>>2]=f;Cx(c,Ec(c));d=Eb(c);dw(a,d,ub(c)+d|0);if(!(w[a+48|0]&3)){break a}while(1){if((b|0)<0){sr(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}sr(a,b)}}function zH(a,b){a=a|0;b=+b;var c=0,d=0;c=ab-16|0;ab=c;a:{b:{c:{if(b<=0|b>4){a=aa(8)|0;v[22452]=0;c=Q(55,c|0,7772)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}d=P()|0;O()|0;pb(c);break b}d=xe(65536/b);a=a+32|0;v[v[a>>2]+480244>>2]=d;bp(v[a>>2]);ab=c+16|0;return}d=P()|0;O()|0;ba(a|0)}S(d|0)}L()}function xH(a,b){a=a|0;b=+b;var c=0,d=0;c=ab-16|0;ab=c;a:{b:{c:{if(b<=0|b>4){a=aa(8)|0;v[22452]=0;c=Q(55,c|0,7793)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}d=P()|0;O()|0;pb(c);break b}d=xe(b*65536);a=a+32|0;v[v[a>>2]+480240>>2]=d;bp(v[a>>2]);ab=c+16|0;return}d=P()|0;O()|0;ba(a|0)}S(d|0)}L()}function u$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=ab-16|0;ab=f;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+24>>2];e=v[a+28>>2];if(d>>>0>=e>>>0){if((eb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{v[f+12>>2]=e-d>>2;v[f+8>>2]=c-g;e=d;d=v[jd(f+12|0,f+8|0)>>2];Uh(e,b,d);e=d<<2;v[a+24>>2]=e+v[a+24>>2];g=g+d|0;b=b+e|0}continue}break}ab=f+16|0;return g|0}function iH(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22452]=0;c=Q(55,c|0,10667)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}lc(b,c);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(c);break b}ab=c+16|0;return+(+(v[(v[a+32>>2]+B(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function cga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-16|0;ab=d;e=-1;a:{if(!tj(a,d+8|0)){break a}c=d+8|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))==(om(8949)|0)){c=c+4|0;c=((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))&-4)==256}else{c=0}e=0;if(!c){break a}c=a;a=d+12|0;e=we(c,b,(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<259?80:76,0)}c=e;ab=d+16|0;return c|0}function $ea(a){a=a|0;var b=0,c=0,d=0,e=0;e=ab-16|0;ab=e;b=pc(2500);c=ab-2496|0;ab=c;hQ(a,c,c+2496|0);a=0;while(1){if((a|0)==624){v[b+2496>>2]=0;a:{if(v[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!v[b+d>>2]){continue}break a}break}v[b>>2]=-2147483648}ab=c+2496|0}else{d=a<<2;v[d+b>>2]=v[c+d>>2];a=a+1|0;continue}break}a=v[yf(e+8|0,b)>>2];ab=e+16|0;return a|0}function oQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-32|0;ab=c;a:{if(!w[b+8|0]){while(1){if((d|0)==8){v[c+24>>2]=0;v[c+28>>2]=0;d=Zb(c+8|0,c+24|0,8);_b(c+16|0,a,v[d>>2],v[d+4>>2]);d=0;b:{if(v[c+20>>2]!=8){break b}if(Ib(c+24|0,b,8)){break b}Ob(a,8);d=1}ab=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17409,9050,413,13128);L()}ca(17388,9050,411,13128);L()}return d|0}function lH(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22452]=0;c=Q(55,c|0,10667)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}lc(b,c);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(c);break b}a=(v[a+32>>2]+B(b,872)|0)+1075080|0;v[a>>2]=v[a>>2]|2048;ab=c+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function kH(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22452]=0;c=Q(55,c|0,10667)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}lc(b,c);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(c);break b}a=(v[a+32>>2]+B(b,872)|0)+1075080|0;v[a>>2]=v[a>>2]|4096;ab=c+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function gH(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22452]=0;c=Q(55,c|0,10667)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}lc(b,c);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(c);break b}ab=c+16|0;return+(+u[(v[a+32>>2]+B(b,872)|0)+1075766>>1]*30517578125e-15)}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function CB(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){c=ab-16|0;ab=c;b=aa(16)|0;a=ab-16|0;ab=a;a:{if(t[460244]&1){break a}if(!Jd(460244)){break a}Id(460244)}Zb(a+8|0,1,89488);d=v[a+12>>2];c=c+8|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=d;ab=a+16|0;v[22452]=0;Q(1087,b|0,c|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){ia(b|0,74372,1088);L()}a=P()|0;O()|0;ba(b|0);S(a|0);L()}}function UP(a){var b=0,c=0;a:{if(Ib(a+44|0,14134,4)|w[a+28|0]!=26|w[a+30|0]>2){break a}b=a+40|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+38|0;if(((w[b|0]|w[b+1|0]<<8)-33&65535)>>>0<65504){break a}b=a+32|0;if(((w[b|0]|w[b+1|0]<<8)-257&65535)>>>0<65280){break a}b=a+34|0;if(((w[b|0]|w[b+1|0]<<8)-256&65535)>>>0<65281){break a}a=a+36|0;c=((w[a|0]|w[a+1|0]<<8)-1&65535)>>>0<128}return c}function o4(a,b){a=a|0;b=b|0;var c=0;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}xb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,5621,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function gY(){var a=0;a:{if(t[464104]&1){break a}if(!Jd(464104)){break a}a=463936;while(1){a=Bb(a)+12|0;if((a|0)!=464104){continue}break}Id(464104)}Xc(463936,5201);Xc(463948,5208);Xc(463960,5174);Xc(463972,5182);Xc(463984,5165);Xc(463996,5215);Xc(464008,5192);Xc(464020,9719);Xc(464032,9925);Xc(464044,11268);Xc(464056,12836);Xc(464068,5464);Xc(464080,10725);Xc(464092,6548)}function L7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab-16|0;ab=d;c=pc(64);v[22452]=0;e=T(811,c|0)|0;f=v[22452];v[22452]=0;a:{if((f|0)!=1){c=yf(d,e);e=v[c>>2];v[22452]=0;a=Y(873,e|0,a|0,b|0)|0;b=v[22452];v[22452]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}of(d+8|0);break b}a=P()|0;O()|0;bg(c);break a}Oh(d+8|0,c)}bg(c);ab=d+16|0;return v[d+8>>2]}a=P()|0;O()|0;xb(c)}S(a|0);L()}function h7(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function yS(a){var b=0,c=0,d=0;a:{if(Ib(a+60|0,15486,4)){break a}b=a+32|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if(w[a+49|0]<32|(w[b|0]|w[b+1|0]<<8)>>>0>255|(t[a+51|0]<4|w[a+50|0]>64)){break a}b=a+576|0;a=a- -64|0;while(1){if((a|0)==(b|0)){d=c;break a}b:{switch(w[a+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+16|0;continue}}return d&1}function gy(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,872)+a|0;v[c+1075688>>2]=0;d=c+1075e3|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075080|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,872)+a|0;v[c+1075680>>2]=0;c=v[c+1075080>>2]}d=B(b,872)+a|0;v[d+1075080>>2]=c|2097152;Ll(a,b,255,0);if(!(w[d+1075081|0]&2)){break a}a=a+1298300|0;if(!td(a)){break a}cj(v[a>>2],b,0)}}function fx(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(y[v[a+16>>2]+24620>>2]);c=C(C(C(eb[v[v[a>>2]+204>>2]](a))*b)/C(1e3));d=a,e=C(C(c*C(eb[v[v[a>>2]+196>>2]](a)))*C(2048)),z[d+4248>>2]=e;d=a,f=Ah(C(C(c+C(2))*C(4096))),v[d+4256>>2]=f;c=C(eb[v[v[a>>2]+208>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(eb[v[v[a>>2]+192>>2]](a)|0)){b=FJ(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function Hi(a,b,c,d,e){var f=0,g=0,h=0;f=ab-16|0;ab=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(Cj(a,f+8|0)){break b}g=4;h=Ak(v[a>>2]);if(!_g(d,2048,h)){break b}b=Km(d,h);while(1){c:{b=b-48|0;h=vl(a);if(!Eo(h,f+8|0)|(e|0)<2){break c}g=Ak(v[a>>2]);if(!_g(d,2048,g)){break a}e=e-1|0;b=Km(d,g)+B(b,10)|0;continue}break}g=2;if(!Cj(h,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}ab=f+16|0;return b}function Gi(a,b,c,d,e){var f=0,g=0,h=0;f=ab-16|0;ab=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(wk(a,f+8|0)){break b}g=4;h=yk(v[a>>2]);if(!xk(d,2048,h)){break b}b=Jm(d,h);while(1){c:{b=b-48|0;h=Sm(a);if(!ur(h,f+8|0)|(e|0)<2){break c}g=yk(v[a>>2]);if(!xk(d,2048,g)){break a}e=e-1|0;b=Jm(d,g)+B(b,10)|0;continue}break}g=2;if(!wk(h,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}ab=f+16|0;return b}function Bl(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return t[a+68688|0]}if(a>>>0<=511){return t[(a>>>5|0)+68688|0]+5|0}return t[(a>>>10|0)+68688|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return t[(a>>>15|0)+68688|0]+15|0}return t[(a>>>20|0)+68688|0]+20|0}if(a>>>0<=536870911){return t[(a>>>25|0)+68688|0]+25|0}a=t[(a>>>30|0)+68688|0]+30|0}else{a=0}return a}function r4(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}xb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,8887,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function AC(a,b){var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;a:{if(b>>>0<5){if(!b){break a}if(!Hb(a,b)){break a}while(1)if((d|0)==4){v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);break a}else{t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){hg(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;continue}}ca(11197,9050,136,14177);L()}ab=c+16|0;return d}function gr(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}t[a|0]=b;return(d|0)!=260}function Nha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-16|0;ab=d;a:{e=ue(a);b:{if(e>>>0>1){break b}c:{if(e){v[22452]=0;U(324,d|0,a|0,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){bm(b,d);Xb(d);break c}a=V(30480)|0;if((O()|0)!=(fa(30480)|0)){break a}_(a|0)|0;$();break b}if(!Hb(a,c)){break b}uu(a,b,c)}f=Ic(v[b>>2],v[b+4>>2])>>>0>=c>>>0}ab=d+16|0;return f|0}S(a|0);L()}function p4(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return $d(a)|0}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,12149,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();return 0}return $d(21598)|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function oh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-32|0;ab=c;a:{if(!w[b+4|0]){while(1){if((d|0)==4){d=0;v[c+28>>2]=0;e=Zb(c+8|0,c+28|0,4);_b(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=4){break b}if(Ib(c+28|0,b,4)){break b}Ob(a,4);d=1}ab=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17409,9050,413,13128);L()}ca(17388,9050,411,13128);L()}return d|0}function XK(a,b){var c=0,d=0,e=0,f=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,872)+a|0;d=w[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;c=t[c+1075785|0];d:{if((c|0)>=0){d=ie(a+901692|0,w[(B(b,872)+a|0)+1075836|0]);break d}d=ie(a+902204|0,c&127)}pM(a,e,b,f,d,c&255,0)}}function AH(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=aa(8)|0;v[22452]=0;c=Q(55,c|0,9334)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}lc(b,c);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);ab=c+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function RQ(a,b){var c=0,d=0,e=0;c=ab-32|0;ab=c;a:{if(!w[b+5|0]){while(1){if((d|0)==5){d=0;t[c+28|0]=0;v[c+24>>2]=0;e=Zb(c+8|0,c+24|0,5);_b(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=5){break b}if(Ib(c+24|0,b,5)){break b}Ob(a,5);d=1}ab=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17409,9050,413,13128);L()}ca(17388,9050,411,13128);L()}return d}function yha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,15);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0}}function x9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=b;c=ab-16|0;ab=c;d=pc(223888);v[22452]=0;b=Q(778,d|0,b+1074376|0)|0;e=v[22452];v[22452]=0;a:{if((e|0)!=1){b=v[yf(c+8|0,b)>>2];ab=c+16|0;break a}a=P()|0;O()|0;xb(d);S(a|0);L()}v[a+4>>2]=b;b=Pb(a+8|0);v[22452]=0;Z(551,a|0);c=v[22452];v[22452]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;Ud(b);fM(a+4|0);S(c|0);L()}function wn(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+810|0]=w[b+810|0]&15|c<<4;break a}c=w[b+810|0]>>>4|0;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(t[a+480180|0]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function Xfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,14);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0}}function vH(a,b){a=a|0;b=+b;var c=0,d=0;c=ab-16|0;ab=c;a:{b:{c:{if(b<0|b>1){a=aa(8)|0;v[22452]=0;c=Q(55,c|0,11726)|0;d=v[22452];v[22452]=0;if((d|0)==1){break c}lc(a,c);v[22452]=0;U(110,a|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}d=P()|0;O()|0;pb(c);break b}d=xe(b*256);v[v[a+32>>2]+1074456>>2]=d;ab=c+16|0;return}d=P()|0;O()|0;ba(a|0)}S(d|0)}L()}function mU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-16|0;ab=d;v[a>>2]=0;v[a+4>>2]=0;if(!Hb(b,c)){c=Ze(b)}v[a>>2]=c;c=v[b>>2];a:{if(eb[v[v[c>>2]+16>>2]](c)|0){c=a;a=v[b>>2];e=c,f=(eb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[e+4>>2]=f;break a}Ei(a+8|0,v[a>>2]);c=v[a+8>>2];a=v[a+12>>2];if(jc(c,a)){break a}de(d+8|0,c,a);_b(d,b,v[d+8>>2],v[d+12>>2])}ab=d+16|0}function BH(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=aa(8)|0;v[22452]=0;c=Q(55,c|0,5809)|0;a=v[22452];v[22452]=0;if((a|0)==1){break c}lc(b,c);v[22452]=0;U(110,b|0,58760,928);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(c);break b}v[v[a+32>>2]+1074416>>2]=b;ab=c+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function yC(a){var b=0,c=0,d=0,e=0;a:{b:{if(Ib(a,11060,2)){if(Ib(a,13753,2)){break a}if(w[a+110|0]<=64){break b}break a}if(w[a+110|0]>64){break a}}if(t[a+112|0]<0|w[a+111|0]>128){break a}while(1){if((b|0)==128){return 1}c=a+b|0;d=t[c+113|0];if((d|0)<-2){break a}e=w[c+241|0];if(!e&(d|0)>=0|e>>>0>15){break a}b=b+1|0;if(w[c+369|0]<64){continue}break}}return 0}function pF(a,b,c,d){var e=0,f=0,g=0;e=ab-16|0;ab=e;a:{if((a|0)!=(b|0)){g=v[114934];v[114934]=0;gd();d=vF(a,e+12|0,d);a=db;f=v[114934];b:{if(f){if(v[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}v[c>>2]=4;a=!!d&(a|0)>=0|(a|0)>0;d=a?-1:0;a=a?2147483647:-2147483648;break a}v[114934]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0}ab=e+16|0;db=a;return d}function HM(a,b,c,d){var e=0,f=0,g=0;e=ab-16|0;ab=e;f=!d|y[c+20>>2]<2?f:v[b+480180>>2]==1;g=v[c+52>>2];d=!g|d;t[e+15|0]=d;a:{if(!d|v[b+480180>>2]!=2){break a}b=x[b+480188>>1];d=0;while(1){if((b|0)==(d|0)){break a}v[(B(d,872)+c|0)+1380>>2]=0;d=d+1|0;continue}}v[c+24>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+48>>2]=g;u[c+72>>1]=x[c+74>>1];Vs(a,f,e+15|0);ab=e+16|0}function o6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ci(a,b,c,d);v[a>>2]=45296;c=Pb(a+4256|0);d=a+4224|0;v[d>>2]=1017370378;v[d+4>>2]=1065353216;d=a+4216|0;v[d>>2]=1028670828;v[d+4>>2]=1059760811;v[a+4208>>2]=1056964608;v[a+4212>>2]=1017370378;v[22452]=0;R(875,a+44|0,2);d=v[22452];v[22452]=0;if((d|0)!=1){bi(b);return a|0}a=P()|0;O()|0;ec(c);ff(b);S(a|0);L()}function et(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;oia(b,0,a,0);a=db?0:B(a,b)}else{a=0}a:{if(!a){break a}v[22452]=0;b=T(724,a|0)|0;c=v[22452];v[22452]=0;b:{c:{if((c|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;X(17);c=v[22452];v[22452]=0;b=0;if((c|0)==1){break c}}break b}V(0)|0;O()|0;Gb();L()}if(!b){break a}d=Jb(b,0,a)- -64|0}return d}function V2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22452]=0;Z(924,a|0);f=v[22452];v[22452]=0;if((f|0)!=1){return Ww(v[a+24>>2],b,c,d,e)|0}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,12392,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function TB(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=w[b|0]|w[b+1|0]<<8;c=oia(w[a+3|0],0,18,0);d=d+c|0;b=db;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=w[b|0]|w[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=w[a|0]|w[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;a=b>>>0<3?a+1|0:a;db=a;return b}function zo(a,b,c){var d=0,e=0,f=0;e=ab-16|0;ab=e;d=e+8|0;zc(d,b);v[22452]=0;b=T(1112,d|0)|0;d=v[22452];v[22452]=0;a:{if((d|0)==1){break a}v[22452]=0;d=T(1121,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break a}v[c>>2]=d;v[22452]=0;R(1122,a|0,b|0);a=v[22452];v[22452]=0;if((a|0)==1){break a}Nb(e+8|0);ab=e+16|0;return}a=P()|0;O()|0;Nb(e+8|0);S(a|0);L()}function _fa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=wb(v[b>>2]);g=wb(v[b+4>>2]);d=ab-16|0;ab=d;v[d>>2]=c;v[d+8>>2]=e;while(1){a:{b:{if(Tb(e,g)){c=ab-16|0;ab=c;f=c+8|0;VR(f,e);ab=c+16|0;if(v[d>>2]!=(w[f|0]|w[f+1|0]<<8)){break b}e=v[d+8>>2]}ab=d+16|0;c=e;break a}em(d+8|0);e=v[d+8>>2];continue}break}if(jc(c,wb(v[b+4>>2]))){Nh(a);return}gm(a,c)}function KP(a,b){var c=0,d=0,e=0;c=ab-32|0;ab=c;a:{if(!w[b+4|0]){while(1){if((d|0)==4){d=0;v[c+28>>2]=0;e=Zb(c+8|0,c+28|0,4);$c(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=4){break b}if(Ib(c+28|0,b,4)){break b}Rc(a,4);d=1}ab=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17409,9050,413,13128);L()}ca(17388,9050,411,13128);L()}return d}function D_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=v[a+84>>2];f=v[e>>2];d=v[e+4>>2];h=v[a+28>>2];g=v[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){gc(f,h,g);f=g+v[e>>2]|0;v[e>>2]=f;d=v[e+4>>2]-g|0;v[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){gc(f,b,d);f=d+v[e>>2]|0;v[e>>2]=f;v[e+4>>2]=v[e+4>>2]-d}t[f|0]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;return c|0}function s1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;a:{b:{if((Qw(a)|0)!=1){break b}if((xI(a)|0)!=(b|0)){break b}d=a+120|0;Xh(d);b=ab-16|0;ab=b;v[b+8>>2]=c+8;a=ab-16|0;ab=a;e=v[13467];v[a+8>>2]=v[13466];v[a+12>>2]=e;e=v[13465];v[a>>2]=v[13464];v[a+4>>2]=e;eb[v[yh(a,Ig(w[d+20|0]))>>2]](b+8|0,d);ab=a+16|0;ab=b+16|0;break a}wI(a,1,b)}ab=c+16|0}function eK(a,b){var c=0,d=0,e=0,f=0,g=0,h=C(0);c=ab-16|0;ab=c;d=0;a:{if(!uh(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;Xj(a,c+12|0);e=v[c+12>>2];d=0;if(e>>>0>65535){break a}Ij(b,e);while(1){if((f|0)==(e|0)){d=uh(v[v[a>>2]-12>>2]+a|0)}else{v[c+8>>2]=0;Vo(a,c+8|0);g=Fb(v[b>>2],f),h=z[c+8>>2],z[g>>2]=h;f=f+1|0;continue}break}}a=d;ab=c+16|0;return a}function Yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-16|0;ab=d;v[d+12>>2]=c;a:{e=Hb(b,c<<2);if(!e){break a}mc(d+12|0,65535);mf(a,x[d+12>>1]);c=wb(v[a>>2]);v[d>>2]=c;a=wb(v[a+4>>2]);while(1){if(!Tb(c,a)){break a}f=d+8|0;if(!lo(b,f)){im(f)}u[c>>1]=w[d+8|0]|w[d+9|0]<<8|(w[d+10|0]<<16|w[d+11|0]<<24);Ke(d);c=v[d>>2];continue}}ab=d+16|0;return e|0}function Bo(a,b,c){var d=0,e=0,f=0;e=ab-16|0;ab=e;d=e+8|0;zc(d,b);v[22452]=0;b=T(1094,d|0)|0;d=v[22452];v[22452]=0;a:{if((d|0)==1){break a}v[22452]=0;d=T(1107,b|0)|0;f=v[22452];v[22452]=0;if((f|0)==1){break a}t[c|0]=d;v[22452]=0;R(1108,a|0,b|0);a=v[22452];v[22452]=0;if((a|0)==1){break a}Nb(e+8|0);ab=e+16|0;return}a=P()|0;O()|0;Nb(e+8|0);S(a|0);L()}function zU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab-16|0;ab=d;c=-1;a:{if(!Qf(a,7)){break a}c=0;if(!VB(a,11748)){break a}c=ab-16|0;ab=c;SB(c+8|0,d);e=v[c+12>>2];$c(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Rc(a,v[c+12>>2])}ab=c+16|0;e=(e|0)==(f|0);if(!e){RB(d)}c=-1;if(!e){break a}c=0;if(!UB(d)){break a}c=we(a,b,TB(d),db)}ab=d+16|0;return c|0}function tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ab-32|0;ab=e;RA(e+8|0,c);v[22452]=0;R(352,e+20|0,d|0);c=v[22452];v[22452]=0;b:{c:{if((c|0)!=1){Di(e,e+8|0);v[22452]=0;W(105,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22452];v[22452]=0;if((a|0)==1){break c}qf(e+8|0);ab=e+32|0;break a}a=P()|0;O()|0;pb(e+8|0);break b}a=P()|0;O()|0;qf(e+8|0)}S(a|0);L()}}function qfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ab-32|0;ab=e;ph(e+8|0,c);v[22452]=0;R(541,e+20|0,d|0);c=v[22452];v[22452]=0;b:{c:{if((c|0)!=1){Di(e,e+8|0);v[22452]=0;W(289,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22452];v[22452]=0;if((a|0)==1){break c}qf(e+8|0);ab=e+32|0;break a}a=P()|0;O()|0;pb(e+8|0);break b}a=P()|0;O()|0;qf(e+8|0)}S(a|0);L()}}function gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ab-32|0;ab=e;Hm(e+8|0,c);v[22452]=0;R(130,e+20|0,d|0);c=v[22452];v[22452]=0;b:{c:{if((c|0)!=1){Di(e,e+8|0);v[22452]=0;W(105,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22452];v[22452]=0;if((a|0)==1){break c}qf(e+8|0);ab=e+32|0;break a}a=P()|0;O()|0;pb(e+8|0);break b}a=P()|0;O()|0;qf(e+8|0)}S(a|0);L()}}function Y8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=ab-16|0;ab=b;u[a>>1]=0;c=Pb(a+4|0);d=Pb(a+16|0);v[a+36>>2]=0;e=Bb(a+40|0);f=Rg(a+52|0);uc(c);u[a+28>>1]=65472;v[22452]=0;v[b+12>>2]=1065353216;R(815,c|0,b+12|0);g=v[22452];v[22452]=0;if((g|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;uc(d);ab=b+16|0;return a|0}a=P()|0;O()|0;eS(f);pb(e);ec(d);ec(c);S(a|0);L()}function Vx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=ab-16|0;ab=d;e=hi(b,c);a:{if(e>>>0<=Do(a)>>>0){f=c;g=v[a>>2];h=Ic(g,v[a+4>>2]);i=h>>>0>=e>>>0;if(!i){v[d+12>>2]=b;v[d+12>>2]=v[d+12>>2]+h;g=v[a>>2];f=v[d+12>>2]}b=Ci(b,f,g);if(!i){Gt(a,f,c,e-Ic(v[a>>2],v[a+4>>2])|0);break a}Hd(a,b);break a}SA(a);kl(a,ul(a,e));Gt(a,b,c,e)}ab=d+16|0}function Qga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ab-32|0;ab=e;Hm(e+8|0,c);v[22452]=0;R(104,e+20|0,d|0);c=v[22452];v[22452]=0;b:{c:{if((c|0)!=1){Di(e,e+8|0);v[22452]=0;W(105,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22452];v[22452]=0;if((a|0)==1){break c}qf(e+8|0);ab=e+32|0;break a}a=P()|0;O()|0;pb(e+8|0);break b}a=P()|0;O()|0;qf(e+8|0)}S(a|0);L()}}function P4(a){a=a|0;var b=0,c=0,d=0,e=0;b=ab-32|0;ab=b;a=Pb(a);v[22452]=0;Z(914,b+16|0);c=v[22452];v[22452]=0;a:{b:{if((c|0)!=1){c=wb(v[b+16>>2]);d=wb(v[b+20>>2]);e=v[$b(b+8|0,a)>>2];v[22452]=0;U(915,c|0,d|0,e|0);c=v[22452];v[22452]=0;if((c|0)==1){break b}ec(b+16|0);ab=b+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;ec(b+16|0)}Uc(a);S(c|0);L()}function Oga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ab-32|0;ab=e;RA(e+8|0,c);v[22452]=0;R(421,e+20|0,d|0);c=v[22452];v[22452]=0;b:{c:{if((c|0)!=1){Di(e,e+8|0);v[22452]=0;W(105,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22452];v[22452]=0;if((a|0)==1){break c}qf(e+8|0);ab=e+32|0;break a}a=P()|0;O()|0;pb(e+8|0);break b}a=P()|0;O()|0;qf(e+8|0)}S(a|0);L()}}function wU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ab-32|0;ab=e;wu(e+8|0,c);v[22452]=0;R(237,e+20|0,d|0);c=v[22452];v[22452]=0;b:{c:{if((c|0)!=1){Di(e,e+8|0);v[22452]=0;W(105,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22452];v[22452]=0;if((a|0)==1){break c}qf(e+8|0);ab=e+32|0;break a}a=P()|0;O()|0;pb(e+8|0);break b}a=P()|0;O()|0;qf(e+8|0)}S(a|0);L()}}function w9(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[vb(a)>>2]){c=ab-16|0;ab=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+32;TL(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;dc(c);ab=c+16|0;return}d=ab-32|0;ab=d;c=vb(a);c=bt(d+8|0,Bp(a,$f(v[a>>2],v[a+4>>2])+1|0),$f(v[a>>2],v[a+4>>2]),c);TL(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;rd(a,c);UO(c);ab=d+32|0}function oW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ab-32|0;ab=e;ph(e+8|0,c);v[22452]=0;R(104,e+20|0,d|0);c=v[22452];v[22452]=0;b:{c:{if((c|0)!=1){Di(e,e+8|0);v[22452]=0;W(105,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22452];v[22452]=0;if((a|0)==1){break c}qf(e+8|0);ab=e+32|0;break a}a=P()|0;O()|0;pb(e+8|0);break b}a=P()|0;O()|0;qf(e+8|0)}S(a|0);L()}}function lu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ab-32|0;ab=e;AB(e+8|0,c);v[22452]=0;R(104,e+20|0,d|0);c=v[22452];v[22452]=0;b:{c:{if((c|0)!=1){Di(e,e+8|0);v[22452]=0;W(105,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22452];v[22452]=0;if((a|0)==1){break c}qf(e+8|0);ab=e+32|0;break a}a=P()|0;O()|0;pb(e+8|0);break b}a=P()|0;O()|0;qf(e+8|0)}S(a|0);L()}}function l2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22452]=0;Z(924,a|0);d=v[22452];v[22452]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,13013,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function zC(a,b){var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;a:{if(b>>>0<3){if(!b){break a}if(!Hb(a,b)){break a}while(1)if((d|0)==2){u[c+10>>1]=x[c+14>>1];a=c+10|0;d=w[a|0]|w[a+1|0]<<8;break a}else{t[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){hg(a,c+13|0);e=w[c+13|0]}else{e=0}t[f|0]=e;d=d+1|0;continue}}ca(11197,9050,136,14177);L()}ab=c+16|0;return d&65535}function xj(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e307;if(b>>>0<2047){b=b-1023|0;break a}a=a*8.98846567431158e307;b=(b>>>0<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.004168360008973e-292;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2.004168360008973e-292;b=(b>>>0>4294964336?b:-2960)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function vn(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+810|0];if(c){t[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(t[a+480180|0]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function As(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=ab-16|0;ab=e;a:{if(!b){break a}rb(e+8|0,a+1074312|0,73);j=sb(v[v[e+8>>2]>>2],v[e+12>>2])?c- -64|0:c;c=120;h=_i(a);k=h^-1;f=1;while(1){if(!c){break a}l=c;c=c>>>1|0;i=f+c|0;g=Kg(a,i,j,d);if(!(g>>>0>b>>>0&k)&(!(!g|h)|b>>>0<=g>>>0)){continue}f=i+1|0;c=(c^-1)+l|0;continue}}ab=e+16|0;return f}function tv(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if((d|0)!=1){break a}if(v[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function qu(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if(!(w[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=42;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=42;t[b|0]=w[d|0]}t[c|0]=0}}function wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ab-32|0;ab=d;e=Pb(a);a=wb(v[b>>2]);v[d+24>>2]=a;b=wb(v[b+4>>2]);a:{while(1){if(Tb(a,b)){qi(d,a);if((GT(d)|0)==(c|0)){gm(d,a);v[22452]=0;R(349,e|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break a}qb(d)}em(d+24|0);a=v[d+24>>2];continue}break}ab=d+32|0;return}a=P()|0;O()|0;qb(d);Yc(e);S(a|0);L()}function vx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=ab-16|0;ab=e;d=ab-16|0;ab=d;i=x[b>>1];c=Kd(a);f=ac(a);g=ab-16|0;ab=g;while(1){if(c){h=lK(c+16|0,i);f=h?f:c;c=v[(h?4:0)+c>>2];continue}break}c=v[$b(g+8|0,f)>>2];ab=g+16|0;v[d+8>>2]=c;a:{if(Tb(c,Jf(a))){if(!mK(x[b>>1],id(d+8|0))){break a}}c=Jf(a)}ab=d+16|0;a=v[$b(e+8|0,c)>>2];ab=e+16|0;return a}function OH(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=eb[a|0](b)|0;d=db;if((d|0)<0){break b}if((eb[c|0](b,0,0,0)|0)<0){break a}if((eb[c|0](b,0,0,2)|0)<0){break a}f=eb[a|0](b)|0;a=db;eb[c|0](b,e,d,0)|0;if((a|0)<0){break b}g=Dy(f,a)}return g}eb[c|0](b,e,d,0)|0;return 0}function Tda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-16|0;ab=d;c=d+11|0;eQ(a,c);if(Ib(c,13553,4)){a=1}else{eQ(a,d+11|0);t[b|0]=1;a=0}c=ab-16|0;ab=c;a:{b:{a=(d+11|0)+a|0;c:{if(!a){a=0;break c}b=Mb(c,a);v[22452]=0;a=T(623,b|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break b}pb(b)}ab=c+16|0;break a}a=P()|0;O()|0;pb(b);S(a|0);L()}ab=d+16|0;return a|0}function jaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=ab-32|0;ab=d;qA(d+8|0,c);v[22452]=0;R(421,d+20|0,43372);c=v[22452];v[22452]=0;b:{c:{if((c|0)!=1){Di(d,d+8|0);v[22452]=0;W(105,a|0,b|0,v[d>>2],v[d+4>>2]);a=v[22452];v[22452]=0;if((a|0)==1){break c}qf(d+8|0);ab=d+32|0;break a}a=P()|0;O()|0;pb(d+8|0);break b}a=P()|0;O()|0;qf(d+8|0)}S(a|0);L()}}function iq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=wb(v[b>>2]);g=wb(v[b+4>>2]);e=ab-16|0;ab=e;v[e>>2]=c;v[e+8>>2]=d;while(1){a:{b:{if(Tb(d,g)){c=ab-16|0;ab=c;f=c+8|0;qi(f,d);d=GT(f);ab=c+16|0;if(v[e>>2]!=(d|0)){break b}d=v[e+8>>2]}ab=e+16|0;c=d;break a}em(e+8|0);d=v[e+8>>2];continue}break}if(jc(c,wb(v[b+4>>2]))){Nh(a);return}gm(a,c)}function uQ(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=w[b|0]|w[b+1|0]<<8;b=oia(w[a+30|0],0,37,0);c=db;d=b;b=a+24|0;b=oia(w[b|0]|w[b+1|0]<<8,0,192,0);d=d+b|0;c=db+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;a=w[a+26|0];c=a>>>26|0;e=d;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;a=b>>>0<192?a+1|0:a;db=a;return b}function ej(a){var b=0,c=0,d=0,e=0;b=v[a+4>>2];if(jc(v[a>>2],b)){a=0}else{b=bO(b);d=bO(v[a>>2]);c=ab-16|0;ab=c;v[c+8>>2]=b;while(1){a:{b:{if(Tb(b,d)){b=ab-16|0;ab=b;v[b+8>>2]=v[c+8>>2];e=aO(b+8|0);ab=b+16|0;if(x[v[e>>2]>>1]==65535){break b}b=v[c+8>>2]}ab=c+16|0;break a}aO(c+8|0);b=v[c+8>>2];continue}break}a=hB(wb(v[a>>2]),b)}return a&65535}function iI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Dk(v[a+8>>2]);Xh(f);e=ab-16|0;ab=e;v[e+8>>2]=d+8;c=ab-16|0;ab=c;g=v[13701];v[c+8>>2]=v[13700];v[c+12>>2]=g;g=v[13699];v[c>>2]=v[13698];v[c+4>>2]=g;eb[v[yh(c,Ig(w[f+20|0]))>>2]](e+8|0,f);ab=c+16|0;ab=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];ab=d+16|0}function hI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Dk(v[a+8>>2]);Xh(f);e=ab-16|0;ab=e;v[e+8>>2]=d+8;c=ab-16|0;ab=c;g=v[13705];v[c+8>>2]=v[13704];v[c+12>>2]=g;g=v[13703];v[c>>2]=v[13702];v[c+4>>2]=g;eb[v[yh(c,Ig(w[f+20|0]))>>2]](e+8|0,f);ab=c+16|0;ab=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];ab=d+16|0}function eI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Dk(v[a+8>>2]);Xh(f);e=ab-16|0;ab=e;v[e+8>>2]=d+8;c=ab-16|0;ab=c;g=v[13906];v[c+8>>2]=v[13905];v[c+12>>2]=g;g=v[13904];v[c>>2]=v[13903];v[c+4>>2]=g;eb[v[yh(c,Ig(w[f+20|0]))>>2]](e+8|0,f);ab=c+16|0;ab=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];ab=d+16|0}function dI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Dk(v[a+8>>2]);Xh(f);e=ab-16|0;ab=e;v[e+8>>2]=d+8;c=ab-16|0;ab=c;g=v[13910];v[c+8>>2]=v[13909];v[c+12>>2]=g;g=v[13908];v[c>>2]=v[13907];v[c+4>>2]=g;eb[v[yh(c,Ig(w[f+20|0]))>>2]](e+8|0,f);ab=c+16|0;ab=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];ab=d+16|0}function bI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Dk(v[a+8>>2]);Xh(f);e=ab-16|0;ab=e;v[e+8>>2]=d+8;c=ab-16|0;ab=c;g=v[14113];v[c+8>>2]=v[14112];v[c+12>>2]=g;g=v[14111];v[c>>2]=v[14110];v[c+4>>2]=g;eb[v[yh(c,Ig(w[f+20|0]))>>2]](e+8|0,f);ab=c+16|0;ab=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];ab=d+16|0}function aI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Dk(v[a+8>>2]);Xh(f);e=ab-16|0;ab=e;v[e+8>>2]=d+8;c=ab-16|0;ab=c;g=v[14117];v[c+8>>2]=v[14116];v[c+12>>2]=g;g=v[14115];v[c>>2]=v[14114];v[c+4>>2]=g;eb[v[yh(c,Ig(w[f+20|0]))>>2]](e+8|0,f);ab=c+16|0;ab=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];ab=d+16|0}function YH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Dk(v[a+8>>2]);Xh(f);e=ab-16|0;ab=e;v[e+8>>2]=d+8;c=ab-16|0;ab=c;g=v[14320];v[c+8>>2]=v[14319];v[c+12>>2]=g;g=v[14318];v[c>>2]=v[14317];v[c+4>>2]=g;eb[v[yh(c,Ig(w[f+20|0]))>>2]](e+8|0,f);ab=c+16|0;ab=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];ab=d+16|0}function XH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Dk(v[a+8>>2]);Xh(f);e=ab-16|0;ab=e;v[e+8>>2]=d+8;c=ab-16|0;ab=c;g=v[14324];v[c+8>>2]=v[14323];v[c+12>>2]=g;g=v[14322];v[c>>2]=v[14321];v[c+4>>2]=g;eb[v[yh(c,Ig(w[f+20|0]))>>2]](e+8|0,f);ab=c+16|0;ab=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];ab=d+16|0}function K6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=ci(a,b,c,d);v[a>>2]=45040;d=Pb(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=1056964608;b=a+4228|0;t[b+4|0]=0;t[b+5|0]=4;t[b|0]=69;t[b+1|0]=99;t[b+2|0]=104;t[b+3|0]=111;t[b+6|0]=1;v[22452]=0;R(875,a+44|0,2);b=v[22452];v[22452]=0;if((b|0)!=1){bi(c);hs(a);return a|0}a=P()|0;O()|0;ec(d);ff(c);S(a|0);L()}function d2(a,b){a=a|0;b=b|0;var c=0;v[22452]=0;Z(924,a|0);c=v[22452];v[22452]=0;if((c|0)!=1){v[v[v[a+24>>2]+24>>2]+480272>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,5745,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function UW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=ab+-64|0;ab=e;d=1;a:{if(Bg(a,b,0)){break a}d=0;if(!b){break a}b=py(b,88060,88108);d=0;if(!b){break a}d=e+8|0;Jb(d|4,0,52);v[e+56>>2]=1;v[e+20>>2]=-1;v[e+16>>2]=a;v[e+8>>2]=b;eb[v[v[b>>2]+28>>2]](b,d,v[c>>2],1);a=v[e+32>>2];if((a|0)==1){v[c>>2]=v[e+24>>2]}d=(a|0)==1}ab=e- -64|0;return d|0}function Hha(a){a=a|0;var b=0,c=0,d=0;c=sd(a);v[22452]=0;Z(333,a|0);b=v[22452];v[22452]=0;if((b|0)==1){a=P()|0;O()|0;ec(c);S(a|0);L()}b=ab-16|0;ab=b;v[b>>2]=a;c=v[a+4>>2];v[b+4>>2]=c;v[b+8>>2]=c+32768;d=v[b+4>>2];c=v[b+8>>2];while(1){if((c|0)==(d|0)){dc(b);ab=b+16|0}else{u[d>>1]=0;u[d+2>>1]=0;d=d+4|0;v[b+4>>2]=d;continue}break}return a|0}function Py(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function tp(a){var b=0,c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;d=wb(v[a>>2]);e=a;f=wb(v[a+4>>2]);a=ab-16|0;ab=a;v[a+8>>2]=d;while(1){if(Tb(d,f)){b=b+A[d>>3];Qs(a+8|0);d=v[a+8>>2];continue}break}ab=a+16|0;a=wb(v[e>>2]);v[c+8>>2]=a;b=-b;e=wb(v[e+4>>2]);while(1){if(Tb(a,e)){b=b+A[a>>3];A[a>>3]=b;Qs(c+8|0);a=v[c+8>>2];continue}else{ab=c+16|0}break}}function rV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ab-32|0;ab=e;f=v[b+16>>2];a:{if(f>>>0<=c>>>0){Ub(a,v[d>>2],0);break a}g=v[b+12>>2];b=v[b+4>>2];v[e+20>>2]=v[d+4>>2];v[e+16>>2]=f-c;Ub(e+24|0,v[d>>2],v[zb(e+20|0,e+16|0)>>2]);d=v[v[b>>2]+28>>2];f=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=f;eb[d|0](a,b,c+g|0,e+8|0)}ab=e+32|0}function pp(a,b){a=a|0;b=b|0;var c=0,d=0;d=ab-16|0;ab=d;t[d+15|0]=b;a:{b:{c:{d:{if(me(a)){c=gk(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=10;b=w[a+11|0];if((b|0)!=10){break c}}Kl(a,c,1,c,c,0,0);b=c;if(me(a)){break b}}c=a;ye(a,b+1|0);break a}c=v[a>>2];Qd(a,b+1|0)}a=b+c|0;md(a,d+15|0);t[d+14|0]=0;md(a+1|0,d+14|0);ab=d+16|0}function k2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22452]=0;Z(924,a|0);d=v[22452];v[22452]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:905;return}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,13043,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function PF(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=ab-16|0;ab=b;e=b+16|0;a:{while(1){d=v[a+36>>2];c=b+8|0;f=eb[v[v[d>>2]+20>>2]](d,v[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=v[b+4>>2]-c|0;if((bk(g,1,c,v[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=$r(v[a+32>>2])?-1:0}ab=b+16|0;return d|0}function FX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=ab-16|0;ab=g;k=Sh(g+8|0,v[a+8>>2]);i=lr(0,c,d-c|0,b?b:463484);Rh(k);ab=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function t9(a,b){a=a|0;b=b|0;var c=0,d=0;d=ab-16|0;ab=d;t[d+15|0]=b;a:{b:{c:{d:{if(me(a)){c=gk(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=10;b=w[a+11|0];if((b|0)!=10){break c}}sy(a,c,1,c,c,0);b=c;if(me(a)){break b}}c=a;ye(a,b+1|0);break a}c=v[a>>2];Qd(a,b+1|0)}a=b+c|0;md(a,d+15|0);t[d+14|0]=0;md(a+1|0,d+14|0);ab=d+16|0}function oR(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=ab-16|0;ab=d;e=$z(b,c);a:{if(e>>>0<=Ch(a)>>>0){f=c;g=v[a>>2];h=nc(g,v[a+4>>2]);i=h>>>0>=e>>>0;if(!i){v[d+12>>2]=b;v[d+12>>2]=v[d+12>>2]+(h<<2);g=v[a>>2];f=v[d+12>>2]}b=Ci(b,f,g);if(!i){_z(a,f,c,e-nc(v[a>>2],v[a+4>>2])|0);break a}Hd(a,b);break a}Zz(a);$n(a,fh(a,e));_z(a,b,c,e)}ab=d+16|0}function SE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=ab-16|0;ab=e;d=ac(a);i=v[b>>2];h=v[a>>2];d=v[d>>2]==1133;f=v[c>>2]-v[a>>2]|0;g=f<<1;f=f>>>0<2147483647?g?g:4:-1;g=Ar(d?0:h,f);if(g){if(!d){Pd(a)}v[e+4>>2]=1098;d=ee(e+8|0,g,e+4|0);a=PE(a,d);Bc(d);v[b>>2]=v[a>>2]+(i-h|0);v[c>>2]=v[a>>2]+(f&-4);ab=e+16|0;return}Rv();L()}function r3(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return y[v[v[a+24>>2]+24>>2]+1074420>>2]/1e4|0}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,9301,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function gaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=ab-32|0;ab=e;v[e+24>>2]=d;c=cf(a,c);Xd(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;f=a;a:{if(!c){d=0;if(Vc(a,5)){break a}}d=v[a+28>>2];a=0;gC(b,v[e+24>>2]);while(1){if(y[e+24>>2]>a>>>0){TN(d,Yb(v[b>>2],a));a=a+1|0;continue}break}d=c}Te(f,d,e+16|0);ab=e+32|0}function bK(a){var b=0,c=0,d=0;c=ab-32|0;ab=c;a:{d=qx(a);b=sj(v[a>>2],v[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}v[22452]=0;b=da(879,c+8|0,b|0,b|0,vb(a)|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){rd(a,b);_J(b);break b}a=V(0)|0;O()|0;_(a|0)|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)==1){break a}}ab=c+32|0;return}V(0)|0;O()|0;Gb();L()}function aK(a){var b=0,c=0,d=0;c=ab-32|0;ab=c;a:{d=Ch(a);b=nc(v[a>>2],v[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}v[22452]=0;b=da(880,c+8|0,b|0,b|0,vb(a)|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){rd(a,b);Zf(b);break b}a=V(0)|0;O()|0;_(a|0)|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)==1){break a}}ab=c+32|0;return}V(0)|0;O()|0;Gb();L()}function Qea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab+-64|0;ab=c;b=-1;a:{if(!(eb[v[v[a>>2]+32>>2]](a,0,1084)|0)){break a}Zk(a,1080);d=c+60|0;_Q(a,d);e=d;d=ZQ(c+40|0);b=0;if(!YQ(e,d)){break a}Zk(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=y[d+4>>2]>=f>>>0}else{e=c+8|0;XQ(a,e);b=b+1|0;f=Qz(e)+f|0;continue}break}}ab=c- -64|0;return b|0}function FQ(a){var b=0,c=0;a:{if(Ib(a,15456,4)){break a}b=a+8|0;if(((w[b|0]|w[b+1|0]<<8)-768&65535)>>>0<65280){break a}b=a+112|0;if(((w[b|0]|w[b+1|0]<<8)-65&65535)>>>0<65472){break a}b=a+106|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+124|0;c=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return c}function g3(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return ej(Kb(v[v[a+24>>2]+24>>2]+484360|0))|0}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,6846,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function Yn(a,b,c,d,e){var f=0,g=0,h=0;f=ab-16|0;ab=f;a:{while(1){g=h&255;if(g>>>0<=3){if(lq(b,c,g>>>0>1)){t[f+15|0]=0;Vs(a,0,f+15|0);break a}else{Tg(b,d);Tg(c,e);h=h+1|0;continue}}break}h=f+12|0;g=w[b|0];if(ti(g)>>>0>ti(w[d|0])>>>0){Tg(b,d);Tg(c,e);g=w[b|0]}Vs(h,g,c);t[b|0]=0;t[c|0]=0;b=x[f+12>>1];t[a|0]=b;t[a+1|0]=b>>>8}ab=f+16|0}function G0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(w[b+40|0]){break a}d=v[b+28>>2];if(!d){t[b+40|0]=1;break a}b:{e=v[c+4>>2];if(!e){break b}f=v[c>>2];while(1){d=eb[d|0](v[b+24>>2],f,e)|0;if(!d){t[b+40|0]=1;break b}g=d+g|0;h=g>>>0<d>>>0?h+1|0:h;e=e-d|0;if(!e){break b}f=d+f|0;d=v[b+28>>2];continue}}e=g}Ub(a,v[c>>2],e)}function faa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-32|0;ab=d;f=cf(a,c);c=d+8|0;Xd(c,v[a+28>>2]);e=v[c+12>>2];v[d+24>>2]=v[c+8>>2];v[d+28>>2]=e;a:{b:{if(!f){c=0;e=-1;if(!Vc(a,5)){break b}break a}e=v[f+8>>2]}c=v[a+28>>2];c:{d:{switch(e+1|0){case 0:case 2:Wh(c,b);break c;default:break d}}aS(c,b,e)}c=f}Te(a,c,d+24|0);ab=d+32|0}function SU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=ab-512|0;ab=d;c=ab-16|0;ab=c;f=d+8|0;wC(c+8|0,f);e=v[c+12>>2];$c(c,a,v[c+8>>2],e);g=v[c+4>>2];if((g|0)==(e|0)){Rc(a,v[c+12>>2])}ab=c+16|0;e=(e|0)==(g|0);if(!e){vC(f)}c=-1;a:{if(!e){break a}c=0;if(!yC(d+8|0)){break a}c=we(a,b,xC(w[d+118|0],w[d+119|0]),db)}ab=d+512|0;return c|0}function qZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=ab-16|0;ab=e;d=ac(a);i=v[b>>2];h=v[a>>2];d=v[d>>2]==1133;f=v[c>>2]-v[a>>2]|0;g=f<<1;f=f>>>0<2147483647?g?g:1:-1;g=Ar(d?0:h,f);if(g){if(!d){Pd(a)}v[e+4>>2]=1098;d=ee(e+8|0,g,e+4|0);a=PE(a,d);Bc(d);v[b>>2]=v[a>>2]+(i-h|0);v[c>>2]=f+v[a>>2];ab=e+16|0;return}Rv();L()}function z0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;a:{if(!v[b+28>>2]){break a}if((eb[v[b+32>>2]](v[b+24>>2],c,0,0)|0)<0){break a}c=v[d+4>>2];if(!c){break a}e=v[d>>2];while(1){b:{f=eb[v[b+28>>2]](v[b+24>>2],e,c)|0;g=f+g|0;h=g>>>0<f>>>0?h+1|0:h;if(!f){break b}e=e+f|0;c=c-f|0;if(c){continue}}break}e=g}Ub(a,v[d>>2],e)}function s3(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return v[v[v[a+24>>2]+24>>2]+1074416>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,12771,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function e3(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return Ps(v[v[a+24>>2]+24>>2]+484344|0)|0}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,6914,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function CJ(a){a=a|0;var b=0,c=0;c=ab-16|0;ab=c;b=v[v[a+16>>2]+24620>>2]/5|0;b=vc(b,b>>31);v[a+4272>>2]=b;v[22452]=0;v[c+12>>2]=0;U(881,a+4256|0,b<<1,c+12|0);b=v[22452];v[22452]=0;a:{if((b|0)==1){b=V(88408)|0;if((O()|0)!=(fa(88408)|0)){break a}_(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;ab=c+16|0;return}S(b|0);L()}function w3(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return x[v[v[a+24>>2]+24>>2]+1074448>>1]}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,8767,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function t3(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return v[v[v[a+24>>2]+24>>2]+1074424>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,5280,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function ed(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;Xl(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;d=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?d|32:d;b=Mb(c,21598);ke(a+43|0,b);pb(b);aP(a);ab=c+16|0}function u3(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return x[v[v[a+24>>2]+24>>2]+480214>>1]}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,7071,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function YL(a,b,c,d){var e=0,f=0,g=0,h=0;e=ab-16|0;ab=e;a:{b:{while(1){v[e+12>>2]=b;v[e+8>>2]=d;if(y[zb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=gp(t[Cb(a,f)|0]);h=gp(t[Cb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}ab=e+16|0;return a}function VH(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a>>2];a:{if(!b){break a}c=v[a+8>>2];if(!c){break a}d=v[a+12>>2];if(!d){break a}e=eb[d|0](b)|0;a=db;f=a;if((a|0)<0){break a}a=0;b:{if((eb[c|0](b,0,0,0)|0)<0){break b}a=0;if((eb[c|0](b,0,0,2)|0)<0){break b}eb[d|0](b)|0;a=db;a=(a|0)>0|(a|0)>=0}g=a;eb[c|0](b,e,f,0)|0}return g|0}function R2(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return v[v[v[a+24>>2]+24>>2]+480272>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,5777,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function sw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=ab-240|0;ab=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((eb[b|0](a,f)|0)>=0){if((eb[b|0](a,e)|0)>=0){break a}}j=f;f=(eb[b|0](f,e)|0)>=0;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}IG(g,h);ab=g+240|0}function c8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ab-16|0;ab=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,52)+e;a=v[d>>2];a:{while(1){if(v[d+4>>2]==(a|0)){break a}v[22452]=0;R(854,a|0,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){a=v[d>>2]+52|0;v[d>>2]=a;continue}break}a=P()|0;O()|0;xd(d);S(a|0);L()}xd(d);ab=d+16|0}function k4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=ab-16|0;ab=f;v[f+8>>2]=d;d=v[Oh(f,f+8|0)>>2];v[22452]=0;ea(919,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){EH(a);b=DH(a+88|0);c=CH(a+92|0);v[a>>2]=58536;v[b>>2]=58648;v[c>>2]=58728;oe(f+8|0);ab=f+16|0;return a|0}a=P()|0;O()|0;oe(f+8|0);S(a|0);L()}function tda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=ab-32|0;ab=d;e=ab-16|0;ab=e;f=e,g=Ab(w[c|0]|w[c+1|0]<<8),u[f+14>>1]=g;c=d+16|0;ZI(c,e+14|0);ab=e+16|0;Ui(d+8|0,c);v[22452]=0;W(105,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22452];v[22452]=0;if((a|0)!=1){yb(d+16|0);ab=d+32|0;break a}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}}function _da(a,b){a=a|0;b=b|0;var c=0;b=ab-32|0;ab=b;c=-1;a:{if(!YA(a,b+16|0)){break a}c=0;if(!gQ(b+16|0)){break a}c=-1;if(!tj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=b+8|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=(a&2139062143)==(a|0)}a=c;ab=b+32|0;return a|0}function Jga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=Ic(e,v[a+4>>2]);if(d>>>0<b>>>0){e=ab-32|0;ab=e;b=b-d|0;d=v[vb(a)>>2];f=v[a+4>>2];a:{if(b>>>0<=d-f>>>0){tm(a,b,c);break a}d=vb(a);d=xl(e+8|0,ul(a,Ic(v[a>>2],f)+b|0),Ic(v[a>>2],v[a+4>>2]),d);TR(d,b,c);rd(a,d);wl(d)}ab=e+32|0;return}if(b>>>0<d>>>0){Hd(a,b+e|0)}}function Gb(){var a=0;a=v[22449];v[22452]=0;X(a|0);a=v[22452];v[22452]=0;a:{if((a|0)!=1){v[22452]=0;X(1194);a=v[22452];v[22452]=0;if((a|0)!=1){break a}}a=V(0)|0;O()|0;_(a|0)|0;v[22452]=0;X(1194);a=v[22452];v[22452]=0;if((a|0)!=1){break a}V(0)|0;O()|0;v[22452]=0;X(17);a=v[22452];v[22452]=0;if((a|0)==1){V(0)|0;O()|0}Gb()}L()}function h$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=v[a+44>>2];c=v[a+24>>2];if(e>>>0<c>>>0){v[a+44>>2]=c;e=c}f=v[a+8>>2];c=v[a+12>>2];d=-1;a:{if(f>>>0>=c>>>0){break a}if(jc(b,-1)){Rm(a,f,c-1|0,e);return cw(b)|0}g=hn(b);if(!(v[a+48>>2]&16)){d=-1;if(!jc(g,t[c-1|0])){break a}}Rm(a,f,c-1|0,e);t[v[a+12>>2]]=g;d=b}return d|0}function B4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ab-16|0;ab=e;a:{if(!(c&1024)){break a}f=e,g=kd(b),v[f+8>>2]=g;b:{if(!ub(b)){break b}if(w[oc(b,0)|0]!=(Sf(43)&255)){if(w[oc(b,0)|0]!=(Sf(45)&255)){break b}}d=d+1|0;RI(e+8|0)}if(ub(b)>>>0>=d>>>0){break a}Xw(b,v[Yg(e,e+8|0)>>2],d-ub(b)|0,Sf(48))}Ac(a,b);ab=e+16|0}function b3(a){a=a|0;var b=0,c=0,d=0;b=ab-32|0;ab=b;a:{b:{if(Vi(a)){of(b+24|0);break b}c=b+8|0;fn(c,a);v[22452]=0;c=T(983,c|0)|0;d=v[22452];v[22452]=0;if((d|0)==1){break a}v[b+24>>2]=c;Hf(b+8|0)}if(Vi(a)){a=a+36|0}else{a=v[b+24>>2]}a=en(v[a>>2],v[a+4>>2]);Ek(b+24|0);ab=b+32|0;return a|0}a=P()|0;O()|0;Hf(b+8|0);S(a|0);L()}function zV(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=ab-32|0;ab=f;v[f+28>>2]=c;v[f+24>>2]=b;v[f+20>>2]=d;v[f+16>>2]=e;v[22452]=0;W(164,f|0,f+24|0,f+20|0,f+16|0);b=v[22452];v[22452]=0;if((b|0)!=1){b=f+8|0;$u(b,v[f>>2],v[f+4>>2]);Gf(a,b);Cd(b);Cd(f);Cd(f+24|0);ab=f+32|0;return}a=P()|0;O()|0;Cd(f+24|0);S(a|0);L()}function wJ(a){var b=C(0),c=0,d=C(0);b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}v[a+4248>>2]=c;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function S7(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[vb(a)>>2]){c=ab-16|0;ab=c;a=li(c,a,1);ns(v[a+4>>2],z[b>>2]);v[a+4>>2]=v[a+4>>2]+4;dc(a);ab=c+16|0;return}d=ab-32|0;ab=d;c=vb(a);c=_f(d+8|0,fh(a,nc(v[a>>2],v[a+4>>2])+1|0),nc(v[a>>2],v[a+4>>2]),c);ns(v[c+8>>2],z[b>>2]);v[c+8>>2]=v[c+8>>2]+4;rd(a,c);Zf(c);ab=d+32|0}function G6(a){a=a|0;var b=0,c=0,d=0,e=0;c=ab-16|0;ab=c;v[v[a+20>>2]+148>>2]=-1;_n(c+8|0,a+4228|0);d=v[a+20>>2];e=v[c+12>>2];b=v[c+8>>2];v[22452]=0;U(893,d+4|0,b|0,Cb(b,e)|0);b=v[22452];v[22452]=0;a:{if((b|0)==1){b=V(88408)|0;if((O()|0)!=(fa(88408)|0)){break a}_(b|0)|0;uc(v[a+20>>2]+4|0);$()}ab=c+16|0;return}S(b|0);L()}function DB(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[vb(a)>>2]){c=ab-16|0;ab=c;a=Ai(c,a,1);wi(v[a+4>>2],x[b>>1]);v[a+4>>2]=v[a+4>>2]+2;dc(a);ab=c+16|0;return}d=ab-32|0;ab=d;c=vb(a);c=qj(d+8|0,rj(a,wc(v[a>>2],v[a+4>>2])+1|0),wc(v[a>>2],v[a+4>>2]),c);wi(v[c+8>>2],x[b>>1]);v[c+8>>2]=v[c+8>>2]+2;rd(a,c);Bi(c);ab=d+32|0}function C9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ab-32|0;ab=d;b=Rf(d,b);v[22452]=0;U(775,d+16|0,b|0,c|0);e=v[22452];v[22452]=0;a:{b:{if((e|0)!=1){v[22452]=0;U(56,a|0,d+16|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}pb(d+16|0);pb(b);ab=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;pb(d+16|0)}pb(b);S(c|0);L()}function x3(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return+hL(v[v[a+24>>2]+24>>2])}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,10110,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function f3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ab-16|0;ab=e;a:{if(!(c&1024)){break a}f=e,g=kd(b),v[f+8>>2]=g;b:{if(!ub(b)){break b}if(w[Eb(b)|0]!=(Sf(43)&255)){if(w[Eb(b)|0]!=(Sf(45)&255)){break b}}d=d+1|0;RI(e+8|0)}if(ub(b)>>>0>=d>>>0){break a}NI(b,v[Yg(e,e+8|0)>>2],d-ub(b)|0,Sf(48))}Ac(a,b);ab=e+16|0}function Wd(a,b){var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;Bm(a);d=yf(c+8|0,a);a:{a=v[116320];if(nc(a,v[116321])>>>0<=b>>>0){v[22452]=0;Z(1184,b+1|0);a=v[22452];v[22452]=0;if((a|0)==1){break a}a=v[116320]}a=v[Fb(a,b)>>2];if(a){Em(a)}a=Pd(d);e=Fb(v[116320],b),f=a,v[e>>2]=f;GE(d);ab=c+16|0;return}a=P()|0;O()|0;GE(d);S(a|0);L()}function TV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ab-32|0;ab=d;b=Rf(d,b);v[22452]=0;U(145,d+16|0,b|0,c|0);e=v[22452];v[22452]=0;a:{b:{if((e|0)!=1){v[22452]=0;U(4,a|0,d+16|0,c|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}pb(d+16|0);pb(b);ab=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;pb(d+16|0)}pb(b);S(c|0);L()}function SH(a){var b=0,c=0,d=0,e=0;b=ab-32|0;ab=b;if(!w[a+20|0]){while(1){if(!(eb[v[v[a>>2]+40>>2]](a)|0)){QH(a,65536);c=Zb(b+16|0,Cb(v[a+4>>2],v[a+16>>2]),65536);d=v[v[a>>2]+44>>2];e=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=e;eb[d|0](b+24|0,a,b+8|0);v[a+16>>2]=v[a+16>>2]+v[b+28>>2];continue}break}t[a+20|0]=1}ab=b+32|0}function NW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Bg(a,v[b+8>>2],e)){sv(b,c,d);return}a:{if(!Bg(a,v[b>>2],e)){break a}if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function PU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=ab-48|0;ab=e;c=ab-16|0;ab=c;f=e+8|0;oC(c+8|0,f);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;d=(d|0)==(g|0);if(!d){nC(f)}c=-1;a:{if(!d){break a}c=0;if(!qC(e+8|0)){break a}c=we(a,b,pC(w[e+43|0]),db)}ab=e+48|0;return c|0}function Jfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=ab+-64|0;ab=e;c=ab-16|0;ab=c;f=e+8|0;xR(c+8|0,f);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;d=(d|0)==(g|0);if(!d){wR(f)}c=-1;a:{if(!d){break a}c=0;if(!zR(e+8|0)){break a}c=we(a,b,yR(e+8|0),db)}ab=e- -64|0;return c|0}function Ik(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=ab-16|0;ab=d;a:{if(!(c&32)){break a}g=d,h=kd(b),v[g+8>>2]=h;g=d,h=Ff(b),v[g>>2]=h;while(1){if(!aj(d+8|0,d)){break a}c=v[d+8>>2];f=Sf(97);e=t[c|0];b:{if((f|0)>(e|0)){break b}if((Sf(122)|0)<(e|0)){break b}g=c,h=(Sf(65)-f|0)+e|0,t[g|0]=h}Fe(d+8|0);continue}}Ac(a,b);ab=d+16|0}function xO(){var a=0,b=0;a=ab-240|0;ab=a;a:{b:{if(t[89968]&1){break b}if(!Jd(89968)){break b}v[22452]=0;X(40);b=v[22452];v[22452]=0;if((b|0)==1){break a}v[22452]=0;Z(41,a+120|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}gc(89848,gc(a,a+120|0,120),116);Id(89968)}ab=a+240|0;return}a=P()|0;O()|0;Xe(89968);S(a|0);L()}function pha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=ab-112|0;ab=e;c=ab-16|0;ab=c;f=e+8|0;MS(c+8|0,f);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;d=(d|0)==(g|0);if(!d){LS(f)}c=-1;a:{if(!d){break a}c=0;if(!OS(e+8|0)){break a}c=we(a,b,NS(e+8|0),db)}ab=e+112|0;return c|0}function I8(a){a=a|0;var b=0,c=0;b=ab-32|0;ab=b;t[b+23|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;v[b+16>>2]=0;v[b+20>>2]=0;c=Zb(b,b+16|0,15);_b(b+8|0,a,v[c>>2],v[c+4>>2]);c=0;a:{if(v[b+12>>2]!=15){break a}if(Ib(b+16|0,8512,15)){break a}Ob(a,15);c=1}ab=b+32|0;return c|0}function lM(a,b,c,d){var e=0,f=0;e=ab-16|0;ab=e;f=-2147483648;f=!c|!(t[c+15|0]&1)?f:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){f=x[d+28>>1];break b}if((f|0)==-2147483648){break a}}xp(b,f,a);rb(e+8|0,a+1074312|0,10);if(!sb(v[v[e+8>>2]>>2],v[e+12>>2])|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}ab=e+16|0}function Nfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,20)+d;a=v[c>>2];a:{while(1){if(v[c+4>>2]==(a|0)){break a}v[22452]=0;Z(222,a|0);a=v[22452];v[22452]=0;if((a|0)!=1){a=v[c>>2]+20|0;v[c>>2]=a;continue}break}a=P()|0;O()|0;xd(c);S(a|0);L()}xd(c);ab=c+16|0}function pg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=ab-16|0;ab=f;a:{e=hi(b,c);if(e>>>0<4294967280){b:{if(e>>>0<=10){ye(a,e);d=a;break b}g=ri(e)+1|0;d=pc(g);nd(a,d);Lf(a,g);Qd(a,e)}while(1){if((b|0)!=(c|0)){md(d,b);d=d+1|0;b=b+1|0;continue}break}t[f+15|0]=0;md(d,f+15|0);ab=f+16|0;break a}Df();L()}return a|0}function U2(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return+A[v[a+24>>2]+16>>3]}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,7560,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function O2(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return v[v[a+24>>2]+8>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,10837,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function Hx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=F(c,.999);h=c*3.141592653589793;i=Rs(b);while(1){if((e|0)!=32768){f=((e<<12^-1)&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=ki(g)*Rs(K(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=sz(c*d*32768),u[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function or(a){var b=0;b=v[a+76>>2];a:{if(!((b|0)>=0&(!b|(b&-1073741825)!=((w[459740]?42:0)|0)))){b=v[a+4>>2];if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;b=w[b|0];break a}b=_v(a);break a}b=v[a+76>>2];v[a+76>>2]=b?b:1073741823;b=v[a+4>>2];b:{if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;b=w[b|0];break b}b=_v(a)}v[a+76>>2]=0}return b}function ml(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d|0){case 1:return oy((B(c,872)+b|0)+616|0,e);case 2:f=oy((B(c,872)+b|0)+616|0,e);if((f+5&255)>>>0>5){break a}case 0:return XL(a,b,c,e);case 3:break b;default:break a}}f=XL(a,b,c,e);if((f+5&255)>>>0>5){break a}f=oy((B(c,872)+b|0)+616|0,e)}return f}function ZY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a:{if(!me(f)){v[a+8>>2]=v[f+8>>2];b=v[f+4>>2];v[a>>2]=v[f>>2];v[a+4>>2]=b;break a}d=v[f>>2];b:{c:{c=v[f+4>>2];d:{if(c>>>0<=1){b=a;ye(a,c);break d}if(c>>>0>=1073741808){break c}e=sl(c)+1|0;b=ji(e);nd(a,b);Lf(a,e);Qd(a,c)}Uh(b,d,c+1|0);break b}Df();L()}}}function Kl(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=ab-16|0;ab=h;i=-17;if(-17-b>>>0>=c>>>0){j=Eb(a);if(b>>>0<=2147483622){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;i=ri(v[Pc(h+12|0,h+8|0)>>2])+1|0}c=pc(i);if(e){dg(c,j,e)}d=d-(e+f|0)|0;if(d){dg((c+e|0)+g|0,(e+j|0)+f|0,d)}if((b|0)!=10){xb(j)}nd(a,c);Lf(a,i);ab=h+16|0;return}Df();L()}function CK(a){var b=0,c=0;a:{if(Ib(a,14168,4)){break a}b=a+4|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=a+16|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!b){break a}a=a+8|0;c=(b+24|0)==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}return c}function x0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=ab-32|0;ab=f;v[f+28>>2]=e;v[f+24>>2]=d;Gg(f+16|0,b,c);b=Gf(f+8|0,f+24|0);c=v[b+4>>2];b=v[b>>2];v[22452]=0;ea(160,a|0,v[f+16>>2],v[f+20>>2],b|0,c|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){Cd(f+24|0);ab=f+32|0;return}a=P()|0;O()|0;Cd(f+24|0);S(a|0);L()}function i3(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return Mo(v[a+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,7039,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function h3(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return Yr(v[a+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,6748,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function fea(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[vb(a)>>2]){c=ab-16|0;ab=c;a=zu(c,a,1);nQ(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+20;dc(a);ab=c+16|0;return}d=ab-32|0;ab=d;c=vb(a);c=NA(d+8|0,OA(a,Ef(v[a>>2],v[a+4>>2])+1|0),Ef(v[a>>2],v[a+4>>2]),c);nQ(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;MA(a,c);Mt(c);ab=d+32|0}function d3(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return Xr(v[a+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,7398,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function cU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=ab-1968|0;ab=e;c=ab-16|0;ab=c;f=e+8|0;xB(c+8|0,f);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;d=(d|0)==(g|0);if(!d){wB(f)}c=-1;a:{if(!d){break a}c=0;if(!yB(e+8|0)){break a}c=we(a,b,1024,0)}ab=e+1968|0;return c|0}function Sea(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,24);a=v[c+4>>2];b=v[c+8>>2];a:{while(1){if((a|0)==(b|0)){break a}v[22452]=0;Z(542,a|0);d=v[22452];v[22452]=0;if((d|0)!=1){a=a+24|0;v[c+4>>2]=a;continue}break}a=P()|0;O()|0;dc(c);S(a|0);L()}dc(c);ab=c+16|0}function tT(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[vb(a)>>2]){c=ab-16|0;ab=c;a=kT(c,a,1);jT(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+48;dc(a);ab=c+16|0;return}d=ab-32|0;ab=d;c=vb(a);c=hT(d+8|0,iT(a,Zp(v[a>>2],v[a+4>>2])+1|0),Zp(v[a>>2],v[a+4>>2]),c);jT(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+48;gT(a,c);fT(c);ab=d+32|0}function sha(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[vb(a)>>2]){c=ab-16|0;ab=c;a=zu(c,a,1);PA(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+20;dc(a);ab=c+16|0;return}d=ab-32|0;ab=d;c=vb(a);c=NA(d+8|0,OA(a,Ef(v[a>>2],v[a+4>>2])+1|0),Ef(v[a>>2],v[a+4>>2]),c);PA(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;MA(a,c);Mt(c);ab=d+32|0}function kaa(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[vb(a)>>2]){c=ab-16|0;ab=c;a=kz(c,a,1);Yy(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+32;dc(a);ab=c+16|0;return}d=ab-32|0;ab=d;c=vb(a);c=bt(d+8|0,Bp(a,$f(v[a>>2],v[a+4>>2])+1|0),$f(v[a>>2],v[a+4>>2]),c);Yy(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;UN(a,c);Xy(c);ab=d+32|0}function _8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=ab-16|0;ab=b;d=a+1298300|0;if(!td(d)){a=v[a+24620>>2];c=ab-16|0;ab=c;e=pc(536);v[22452]=0;f=Q(810,e|0,a|0)|0;a=v[22452];v[22452]=0;a:{if((a|0)!=1){a=v[yf(c+8|0,f)>>2];ab=c+16|0;break a}a=P()|0;O()|0;xb(e);S(a|0);L()}v[b+8>>2]=a;a=b+8|0;vL(d,Pd(a));xs(a)}ab=b+16|0}function Px(a,b,c){var d=0,e=0,f=0;d=ab-16|0;ab=d;f=v[b+656>>2];e=0;a:{if(!f){break a}f=Eu(f,c);e=a+1074312|0;rb(d+8|0,e,31);a=0;if(!sb(v[v[d+8>>2]>>2],v[d+12>>2])){rb(d,e,93);a=sb(v[v[d>>2]>>2],v[d+4>>2])^1}if(!(t[TK(b,c)+6|0]&1)){e=0;if(!(t[f+12|0]&1)|a){break a}}e=jc(v[f>>2],v[f+4>>2])^1}ab=d+16|0;return e}function ME(a,b,c,d,e){var f=0,g=0,h=0;f=ab-16|0;ab=f;g=1073741807;if(1073741807-b>>>0>=c>>>0){h=Eb(a);if(b>>>0<=536870886){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;g=sl(v[Pc(f+12|0,f+8|0)>>2])+1|0}c=ji(g);if(e){Uh(c,h,e)}d=d-e|0;if(d){e=e<<2;Uh(e+c|0,e+h|0,d)}if((b|0)!=1){xb(h)}nd(a,c);Lf(a,g);ab=f+16|0;return}Df();L()}function pda(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[vb(a)>>2]){c=ab-16|0;ab=c;a=lv(c,a);vz(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;dc(a);ab=c+16|0;return}d=ab-32|0;ab=d;c=vb(a);c=ql(d+8|0,to(a,ad(v[a>>2],v[a+4>>2])+1|0),ad(v[a>>2],v[a+4>>2]),c);vz(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;rP(a,c);qP(c);ab=d+32|0}function p5(a,b){a=a|0;b=b|0;var c=0,d=0;a=Bb(a);c=ub(b);v[22452]=0;R(74,a|0,c|0);c=v[22452];v[22452]=0;if((c|0)!=1){a:{b:{while(1){if(ub(b)>>>0<=d>>>0){break b}c=t[oc(b,d)|0];v[22452]=0;R(51,a|0,Sf(c)|0);c=v[22452];v[22452]=0;if((c|0)!=1){d=d+1|0;continue}break}break a}return}}b=P()|0;O()|0;pb(a);S(b|0);L()}function k8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=ab-32|0;ab=e;f=cf(a,c);c=e+8|0;Xd(c,v[a+28>>2]);d=v[c+12>>2];v[e+24>>2]=v[c+8>>2];v[e+28>>2]=d;a:{b:{if(!f){c=0;d=-1;if(!Vc(a,5)){break b}break a}d=v[f+8>>2]}c=v[a+28>>2];c:{if(!((d|0)!=4&(d|0)!=-1)){Xj(c,b);break c}TH(c,b,d)}c=f}Te(a,c,e+24|0);ab=e+32|0}function CZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=ab-32|0;ab=g;h=v[19995];v[g+24>>2]=v[19994];v[g+28>>2]=h;h=v[19993];v[g+16>>2]=v[19992];v[g+20>>2]=h;h=v[19991];v[g+8>>2]=v[19990];v[g+12>>2]=h;h=v[19989];v[g>>2]=v[19988];v[g+4>>2]=h;h=a;a=g+32|0;b=zj(h,b,c,d,e,f,g,a);ab=a;return b|0}function tf(a,b,c,d){var e=0,f=0,g=0;a:{if(!ub(a)|(c-b|0)<5){break a}ir(b,c);e=c-4|0;c=Eb(a);g=c+ub(a)|0;b:{while(1){c:{a=t[c|0];f=a-127|0;if(b>>>0>=e>>>0){break c}if((a|0)!=v[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;c=((g-c|0)>1)+c|0;continue}break}if((f&255)>>>0<130|a>>>0>v[e>>2]-1>>>0){break a}}v[d>>2]=4}}function eV(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[vb(a)>>2]){c=ab-16|0;ab=c;a=lD(c,a);Zu(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+36;dc(a);ab=c+16|0;return}d=ab-32|0;ab=d;c=vb(a);c=jD(d+8|0,kD(a,Gq(v[a>>2],v[a+4>>2])+1|0),Gq(v[a>>2],v[a+4>>2]),c);Zu(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+36;iD(a,c);_u(c);ab=d+32|0}function Rf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(!me(b)){v[a+8>>2]=v[b+8>>2];c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a|0}e=v[b>>2];a:{b:{c=v[b+4>>2];c:{if(c>>>0<=10){b=a;ye(a,c);break c}if(c>>>0>=4294967280){break b}d=ri(c)+1|0;b=pc(d);nd(a,b);Lf(a,d);Qd(a,c)}dg(b,e,c+1|0);break a}Df();L()}return a|0}function J8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ab+-64|0;ab=d;Pe(b);e=d+40|0;Je(e,a,c);a=v[d+40>>2];Se(d+8|0,1,Sd(e),a);v[22452]=0;W(213,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22452];v[22452]=0;if((a|0)!=1){a=d+24|0;tb(b,a);pb(a);rc(d+40|0);ab=d- -64|0;break a}a=P()|0;O()|0;rc(d+40|0);S(a|0);L()}}function rca(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[vb(a)>>2]){c=ab-16|0;ab=c;a=fz(c,a);EO(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;dc(a);ab=c+16|0;return}d=ab-32|0;ab=d;c=vb(a);c=_f(d+8|0,fh(a,nc(v[a>>2],v[a+4>>2])+1|0),nc(v[a>>2],v[a+4>>2]),c);EO(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;rd(a,c);Zf(c);ab=d+32|0}function WJ(a){a=a|0;var b=0,c=0;c=ab-16|0;ab=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[22452]=0;v[c+12>>2]=0;U(881,a+4208|0,b<<1,c+12|0);b=v[22452];v[22452]=0;a:{if((b|0)==1){b=V(88408)|0;if((O()|0)!=(fa(88408)|0)){break a}_(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;ab=c+16|0;return}S(b|0);L()}function UT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;v[d+12>>2]=c;a:{if(!Hb(b,c<<1)){break a}mc(d+12|0,65535);mf(a,x[d+12>>1]);c=wb(v[a>>2]);v[d>>2]=c;e=wb(v[a+4>>2]);while(1){if(!Tb(c,e)){break a}a=d+8|0;su(b,a);f=c,g=Ab(w[a|0]|w[a+1|0]<<8),u[f>>1]=g;Ke(d);c=v[d>>2];continue}}ab=d+16|0}function Tfa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=ab+-64|0;ab=c;d=c+40|0;Je(d,a,16);a=v[c+40>>2];Se(c+8|0,3,Sd(d),a);v[22452]=0;W(213,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22452];v[22452]=0;if((a|0)!=1){Zb(c,b,17);a=c+24|0;pj(c,a);pb(a);rc(c+40|0);ab=c- -64|0;break a}a=P()|0;O()|0;rc(c+40|0);S(a|0);L()}}function Pha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=ab-32|0;ab=e;c=ab-16|0;ab=c;f=e+8|0;KB(c+8|0,f);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;d=(d|0)==(g|0);if(!d){nu(f)}c=-1;a:{if(!d){break a}c=0;if(!YS(e+8|0)){break a}c=we(a,b,72,0)}ab=e+32|0;return c|0}function q4(a){a=a|0;var b=0;v[22452]=0;Z(924,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,5651,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function ks(a){var b=0,c=0,d=0;b=Ej(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){if(b>45e-5){c=So(b)/.6931471805599453;b=c-H(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Ej(d+c)*.5}else{b=0}A[a+4248>>3]=b}js(a)}function e6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ci(a,b,c,d);v[a+4224>>2]=1049951732;c=a+4216|0;v[c>>2]=1065353216;v[c+4>>2]=1049951732;v[a+4208>>2]=1060320051;v[a+4212>>2]=1041865114;v[a>>2]=45532;v[22452]=0;R(875,a+44|0,2);c=v[22452];v[22452]=0;if((c|0)!=1){bi(b);return a|0}a=P()|0;O()|0;ff(b);S(a|0);L()}function dB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=ab-32|0;ab=f;v[f+8>>2]=c;g=f,h=Ze(b),v[g+28>>2]=h;c=f+8|0;Je(c,b,v[zb(c,f+28|0)>>2]);b=Sd(c);v[22452]=0;ga(230,a|0,b|0,v[f+8>>2],d|0,e|0);a=v[22452];v[22452]=0;if((a|0)!=1){rc(f+8|0);ab=f+32|0;return}a=P()|0;O()|0;rc(f+8|0);S(a|0);L()}function XT(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=ab+-64|0;ab=c;d=c+40|0;Je(d,a,44);a=v[c+40>>2];Se(c+8|0,2,Sd(d),a);v[22452]=0;W(213,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22452];v[22452]=0;if((a|0)!=1){Zb(c,b,44);a=c+24|0;pj(c,a);pb(a);rc(c+40|0);ab=c- -64|0;break a}a=P()|0;O()|0;rc(c+40|0);S(a|0);L()}}function L3(a){a=a|0;var b=0;v[22452]=0;Z(949,a|0);b=v[22452];v[22452]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[22452]=0;W(911,11948,a|0,0,0);a=v[22452];v[22452]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Gb();L()}function yx(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;v[d>>2]=a;a=v[a+4>>2];v[d+4>>2]=a;v[d+8>>2]=a+B(b,52);a=v[d+4>>2];b=v[d+8>>2];a:{while(1){if((a|0)==(b|0)){break a}v[22452]=0;R(854,a|0,c|0);e=v[22452];v[22452]=0;if((e|0)!=1){a=a+52|0;v[d+4>>2]=a;continue}break}a=P()|0;O()|0;dc(d);S(a|0);L()}dc(d);ab=d+16|0}function ym(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(v[c>>2]|v[d>>2]){while(1){if((b|0)==(f|0)){break a}e=v[d>>2];g=v[c>>2];h=c,i=g-Wc((Wc(0-g|0,31)&255)+g|0,8)|0,v[h>>2]=i;h=d,i=v[d>>2]-Wc(e+(Wc(0-e|0,31)&255)|0,8)|0,v[h>>2]=i;e=(f<<3)+a|0;v[e>>2]=v[c>>2];v[e+4>>2]=v[d>>2];f=f+1|0;continue}}Jb(a,0,b<<3)}}function ZT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,10);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0}return a|0}function y7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ab-16|0;ab=d;zc(a,b);v[22452]=0;U(67,d+8|0,b|0,c|0);e=v[22452];v[22452]=0;a:{if((e|0)==1){break a}Nb(d+8|0);b=v[b+24>>2];if(b){v[22452]=0;U(68,d|0,b|0,c|0);b=v[22452];v[22452]=0;if((b|0)==1){break a}Nb(d)}ab=d+16|0;return}b=P()|0;O()|0;Nb(a);S(b|0);L()}function xN(a,b){var c=0,d=0,e=0,f=0;c=A[b+8>>3];a:{d=A[b>>3];if(Ue(d)){if(d<0){c=sN(c)?c:1;break a}if(c!=0){if(sN(c)){break a}}Rl(a,d,Ue(c)?M:c);return}if(!Bh(d)|c!=0){break a}e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;return}d=dx(d);f=ki(c);Rl(a,d*Ge(c),f*d)}function vy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=ab-16|0;ab=e;f=w[c+4|0];g=v[b+480180>>2];a:{if(g&64671904){b=w[(f&15)+43904|0];t[a+2|0]=0;u[a>>1]=b;break a}c=w[c+3|0];rb(e+8|0,b+1074312|0,66);h=a;a=(c|0)==4&(g|0)==4;b=f<<a<<4;Qn(h,(i=sb(v[v[e+8>>2]>>2],v[e+12>>2])?0:b,j=b,k=d,k?i:j),a)}ab=e+16|0}function sk(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}t[a|0]=b}function eia(a,b){a=a|0;b=b|0;var c=0;_t(a,b);Mf(b);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}t[b+3|0]=45;t[b+5|0]=a&15;return}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;return}t[b+3|0]=20;t[b+5|0]=a&15|160;return}t[b+3|0]=0}}function Hk(a,b){a=a|0;b=b|0;var c=0;c=ab-32|0;ab=c;ch(c,b);v[22452]=0;R(1028,c+16|0,c|0);b=v[22452];v[22452]=0;a:{b:{if((b|0)!=1){v[22452]=0;U(1029,a|0,0,c+16|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}Oc(c+16|0);pb(c);ab=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Oc(c+16|0)}pb(c);S(b|0);L()}function HX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;b=ab-16|0;ab=b;v[e>>2]=c;a=xv(b+12|0,0,v[a+8>>2]);c=2;a:{if(a+1>>>0<2){break a}a=a-1|0;c=1;if(a>>>0>d-v[e>>2]>>>0){break a}c=b+12|0;while(1){if(a){d=w[c|0];f=v[e>>2];v[e>>2]=f+1;t[f|0]=d;a=a-1|0;c=c+1|0;continue}break}c=0}ab=b+16|0;return c|0}function DN(a,b){var c=0,d=0,e=0;c=sd(a);a:{if(b){v[22452]=0;R(740,a|0,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break a}d=ab-16|0;ab=d;c=xo(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){dc(c);ab=d+16|0}else{Rl(b,0,0);b=b+16|0;v[c+4>>2]=b;continue}break}}return a}a=P()|0;O()|0;Vj(c);S(a|0);L()}function lS(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=ab+-64|0;ab=c;d=c+40|0;Je(d,a,32);a=v[c+40>>2];Se(c+8|0,2,Sd(d),a);v[22452]=0;W(213,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22452];v[22452]=0;if((a|0)!=1){sm(c,b);a=c+24|0;pj(c,a);pb(a);rc(c+40|0);ab=c- -64|0;break a}a=P()|0;O()|0;rc(c+40|0);S(a|0);L()}}function Uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ab+-64|0;ab=d;e=d+40|0;Je(e,a,c);a=v[d+40>>2];Se(d+8|0,2,Sd(e),a);v[22452]=0;W(213,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22452];v[22452]=0;if((a|0)!=1){a=d+24|0;jm(b,a);pb(a);rc(d+40|0);ab=d- -64|0;break a}a=P()|0;O()|0;rc(d+40|0);S(a|0);L()}}function H7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ci(a,b,c,d);v[a>>2]=43996;d=Pb(a+4208|0);v[a+4228>>2]=0;v[a+4220>>2]=0;v[a+4224>>2]=0;v[a+4232>>2]=v[c+24620>>2];lB(a+4260|0,80,150,80,255);v[22452]=0;R(875,a+44|0,2);c=v[22452];v[22452]=0;if((c|0)!=1){bi(b);return a|0}a=P()|0;O()|0;ec(d);ff(b);S(a|0);L()}function yT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ab+-64|0;ab=d;e=d+40|0;Je(e,a,c);a=v[d+40>>2];Se(d+8|0,2,Sd(e),a);v[22452]=0;W(213,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22452];v[22452]=0;if((a|0)!=1){a=d+24|0;sc(b,a);pb(a);rc(d+40|0);ab=d- -64|0;break a}a=P()|0;O()|0;rc(d+40|0);S(a|0);L()}}function G8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ab+-64|0;ab=d;e=d+40|0;Je(e,a,c);a=v[d+40>>2];Se(d+8|0,1,Sd(e),a);v[22452]=0;W(213,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22452];v[22452]=0;if((a|0)!=1){a=d+24|0;ke(b,a);pb(a);rc(d+40|0);ab=d- -64|0;break a}a=P()|0;O()|0;rc(d+40|0);S(a|0);L()}}function sy(a,b,c,d,e,f){var g=0,h=0,i=0;g=ab-16|0;ab=g;h=-17;if(-17-b>>>0>=c>>>0){i=Eb(a);if(b>>>0<=2147483622){v[g+8>>2]=b<<1;v[g+12>>2]=b+c;h=ri(v[Pc(g+12|0,g+8|0)>>2])+1|0}c=pc(h);if(e){dg(c,i,e)}d=d-e|0;if(d){dg((c+e|0)+f|0,e+i|0,d)}if((b|0)!=10){xb(i)}nd(a,c);Lf(a,h);ab=g+16|0;return}Df();L()}function maa(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:Sk(a,0,c);return;case 1:Sk(a,1,c);return;case 2:Sk(a,2,c);return;case 3:Sk(a,3,c);return;case 4:Sk(a,4,c);return;case 5:Sk(a,5,c);return;case 6:IN(a,23712,c);return;case 7:IN(a,24736,c);return;case 8:Sk(a,6,c);return;default:break a}}Bb(a)}function Pp(a){var b=0,c=0;b=ab-32|0;ab=b;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;c=a+288|0;dz(c,c+512|0,b);v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;a=a+800|0;dz(a,gP(a),b);ab=b+32|0}function MV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(d>>>0>=c>>>0){break a}a=a+4|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);if(a>>>0>c>>>0|a>>>0>c-d>>>0|!a){break a}e=1;a=a+d|0;if(Ic(v[b>>2],v[b+4>>2])>>>0>=a>>>0){break a}Ei(b,a)}return e|0}function JB(a,b,c){var d=0,e=0;d=ab+-64|0;ab=d;Pe(b);e=d+40|0;Je(e,a,c);a=v[d+40>>2];Se(d+8|0,3,Sd(e),a);v[22452]=0;W(213,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);e=v[22452];v[22452]=0;if((e|0)!=1){e=b;b=d+24|0;tb(e,b);pb(b);rc(d+40|0);ab=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;rc(d+40|0);S(a|0);L()}function nha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab-224|0;ab=d;c=ab-16|0;ab=c;ES(c+8|0,d);e=v[c+12>>2];$c(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Rc(a,v[c+12>>2])}ab=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!GS(d)){break a}c=we(a,b,FS(w[d+216|0],w[d+217|0]),db)}ab=d+224|0;return c|0}function xda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab+-64|0;ab=d;c=ab-16|0;ab=c;Zt(c+8|0,d);e=v[c+12>>2];$c(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Rc(a,v[c+12>>2])}ab=c+16|0;e=(e|0)==(f|0);if(!e){Qt(d)}c=-1;a:{if(!e){break a}c=0;if(!yP(d)){break a}c=we(a,b,xP(d),db)}ab=d- -64|0;return c|0}function ff(a){a=a|0;var b=0,c=0;v[a>>2]=44464;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;RJ(a+44|0);return a|0}function Te(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-48|0;ab=d;a:{if(!b){b=1;if(Vc(a,5)){break a}b=nF(d+32|0);e=v[a+8>>2];f=v[c>>2];v[b+4>>2]=f-e;Xd(d,v[a+28>>2]);e=d+16|0;KF(e,d,v[c>>2],v[c+4>>2]);v[b+8>>2]=v[e+8>>2]}v[a>>2]=v[a>>2]|134217728;v[a+20>>2]=v[a+20>>2]+1;b=0}ab=d+48|0;return b|0}function op(a,b,c){var d=0,e=0;a=Bb(a);d=ub(b);v[22452]=0;R(48,a|0,d|0);d=v[22452];v[22452]=0;if((d|0)!=1){a:{while(1){if(ub(b)>>>0>e>>>0){d=v[(w[oc(b,e)|0]<<2)+c>>2];v[22452]=0;R(49,a|0,d|0);d=v[22452];v[22452]=0;if((d|0)==1){break a}e=e+1|0;continue}break}return}}b=P()|0;O()|0;Oc(a);S(b|0);L()}function hha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab-576|0;ab=d;c=ab-16|0;ab=c;wS(c+8|0,d);e=v[c+12>>2];$c(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Rc(a,v[c+12>>2])}ab=c+16|0;e=(e|0)==(f|0);if(!e){vS(d)}c=-1;a:{if(!e){break a}c=0;if(!yS(d)){break a}c=we(a,b,xS(d),db)}ab=d+576|0;return c|0}function bha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab-192|0;ab=d;c=ab-16|0;ab=c;jq(c+8|0,d);e=v[c+12>>2];$c(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Rc(a,v[c+12>>2])}ab=c+16|0;e=(e|0)==(f|0);if(!e){qS(d)}c=-1;a:{if(!e){break a}c=0;if(!sS(d)){break a}c=we(a,b,rS(d),db)}ab=d+192|0;return c|0}function SJ(a){a=a|0;var b=0,c=0,d=0;b=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];a:{if(D(b)<0x8000000000000000){d=~~b>>>0;c=D(b)>=1?~~(b>0?F(H(b*2.3283064365386963e-10),4294967295):I((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}A[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function Kda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab-608|0;ab=d;c=ab-16|0;ab=c;SP(c+8|0,d);e=v[c+12>>2];$c(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Rc(a,v[c+12>>2])}ab=c+16|0;e=(e|0)==(f|0);if(!e){RP(d)}c=-1;a:{if(!e){break a}c=0;if(!UP(d)){break a}c=we(a,b,TP(d),db)}ab=d+608|0;return c|0}function sda(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=ab+-64|0;ab=c;d=c+40|0;Je(d,a,31);a=v[c+40>>2];Se(c+8|0,2,Sd(d),a);v[22452]=0;W(213,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22452];v[22452]=0;if((a|0)!=1){a=c+24|0;ke(b,a);pb(a);rc(c+40|0);ab=c- -64|0;break a}a=P()|0;O()|0;rc(c+40|0);S(a|0);L()}}function p9(a,b){a=a|0;b=b|0;var c=0,d=0;c=gc(a,b,614);a=0;while(1){d=B(a,872);hp((d+c|0)+616|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=yz(c+223848|0,b+223848|0);v[22452]=0;Q(779,c+223860|0,b+223860|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return c|0}b=P()|0;O()|0;Xb(a);S(b|0);L()}function Vha(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=ab+-64|0;ab=c;d=c+40|0;Je(d,a,8);a=v[c+40>>2];Se(c+8|0,3,Sd(d),a);v[22452]=0;W(213,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22452];v[22452]=0;if((a|0)!=1){a=c+24|0;ke(b,a);pb(a);rc(c+40|0);ab=c- -64|0;break a}a=P()|0;O()|0;rc(c+40|0);S(a|0);L()}}function D9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=ab+-64|0;ab=c;d=c+40|0;Je(d,a,32);a=v[c+40>>2];Se(c+8|0,1,Sd(d),a);v[22452]=0;W(213,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22452];v[22452]=0;if((a|0)!=1){a=c+24|0;sc(b,a);pb(a);rc(c+40|0);ab=c- -64|0;break a}a=P()|0;O()|0;rc(c+40|0);S(a|0);L()}}function Bca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab-80|0;ab=d;c=ab-16|0;ab=c;QR(c+8|0,d);e=v[c+12>>2];$c(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Rc(a,v[c+12>>2])}ab=c+16|0;e=(e|0)==(f|0);if(!e){pA(d)}c=-1;a:{if(!e){break a}c=0;if(!IO(d)){break a}c=we(a,b,HO(d),db)}ab=d+80|0;return c|0}function lga(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;v[c+8>>2]=b;b=0;a:{if(nc(v[a>>2],v[a+4>>2])>>>0>511){break a}if(!td(c+8|0)){break a}d=c+8|0;b=v[d>>2];v[22452]=0;R(446,a|0,d|0);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;bg(c+8|0);S(a|0);L()}bg(c+8|0);ab=c+16|0;return b|0}function iha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;v[d+8>>2]=c;v[d+12>>2]=-1;if((c|0)!=-1){f=d,g=ub(a),v[f>>2]=g;e=v[zb(d+12|0,d)>>2];v[d+4>>2]=e;a=pn(Eb(a),b,v[zb(d+4|0,d+8|0)>>2]);a:{if(a){break a}a=-1;if(c>>>0>e>>>0){break a}a=c>>>0<e>>>0}ab=d+16|0;return a|0}Vp();L()}function P1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=sd(a);a:{c=Cg(v[b+4>>2],v[b+8>>2]);if(!c){break a}v[22452]=0;R(1030,a|0,c|0);d=v[22452];v[22452]=0;if((d|0)!=1){d=v[b+8>>2];b=v[b+4>>2];v[22452]=0;W(1031,a|0,b|0,d|0,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Wr(e);S(a|0);L()}}function MB(a,b,c){var d=0,e=0;d=ab+-64|0;ab=d;e=d+40|0;Je(e,a,c);a=v[d+40>>2];Se(d+8|0,3,Sd(e),a);v[22452]=0;W(213,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);e=v[22452];v[22452]=0;if((e|0)!=1){e=b;b=d+24|0;sc(e,b);pb(b);rc(d+40|0);ab=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;rc(d+40|0);S(a|0);L()}function GM(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;e=v[b+48>>2]+1|0;v[b+52>>2]=e;a:{if(y[Rb(a+484344|0,x[b+70>>1])+12>>2]>e>>>0){break a}if(!c){u[b+74>>1]=x[b+72>>1]+1}v[b+52>>2]=0;rb(d+8|0,a+1074312|0,63);if(!sb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}a=v[b+56>>2];v[b+56>>2]=0;v[b+52>>2]=a}ab=d+16|0}function Fea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=ab-128|0;ab=e;c=ab-16|0;ab=c;EQ(c+8|0,e);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;d=(d|0)==(f|0);if(!d){DQ(e)}c=-1;a:{if(!d){break a}c=0;if(!FQ(e)){break a}c=we(a,b,256,0)}ab=e+128|0;return c|0}function pea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab-1120|0;ab=d;c=ab-16|0;ab=c;rQ(c+8|0,d+8|0);e=v[c+12>>2];$c(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Rc(a,v[c+12>>2])}ab=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!tQ(d+8|0)){break a}c=we(a,b,sQ(d+8|0),db)}ab=d+1120|0;return c|0}function YW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ab-16|0;ab=d;a:{e=v[b>>2];if(FC(e)){if(!pd(c)){jv(c,17713);e=v[b>>2]}b=v[b+4>>2];eb[v[v[b>>2]+24>>2]](d,b,e);v[22452]=0;Q(776,c|0,d|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break a}pb(d)}Ac(a,c);ab=d+16|0;return}a=P()|0;O()|0;pb(d);S(a|0);L()}function VA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ab-32|0;ab=e;v[e+8>>2]=c;f=e,g=Ze(b),v[f+28>>2]=g;c=e+8|0;Je(c,b,v[zb(c,e+28|0)>>2]);b=Sd(c);v[22452]=0;W(332,a|0,b|0,v[e+8>>2],d|0);a=v[22452];v[22452]=0;if((a|0)!=1){rc(e+8|0);ab=e+32|0;return}a=P()|0;O()|0;rc(e+8|0);S(a|0);L()}function MD(a){var b=0,c=0;a:{if(Ib(a,13324,8)){break a}b=a+8|0;if((w[b|0]|w[b+1|0]<<8)!=14){break a}b=a+12|0;if(!(w[b|0]|w[b+1|0]<<8)){break a}b=a+14|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))<=0){break a}a=a+18|0;c=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>23}return c}function tR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;e=Rg(a);a=b+236|0;b=$s(a);a:{while(1){if((a|0)!=(b|0)){d=x[a>>1];u[c+14>>1]=d;if(d){v[22452]=0;U(500,c|0,e|0,c+14|0);d=v[22452];v[22452]=0;if((d|0)==1){break a}}a=a+2|0;continue}break}ab=c+16|0;return}a=P()|0;O()|0;dA(e);S(a|0);L()}function n9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(zd(w[b+24|0])){d=SL(a);c=al(b);e=Af(b);v[22452]=0;U(782,a|0,c|0,e|0);c=v[22452];v[22452]=0;a:{b:{if((c|0)==1){break b}d=a;v[22452]=0;Q(781,a+12|0,b+12|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;dM(d);S(a|0);L()}t[a+24|0]=1}}function eQ(a,b){var c=0,d=0;a:{c=ab+-64|0;ab=c;d=c+40|0;Je(d,a,4);a=v[c+40>>2];Se(c+8|0,3,Sd(d),a);v[22452]=0;W(213,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22452];v[22452]=0;if((a|0)!=1){Zb(c,b,5);a=c+24|0;pj(c,a);pb(a);rc(c+40|0);ab=c- -64|0;break a}a=P()|0;O()|0;rc(c+40|0);S(a|0);L()}}function dK(a,b){var c=0,d=0,e=0,f=0,g=C(0);c=ab-16|0;ab=c;if(uh(v[v[a>>2]-12>>2]+a|0)){u[c+14>>1]=0;Kf(a,c+14|0);e=x[c+14>>1];Ij(b,e);while(1){if((d|0)!=(e|0)){v[c+8>>2]=0;Vo(a,c+8|0);f=Fb(v[b>>2],d),g=z[c+8>>2],z[f>>2]=g;d=d+1|0;continue}break}d=uh(v[v[a>>2]-12>>2]+a|0)}ab=c+16|0;return d}function II(a,b){var c=0;c=ab-32|0;ab=c;ch(c,b);v[22452]=0;U(1034,c+16|0,0,c|0);b=v[22452];v[22452]=0;a:{b:{if((b|0)!=1){v[22452]=0;R(1035,a|0,c+16|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}Oc(c+16|0);pb(c);ab=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Oc(c+16|0)}pb(c);S(b|0);L()}function iv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function cB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=v[a>>2];g=ck(e,v[a+4>>2]);while(1){a:{f=d&65535;if(f>>>0>=g>>>0){break a}if(!Gh(Nf(e,f))){break a}d=d+1|0;continue}break}b:{if(c){c=65535;if(x[v[v[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0){break b}}c=Vg(a,d&65535,b)?d:-1}return c&65535}function Tv(a,b,c,d){var e=0,f=0,g=0,h=0;e=ab-160|0;ab=e;v[e+60>>2]=b;v[e+20>>2]=b;v[e+24>>2]=-1;f=e+16|0;Th(f,0,0);HF(e,f,d,1);d=v[e+8>>2];f=v[e+12>>2];g=v[e>>2];h=v[e+4>>2];if(c){v[c>>2]=((v[e+20>>2]+v[e+136>>2]|0)-v[e+60>>2]|0)+b}v[a+8>>2]=d;v[a+12>>2]=f;v[a>>2]=g;v[a+4>>2]=h;ab=e+160|0}function PS(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function uJ(a){a=a|0;var b=0,c=0;c=ab-16|0;ab=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[22452]=0;v[c+12>>2]=0;U(881,a+4208|0,b<<2,c+12|0);b=v[22452];v[22452]=0;a:{if((b|0)==1){b=V(88408)|0;if((O()|0)!=(fa(88408)|0)){break a}_(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;ab=c+16|0;return}S(b|0);L()}function dy(a,b,c){var d=0;d=v[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=w[b+813|0];if(c){t[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}Jj(a,b,b+700|0,c<<2,0)}}function TC(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=v[a+92>>2];e=v[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){v[a+96>>2]=e;v[a+92>>2]=d}else{f=(g<<3)+b|0;h=v[f>>2];d=d-Wc((Wc(0-d|0,31)&255)+d|0,8)|0;v[f>>2]=h+d;h=v[f+4>>2];e=e-Wc((Wc(0-e|0,31)&255)+e|0,8)|0;v[f+4>>2]=h+e;g=g+1|0;continue}break}}}function Fg(a,b){var c=0,d=0,e=0,f=0;d=ab-16|0;ab=d;a:{if(!b){b=0;break a}c=b>>31;e=c+b^c;c=E(e);zf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;ab=d+16|0}function Ao(a,b){var c=0,d=0;c=ab-16|0;ab=c;d=c+8|0;zc(d,a);v[22452]=0;a=T(1111,d|0)|0;d=v[22452];v[22452]=0;a:{b:{if((d|0)==1){break b}v[22452]=0;W(1123,a|0,79744,79770,b|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}Nb(c+8|0);ab=c+16|0;break a}a=P()|0;O()|0;Nb(c+8|0);S(a|0);L()}return b}function jga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-16|0;ab=d;Pe(b);v[d+12>>2]=0;a:{if(!Xj(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}t[d+11|0]=0;if(wh(a,d+11|0)){pp(b,t[d+11|0]);e=e+1|0;continue}break}e=0}ab=d+16|0;return e|0}function VF(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=ab-16|0;ab=d;e=bs(a);v[a+32>>2]=b;v[a>>2]=74860;b=d+8|0;rr(b,e);v[22452]=0;b=T(1090,b|0)|0;f=v[22452];v[22452]=0;if((f|0)!=1){Nb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Qm(b),t[g+44|0]=h;ab=d+16|0;return}a=P()|0;O()|0;Nb(d+8|0);Fl(e);S(a|0);L()}function UF(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=ab-16|0;ab=d;e=oG(a);v[a+32>>2]=b;v[a>>2]=75028;b=d+8|0;rr(b,e);v[22452]=0;b=T(1091,b|0)|0;f=v[22452];v[22452]=0;if((f|0)!=1){Nb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Qm(b),t[g+44|0]=h;ab=d+16|0;return}a=P()|0;O()|0;Nb(d+8|0);Fo(e);S(a|0);L()}function wz(a,b,c,d,e){var f=0;a:{if(!Fd(a)){break a}f=v[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break a}Xl(b);b=Ln(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!sg(b)){break a}if(v[a>>2]!=(d|0)){Dq(b+68|0)}gc(v[b+20>>2],v[a+20>>2]+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}}function m8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ab-32|0;ab=e;c=cf(a,c);f=e+8|0;Xd(f,v[a+28>>2]);g=v[f+12>>2];v[e+24>>2]=v[f+8>>2];v[e+28>>2]=g;a:{b:{if(!c){f=0;g=-1;if(!Vc(a,5)){break b}break a}g=v[c+8>>2]}eb[d|0](v[a+28>>2],b,g);f=c}a=Te(a,f,e+24|0);ab=e+32|0;return a|0}function XP(a){var b=0,c=0;a:{if(Ib(a,3868,4)|w[a+63|0]!=26){break a}b=w[a+65|0];if(w[a- -64|0]&3|(w[a+66|0]|(b|0)!=16&(b|0)!=1)){break a}b=a+78|0;if((w[b|0]|w[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((w[a|0]|w[a+1|0]<<8)>>>0>127){break a}a=_B(b,a)?a:b;c=(w[a|0]|w[a+1|0]<<8)!=0}return c}function MN(a){a=a|0;var b=0,c=0,d=0;b=ab-16|0;ab=b;if(w[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){t[a+534|0]=0}else{cj(a,d,1);c=c+1|0;continue}break}}t[b+15|0]=0;Lh(a+8|0,18,b+15|0);wt(a+26|0,18,29194);t[b+14|0]=255;Lh(a+62|0,256,b+14|0);Mg(a,65535,261,1);Mg(a,65535,260,0);ab=b+16|0}function IL(a,b,c){var d=0;d=v[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=w[b+814|0];if(c){t[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}Jj(a,b,b+700|0,c,0)}}function x6(a,b,c){a=a|0;b=b|0;c=C(c);var d=C(0);if((b|0)<=6){c=Ed(c,C(0));a:{b:{switch(b-3|0){case 0:d=z[a+4220>>2];c=kf(c);if(d==c){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 1:break b;default:break a}}c=C(kf(C(c*C(4)))*C(.25))}z[((b<<2)+a|0)+4208>>2]=c;fx(a)}}function mR(a,b,c){var d=0,e=0,f=0;f=ab-16|0;ab=f;e=ub(a);d=Ec(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Eb(a);if(e){_j(c+d|0,d,e);b=(b>>>0>=d>>>0?d+e>>>0>b>>>0?c:0:0)+b|0}b=_j(d,b,c);c=c+e|0;cg(a,c);t[f+15|0]=0;md(b+c|0,f+15|0);break a}Un(a,d,(c+e|0)-d|0,e,0,0,c,b)}ab=f+16|0;return a}function O5(a,b,c){a=a|0;b=b|0;c=C(c);var d=C(0);if((b|0)<=6){c=Ed(c,C(0));a:{b:{switch(b-1|0){case 0:d=z[a+4212>>2];c=kf(c);if(d==c){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 3:break b;default:break a}}c=C(kf(C(c*C(4)))*C(.25))}z[((b<<2)+a|0)+4208>>2]=c;fx(a)}}function Ll(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,872)+a|0)+1075648>>2];if(!f){break a}if(!fj(w[f+31|0])){break a}e=w[f+34|0];if((e-1&255)>>>0>249){break a}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break a}eb[v[v[e>>2]+92>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,872)+a|0)+1075834>>1]=65535}}function kB(a,b,c){var d=0,e=0;d=ab+-64|0;ab=d;Pe(b);e=d+40|0;Je(e,a,c);a=v[d+40>>2];Se(d+8|0,2,Sd(e),a);v[22452]=0;W(213,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22452];v[22452]=0;if((a|0)!=1){a=d+24|0;tb(b,a);pb(a);rc(d+40|0);ab=d- -64|0;return}a=P()|0;O()|0;rc(d+40|0);S(a|0);L()}function iK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-16|0;ab=d;v[d+12>>2]=b;a:{if(Ch(a)>>>0>=b>>>0){f=v[a>>2];e=nc(f,v[a+4>>2]);v[d+8>>2]=e;hK(f,v[zb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){xx(a,b-e|0,c);break a}Hd(a,v[a>>2]+(b<<2)|0);break a}Zz(a);$n(a,fh(a,b));xx(a,b,c)}ab=d+16|0}function PI(a,b,c,d,e){var f=0;a:{if((e|0)==10){lJ(a,b,c,d);break a}f=d>>>0<e>>>0?1:B(e,e)>>>0>d>>>0?2:3;if((f|0)>(c-b|0)){v[a+4>>2]=61;v[a>>2]=c;break a}c=b+f|0;b=c;while(1){f=d&255;d=(f|0)/(e|0)|0;b=b-1|0;t[b|0]=w[(f-B(d,e)|0)+4856|0];if(d&255){continue}break}v[a+4>>2]=0;v[a>>2]=c}}function NC(a,b,c,d){var e=0,f=0,g=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;e=d;d=v[a+1068>>2];u[e+(d<<1)>>1]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;f=a,g=qd(x[v[a+1060>>2]+34>>1])+d|0,v[f+1068>>2]=g;v[a+1072>>2]=v[a+1072>>2]-1}function wZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=ab-128|0;ab=c;v[c+12>>2]=c+116;d=a+8|0;a=c+16|0;VE(d,a,c+12|0,e,f,g);e=v[c+12>>2];d=ab-16|0;ab=d;v[d+8>>2]=b;while(1){if((a|0)!=(e|0)){bG(d+8|0,t[a|0]);a=a+1|0;continue}break}ab=d+16|0;ab=c+128|0;return v[d+8>>2]}function kj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=wb(v[b>>2]);f=wb(v[b+4>>2]);d=ab-16|0;ab=d;v[d>>2]=c;v[d+8>>2]=e;while(1){a:{b:{if(Tb(e,f)){if(!lT(d,e)){break b}e=v[d+8>>2]}ab=d+16|0;c=e;break a}em(d+8|0);e=v[d+8>>2];continue}break}if(jc(c,wb(v[b+4>>2]))){Nh(a);return}gm(a,c)}function kr(a,b,c,d){var e=0,f=0;e=ab-160|0;ab=e;f=-1;v[e+148>>2]=b?b-1|0:0;a=b?a:e+158|0;v[e+144>>2]=a;e=Jb(e,0,144);v[e+76>>2]=-1;v[e+36>>2]=1093;v[e+80>>2]=-1;v[e+44>>2]=e+159;v[e+84>>2]=e+144;a:{if((b|0)<0){v[114934]=61;break a}t[a|0]=0;f=CG(e,c,d,1072,1073)}ab=e+160|0;return f}function Pf(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=w[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function Cc(a,b,c){var d=0,e=0;d=b^-2147483648;e=a;b=c&31;if((c&63)>>>0>=32){a=0;b=d>>>b|0}else{a=d>>>b|0;b=((1<<b)-1&d)<<32-b|e>>>b}d=c&31;if((c&63)>>>0>=32){c=0;d=-2147483648>>>d|0}else{c=-2147483648>>>d|0;d=((1<<d)-1&-2147483648)<<32-d}e=b-d|0;db=a-(c+(b>>>0<d>>>0)|0)|0;return e}function yl(a,b){v[a>>2]=0;v[a+4>>2]=0;v[a+20>>2]=0;u[a+16>>1]=65535;v[a+8>>2]=0;v[a+12>>2]=0;v[a+24>>2]=11;v[a+28>>2]=b;Pb(a+32|0);Pb(a+44|0);v[a+72>>2]=0;v[a+76>>2]=0;v[a+64>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;v[a+80>>2]=0;v[a+84>>2]=0;v[a+88>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;return a}function t2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=is(c);v[a>>2]=74120;v[d>>2]=74140;v[a>>2]=74160;v[a+4>>2]=0;v[c>>2]=74180;e=c;c=a+8|0;jn(e,c);v[a>>2]=74120;v[d>>2]=74140;v[22452]=0;Q(82,c|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Jk(d);S(a|0);L()}function rS(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+38|0;e=w[b|0]|w[b+1|0]<<8;b=a+36|0;a=a+34|0;c=w[a|0]|w[a+1|0]<<8;b=(w[b|0]|w[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;db=a;return b}function hJ(a,b,c){t[a+12|0]=0;v[c>>2]=0;v[b>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;u[a+24>>1]=0;v[a+36>>2]=0;v[a+40>>2]=0;v[a+44>>2]=0;v[a+48>>2]=0;gJ(a+60|0);gJ(a+52|0);dp(a+49956|0);dp(a+58148|0);dp(a+66340|0);dp(a+74532|0);Jb(a+228|0,0,32768);Jb(a+32996|0,0,512);Jb(a+33508|0,0,16384)}function dO(a,b,c){a:{switch(b|0){case 0:Tk(a,0,c);return;case 1:Tk(a,1,c);return;case 2:Tk(a,2,c);return;case 3:Tk(a,3,c);return;case 4:Tk(a,4,c);return;case 5:Tk(a,5,c);return;case 6:QN(a,23712,c);return;case 7:QN(a,24736,c);return;case 8:Tk(a,6,c);return;default:break a}}Bb(a)}function cv(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=ab-16|0;ab=f;v[f+12>>2]=e;v[f+8>>2]=d;Gg(f,b,c);v[22452]=0;U(162,a|0,v[f>>2],v[f+4>>2]);b=v[22452];v[22452]=0;if((b|0)!=1){v[a+8>>2]=0;b=f+8|0;Gf(a+12|0,b);Cd(b);ab=f+16|0;return a|0}a=P()|0;O()|0;Cd(f+8|0);S(a|0);L()}function Ji(a,b,c,d){var e=0,f=0,g=0,h=0;e=ab-16|0;ab=e;v[e+12>>2]=d;g=Sh(e+8|0,b);b=ab-16|0;ab=b;d=v[e+12>>2];v[b+12>>2]=d;v[b+8>>2]=d;f=-1;d=kr(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=yd(d);v[h>>2]=a;if(!a){break a}f=kr(a,d,c,v[b+12>>2])}ab=b+16|0;Rh(g);ab=e+16|0;return f}function tfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=ab-16|0;ab=f;v[f+12>>2]=e;v[f+8>>2]=d;d=Gf(f,f+8|0);e=v[d+4>>2];d=v[d>>2];v[22452]=0;ea(536,a|0,b|0,c|0,d|0,e|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){Cd(f+8|0);ab=f+16|0;return a|0}a=P()|0;O()|0;Cd(f+8|0);S(a|0);L()}function kf(a){var b=C(0),c=0,d=0;c=(p(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return C(a*C(0))}a=(c|0)>=0?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){a=C(C(a+b)+C(-1));break a}a=C(a+b);if(!(b<=C(-.5))){break a}a=C(a+C(1))}a=(c|0)>=0?a:C(-a)}return a}function X9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=sd(a);a:{d=Ag(v[b>>2],v[b+4>>2]);if(d){v[22452]=0;R(739,a|0,d|0);e=v[22452];v[22452]=0;if((e|0)==1){break a}c=ab-16|0;ab=c;e=v[b>>2];f=v[b+4>>2];b=Hq(c,a,d);Ft(e,f,b+4|0);dc(b);ab=c+16|0}return a|0}a=P()|0;O()|0;Ud(c);S(a|0);L()}function W6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-32|0;ab=d;v[d+28>>2]=c;v[d+8>>2]=33;c=v[zb(d+28|0,d+8|0)>>2];if(!Hb(a,c)){c=Ze(a)}e=d+8|0;kA(e,b);f=Zb(d+16|0,v[d+8>>2],c);_b(d,a,v[f>>2],v[f+4>>2]);kA(e,b);Jb(v[d+8>>2]+c|0,0,33-c|0);Ob(a,v[d+28>>2]);ab=d+32|0;return c|0}function S9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-16|0;ab=d;v[d+12>>2]=b;a:{if(Do(a)>>>0>=b>>>0){f=v[a>>2];e=Ic(f,v[a+4>>2]);v[d+8>>2]=e;Lh(f,v[zb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){tm(a,b-e|0,c);break a}Hd(a,v[a>>2]+b|0);break a}SA(a);kl(a,ul(a,b));tm(a,b,c)}ab=d+16|0}function A7(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{d=v[a+20>>2];c=v[d+4>>2];if((Ic(c,v[d+8>>2])|0)!=8){break b}if(Ib(c,9527,4)){break b}b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);v[a+4260>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[a+4264>>2]=b;break a}mx(a,b)}ls(a)}function uO(a,b){var c=0,d=0,e=0,f=0;c=ab-96|0;ab=c;hQ(b,c,c+96|0);b=0;while(1){if((b|0)==12){v[a+104>>2]=0;v[a+96>>2]=!(v[a+88>>2]|v[a+92>>2]);v[a+100>>2]=0;ab=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d&65535;b=b+1|0;continue}break}v[a+112>>2]=0}function rq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=ab-16|0;ab=f;v[f+12>>2]=c;c=f+12|0;mc(c,256);mc(c,65535);h=x[f+12>>1];mf(a,h);c=0;while(1){if((c|0)==(h|0)){ab=f+16|0}else{g=w[b+c|0];i=yi(v[a>>2],v[a+4>>2],c),j=(d|0)==(g|0)?-1:(e|0)==(g|0)?-2:g,u[i>>1]=j;c=c+1|0;continue}break}}function n5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ci(a,b,c,d);v[a+4272>>2]=1065353216;v[a>>2]=47152;v[a+4216>>2]=1056964608;v[a+4208>>2]=1056880300;v[a+4212>>2]=1050733080;v[22452]=0;R(875,a+44|0,2);c=v[22452];v[22452]=0;if((c|0)!=1){bi(b);return a|0}a=P()|0;O()|0;ff(b);S(a|0);L()}function WS(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=ab-16|0;ab=f;v[f+12>>2]=e;v[f+8>>2]=d;d=Gf(f,f+8|0);e=v[d+4>>2];d=v[d>>2];v[22452]=0;ea(328,a|0,b|0,c|0,d|0,e|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){Cd(f+8|0);ab=f+16|0;return a|0}a=P()|0;O()|0;Cd(f+8|0);S(a|0);L()}function OB(a,b,c){var d=0,e=0;d=ab+-64|0;ab=d;e=d+40|0;Je(e,a,c);a=v[d+40>>2];Se(d+8|0,3,Sd(e),a);v[22452]=0;W(213,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22452];v[22452]=0;if((a|0)!=1){a=d+24|0;jm(b,a);pb(a);rc(d+40|0);ab=d- -64|0;return}a=P()|0;O()|0;rc(d+40|0);S(a|0);L()}function Nq(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=ab-16|0;ab=f;v[f+12>>2]=e;v[f+8>>2]=d;d=Gf(f,f+8|0);e=v[d+4>>2];d=v[d>>2];v[22452]=0;ea(160,a|0,b|0,c|0,d|0,e|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){Cd(f+8|0);ab=f+16|0;return a|0}a=P()|0;O()|0;Cd(f+8|0);S(a|0);L()}function pR(a,b,c,d){var e=0,f=0;e=ab-16|0;ab=e;v[e+12>>2]=a;a:{if(!(!c|b)){a=xe(+(B(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){mc(e+12|0,10);a=B(w[v[e+12>>2]+26800|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=xe(733.8401379310345/f*1e4);break a}a=xe(f/.264*1e4)}ab=e+16|0;return a}function MC(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;t[v[a+1068>>2]+d|0]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=v[a+1068>>2]+qd(x[v[a+1060>>2]+34>>1])|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function Ey(a,b){var c=0,d=0,e=0,f=0,g=0;c=ab-16|0;ab=c;qe(c+8|0,b);b=ab-16|0;ab=b;f=v[c+8>>2];d=v[c+12>>2];e=ub(a);v[b+12>>2]=e;v[b+8>>2]=d;g=zb(b+12|0,b+8|0);a=pn(Eb(a),f,v[g>>2]);a:{if(a){break a}a=-1;if(d>>>0>e>>>0){break a}a=d>>>0<e>>>0}ab=b+16|0;ab=c+16|0;return a>>>31|0}function AI(a,b,c){var d=0,e=0;while(1){a:{if((a|0)!=(b|0)){e=v[a>>2];d=Pf(e);b:{c:{if((ub(c)|0)==(d|0)){v[22452]=0;d=Y(358,c|0,e|0,d|0)|0;e=v[22452];v[22452]=0;if((e|0)==1){break c}d=!d}else{d=0}break b}V(0)|0;O()|0;Gb();L()}if(!d){break a}}else{a=b}return a}a=a+8|0;continue}}function pj(a,b){var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;d=Eb(b);e=c,f=ub(b),v[e+12>>2]=f;v[c+8>>2]=v[a+4>>2]-1;fk(d,d+v[zb(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];e=c,f=ub(b),v[e+12>>2]=f;a=v[a+4>>2];v[c+8>>2]=a-1;b=v[zb(c+12|0,c+8|0)>>2];t[c+7|0]=0;Jl(b+d|0,a+d|0,c+7|0);ab=c+16|0}function Le(a){var b=0,c=0;b=ab-32|0;ab=b;t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;sC(b+9|0);v[a>>2]=v[b>>2];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;c=v[b+24>>2];v[a+20>>2]=v[b+20>>2];v[a+24>>2]=c;t[a+28|0]=w[b+28|0];ab=b+32|0}function baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;b=SO(d,a+8|0,b);a=v[b>>2];a:{while(1){if(v[b+4>>2]==(a|0)){break a}v[22452]=0;R(727,a|0,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){a=v[b>>2]+32|0;v[b>>2]=a;continue}break}a=P()|0;O()|0;xd(b);S(a|0);L()}xd(b);ab=d+16|0}function xI(a){var b=0,c=0,d=0,e=0;d=ab-16|0;ab=d;b=a+120|0;Xh(b);c=ab-16|0;ab=c;v[c+8>>2]=d+8;a=ab-16|0;ab=a;e=v[13463];v[a+8>>2]=v[13462];v[a+12>>2]=e;e=v[13461];v[a>>2]=v[13460];v[a+4>>2]=e;b=eb[v[yh(a,Ig(w[b+20|0]))>>2]](c+8|0,b)|0;ab=a+16|0;ab=c+16|0;ab=d+16|0;return b}function haa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-32|0;ab=d;f=cf(a,c);c=d+8|0;Xd(c,v[a+28>>2]);e=v[c+12>>2];v[d+24>>2]=v[c+8>>2];v[d+28>>2]=e;a:{b:{if(!f){c=0;e=-1;if(!Vc(a,5)){break b}break a}e=v[f+8>>2]}Wy(v[a+28>>2],b,e);c=f}a=Te(a,c,d+24|0);ab=d+32|0;return a|0}function NJ(a){a=a|0;var b=0,c=0;c=ab-16|0;ab=c;b=v[v[a+16>>2]+1074404>>2];v[22452]=0;v[c+12>>2]=0;U(881,a+4208|0,B(b,254)|0,c+12|0);b=v[22452];v[22452]=0;a:{if((b|0)==1){b=V(88408)|0;if((O()|0)!=(fa(88408)|0)){break a}_(b|0)|0;$()}v[a+4220>>2]=0;ab=c+16|0;return}S(b|0);L()}function pca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-32|0;ab=d;v[d+28>>2]=c;v[d+8>>2]=4896;c=v[zb(d+28|0,d+8|0)>>2];if(!Hb(a,c)){c=Ze(a)}e=d+8|0;nA(e,b);f=Zb(d+16|0,v[d+8>>2],c);_b(d,a,v[f>>2],v[f+4>>2]);nA(e,b);Jb(v[d+8>>2]+c|0,0,4896-c|0);Ob(a,v[d+28>>2]);ab=d+32|0}function H9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{d:{if(me(a)){c=gk(a)-1|0;d=v[a+4>>2];if((c|0)==(d|0)){break d}break b}c=1;d=w[a+11|0];if((d|0)!=1){break c}}ME(a,c,1,c,c);d=c;if(me(a)){break b}}c=a;ye(a,d+1|0);break a}c=v[a>>2];Qd(a,d+1|0)}a=(d<<2)+c|0;nd(a,b);nd(a+4|0,0)}function ET(a,b){var c=0,d=0,e=0;d=ab-16|0;ab=d;v[d+12>>2]=b;c=ab-16|0;ab=c;v[c+12>>2]=153391689;v[c+8>>2]=2147483647;e=zb(c+12|0,c+8|0);ab=c+16|0;c=b;b=v[e>>2];if(c>>>0<=b>>>0){a=iB(a);if(a>>>0<b>>>1>>>0){v[d+8>>2]=a<<1;b=v[Pc(d+8|0,d+12|0)>>2]}ab=d+16|0;return b}hd();L()}function pB(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function iT(a,b){var c=0,d=0,e=0;d=ab-16|0;ab=d;v[d+12>>2]=b;c=ab-16|0;ab=c;v[c+12>>2]=89478485;v[c+8>>2]=2147483647;e=zb(c+12|0,c+8|0);ab=c+16|0;c=b;b=v[e>>2];if(c>>>0<=b>>>0){a=eT(a);if(a>>>0<b>>>1>>>0){v[d+8>>2]=a<<1;b=v[Pc(d+8|0,d+12|0)>>2]}ab=d+16|0;return b}hd();L()}function g5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ci(a,b,c,d);c=a+4216|0;v[c>>2]=1051372203;v[c+4>>2]=0;v[a+4208>>2]=1065353216;v[a+4212>>2]=1065353216;v[a>>2]=47384;v[22452]=0;R(875,a+44|0,2);c=v[22452];v[22452]=0;if((c|0)!=1){bi(b);return a|0}a=P()|0;O()|0;ff(b);S(a|0);L()}function dC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;b=zu(c,a,b);a=v[b+4>>2];d=v[b+8>>2];a:{while(1){if((a|0)==(d|0)){break a}v[22452]=0;Z(222,a|0);e=v[22452];v[22452]=0;if((e|0)!=1){a=a+20|0;v[b+4>>2]=a;continue}break}a=P()|0;O()|0;dc(b);S(a|0);L()}dc(b);ab=c+16|0}function a8(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-48|0;ab=c;d=c+40|0;t[d|0]=b;t[d+1|0]=b>>>8;ll(c+16|0,d);b=v[c+16>>2];ll(c+8|0,d);b=pg(c+24|0,b,v[c+8>>2]+2|0);v[22452]=0;Q(730,a|0,b|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){pb(b);ab=c+48|0;return}a=P()|0;O()|0;pb(b);S(a|0);L()}function Vm(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=ria(a,b,10,0);f=db;e=oia(d,f,-10,-1)+a|0;c=c-1|0;t[c|0]=e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=B(a,-10)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function KD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ab-32|0;ab=e;f=v[b>>2];g=v[b+8>>2];Gg(e+16|0,c,d);c=v[v[f>>2]+28>>2];d=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=d;eb[c|0](e+24|0,f,g,e+8|0);Gg(a,v[e+24>>2],v[e+28>>2]);v[b+8>>2]=v[b+8>>2]+v[a+4>>2];ab=e+32|0}function xca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-32|0;ab=d;v[d+28>>2]=c;v[d+8>>2]=263;c=v[zb(d+28|0,d+8|0)>>2];if(!Hb(a,c)){c=Ze(a)}e=d+8|0;CO(e,b);f=Zb(d+16|0,v[d+8>>2],c);_b(d,a,v[f>>2],v[f+4>>2]);CO(e,b);Jb(v[d+8>>2]+c|0,0,263-c|0);Ob(a,v[d+28>>2]);ab=d+32|0}function F1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;fn(c,a);if(v[b>>2]){uc(b);a=v[b>>2];ut(b);xb(a);d=vb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=vb(c);d=vb(b),e=v[a>>2],v[d>>2]=e;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Hf(c);ab=c+16|0}function C_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=t[b|0];g=t[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function AP(a){var b=0,c=0,d=0,e=0;b=ab-16|0;ab=b;c=wb(v[a>>2]);v[b+8>>2]=c;e=wb(v[a+4>>2]);while(1){a:{d=Tb(c,e);if(!d){break a}a=x[c>>1];b:{if(!((a|0)!=255&(a|0)!=99)){u[c>>1]=65535;break b}if(a>>>0>63){break a}}Ke(b+8|0);c=v[b+8>>2];continue}break}ab=b+16|0;return d^1}function tC(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=ab-16|0;ab=d;v[d+12>>2]=c;c=d+12|0;mc(c,128);mc(c,65535);f=x[d+12>>1];mf(a,f);c=0;while(1){if((c|0)==(f|0)){ab=d+16|0}else{e=w[b+c|0];g=yi(v[a>>2],v[a+4>>2],c),h=(e|0)==255?-1:(e|0)==254?-2:e,u[g>>1]=h;c=c+1|0;continue}break}}function be(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function U0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ab-32|0;ab=d;v[d+24>>2]=c;a:{while(1){if((a|0)==(b|0)){break a}c=Mb(d+8|0,v[a>>2]);v[22452]=0;Q(1053,d+24|0,c|0)|0;e=v[22452];v[22452]=0;if((e|0)!=1){pb(c);a=a+4|0;continue}break}a=P()|0;O()|0;pb(c);S(a|0);L()}ab=d+32|0}function JS(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=ab-16|0;ab=d;v[d+12>>2]=c;c=d+12|0;mc(c,256);mc(c,65535);f=x[d+12>>1];mf(a,f);c=0;while(1){if((c|0)==(f|0)){ab=d+16|0}else{e=w[b+c|0];g=yi(v[a>>2],v[a+4>>2],c),h=(e|0)==255?-1:(e|0)==254?-2:e,u[g>>1]=h;c=c+1|0;continue}break}}function wP(a){var b=0,c=0;a:{if(Ib(a,14972,4)){break a}b=a+4|0;if(Ab(w[b|0]|w[b+1|0]<<8)>>>0>2|w[a+6|0]>128){break a}b=a+200|0;if(Ab(w[b|0]|w[b+1|0]<<8)>>>0>3999){break a}b=a+140|0;if(!Ab(w[b|0]|w[b+1|0]<<8)){break a}a=a+148|0;c=(Ab(w[a|0]|w[a+1|0]<<8)|0)==50}return c}function mO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=ab-16|0;ab=e;b:{c:{if((b|0)==(c|0)){b=a;a=Eb(d);pg(b,a,ub(d)+a|0);break c}dO(e,c,d);v[22452]=0;U(44,a|0,b|0,e|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}Oc(e)}ab=e+16|0;break a}a=P()|0;O()|0;Oc(e);S(a|0);L()}}function VD(a,b,c,d){var e=0,f=0,g=0;e=ab-16|0;ab=e;d=d-c|0;a:{if(!d){b=a;break a}if((d|0)>(b-a|0)){break a}t[e+15|0]=w[c|0];g=1-d|0;while(1){f=b-a|0;if((d|0)>(f|0)){break a}a=Qp(a,g+f|0,e+15|0);if(!a){break a}if(pn(a,c,d)){a=a+1|0;continue}break}b=a}ab=e+16|0;return b}function V6(a){a=a|0;var b=0,c=0,d=0,e=0;b=ab-16|0;ab=b;v[b+12>>2]=a;v[b+8>>2]=4104;a=0;d=v[b+8>>2];a:{if(d>>>0<4096){break a}c=v[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}v[b+12>>2]=e;v[b+8>>2]=d-c;a=e}if(!a){ca(6014,8985,88,7318);L()}ab=b+16|0;return a|0}function Pm(a,b){var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;a:{if(!b){b=0;break a}d=b;b=E(b);zf(c,d,0,0,0,b+81|0);e=16414-b<<16;b=0;d=b+v[c+8>>2]|0;e=e+(v[c+12>>2]^65536)|0;e=b>>>0>d>>>0?e+1|0:e;f=d;d=v[c>>2];b=v[c+4>>2]}v[a>>2]=d;v[a+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=e;ab=c+16|0}function IV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-16|0;ab=d;v[d+12>>2]=c;v[d+8>>2]=b;b=ab-16|0;ab=b;v[b+4>>2]=1;e=b,f=pc(24),v[e+8>>2]=f;c=v[b+8>>2];oo(c);v[c>>2]=58228;ED(ic(c),v[d+8>>2],v[d+12>>2]);c=qo(b);po(d,ic(c),c);Dm(b);ab=b+16|0;Gf(a,d);Cd(d);ab=d+16|0}function Efa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-32|0;ab=d;v[d+28>>2]=c;v[d+8>>2]=22;c=v[zb(d+28|0,d+8|0)>>2];if(!Hb(a,c)){c=Ze(a)}e=d+8|0;Ot(e,b);f=Zb(d+16|0,v[d+8>>2],c);_b(d,a,v[f>>2],v[f+4>>2]);Ot(e,b);Jb(v[d+8>>2]+c|0,0,22-c|0);Ob(a,v[d+28>>2]);ab=d+32|0}function Cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-32|0;ab=d;v[d+28>>2]=c;v[d+8>>2]=40;c=v[zb(d+28|0,d+8|0)>>2];if(!Hb(a,c)){c=Ze(a)}e=d+8|0;aA(e,b);f=Zb(d+16|0,v[d+8>>2],c);_b(d,a,v[f>>2],v[f+4>>2]);aA(e,b);Jb(v[d+8>>2]+c|0,0,40-c|0);Ob(a,v[d+28>>2]);ab=d+32|0}function jB(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=ab-16|0;ab=b;f=Cb(a,31),g=0,t[f|0]=g;t[b+15|0]=0;c=fi(a,zp(a),b+15|0);t[b+14|0]=0;c=hi(a,c);Jl(c+a|0,zp(a),b+14|0);while(1){if((c|0)!=(d|0)){e=Cb(a,d);if((w[e|0]-127&255)>>>0<=160){t[e|0]=32}d=d+1|0;continue}break}ab=b+16|0}function hs(a){var b=0,c=0,d=C(0);b=a+4232|0;c=w[b|0];if(c>>>0>=5){t[b|0]=0;c=0}if(t[a+4233|0]<0){t[a+4233|0]=127}b=t[a+4234|0];if((b|0)<0){t[a+4234|0]=127;b=127}a:{if((c|0)==3){d=C(C(1)-fe(C(2),C(-C((b&255)+1|0))));break a}d=fe(C(2),C(-C((b&255)>>>0)))}z[a+4224>>2]=d}function a1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Bb(a);d=ub(b);e=ub(c);b=Eb(b);v[22452]=0;W(92,a|0,b|0,d|0,d+e|0);b=v[22452];v[22452]=0;a:{if((b|0)!=1){b=Eb(c);v[22452]=0;Y(93,a|0,b|0,e|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;pb(a);S(b|0);L()}}function EU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-32|0;ab=d;v[d+28>>2]=c;v[d+8>>2]=65;c=v[zb(d+28|0,d+8|0)>>2];if(!Hb(a,c)){c=Ze(a)}e=d+8|0;yu(e,b);f=Zb(d+16|0,v[d+8>>2],c);_b(d,a,v[f>>2],v[f+4>>2]);yu(e,b);Jb(v[d+8>>2]+c|0,0,65-c|0);Ob(a,v[d+28>>2]);ab=d+32|0}function S5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;MJ(a,b,c,d,e^1);v[a+4232>>2]=1056964608;b=a+4224|0;v[b>>2]=1056964608;v[b+4>>2]=1048406533;b=a+4216|0;v[b>>2]=1020054733;v[b+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1065353216;v[a>>2]=46132;return a|0}function wo(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function pT(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[$e(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[$e(d+13|0,d+12|0)|0]}ab=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function lh(a,b){var c=0,d=0,e=0;a:{if(!(b?1:t[a+480180|0]&1)){break a}e=v[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function iia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=ab-624|0;ab=b;e=-1;c=ab-16|0;ab=c;f=b+8|0;AT(c+8|0,f);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(g|0);if(!a){zT(f)}if(a){e=BT(b+8|0)}ab=b+624|0;return e|0}function fA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;vR(a,b);e=b+8|0;Nc(a,Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+504|0);uR(a,d);a:{b=b+32|0;b=Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));if(!b){break a}if(!Nc(a,b)){break a}hA(a,c);return}Jb(c,0,80)}function Zy(a,b,c){var d=0,e=0,f=0;d=ab-16|0;ab=d;b=kz(d,a,b);a=v[b+4>>2];e=v[b+8>>2];a:{while(1){if((a|0)==(e|0)){break a}v[22452]=0;R(727,a|0,c|0);f=v[22452];v[22452]=0;if((f|0)!=1){a=a+32|0;v[b+4>>2]=a;continue}break}a=P()|0;O()|0;dc(b);S(a|0);L()}dc(b);ab=d+16|0}function O_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=rg(t[b|0]),e=v[v[a>>2]+52>>2],eb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=bk(b,1,c,v[a+32>>2])}return c|0}function Nda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=ab-160|0;ab=b;e=-1;c=ab-16|0;ab=c;f=b+8|0;WP(c+8|0,f);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(g|0);if(!a){VP(f)}if(a){e=XP(b+8|0)}ab=b+160|0;return e|0}function KC(a,b){var c=0,d=0;c=ab-16|0;ab=c;d=c+8|0;zc(d,a);v[22452]=0;a=T(18,d|0)|0;d=v[22452];v[22452]=0;a:{if((d|0)==1){break a}v[22452]=0;a=Q(19,a|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break a}Nb(c+8|0);ab=c+16|0;return a}a=P()|0;O()|0;Nb(c+8|0);S(a|0);L()}function HC(a,b,c){var d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;e=v[a+4>>2];f=e+b|0;v[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=v[a>>2];break a}a=v[a>>2];v[a+((f>>>0<33?0:g>>>5|0)<<2)>>2]=0}go(d+8|0,a,e);Mu(v[d+8>>2],v[d+12>>2],b,c);ab=d+16|0}function M6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;v[a+4>>2]=b;v[a>>2]=0;b=Us(a+8|0,d);v[22452]=0;Q(891,a+20|0,c|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&224|25;return a|0}a=P()|0;O()|0;yb(b);S(a|0);L()}function zI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Bb(a);d=Pf(b);e=ub(c);v[22452]=0;W(1039,a|0,b|0,d|0,d+e|0);b=v[22452];v[22452]=0;a:{if((b|0)!=1){b=Eb(c);v[22452]=0;Y(1040,a|0,b|0,e|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;pb(a);S(b|0);L()}}function bga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=ab-16|0;ab=b;e=-1;c=ab-16|0;ab=c;f=b+8|0;gu(c+8|0,f);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(g|0);if(!a){IR(f)}if(a){e=JR(b+8|0)}ab=b+16|0;return e|0}function Eha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=ab-32|0;ab=b;e=-1;c=ab-16|0;ab=c;f=b+8|0;Ot(c+8|0,f);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(g|0);if(!a){PS(f)}if(a){e=QS(b+8|0)}ab=b+32|0;return e|0}function w0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=sd(a);a:{if(!c){break a}v[22452]=0;R(1061,a|0,c|0);e=v[22452];v[22452]=0;if((e|0)!=1){v[22452]=0;W(1062,a|0,b|0,ld(b,c)|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Uc(d);S(a|0);L()}return a|0}function nr(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=v[b+76>>2]>=0;b:{c=v[b+4>>2];c:{if(!c){kw(b);c=v[b+4>>2];if(!c){break c}}if(v[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;d=a&255}return d}function i$(a){a=a|0;var b=0,c=0,d=0;c=v[a+44>>2];b=v[a+24>>2];if(c>>>0<b>>>0){v[a+44>>2]=b;c=b}d=-1;a:{if(!(w[a+48|0]&8)){break a}b=v[a+16>>2];if(b>>>0<c>>>0){Rm(a,v[a+8>>2],v[a+12>>2],c);b=v[a+16>>2]}a=v[a+12>>2];if(a>>>0>=b>>>0){break a}d=rg(t[a|0])}return d|0}function wD(a){var b=0,c=0,d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;c=ab-16|0;ab=c;v[c+4>>2]=1;f=c,g=pc(16),v[f+8>>2]=g;b=v[c+8>>2];oo(b);v[b>>2]=42888;b=ic(b);Cm(b);v[b>>2]=43020;b=d+8|0;e=qo(c);po(b,ic(e),e);Dm(c);ab=c+16|0;Gf(a,b);Cd(b);ab=d+16|0;v[a+8>>2]=0;Vd(a+12|0)}function Mz(a,b,c){var d=0;d=ab-16|0;ab=d;u[d+14>>1]=b;u[d+12>>1]=c;if((b|0)!=(c|0)){b=wb(v[a>>2]);c=wb(v[a+4>>2]);a=ab-16|0;ab=a;v[a+8>>2]=b;while(1){if(Tb(b,c)){if(x[b>>1]==x[d+14>>1]){u[b>>1]=x[d+12>>1]}Ke(a+8|0);b=v[a+8>>2];continue}break}ab=a+16|0}ab=d+16|0}function P0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=ab-16|0;ab=c;v[c+4>>2]=1;e=c,f=pc(52),v[e+8>>2]=f;d=v[c+8>>2];v[22452]=0;Q(1060,d|0,b|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){b=a;a=qo(c);po(b,ic(a),a);Dm(c);ab=c+16|0;break a}a=P()|0;O()|0;Dm(c);S(a|0);L()}}function Bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=ab-16|0;ab=d;v[d+12>>2]=c;c=d+12|0;mc(c,256);mc(c,65535);e=x[d+12>>1];mf(a,e);c=0;while(1){if((c|0)==(e|0)){ab=d+16|0}else{f=w[b+c|0];g=yi(v[a>>2],v[a+4>>2],c),h=f,u[g>>1]=h;c=c+1|0;continue}break}}function ky(a,b,c,d){var e=0,f=0;e=Kd(a);a:{if(e){f=ac(a);while(1){b:{a=e+16|0;if(jy(c,d,a)){a=v[e>>2];if(!a){break a}break b}if(iy(a,c,d)){f=e+4|0;a=v[e+4>>2];if(a){e=f;break b}v[b>>2]=e;return f}v[b>>2]=e;return f}f=e;e=a;continue}}e=ac(a)}v[b>>2]=e;return e}function j8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-32|0;ab=d;c=cf(a,c);e=d+8|0;Xd(e,v[a+28>>2]);f=v[e+12>>2];v[d+24>>2]=v[e+8>>2];v[d+28>>2]=f;a:{b:{if(!c){e=0;f=-1;if(!Vc(a,5)){break b}break a}f=v[c+8>>2]}mS(v[a+28>>2],b,f);e=c}Te(a,e,d+24|0);ab=d+32|0}function dV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-48|0;ab=c;d=-1;a:{if(!WC(a,c+8|0)){break a}d=0;if(!VC(c+8|0)){break a}if(b){a=v[b>>2];e=!v[b+4>>2];b=c+12|0;if(e&a>>>0<Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-8>>>0){break a}}d=1}ab=c+48|0;return d|0}function V7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-32|0;ab=d;f=cf(a,c);c=d+8|0;Xd(c,v[a+28>>2]);e=v[c+12>>2];v[d+24>>2]=v[c+8>>2];v[d+28>>2]=e;a:{b:{if(!f){c=0;e=-1;if(!Vc(a,5)){break b}break a}e=v[f+8>>2]}Wy(v[a+28>>2],b,e);c=f}Te(a,c,d+24|0);ab=d+32|0}function Ly(a,b,c,d){var e=0,f=0;e=Kd(a);a:{if(e){f=ac(a);while(1){b:{a=e+16|0;if(Os(c,d,a)){a=v[e>>2];if(!a){break a}break b}if(Ns(a,c,d)){f=e+4|0;a=v[e+4>>2];if(a){e=f;break b}v[b>>2]=e;return f}v[b>>2]=e;return f}f=e;e=a;continue}}e=ac(a)}v[b>>2]=e;return e}function Lca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;v[c+12>>2]=4925421;v[c+8>>2]=2147483647;d=zb(c+12|0,c+8|0);ab=c+16|0;if(y[d>>2]<b>>>0){hd();L()}if(b>>>0>=4925422){Oe(11129);L()}c=B(b,872);b=pc(c);v[a>>2]=b;v[a+4>>2]=b;e=vb(a),f=b+c|0,v[e>>2]=f}function Bk(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=Hr(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function w7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0),f=0,g=C(0);d=ab-16|0;ab=d;f=d,g=C(C(eb[v[v[a>>2]+48>>2]](a,b))+c),z[f+12>>2]=g;c=C(0);e=z[d+12>>2];a:{if(!(e<C(0))){c=C(1);if(!(e>C(1))){break a}}z[d+12>>2]=c}eb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);ab=d+16|0}function sO(a,b){var c=0,d=0;v[a+4>>2]=b;v[a>>2]=89816;v[a+20>>2]=0;v[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;v[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;v[a+8>>2]=d;v[a+32>>2]=d>>>0<31?-1>>>31-d|0:-1;v[a+28>>2]=b>>>0<c>>>0?0:-1>>>32-d|0;v[a+16>>2]=(B(c,d)-b|0)+c;return a}function daa(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-48|0;ab=c;d=c+40|0;t[d|0]=b;uq(c+16|0,d);b=v[c+16>>2];uq(c+8|0,d);b=pg(c+24|0,b,v[c+8>>2]+1|0);v[22452]=0;Q(730,a|0,b|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){pb(b);ab=c+48|0;return}a=P()|0;O()|0;pb(b);S(a|0);L()}function PW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Bg(a,v[b+8>>2],0)){rv(b,c,d);return}e=v[a+12>>2];f=a+16|0;lE(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){lE(a,b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function GL(a,b,c,d){var e=0,f=0,g=0;t[c+851|0]=w[c+851|0]|64;e=a?w[c+813|0]:0;g=(d|0)>=0?0-e|0:e;f=(+(a>>>0)+1)*+(d|0)/+(b>>>0);a:{if(D(f)<2147483648){e=~~f;break a}e=-2147483648}v[c+852>>2]=g+(e+v[c+852>>2]|0);b=(a+1|0)==(b|0)?d:e;a=b>>31;t[c+813|0]=a^a+b}function Fk(a,b,c){var d=0,e=0,f=0,g=0;e=ab-16|0;ab=e;v[e+8>>2]=c;while(1){a:{if((a|0)!=(b|0)){c=ab-16|0;ab=c;d=kc(c+8|0,v[a>>2]);f=v[d>>2];g=v[d+4>>2];d=v[e+8>>2];d=yc(f,g,v[d>>2],v[d+4>>2]);ab=c+16|0;if(!d){break a}b=a}ab=e+16|0;return b}a=a+8|0;continue}}function FV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ab-16|0;ab=e;f=v[b+8>>2];a:{if(f>>>0<=c>>>0){c=v[d>>2];b=0;break a}v[e+12>>2]=f-c;v[e+8>>2]=v[d+4>>2];c=v[b+4>>2]+c|0;f=c;b=v[zb(e+12|0,e+8|0)>>2];g=c+b|0;c=v[d>>2];Ci(f,g,c)}Ub(a,c,b);ab=e+16|0}function hga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;Pe(b);t[c+15|0]=0;a:{if(!wh(a,c+15|0)){break a}f=w[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}t[c+14|0]=0;if(wh(a,c+14|0)){pp(b,t[c+14|0]);e=e+1|0;continue}break}d=0}ab=c+16|0;return d|0}function WT(a){a=a|0;var b=0,c=0,d=0;c=ab-32|0;ab=c;b=255;a:{if(dj(a)>>>0<=49){b=$y(c,v[a+12>>2]);v[22452]=0;R(283,a|0,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break a}Uk(b);si(a,dj(a)-1&255);b=dj(a)-1|0}ab=c+32|0;return b&255}a=P()|0;O()|0;Uk(b);S(a|0);L()}function HB(a){var b=0,c=0,d=0,e=0;b=a+5|0;c=w[b|0]|w[b+1|0]<<8;b=w[a+2|0];c=c+b|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;a=a+3|0;a=w[a|0]|w[a+1|0]<<8;d=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;a=b>>>0<47?a+1|0:a;db=a;return b}function z_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function zZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=ab-16|0;ab=g;v[g+8>>2]=b;zc(g,d);v[22452]=0;b=T(1111,g|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){Nb(g);XE(a,f+16|0,g+8|0,c,e,b);ab=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Nb(g);S(a|0);L()}function ny(a,b,c){var d=0,e=0;d=Kd(a);a:{if(d){e=ac(a);while(1){b:{a=d+16|0;if(my(c,a)){a=v[d>>2];if(!a){break a}break b}if(ly(a,c)){e=d+4|0;a=v[d+4>>2];if(a){d=e;break b}v[b>>2]=d;return e}v[b>>2]=d;return e}e=d;d=a;continue}}d=ac(a)}v[b>>2]=d;return d}function AZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=ab-16|0;ab=g;v[g+8>>2]=b;zc(g,d);v[22452]=0;b=T(1111,g|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){Nb(g);YE(a,f+24|0,g+8|0,c,e,b);ab=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Nb(g);S(a|0);L()}function uF(a,b,c){var d=0,e=0,f=0;a:{e=$z(b,c);if(e>>>0<1073741808){b:{if(e>>>0<=1){ye(a,e);d=a;break b}f=sl(e)+1|0;d=ji(f);nd(a,d);Lf(a,f);Qd(a,e)}while(1){if((b|0)!=(c|0)){nd(d,v[b>>2]);d=d+4|0;b=b+4|0;continue}break}nd(d,0);break a}Df();L()}return a}function kw(a){var b=0,c=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;if(v[a+20>>2]!=v[a+28>>2]){eb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function rT(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[$e(d+15|0,d+14|0)|0]}a=e;ab=d+16|0;return a&255}function GZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=ab-16|0;ab=g;v[g+8>>2]=b;zc(g,d);v[22452]=0;b=T(18,g|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){Nb(g);$E(a,f+24|0,g+8|0,c,e,b);ab=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Nb(g);S(a|0);L()}function FZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=ab-16|0;ab=g;v[g+8>>2]=b;zc(g,d);v[22452]=0;b=T(18,g|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){Nb(g);_E(a,f+16|0,g+8|0,c,e,b);ab=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Nb(g);S(a|0);L()}function F6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ab-16|0;ab=d;a:{b:{e=v[a+20>>2];c=v[e+4>>2];if((Ic(c,v[e+8>>2])|0)!=7){break b}if(Ib(c,9527,4)){break b}b=wb(c);c=wb(v[v[a+20>>2]+8>>2]);_n(d+8|0,a+4228|0);fk(b,c,v[d+8>>2]);break a}mx(a,b)}hs(a);ab=d+16|0}function BB(a,b,c){var d=0,e=0,f=0;d=ab-32|0;ab=d;v[d+28>>2]=c;v[d+8>>2]=192;c=v[zb(d+28|0,d+8|0)>>2];if(!Hb(a,c)){c=Ze(a)}e=d+8|0;jq(e,b);f=Zb(d+16|0,v[d+8>>2],c);_b(d,a,v[f>>2],v[f+4>>2]);jq(e,b);Jb(v[d+8>>2]+c|0,0,192-c|0);Ob(a,v[d+28>>2]);ab=d+32|0}function ze(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-16|0;ab=d;a:{if(b>>>0<4294967280){b:{if(b>>>0<=10){ye(a,b);e=a;break b}f=ri(b)+1|0;e=pc(f);nd(a,e);Lf(a,f);Qd(a,b)}c=dq(e,b,c);t[d+15|0]=0;md(b+c|0,d+15|0);ab=d+16|0;break a}Df();L()}return a|0}function vp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{e=Rk(a,b);if((e|0)==255){break a}if(Oj(a)){break a}f=ld(a+318|0,e);e=LN(e);if(g=1,h=t[Cb(f,10)|0]&1,i=d,i?g:h){Mg(a,b,e- -64&65535,KN(c,w[Cb(f,2)|0]))}if(d){break a}Mg(a,b,e+67&65535,KN(c,w[Cb(f,3)|0]))}}function o1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[b+8>>2];e=v[b+4>>2];f=v[b>>2];a=0;a:while(1){b:{b=0;if((a|0)==(e|0)){break b}while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{c=v[(a<<2)+f>>2]+(b<<3)|0;v[c>>2]=0;v[c+4>>2]=0;b=b+1|0;continue}}break}}function vda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=ab-208|0;ab=b;e=-1;c=ab-16|0;ab=c;vP(c+8|0,b);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(f|0);if(!a){uP(b)}if(a){e=wP(b)}ab=b+208|0;return e|0}function r9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b:{if((b|0)!=437){if((b|0)==1252){break b}d=0;if((b|0)==65001){break a}c:{if((b|0)!=28591){if((b|0)==28605){break c}if((b|0)!=20127){break b}d=1;break a}d=2;break a}d=3;break a}d=5;break a}d=8}UC(a,d,c)}function kha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=ab-160|0;ab=b;e=-1;c=ab-16|0;ab=c;BS(c+8|0,b);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(f|0);if(!a){AS(b)}if(a){e=CS(b)}ab=b+160|0;return e|0}function Wy(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:TN(a,b);return;default:break a}}d=ab-32|0;ab=d;v[d+28>>2]=c;u[d+26>>1]=0;v[d+12>>2]=2;Er(d+16|0,a,d+26|0,v[zb(d+28|0,d+12|0)>>2]);u[d+16>>1]=x[d+26>>1];u[b>>1]=w[d+16|0]|w[d+17|0]<<8;ab=d+32|0}function B0(a){a=a|0;var b=0,c=0,d=0;b=ab-32|0;ab=b;if(!w[a+8|0]){Ei(a+12|0,v[a+4>>2]);de(b+24|0,v[a+12>>2],v[a+16>>2]);c=v[v[a>>2]+40>>2];d=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=d;eb[c|0](b+16|0,a,0,b+8|0);t[a+8|0]=1}ab=b+32|0;return v[a+12>>2]}function ID(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=ab-16|0;ab=d;b:{c:{if(!b){b=a;a=Eb(c);pg(b,a,ub(c)+a|0);break c}kM(d,c);v[22452]=0;U(44,a|0,b|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}Oc(d)}ab=d+16|0;break a}a=P()|0;O()|0;Oc(d);S(a|0);L()}}function aF(a,b){var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;v[b>>2]=0;t[c+15|0]=0;wh(a,c+15|0);d=w[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){v[b>>2]=e;if((d|0)==(f|0)){ab=c+16|0}else{t[c+15|0]=0;wh(a,c+15|0);d=d+1|0;e=v[b>>2]|w[c+15|0]<<(d<<3)-2;continue}break}}function VC(a){var b=0,c=0;a:{if(Ib(a,14153,4)){break a}if(Ib(a+8|0,14074,4)){break a}b=a+4|0;b=Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));if(!b){break a}a=a+12|0;c=(Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0)!=0&b>>>0>27}return c}function MU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=ab-48|0;ab=b;e=-1;c=ab-16|0;ab=c;jC(c+8|0,b);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(f|0);if(!a){iC(b)}if(a){e=kC(b)}ab=b+48|0;return e|0}function yN(a){var b=0,c=0,d=0,e=0,f=0;b=ab-16|0;ab=b;c=a;d=v[a>>2];f=Cg(d,v[a+4>>2]);a=wb(d);v[b+8>>2]=a;e=+(f>>>0);c=wb(v[c+4>>2]);while(1){if(Tb(a,c)){A[a>>3]=A[a>>3]/e;A[a+8>>3]=A[a+8>>3]/e;In(b+8|0);a=v[b+8>>2];continue}else{ab=b+16|0}break}}function Op(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=ab-16|0;ab=f;d=Ec(a);e=ub(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Eb(a);dg(d+e|0,b,c);b=c+e|0;cg(a,b);t[f+15|0]=0;md(b+d|0,f+15|0);break a}Un(a,d,(c+e|0)-d|0,e,e,0,c,b)}ab=f+16|0;return a|0}function DG(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=DG(a*0x10000000000000000,b);c=v[b>>2]+-64|0}v[b>>2]=c;return a}v[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function cF(a,b,c){var d=0,e=0,f=0;a:{if(b>>>0<1073741808){b:{if(b>>>0<=1){ye(a,1);e=a;break b}d=sl(b)+1|0;e=ji(d);nd(a,e);Lf(a,d);Qd(a,b)}f=b;d=e;while(1){v[d>>2]=c;d=d+4|0;f=f-1|0;if(f){continue}break}nd((b<<2)+e|0,0);break a}Df();L()}return a}function yZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=ab-16|0;ab=a;v[a+8>>2]=b;zc(a,d);v[22452]=0;b=T(1111,a|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){Nb(a);WE(f+20|0,a+8|0,c,e,b);ab=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Nb(a);S(b|0);L()}function xA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Pb(a+8|0);v[22452]=0;d=T(193,b|0)|0;e=v[22452];v[22452]=0;b:{if((e|0)==1){break b}v[22452]=0;U(238,a|0,b|0,d|0);a=v[22452];v[22452]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;Xb(c);S(a|0);L()}}function uj(a,b){var c=0,d=0,e=0,f=0;while(1){if((b|0)!=(e|0)){d=v[a>>2];if(d){c=v[a+4>>2]}else{v[a>>2]=8;c=v[a+12>>2];if((c|0)!=v[a+8>>2]){c=c-1|0;v[a+12>>2]=c}d=8;c=w[c|0]}v[a>>2]=d-1;v[a+4>>2]=c>>>1;f=c&1|f<<1;e=e+1|0;continue}break}return f}function kR(a,b){var c=0;a:{if(!Fd(b)){break a}if(v[b+20>>2]==v[a+20>>2]){v[a+20>>2]=0}mc(a,v[b>>2]);c=x[a+34>>1]&-2|u[b+34>>1]&1;u[a+34>>1]=c;u[a+34>>1]=c&65471|x[b+34>>1]&64;if(!sg(a)){break a}gc(v[a+20>>2],v[b+20>>2],mj(v[a>>2],x[a+34>>1]))}}function Lga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ab-32|0;ab=d;e=d+16|0;qA(e,c);Ui(d+8|0,e);v[22452]=0;W(105,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22452];v[22452]=0;if((a|0)!=1){yb(d+16|0);ab=d+32|0;break a}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}}function Hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ab-32|0;ab=d;e=d+16|0;Hm(e,c);Ui(d+8|0,e);v[22452]=0;W(105,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22452];v[22452]=0;if((a|0)!=1){yb(d+16|0);ab=d+32|0;break a}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}}function Aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ab-32|0;ab=d;e=d+16|0;Uo(e,c);Ui(d+8|0,e);v[22452]=0;W(289,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22452];v[22452]=0;if((a|0)!=1){yb(d+16|0);ab=d+32|0;break a}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}}function $N(a,b,c){var d=0,e=0,f=0,g=0;f=v[b+4>>2];e=b+4|0;Gn(v[a>>2],c,e);g=v[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){wi(v[d>>2],x[c>>1]);v[d>>2]=v[d>>2]+2;c=c+2|0;continue}break}cc(a,e);cc(a+4|0,d);cc(vb(a),ic(b));v[b>>2]=v[b+4>>2];return f}function uT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ab-32|0;ab=d;e=d+16|0;AB(e,c);Ui(d+8|0,e);v[22452]=0;W(105,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22452];v[22452]=0;if((a|0)!=1){yb(d+16|0);ab=d+32|0;break a}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}}function TS(a,b,c){var d=0,e=0,f=0,g=0;f=v[b+4>>2];e=b+4|0;Gn(v[a>>2],c,e);g=v[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){Bj(v[d>>2],w[c|0]);v[d>>2]=v[d>>2]+1;c=c+1|0;continue}break}cc(a,e);cc(a+4|0,d);cc(vb(a),ic(b));v[b>>2]=v[b+4>>2];return f}function PD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ab-32|0;ab=d;e=d+16|0;ph(e,c);Ui(d+8|0,e);v[22452]=0;W(105,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22452];v[22452]=0;if((a|0)!=1){yb(d+16|0);ab=d+32|0;break a}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}}function NT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ab-32|0;ab=d;e=d+16|0;ph(e,c);Ui(d+8|0,e);v[22452]=0;W(289,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22452];v[22452]=0;if((a|0)!=1){yb(d+16|0);ab=d+32|0;break a}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}}function KU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=ab-32|0;ab=d;e=d+16|0;wu(e,c);Ui(d+8|0,e);v[22452]=0;W(105,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22452];v[22452]=0;if((a|0)!=1){yb(d+16|0);ab=d+32|0;break a}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}}function yr(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;d=aa(16)|0;oE();a=Zb(c+8|0,a,89792);c=v[a+4>>2];a=v[a>>2];v[22452]=0;da(1074,d|0,a|0,c|0,b|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){ia(d|0,87760,1075);L()}a=P()|0;O()|0;ba(d|0);S(a|0);L()}function vo(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function mD(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function cq(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=ab-16|0;ab=d;v[d+12>>2]=c;c=d+12|0;mc(c,128);mc(c,65535);e=x[d+12>>1];mf(a,e);c=0;while(1){if((c|0)==(e|0)){ab=d+16|0}else{f=w[b+c|0];g=yi(v[a>>2],v[a+4>>2],c),h=f,u[g>>1]=h;c=c+1|0;continue}break}}function EZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=ab-16|0;ab=a;v[a+8>>2]=b;zc(a,d);v[22452]=0;b=T(18,a|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){Nb(a);ZE(f+20|0,a+8|0,c,e,b);ab=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Nb(a);S(b|0);L()}function fd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=ab-16|0;ab=e;f=v[b>>2];g=v[b+8>>2];v[e+12>>2]=d;v[e+8>>2]=c;c=v[v[f>>2]+28>>2];d=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=d;eb[c|0](a,f,g,e);v[b+8>>2]=v[b+8>>2]+v[a+4>>2];ab=e+16|0}function Zr(a){var b=0,c=0;b=a+24|0;c=v[b>>2];v[22452]=0;Z(789,c|0);c=v[22452];v[22452]=0;if((c|0)!=1){Uc(a+68|0);Hf(a+36|0);Lo(a+32|0);Zh(b);Yh(a+4|0);oe(a);return}V(0)|0;O()|0;Uc(a+68|0);Hf(a+36|0);Lo(a+32|0);Zh(b);Yh(a+4|0);oe(a);Gb();L()}function yM(a,b){var c=0,d=0;d=ab-16|0;ab=d;c=v[a+104>>2];a:{if(!c){break a}c=v[c>>2];if(!c){break a}v[a+76>>2]=c;v[a+88>>2]=v[a+88>>2]&-131|128;v[d+12>>2]=b<<8;v[d+8>>2]=c-1;b=c+(v[zb(d+12|0,d+8|0)>>2]^-1)|0;v[a>>2]=0;v[a+4>>2]=b}ab=d+16|0}function kfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=sd(a);a:{if(!b){break a}v[22452]=0;R(538,a|0,b|0);d=v[22452];v[22452]=0;if((d|0)!=1){v[22452]=0;R(539,a|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Rz(c);S(a|0);L()}return a|0}function Y7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=ab-32|0;ab=f;c=cf(a,c);e=f+8|0;Xd(e,v[a+28>>2]);g=v[e+12>>2];v[f+24>>2]=v[e+8>>2];v[f+28>>2]=g;a:{if(!c){e=0;if(Vc(a,5)){break a}}fK(d,v[a+28>>2],b);e=c}Te(a,e,f+24|0);ab=f+32|0}function WH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=ab-16|0;ab=e;if(d>>>0<4294967280){a:{if(d>>>0<=10){ye(a,c);d=a;break a}f=ri(d)+1|0;d=pc(f);nd(a,d);Lf(a,f);Qd(a,c)}a=dg(d,b,c);t[e+15|0]=0;md(a+c|0,e+15|0);ab=e+16|0;return}Df();L()}function HU(a,b){a=a|0;b=b|0;var c=0,d=0;c=sd(a);a:{if(!b){break a}v[22452]=0;R(220,a|0,b|0);d=v[22452];v[22452]=0;if((d|0)!=1){v[22452]=0;R(221,a|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Yc(c);S(a|0);L()}return a|0}function DJ(a,b,c){var d=0,e=0;if(C(D(a))<C(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return C((e?b^-1|e:b)|0)}function SM(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+3|0]|w[b+4|0]<<8|(w[b+5|0]<<16|w[b+6|0]<<24);t[a+3|0]=b;t[a+4|0]=b>>>8;t[a+5|0]=b>>>16;t[a+6|0]=b>>>24}function M1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-32|0;ab=d;Hk(d,c);c=d+16|0;v[c>>2]=b;Ac(c+4|0,d);v[22452]=0;R(1033,a+4|0,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){cl(d+16|0);pb(d);ab=d+32|0;return}a=P()|0;O()|0;cl(d+16|0);pb(d);S(a|0);L()}function Je(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Pb(a+8|0);v[22452]=0;U(238,a|0,b|0,c|0);c=v[22452];v[22452]=0;a:{if((c|0)!=1){a=v[a>>2];v[22452]=0;Q(179,b|0,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Xb(d);S(a|0);L()}}function DP(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if((b|0)!=26&(b|0)!=2|w[a+30|0]!=2){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=BP(a+20|0)}return c}function Sha(a,b){a=a|0;b=b|0;var c=0;b=ab-32|0;ab=b;c=-1;a:{if(!YA(a,b+16|0)){break a}c=0;if(!bT(b+16|0)){break a}if(!Ib(b+16|0,14139,4)){c=-1;if(!Rc(a,4)){break a}}c=-1;if(!tj(a,b+8|0)){break a}c=!Ib(b+8|0,14115,4)}ab=b+32|0;return c|0}function Iv(a,b){var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;u[b>>1]=0;t[c+15|0]=0;wh(a,c+15|0);d=w[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){u[b>>1]=e;if(d>>>0>=f>>>0){ab=c+16|0}else{t[c+15|0]=0;wh(a,c+15|0);e=x[b>>1]|w[c+15|0]<<7;d=1;continue}break}}function vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=ab-32|0;ab=e;c=cf(a,c);Xd(e+8|0,v[a+28>>2]);f=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=f;a:{if(!c){f=0;if(Vc(a,5)){break a}}hS(v[a+28>>2],b,d,0);f=c}Te(a,f,e+24|0);ab=e+32|0}function r8(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-32|0;ab=c;d=-1;a:{if(!ND(a,c+8|0)){break a}d=0;if(!CK(c+8|0)){break a}if(b){a=c+16|0;if(v[b>>2]!=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|v[b+4>>2]){break a}}d=1}ab=c+32|0;return d|0}function hea(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;a:{if(!Hb(b,8)){u[c>>1]=0;b=4;while(1){if(b){d=w[c|0]|w[c+1|0]<<8;t[a|0]=d;t[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}break a}Am(c+8|0,a);fd(c,b,v[c+8>>2],v[c+12>>2])}ab=c+16|0}function hM(a,b){var c=0,d=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}c=v[c>>2];b:{if(c){d=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[d+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[b>>2]=a}}function Zd(a,b){var c=0,d=0;d=v[a+4>>2];c=d+b|0;v[a+4>>2]=c;if(v[a+8>>2]>=(c|0)){c=d&7;b=c+b|0;d=v[a>>2]+(d>>3)|0;a=w[d|0]&255>>>c;c=0;while(1){if((b|0)>=9){b=b-8|0;c=a<<b|c;d=d+1|0;a=w[d|0];continue}break}a=a>>>8-b|c}else{a=0}return a}function Jd(a){var b=0,c=0,d=0;c=ab-16|0;ab=c;a=uv(c,a);d=ab-16|0;ab=d;if(!rg(w[v[$b(d+8|0,v[a+4>>2])>>2]])){a:{b:{a=v[a+8>>2];b=w[a|0];if((b|0)!=1){if(b&2){break b}t[a|0]=2;a=1}else{a=0}break a}vv();L()}b=a}ab=d+16|0;ab=c+16|0;return b}function xM(a,b){var c=0,d=0;a:{if(!(t[a+851|0]&1)){break a}c=v[a+104>>2];if(!c){break a}d=v[c>>2];if(!d){break a}v[a+76>>2]=d;v[a>>2]=0;v[a+4>>2]=d-1;c=v[a+88>>2];v[a+88>>2]=b?c|134:c&-135|128;if(!b){break a}v[a+84>>2]=d;v[a+80>>2]=0}}function Th(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;e=v[a+4>>2];d=v[a+44>>2]-e|0;v[a+120>>2]=d;v[a+124>>2]=d>>31;d=a;a=v[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}v[d+104>>2]=a}function Nz(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=ab-1024|0;ab=e;d=ab-16|0;ab=d;Jz(d+8|0,e);f=v[d+12>>2];_b(d,a,v[d+8>>2],f);g=v[d+4>>2];if((g|0)==(f|0)){Ob(a,v[d+12>>2])}ab=d+16|0;if((f|0)==(g|0)){h=Lz(e,c)>>>0<=b>>>0}ab=e+1024|0;return h}function sM(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;e=c&15;if(e){t[b+824|0]=e}c=c&240;if(c){t[b+823|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;rb(d+8|0,a+1074312|0,80);if(!(!e|!sb(v[v[d+8>>2]>>2],v[d+12>>2]))){t[b+824|0]=w[b+824|0]<<2}ab=d+16|0}function p1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=v[b+8>>2];d=v[b+4>>2];e=v[b>>2];a=0;a:while(1){b:{b=0;if((a|0)==(d|0)){break b}while(1)if((b|0)==(c|0)){a=a+1|0;continue a}else{f=Gp(e,a,b),g=0,v[f>>2]=g;b=b+1|0;continue}}break}}function nga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;while(1){a:{d=v[a>>2];if(nc(d,v[a+4>>2])>>>0>e>>>0){Rf(c,v[Fb(d,e)>>2]+40|0);d=Mp(c,b);pb(c);if(!d){break a}f=v[Fb(v[a>>2],e)>>2]}ab=c+16|0;return f|0}e=e+1|0;continue}}function f8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=sd(a);a:{b:{c=nc(v[b>>2],v[b+4>>2]);if(c){v[22452]=0;R(219,a|0,c|0);e=v[22452];v[22452]=0;if((e|0)==1){break b}_z(a,v[b>>2],v[b+4>>2],c)}break a}a=P()|0;O()|0;ec(d);S(a|0);L()}return a|0}function p7(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(v[b+4>>2]!=8){break a}b=v[b>>2];if(Ib(b,9527,4)){break a}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4264>>2]=c;ls(a)}}function Dg(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function B6(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(v[b+4>>2]!=8){break a}b=v[b>>2];if(Ib(b,9527,4)){break a}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4228>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4232>>2]=c;hs(a)}}function WO(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,872);a=v[c+4>>2];b=v[c+8>>2];while(1){if((a|0)==(b|0)){dc(c);ab=c+16|0}else{VO(Jb(a,0,872));a=a+872|0;v[c+4>>2]=a;continue}break}}function R_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((eb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=bk(b,4,c,v[a+32>>2])}return c|0}function Zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ab-32|0;ab=d;a:{if(a){eb[v[v[a>>2]+8>>2]](a,b,c);break a}if(!iS(us(d+8|0),b)){break a}a=d+8|0;us(a);v[d+24>>2]=0;e=us(d+24|0);rL(a,9124,10798,140,42);aE(e,a,b,13220,c)}ab=d+32|0}function SD(){var a=0,b=0,c=0;b=ab-16|0;ab=b;a=Mb(b,14944);a:{if(!ub(a)){break a}c=1;if((kg(a,14621)|0)!=-1){break a}if((kg(a,16743)|0)!=-1){break a}if((kg(a,13687)|0)!=-1){break a}c=(kg(a,13730)|0)!=-1}pb(a);ab=b+16|0;return c|0}function WQ(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){e=v[a+4>>2];f=e>>>8|0;d=v[a>>2];e=(e&255)<<24|d>>>8;d=(((d^w[b|0])&255)<<3)+21664|0;g=v[d>>2];d=v[d+4>>2]^f;v[a>>2]=e^g;v[a+4>>2]=d;b=b+1|0;continue}break}return a}function Uf(a,b){var c=0,d=0,e=0,f=0;d=x[a+22>>1];e=d+x[a+20>>1]|0;c=x[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-B(v[Fb(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;continue}break}return a}function nda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ab-16|0;ab=c;v[c+12>>2]=477218588;v[c+8>>2]=2147483647;d=zb(c+12|0,c+8|0);ab=c+16|0;if(y[d>>2]<b>>>0){hd();L()}c=B(b,9);b=pc(c);v[a>>2]=b;v[a+4>>2]=b;e=vb(a),f=b+c|0,v[e>>2]=f}function Xj(a,b){var c=0,d=0;c=ab-32|0;ab=c;v[c+28>>2]=0;ov(c+8|0,c+28|0);d=c+16|0;_m(d,a,v[c+8>>2],v[c+12>>2]);a=v[c+20>>2];v[c+16>>2]=v[c+28>>2];v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);ab=c+32|0;return(a|0)==4}function QK(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=vc(pia(oia(d,d>>31,g,h),db,256,0),db);v[a+4>>2]=f-d;v[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function yy(a,b,c){var d=0,e=0,f=0;d=ab-16|0;ab=d;a:{if(!c){break a}v[b+40>>2]=c;if(!c|v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Pc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=xz(c&255),v[e+44>>2]=f}ab=d+16|0}function pl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Pf(b);e=ab-16|0;ab=e;d=Ec(a);a:{if(d>>>0>=c>>>0){b=_j(Eb(a),b,c);t[e+15|0]=0;md(b+c|0,e+15|0);cg(a,c);break a}f=d;g=c-d|0;d=ub(a);Un(a,f,g,d,0,d,c,b)}ab=e+16|0;return a|0}function pia(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=ria(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;db=(g^db)-((a>>>0<f>>>0)+g|0)|0;return b}function fH(a,b,c,d){var e=0,f=0;e=ab-16|0;ab=e;f=e+8|0;$b(f,v[v[b>>2]-12>>2]+b|0);v[f+4>>2]=b;Ck(v[e+12>>2],c,d);b=ab-16|0;ab=b;v[b+12>>2]=v[v[e+12>>2]+4>>2];v[b+8>>2]=0;d=v[Ee(b+8|0,b+12|0)>>2];ab=b+16|0;Ub(a,c,d);ab=e+16|0}function $t(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=ab-16|0;ab=f;if(b){e=Ec(a);d=ub(a);g=d+b|0;if(e-d>>>0<b>>>0){Kl(a,e,g-e|0,d,d,0,0)}e=d;d=Eb(a);dq(e+d|0,b,c);cg(a,g);t[f+15|0]=0;md(d+g|0,f+15|0)}ab=f+16|0;return a|0}function di(a){var b=0,c=0,d=0,e=0;b=ue(a);c=b&63;e=b&128;a:{if(!(b&64)){break a}b=6;while(1){d=ue(a);c=(d&127)<<b|c;if(!(d&128)){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}a=e?-2147483648:c;return e?(c|0)>=0?0-c|0:a:a}function cL(a){var b=0,c=0;b=ab-544|0;ab=b;a:{if(!(w[a+480210|0]&128)|!v[a+24668>>2]){break a}oz(b,v[a+24620>>2]);c=a+1298224|0;a=a+1074992|0;while(1){if((a|0)==(c|0)){break a}gc(a+112|0,b,538);a=a+872|0;continue}}ab=b+544|0}function ts(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=43980;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=43832;break a;case 2:c=43828;break a;case 1:break b;case 0:break c}}c=43824;break a}c=43820}v[a>>2]=v[c>>2]}function Sz(a,b){var c=0,d=0,e=0,f=0;c=a<<8;d=c&16711680;c=e;e=a<<24|d;f=c;d=b<<24|a>>>8;c=b<<8|a>>>24;a=f|(((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24));db=e|(d&65280|c&255);return a}function Ad(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+22>>1];g=d+x[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0<2048){break a}u[a+20>>1]=c-d}return}c=c+1|0;continue}}function $ga(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;v[a+480180>>2]=b;uz(c,Rp(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;ts(a+8|0,Rp(a));ab=c+16|0}
function yz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=sd(a);a:{c=Ic(v[b>>2],v[b+4>>2]);if(c){v[22452]=0;R(312,a|0,c|0);e=v[22452];v[22452]=0;if((e|0)==1){break a}Gt(a,v[b>>2],v[b+4>>2],c)}return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function sp(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(A[b-8>>3]-A[a>>3]);b=0;while(1){if((b|0)!=2048){d=-be(f*A[He(a,b)>>3]);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=Fb(c,b),h=e,v[g>>2]=h;b=b+1|0;continue}break}}function _ga(a){a=a|0;var b=0,c=0,d=0;b=ab-32|0;ab=b;t[b+30|0]=0;u[b+28>>1]=0;c=Zb(b+8|0,b+28|0,3);_b(b+16|0,a,v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=3){break a}if(Ib(b+28|0,14725,3)){break a}Ob(a,3);d=1}ab=b+32|0;return d|0}function Qca(a){a=a|0;var b=0,c=0,d=0;b=ab-32|0;ab=b;u[b+28>>1]=0;v[b+24>>2]=0;c=Zb(b+8|0,b+24|0,6);_b(b+16|0,a,v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=6){break a}if(Ib(b+24|0,3856,6)){break a}Ob(a,6);d=1}ab=b+32|0;return d|0}function wM(a,b,c,d){var e=0;a=Jc(un(a,x[c+70>>1],v[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=Nk(c)-v[c+16>>2]|0;if((d|0)<2){break a}e=a;a=u[(B(b,872)+c|0)+1390>>1];a=Jc(((e-a|0)/(d|0)|0)+a|0)}u[(B(b,872)+c|0)+1390>>1]=a}function oz(a,b){var c=0,d=0,e=0,f=0;u[a+24>>1]=0;v[a+20>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(D(d)<2147483648){b=~~d;break a}b=-2147483648}v[a+16>>2]=b;v[a>>2]=0;v[a+4>>2]=0;e=a,f=dP(c-+(b<<2)),v[e+8>>2]=f;v[a+12>>2]=db}function I5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ci(a,b,c,d);v[a+4208>>2]=1017370378;v[a+4212>>2]=0;v[a>>2]=46628;v[22452]=0;R(875,a+44|0,2);c=v[22452];v[22452]=0;if((c|0)!=1){bi(b);return a|0}a=P()|0;O()|0;ff(b);S(a|0);L()}function ot(a,b){var c=0,d=0,e=0;if(v[a>>2]){JT(a);c=v[a>>2];iB(a);xb(c);d=vb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=vb(b);d=vb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function Ur(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=0;c=ab-16|0;ab=c;d=v[b>>2];while(1){if(nc(d,v[b+4>>2])>>>0<=a>>>0){ab=c+16|0}else{v[c+8>>2]=0;dh(c+8|0);d=v[b>>2];e=Fb(d,a),f=v[c+8>>2],v[e>>2]=f;a=a+1|0;continue}break}}function $J(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;Ve(a+12|0,d);if(b){if(b>>>0>=2097152){Oe(11129);L()}d=pc(b<<11)}else{d=0}v[a>>2]=d;c=d+(c<<11)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=ic(a),f=d+(b<<11)|0,v[e>>2]=f;return a|0}function Lz(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;c=a;e=a+1024|0;b=0;a:while(1){if((c|0)!=(e|0)){a=c;f=a+16|0;while(1)if((a|0)==(f|0)){c=c+16|0;continue a}else{b=((w[Cb(a,0)|0]&d)!=0)+b|0;a=a+4|0;continue}}break}return b}function Hr(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!xw(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=De(a)}return b}ca(15657,13164,1578,5390);L()}function HO(a){var b=0,c=0,d=0;b=a- -64|0;d=w[b|0]|w[b+1|0]<<8;b=a+72|0;a=a+70|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<2|a>>>30;c=c<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;db=a;return b}function FP(a,b,c){var d=0;d=ab-16|0;ab=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){t[d+14|0]=(x[(b<<1)+32782>>1]-x[(c<<1)+32782>>1]|0)/5;a=w[Qb(d+15|0,d+14|0)|0]}ab=d+16|0;return a&255}function u6(a){a=a|0;var b=0;eb[v[v[a>>2]+128>>2]](a);fx(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=eb[v[v[a>>2]+192>>2]](a)|0;v[a+4328>>2]=0;v[a+4312>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4324>>2]=b;v[a+4320>>2]=b}function gX(){var a=0;a:{b:{if(t[463676]&1){break b}if(!Jd(463676)){break b}v[22452]=0;X(1192);a=v[22452];v[22452]=0;if((a|0)==1){break a}v[115918]=463668;Id(463676)}return v[115918]}a=P()|0;O()|0;Xe(463676);S(a|0);L()}function XL(a,b,c,d){var e=0,f=0;e=v[(B(c,872)+b|0)+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=x[(B(c,872)+b|0)+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=w[((b<<5)+a|0)+480288|0]}return f}function Lq(a,b,c){var d=0,e=0,f=0;d=ab-16|0;ab=d;if(c>>>0<4294967280){a:{if(c>>>0<=10){ye(a,c);e=a;break a}f=ri(c)+1|0;e=pc(f);nd(a,e);Lf(a,f);Qd(a,c)}a=dg(e,b,c);t[d+15|0]=0;md(a+c|0,d+15|0);ab=d+16|0;return}Df();L()}function ER(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function xp(a,b,c){var d=0;d=ab-16|0;ab=d;rb(d+8|0,c+1074312|0,102);a:{if(!sb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}c=x[a+692>>1]+1|0;u[a+784>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+784>>1]=c|32768}v[a+692>>2]=b;ab=d+16|0}function rY(a){a=a|0;a:{b:{if(t[463760]&1){break b}if(!Jd(463760)){break b}v[22452]=0;X(1185);a=v[22452];v[22452]=0;if((a|0)==1){break a}v[115939]=464112;Id(463760)}return v[115939]}a=P()|0;O()|0;Xe(463760);S(a|0);L()}function pY(a){a=a|0;a:{b:{if(t[463776]&1){break b}if(!Jd(463776)){break b}v[22452]=0;X(1186);a=v[22452];v[22452]=0;if((a|0)==1){break a}v[115943]=464592;Id(463776)}return v[115943]}a=P()|0;O()|0;Xe(463776);S(a|0);L()}function nY(a){a=a|0;a:{b:{if(t[463792]&1){break b}if(!Jd(463792)){break b}v[22452]=0;X(1187);a=v[22452];v[22452]=0;if((a|0)==1){break a}v[115947]=464928;Id(463792)}return v[115947]}a=P()|0;O()|0;Xe(463792);S(a|0);L()}function kq(a){var b=0,c=0,d=0,e=0;c=ab-16|0;ab=c;b=ab-16|0;ab=b;uq(b+8|0,c+15|0);d=v[b+12>>2];$c(b,a,v[b+8>>2],d);e=v[b+4>>2];if((e|0)==(d|0)){Rc(a,v[b+12>>2])}ab=b+16|0;ab=c+16|0;return((d|0)==(e|0)?w[c+15|0]:0)&255}function hY(a){a=a|0;a:{b:{if(t[463752]&1){break b}if(!Jd(463752)){break b}v[22452]=0;X(1189);a=v[22452];v[22452]=0;if((a|0)==1){break a}v[115937]=463936;Id(463752)}return v[115937]}a=P()|0;O()|0;Xe(463752);S(a|0);L()}function fY(a){a=a|0;a:{b:{if(t[463768]&1){break b}if(!Jd(463768)){break b}v[22452]=0;X(1190);a=v[22452];v[22452]=0;if((a|0)==1){break a}v[115941]=464288;Id(463768)}return v[115941]}a=P()|0;O()|0;Xe(463768);S(a|0);L()}function dY(a){a=a|0;a:{b:{if(t[463784]&1){break b}if(!Jd(463784)){break b}v[22452]=0;X(1191);a=v[22452];v[22452]=0;if((a|0)==1){break a}v[115945]=464896;Id(463784)}return v[115945]}a=P()|0;O()|0;Xe(463784);S(a|0);L()}function PP(a){var b=0,c=0,d=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+36|0;a=a+34|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<1|a>>>31;c=c<<1;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;db=a;return b}function ON(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function K1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;a=v[a+24>>2];II(d,c);a=v[a+1298464>>2];v[22452]=0;U(364,a|0,b|0,d|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(d);ab=d+16|0;return}a=P()|0;O()|0;pb(d);S(a|0);L()}function Gx(a,b,c,d,e){var f=0,g=0,h=0;f=ab-16|0;ab=f;a:{if(!c){a=Hc(v[a>>2],b);A[a+8>>3]=e;A[a>>3]=d;break a}g=c>>>1|0;Gx(a,b,g,d,e);h=Hc(v[a>>2],c);ei(f,d,e,A[h>>3],A[h+8>>3]);Gx(a,b|c,g,A[f>>3],A[f+8>>3])}ab=f+16|0}function oia(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;db=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function hU(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;d=Hb(a,120);a:{if(!d){a=b+120|0;while(1){if((a|0)!=(b|0)){rf(b);b=b+1|0;continue}break}break a}Ub(c+8|0,b,120);fd(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0;return d|0}function YJ(){var a=0;a:{b:{if(t[463664]&1){break b}if(!Jd(463664)){break b}v[22452]=0;X(66);a=v[22452];v[22452]=0;if((a|0)==1){break a}v[115915]=463656;Id(463664)}return v[115915]}a=P()|0;O()|0;Xe(463664);S(a|0);L()}function wy(a,b,c){var d=0,e=0;e=x[a+480192>>1];a:{if(e){if(!Kc(b)|c>>>0>e>>>0){break a}c=v[((c<<2)+a|0)+900380>>2];if(!c){break a}d=x[Yb(c+236|0,b-1|0)>>1];break a}d=c}return(x[a+480190>>1]<(d&65535)>>>0?0:d)&65535}function vw(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!Gr(a)){break a}if(!(t[a+1375|0]&1)){continue}break}Vb(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function TH(a,b,c){var d=0;d=ab-32|0;ab=d;v[d+28>>2]=c;v[d+24>>2]=0;v[d+12>>2]=4;c=d+16|0;Er(c,a,d+24|0,v[zb(d+28|0,d+12|0)>>2]);v[d+16>>2]=v[d+24>>2];v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);ab=d+32|0}function IG(a,b){var c=0,d=0,e=0;c=ab-256|0;ab=c;if((b|0)>=2){v[(b<<2)+a>>2]=c;gc(c,v[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;gc(v[e>>2],v[(d<<2)+a>>2],4);v[e>>2]=v[e>>2]+4;if((b|0)!=(d|0)){continue}break}}ab=c+256|0}function Hca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ab-32|0;ab=d;e=lf(b);c=OO(d+8|0,c);v[22452]=0;W(699,a|0,b|0,e-1&65535,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){Be(c);ab=d+32|0;return}a=P()|0;O()|0;Be(c);S(a|0);L()}function uN(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=e*A[a+16>>3]+(A[a>>3]*b+c*A[a+8>>3])-d*A[a+24>>3]-f*A[a+32>>3];A[a+56>>3]=b;return b}function V9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Pb(a);e=Rg(a+12|0);t[a+32|0]=c;v[a+28>>2]=0;v[a+24>>2]=b;v[22452]=0;R(741,a|0,1);b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;oN(e);nN(d);S(a|0);L()}function hp(a,b){a=gc(a,b,88);v[a+88>>2]=v[b+88>>2];gc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];gc(a+672|0,b+672|0,52);qy(a+724|0,b+724|0);qy(a+732|0,b+732|0);qy(a+740|0,b+740|0);gc(a+748|0,b+748|0,123);return a}function hZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=yo(a);e=ub(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Eb(a);Uh(d+(e<<2)|0,b,c);b=c+e|0;cg(a,b);nd(d+(b<<2)|0,0);return a|0}rE(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function dS(a,b,c){var d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;b=ac(b);e=hh(a,pc(32),ih(d+8|0,b));b=v[e>>2]+16|0;a=ab-16|0;ab=a;v[a+8>>2]=v[c>>2];u[b>>1]=x[v[a+8>>2]>>1];Bb(b+4|0);ab=a+16|0;f=ac(e),g=1,t[f+4|0]=g;ab=d+16|0}function Xm(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return C(b?-1/a:a)}function Il(a,b){var c=C(0),d=0,e=0;c=C(1);d=u[a+28>>1];a:{if((d|0)>(b|0)){break a}e=v[a+4>>2];if((nc(e,v[a+8>>2])+d<<16)-65536>>16<(b|0)){break a}c=z[Fb(e,b-d|0)>>2];c=c<=C(1.0000000036274937e-15)?C(1):c}return c}function Bha(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;d=Hb(a,64);a:{if(!d){a=b- -64|0;while(1){if((a|0)!=(b|0)){qq(b);b=b+2|0;continue}break}break a}Zt(c+8|0,b);fd(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0;return d|0}function zea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,1030);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){Jb(b,0,1030)}return a|0}function qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{e=sd(a);b:{d=b+c|0;c=hi(b,d);if(c){v[22452]=0;R(334,a|0,c|0);f=v[22452];v[22452]=0;if((f|0)==1){break b}Gt(a,b,d,c)}break a}a=P()|0;O()|0;Xb(e);S(a|0);L()}}function lY(a){a=a|0;a:{b:{if(t[463888]&1){break b}if(!Jd(463888)){break b}v[22452]=0;Q(1188,463876,80300)|0;a=v[22452];v[22452]=0;if((a|0)==1){break a}Id(463888)}return 463876}a=P()|0;O()|0;Xe(463888);S(a|0);L()}function ku(a,b,c){var d=0;a=a+3|0;a=(w[a|0]|w[a+1|0]<<8)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function kY(a){a=a|0;a:{b:{if(t[463920]&1){break b}if(!Jd(463920)){break b}v[22452]=0;Q(1188,463908,80384)|0;a=v[22452];v[22452]=0;if((a|0)==1){break a}Id(463920)}return 463908}a=P()|0;O()|0;Xe(463920);S(a|0);L()}function jY(a){a=a|0;a:{b:{if(t[463824]&1){break b}if(!Jd(463824)){break b}v[22452]=0;Q(1188,463812,80228)|0;a=v[22452];v[22452]=0;if((a|0)==1){break a}Id(463824)}return 463812}a=P()|0;O()|0;Xe(463824);S(a|0);L()}function iY(a){a=a|0;a:{b:{if(t[463856]&1){break b}if(!Jd(463856)){break b}v[22452]=0;Q(1188,463844,80264)|0;a=v[22452];v[22452]=0;if((a|0)==1){break a}Id(463856)}return 463844}a=P()|0;O()|0;Xe(463856);S(a|0);L()}function IE(a){var b=0,c=0;b=ab-16|0;ab=b;v[b>>2]=465280;c=v[116321];v[b+4>>2]=c;v[b+8>>2]=c+(a<<2);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){dc(b);ab=b+16|0}else{_s(a);a=a+4|0;v[b+4>>2]=a;continue}break}}function bM(a,b){var c=0,d=0,e=0,f=0;a:{v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];d=vb(a);c=ac(a);if(!v[d>>2]){v[a>>2]=c;break a}v[v[c>>2]+8>>2]=c;a=ac(b);v[b>>2]=a;v[a>>2]=0;e=vb(b),f=0,v[e>>2]=f}}function YR(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,6)+e;a=v[d>>2];while(1){if(v[d+4>>2]!=(a|0)){Et(a,c);a=v[d>>2]+6|0;v[d>>2]=a;continue}break}xd(d);ab=d+16|0}function Tx(a,b){var c=0;c=v[b+24>>2];c=c?c:1;v[a+24628>>2]=c>>>0<512?c:512;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}gc(a+24604|0,b,40);ZK(a,c)}function Bv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=zF(b);if(c>>>0<1073741808){b:{if(c>>>0<=1){ye(a,c);d=a;break b}e=sl(c)+1|0;d=ji(e);nd(a,d);Lf(a,e);Qd(a,c)}Uh(d,b,c);nd((c<<2)+d|0,0);break a}Df();L()}return a|0}function xea(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;d=Hb(a,6);a:{if(!d){a=b+6|0;while(1){if((a|0)!=(b|0)){rf(b);b=b+1|0;continue}break}break a}QA(c+8|0,b);fd(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0;return d|0}
function sfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,422);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){Jb(b,0,422)}return a|0}function mfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,826);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){Jb(b,0,826)}return a|0}function fO(a,b,c,d){var e=0;e=ab-16|0;ab=e;a=Ai(e,a,d);d=ab-16|0;ab=d;v[d+8>>2]=b;while(1){if(Tb(b,c)){wi(v[a+4>>2],x[b>>1]);Ke(d+8|0);v[a+4>>2]=v[a+4>>2]+2;b=v[d+8>>2];continue}break}ab=d+16|0;dc(a);ab=e+16|0}function ek(a){mc(a+16|0,v[a>>2]);mc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function bY(a){a=a|0;a:{b:{if(t[463872]&1){break b}if(!Jd(463872)){break b}v[22452]=0;Q(55,463860,13464)|0;a=v[22452];v[22452]=0;if((a|0)==1){break a}Id(463872)}return 463860}a=P()|0;O()|0;Xe(463872);S(a|0);L()}function aia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Wu(c+8|0,b);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){t[b+2|0]=0;t[b|0]=0;t[b+1|0]=0}}function _X(a){a=a|0;a:{b:{if(t[463840]&1){break b}if(!Jd(463840)){break b}v[22452]=0;Q(55,463828,13680)|0;a=v[22452];v[22452]=0;if((a|0)==1){break a}Id(463840)}return 463828}a=P()|0;O()|0;Xe(463840);S(a|0);L()}function Iea(a){a=a|0;var b=0,c=0,d=0;b=ab-32|0;ab=b;u[b+30>>1]=0;c=Zb(b+8|0,b+30|0,2);_b(b+16|0,a,v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=2){break a}if(Ib(b+30|0,13595,2)){break a}Ob(a,2);d=1}ab=b+32|0;return d|0}function z8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,225);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){Jb(b,0,225)}return a|0}function w8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,326);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){Jb(b,0,326)}return a|0}function aY(a){a=a|0;a:{b:{if(t[463904]&1){break b}if(!Jd(463904)){break b}v[22452]=0;Q(55,463892,9224)|0;a=v[22452];v[22452]=0;if((a|0)==1){break a}Id(463904)}return 463892}a=P()|0;O()|0;Xe(463904);S(a|0);L()}function aG(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=eb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!Tm(b)){break a}v[a>>2]=0}return a|0}function V1(a,b){a=a|0;b=b|0;var c=0,d=0;c=bs(a);v[a>>2]=73440;d=Bb(a+32|0);v[a+44>>2]=0;v[a+48>>2]=8;v[22452]=0;R(83,a|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;pb(d);Fl(c);S(a|0);L()}function Sx(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;YK(a+24648|0);cL(a)}function $X(a){a=a|0;a:{b:{if(t[463808]&1){break b}if(!Jd(463808)){break b}v[22452]=0;Q(55,463796,5226)|0;a=v[22452];v[22452]=0;if((a|0)==1){break a}Id(463808)}return 463796}a=P()|0;O()|0;Xe(463808);S(a|0);L()}function rv(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function od(a,b){var c=0,d=0;c=ab-16|0;ab=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Hb(a,1)){break b}t[c+15|0]=0;hg(a,c+15|0);t[c+8|0]=w[c+15|0];d=w[c+8|0]}ab=c+16|0;break a}ca(11197,9050,136,14177);L()}return d}function kv(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;_q(v[d>>2]-12|0,c);v[d>>2]=v[d>>2]-12;continue}break}cc(a,d);cc(a+4|0,b+8|0);cc(vb(a),ic(b));v[b>>2]=v[b+4>>2]}function jda(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;Vl(a,b);b=wb(v[a>>2]);v[c+8>>2]=b;a=wb(v[a+4>>2]);while(1){if(Tb(b,a)){d=w[b|0]+(d&255)|0;t[b|0]=d;Fe(c+8|0);b=v[c+8>>2];continue}else{ab=c+16|0}break}}function iD(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-36|0;Zu(v[d>>2]-36|0,c);v[d>>2]=v[d>>2]-36;continue}break}cc(a,d);cc(a+4|0,b+8|0);cc(vb(a),ic(b));v[b>>2]=v[b+4>>2]}function ft(a){var b=0,c=0;a:{if(Ib(a,13568,4)|w[a+4|0]){break a}b=a+6|0;if(Ab(w[b|0]|w[b+1|0]<<8)>>>0>1){break a}b=a+12|0;if(Ab(w[b|0]|w[b+1|0]<<8)){break a}a=a+16|0;c=(Ab(w[a|0]|w[a+1|0]<<8)|0)==20}return c}function c7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;a=Hj(a);if(a){d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;e=v[v[a>>2]+72>>2];v[c>>2]=b;v[c+4>>2]=d;a=eb[e|0](a,c)|0}else{a=1}ab=c+16|0;return a|0}function bea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,71);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){Jb(b,0,71)}return a|0}function Zfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,91);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){Jb(b,0,91)}return a|0}function UN(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-32|0;Yy(v[d>>2]-32|0,c);v[d>>2]=v[d>>2]-32;continue}break}cc(a,d);cc(a+4|0,b+8|0);cc(vb(a),ic(b));v[b>>2]=v[b+4>>2]}function MA(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-20|0;PA(v[d>>2]-20|0,c);v[d>>2]=v[d>>2]-20;continue}break}cc(a,d);cc(a+4|0,b+8|0);cc(vb(a),ic(b));v[b>>2]=v[b+4>>2]}function Gm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;a:{if(c){Mb(d,c);break a}Bb(d)}v[22452]=0;U(11,a|0,b|0,d|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(d);ab=d+16|0;return}a=P()|0;O()|0;pb(d);S(a|0);L()}function BC(a,b){var c=0,d=0;c=ab-16|0;ab=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Hb(a,1)){break b}t[c+15|0]=0;hg(a,c+15|0);t[c+8|0]=w[c+15|0];d=t[c+8|0]}ab=c+16|0;break a}ca(11197,9050,136,14177);L()}return d}function u8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,60);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){Jb(b,0,60)}return a|0}function dP(a){a=a*4294967296;if(D(a)<0x8000000000000000){db=D(a)>=1?~~(a>0?F(H(a*2.3283064365386963e-10),4294967295):I((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}db=-2147483648;return 0}function Z1(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a=v[a+24>>2];II(c,b);a=v[a+1298464>>2];v[22452]=0;U(364,a|0,1,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(c);ab=c+16|0;return}a=P()|0;O()|0;pb(c);S(a|0);L()}function Vga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;nA(c+8|0,b);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){Jb(b,0,4896)}return a|0}function B8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,73);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){Jb(b,0,73)}return a|0}function nu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function ng(a){var b=0;v[22452]=0;a=T(788,a|0)|0;b=v[22452];v[22452]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[22452]=0;X(17);b=v[22452];v[22452]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Gb();L()}function e9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;v[a>>2]=v[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){Vx(d,v[c+4>>2],v[c+8>>2])}gc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function TL(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+28>>2];v[a+24>>2]=v[b+24>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function Pz(a,b,c,d){var e=0,f=0;e=ab-16|0;ab=e;f=v[b+12>>2];v[e+12>>2]=d;v[e+8>>2]=c;c=v[v[b>>2]+28>>2];d=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=d;eb[c|0](a,b,f,e);v[b+12>>2]=v[b+12>>2]+v[a+4>>2];ab=e+16|0}function CS(a){var b=0;a:{if(Ib(a,3873,4)|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(Ib(a+71|0,13675,4)|w[a+75|0]!=1|w[a+76|0]){break a}a=a+116|0;b=((w[a|0]|w[a+1|0]<<8)-1&65535)>>>0<9}return b}function VE(a,b,c,d,e,f){var g=0,h=0,i=0;g=ab-16|0;ab=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){Tg(g+13|0,g+14|0)}h=c,i=(Xa(b|0,Ic(b,v[c>>2])|0,g+12|0,d|0,v[a>>2])|0)+b|0,v[h>>2]=i;ab=g+16|0}function jw(a){a=a|0;var b=0;v[a>>2]=74636;v[22452]=0;R(71,a|0,0);b=v[22452];v[22452]=0;if((b|0)!=1){Nb(a+28|0);xb(v[a+32>>2]);xb(v[a+36>>2]);xb(v[a+48>>2]);xb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Gb();L()}function ZD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ab-16|0;ab=d;c=Ec(a);e=ub(a);f=e+1|0;if((c|0)==(e|0)){sy(a,c,f-c|0,c,c,0)}c=Eb(a);dq(c+e|0,1,b);cg(a,f);t[d+15|0]=0;md(c+f|0,d+15|0);ab=d+16|0;return a|0}function Xba(a){a=a|0;var b=0;b=ab-16|0;ab=b;a:{if(Sp(a,10226)){zI(b,17517,a);a=Eb(b);v[22452]=0;R(39,44,a|0);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(b);S(a|0);L()}ab=b+16|0;return}L()}function Vy(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=v[c>>2];if(d){Cn(d);PN(v[c>>2])}b=b+1|0;continue}break}}function JU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;yu(c+8|0,b);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){Jb(b,0,65)}return a|0}function uf(a,b,c,d,e){var f=0;f=ab-256|0;ab=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Jb(f,b&255,d?c:256);if(!d){while(1){df(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}df(a,f,c)}ab=f+256|0}function AM(a,b,c){var d=0;a:{if(v[a+480180>>2]!=67108864){break a}d=B(c,872)+b|0;v[d+704>>2]=v[d+704>>2]&-129;d=x[a+480188>>1];a=c^1;if(d>>>0<=a>>>0){break a}a=B(a,872)+b|0;v[a+704>>2]=v[a+704>>2]&-129}}function nh(a,b){var c=0;a=v[a>>2];b=Od(b);c=v[a+8>>2];if(nc(c,v[a+12>>2])>>>0>b>>>0){c=v[Fb(c,b)>>2]!=0}else{c=0}if(!c){a=aa(4)|0;Dl(a);v[a>>2]=88852;ia(a|0,88988,1084);L()}return v[Fb(v[a+8>>2],b)>>2]}function j7(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=v[b+52>>2];if(c&16){d=v[b+48>>2];c=v[b+28>>2];if(d>>>0<c>>>0){v[b+48>>2]=c;d=c}pg(a,v[b+24>>2],d);break a}if(c&8){pg(a,v[b+12>>2],v[b+20>>2]);break a}Bb(a)}}function Yd(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=yd(b)}return c}function Eca(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;if((b|0)>=0){d=2147483647;a=at(a);if(a>>>0<=1073741822){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Pc(c+12|0,c+8|0)>>2]}ab=c+16|0;return d|0}gz();L()}function B5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=ab-16|0;ab=f;b=vc(pia(oia(d,d>>31,b,0),db,1e3,0),db);v[a+16>>2]=0;v[a+12>>2]=b+c;sJ(a,e);b=v[a+12>>2];v[f+12>>2]=0;iK(a,b,f+12|0);ab=f+16|0}function u0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ab-16|0;ab=e;a=kt(e,a,d);v[22452]=0;U(1063,b|0,c|0,a+4|0);b=v[22452];v[22452]=0;if((b|0)!=1){dc(a);ab=e+16|0;return}b=P()|0;O()|0;dc(a);S(b|0);L()}function kQ(a){var b=0,c=0,d=0,e=0;db=0;d=w[a+4|0];e=w[a+92|0];b=w[a+93|0];a=a+94|0;c=w[a|0]|w[a+1|0]<<8;b=b+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function SK(a,b,c){var d=0,e=0,f=0,g=0;e=ab-16|0;ab=e;d=Ec(a);a:{if(d>>>0>=c>>>0){b=_j(Eb(a),b,c);t[e+15|0]=0;md(b+c|0,e+15|0);cg(a,c);break a}f=d;g=c-d|0;d=ub(a);Un(a,f,g,d,0,d,c,b)}ab=e+16|0;return a}function O1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ab-16|0;ab=e;a=xo(e,a,d);v[22452]=0;U(1032,b|0,c|0,a+4|0);b=v[22452];v[22452]=0;if((b|0)!=1){dc(a);ab=e+16|0;return}b=P()|0;O()|0;dc(a);S(b|0);L()}function If(a){var b=0,c=0,d=0,e=0;b=ab-16|0;ab=b;c=2;if(a>>>0>=2){v[b+12>>2]=a>>>1;v[b+8>>2]=a^-1;d=b,e=v[zb(b+12|0,b+8|0)>>2]+a|0,v[d+12>>2]=e;v[b+8>>2]=-1;c=v[zb(b+12|0,b+8|0)>>2]}ab=b+16|0;return c}function GS(a){var b=0,c=0;a:{if(Ib(a,21587,11)){break a}b=a+215|0;a=a+63|0;while(1){if((a|0)==(b|0)){return 1}if(w[a+16|0]>3|w[a+17|0]>3){break a}c=a;a=a+19|0;if(w[c+18|0]<16){continue}break}}return 0}function xS(a){var b=0,c=0;b=a+36|0;c=oia(w[b|0]|w[b+1|0]<<8,0,384,0);a=a+34|0;b=w[a|0]|w[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+db|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;a=b>>>0<256?a+1|0:a;db=a;return b}function Ofa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;kA(c+8|0,b);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){lA(b)}return a|0}function vu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;SB(c+8|0,b);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){RB(b)}return a|0}function rW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ab-16|0;ab=d;f=v[v[b>>2]+20>>2];e=v[c+12>>2];v[d+8>>2]=v[c+8>>2];v[d+12>>2]=e;e=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=e;eb[f|0](a,b,d,8);ab=d+16|0}function pt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;iQ(c+8|0,b);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){jQ(b)}return a|0}function hC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;jC(c+8|0,b);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){iC(b)}return a|0}function P7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;e=1;f=v[b>>2];g=v[a+32>>2];if(f>>>0<Ic(g,v[a+36>>2])>>>0){a=Mm(d,Cb(g,f),x[b+12>>1]);b=Jv(c,a);yb(a);e=b^1}ab=d+16|0;return e|0}function Jg(a,b){var c=0,d=0,e=0;c=ub(a);a:{if((c|0)!=(ub(b)|0)){break a}d=Eb(a);b=Eb(b);if(!me(a)){while(1){e=!c;if(!c|w[d|0]!=w[b|0]){break a}b=b+1|0;d=d+1|0;c=c-1|0;continue}}e=!pn(d,b,c)}return e}function $9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;GN(c+8|0,b);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){Py(b)}return a|0}function jD(a,b,c,d){var e=0,f=0;Ve(a+12|0,d);if(b){if(b>>>0>=119304648){Oe(11129);L()}d=pc(B(b,36))}else{d=0}v[a>>2]=d;c=d+B(c,36)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=ic(a),f=d+B(b,36)|0,v[e>>2]=f;return a}function fL(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){if((a|0)!=(c|0)){b=v[a>>2];a:{if(!b){break a}if(!(eb[v[v[b>>2]+116>>2]](b)|0)){break a}eb[v[v[b>>2]+96>>2]](b)}a=a+160|0;continue}break}}function fJ(a){var b=0,c=0,d=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(D(c)<2147483648){a=~~c;break a}a=-2147483648}d=C(Ej(b-+(a|0)))}else{d=C(0)}return d}function DT(a,b,c,d){var e=0,f=0;Ve(a+12|0,d);if(b){if(b>>>0>=153391690){Oe(11129);L()}d=pc(B(b,28))}else{d=0}v[a>>2]=d;c=d+B(c,28)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=ic(a),f=d+B(b,28)|0,v[e>>2]=f;return a}function hT(a,b,c,d){var e=0,f=0;Ve(a+12|0,d);if(b){if(b>>>0>=89478486){Oe(11129);L()}d=pc(B(b,48))}else{d=0}v[a>>2]=d;c=d+B(c,48)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=ic(a),f=d+B(b,48)|0,v[e>>2]=f;return a}function wh(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-32|0;ab=c;t[c+24|0]=0;Ui(c+8|0,c+24|0);d=c+16|0;_m(d,a,v[c+8>>2],v[c+12>>2]);a=v[c+20>>2];t[c+16|0]=w[c+24|0];t[b|0]=w[d|0];ab=c+32|0;return(a|0)==1|0}function wN(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function GI(){var a=0,b=0,c=0,d=0;a=ab-16|0;ab=a;b=pc(1298472);v[22452]=0;c=T(1037,b|0)|0;d=v[22452];v[22452]=0;if((d|0)!=1){b=v[yf(a+8|0,c)>>2];ab=a+16|0;return b|0}a=P()|0;O()|0;xb(b);S(a|0);L()}function Bd(a,b){var c=0,d=0,e=0;d=x[a+24>>1];if((d|0)!=(b&65535)){c=x[a+22>>1]-1&127;u[a+22>>1]=c;e=x[a+20>>1];if(e>>>0<=127){u[a+20>>1]=e+1}c=(c<<2)+a|0;u[c+26>>1]=b-d;u[c+28>>1]=0;u[a+24>>1]=b}}function uea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,106);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){Jb(b,0,106)}}function WM(a,b,c,d){var e=0,f=0;Ve(a+12|0,d);if(b){if(b>>>0>=613566757){Oe(11129);L()}d=pc(B(b,7))}else{d=0}v[a>>2]=d;c=d+B(c,7)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=ic(a),f=d+B(b,7)|0,v[e>>2]=f;return a}function Ti(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Cea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,274);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){Jb(b,0,274)}}function AG(a){var b=0,c=0,d=0;d=v[a>>2];while(1){c=t[d|0];if(Dj(c)){d=d+1|0;v[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=B(b,10);b=(c|0)>(2147483647-b|0)?-1:c+b|0}else{b=-1}continue}break}return b}
function uR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,284);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){Jb(b,0,284)}}function fia(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{if(!Hb(a,64)){a=b- -64|0;while(1){if((a|0)!=(b|0)){rf(b);b=b+1|0;continue}break}break a}Zt(c+8|0,b);fd(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0}function Tt(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function MT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,136);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){Jb(b,0,136)}}function xha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,34);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){Jb(b,0,34)}}function sea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,72);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){Jb(b,0,72)}}function _N(a){a=a|0;var b=0,c=0;b=ab-32|0;ab=b;t[a+16|0]=0;c=$y(b,v[a+12>>2]);v[22452]=0;R(726,a|0,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){Uk(c);ab=b+32|0;return}a=P()|0;O()|0;Uk(c);S(a|0);L()}function Afa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,42);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){Jb(b,0,42)}}function $A(a,b){var c=0;c=ab-16|0;ab=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Sb(128/(B(v[Ee(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[$e(c+7|0,c+6|0)|0];ab=c+16|0;return a|b<<4&240}function sB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,50);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){Jb(b,0,50)}}function mS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ab-16|0;ab=d;Kf(a,d+14|0);e=x[d+14>>1];mL(b,e);c=0;while(1){if((c|0)==(e|0)){Wx(b);ab=d+16|0}else{Xj(a,Fb(v[b>>2],c));c=c+1|0;continue}break}}function eJ(a,b){var c=0,d=0,e=0,f=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);c=+a;e=32768/(1-c);f=c;c=Ge(31415.926535897932/+b);d=Tl(e*(1-(f*c+K(+C(a+a)*(1-c)-+C(a*a)*(1-c*c)))))}return d}function aH(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=z[e>>2];c=c+h|0;g=z[c>>2];z[e>>2]=f+g;z[c>>2]=f-g;d=d+1|0;continue}break}}function L4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=ab-16|0;ab=e;f=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;a=LH(a,e,c,d);ab=e+16|0;return a|0}function GU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,59);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){Jb(b,0,59)}}function vc(a,b){var c=0;c=ab-32|0;ab=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=-2147483648;v[c+20>>2]=-1;v[c+8>>2]=2147483647;v[c+12>>2]=0;a=fE(c+16|0,iu(c+24|0,c+8|0));ab=c+32|0;return v[a>>2]}function fg(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab+-64|0;ab=c;d=zx(c+8|0,a);v[22452]=0;U(192,a|0,b|0,d|0);a=v[22452];v[22452]=0;if((a|0)!=1){Lk(d);ab=c- -64|0;return}a=P()|0;O()|0;Lk(d);S(a|0);L()}function _9(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{if(!Hb(a,27)){a=b+27|0;while(1){if((a|0)!=(b|0)){rf(b);b=b+1|0;continue}break}break a}GN(c+8|0,b);fd(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0}function BQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!he(a,b)){break a}c=cB(a,v[Nf(v[a>>2],b)+12>>2],c);d=65535;if((c|0)==65535){break a}a=v[a>>2];b=Nf(a,b);xK(Nf(a,c),b);d=c}return d|0}function AQ(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{if(!Hb(a,32)){a=b+32|0;while(1){if((a|0)!=(b|0)){rf(b);b=b+1|0;continue}break}break a}wQ(c+8|0,b);fd(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0}function tE(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=79992;d=a+8|0;while(1){b=v[a+8>>2];if(nc(b,v[a+12>>2])>>>0>c>>>0){b=v[Fb(b,c)>>2];if(b){Em(b)}c=c+1|0;continue}break}pb(a+152|0);Fv(d);return a|0}function rP(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-12|0,12)|0;v[c>>2]=f;if((d|0)>0){gc(f,e,d)}cc(a,c);cc(a+4|0,b+8|0);cc(vb(a),ic(b));v[b>>2]=v[b+4>>2]}function pO(a,b){var c=0;c=w[a+800|0];a:{if(c){break a}c=pi(w[a+797|0]-u[a+770>>1]|0);if(!b|(c<<24)-16777216>>24<0){break a}a=v[a+656>>2];if(!a){break a}c=w[Cb(a+108|0,c-1|0)|0]}return c&255}function ofa(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{if(!Hb(a,2)){a=b+2|0;while(1){if((a|0)!=(b|0)){rf(b);b=b+1|0;continue}break}break a}ll(c+8|0,b);fd(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0}function gT(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-48|0,48)|0;v[c>>2]=f;if((d|0)>0){gc(f,e,d)}cc(a,c);cc(a+4|0,b+8|0);cc(vb(a),ic(b));v[b>>2]=v[b+4>>2]}function cj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=Rk(a,b);if((d|0)==255){break a}Nj(a,b);vp(a,b,0,0);if(!c){break a}e=Yb(a+26|0,d),f=65535,u[e>>1]=f;a=Cb(a+62|0,b);t[a|0]=w[a|0]|128}}function YS(a){var b=0,c=0;a:{if(Ib(a,17792,8)|w[a+8|0]>1|(w[a+9|0]-1&255)>>>0>7){break a}b=a+10|0;if((w[b|0]|w[b+1|0]<<8)>>>0>4096){break a}a=a+12|0;c=(w[a|0]|w[a+1|0]<<8)>>>0<4097}return c}function yQ(a,b){var c=0,d=0,e=0;c=ab-16|0;ab=c;d=c,e=(So(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),A[d+8>>3]=e;LM(c+8|0,127);a=Nn(A[c+8>>3]);ab=c+16|0;return a}function oB(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{if(!Hb(a,8)){a=b+8|0;while(1){if((a|0)!=(b|0)){rf(b);b=b+1|0;continue}break}break a}Am(c+8|0,b);fd(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0}function Ux(a,b){var c=0;jP(a,b);t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function T5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ng(4332);if(!d){return 0}v[22452]=0;a=ea(898,d|0,a|0,b|0,c|0,0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;xb(d);S(a|0);L()}function K5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ng(4332);if(!d){return 0}v[22452]=0;a=ea(898,d|0,a|0,b|0,c|0,1)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;xb(d);S(a|0);L()}function A6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ng(4332);if(!d){return 0}v[22452]=0;a=ea(894,d|0,a|0,b|0,c|0,0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;xb(d);S(a|0);L()}function mC(a){var b=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;b=v[a>>2];if(b&8){v[a>>2]=b|32;return-1}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];return 0}function h5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ng(86224);if(!d){return 0}v[22452]=0;a=da(903,d|0,a|0,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;xb(d);S(a|0);L()}function cn(a){var b=0,c=0;b=ab-16|0;ab=b;a:{if(uI(w[a+20|0])){break a}v[22452]=0;R(1042,b+8|0,a|0);c=v[22452];v[22452]=0;if((c|0)!=1){break a}V(0)|0;O()|0;Gb();L()}t[a+20|0]=255;ab=b+16|0}function W8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=ab-16|0;ab=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(nc(v[a+4>>2],v[a+8>>2])+e|0)-1|0,u[f+10>>1]=g;a=nK(a,b,c,d+8|0);ab=d+16|0;return a|0}function VM(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-7|0,7)|0;v[c>>2]=f;if((d|0)>0){gc(f,e,d)}cc(a,c);cc(a+4|0,b+8|0);cc(vb(a),ic(b));v[b>>2]=v[b+4>>2]}function QS(a){var b=0,c=0;a:{if(Ib(a,16661,4)){break a}b=a+4|0;if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-257>>>0<4294967053){break a}a=a+8|0;c=!Ab(w[a|0]|w[a+1|0]<<8)}return c}function KF(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;b=v[a+8>>2];d=v[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;v[a+8>>2]=b-c;v[a+12>>2]=d}function FF(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function p6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ng(4280);if(!d){return 0}v[22452]=0;a=da(895,d|0,a|0,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;xb(d);S(a|0);L()}function o7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ng(4304);if(!d){return 0}v[22452]=0;a=da(882,d|0,a|0,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;xb(d);S(a|0);L()}function o5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ng(4276);if(!d){return 0}v[22452]=0;a=da(902,d|0,a|0,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;xb(d);S(a|0);L()}function f6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ng(4276);if(!d){return 0}v[22452]=0;a=da(896,d|0,a|0,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;xb(d);S(a|0);L()}function _5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ng(4268);if(!d){return 0}v[22452]=0;a=da(897,d|0,a|0,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;xb(d);S(a|0);L()}function Pw(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function L6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ng(4236);if(!d){return 0}v[22452]=0;a=da(892,d|0,a|0,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;xb(d);S(a|0);L()}function Kz(a,b){var c=0,d=0;d=ab-32|0;ab=d;c=vb(a);c=_f(d+8|0,fh(a,nc(v[a>>2],v[a+4>>2])+1|0),nc(v[a>>2],v[a+4>>2]),c);Dp(v[c+8>>2],v[b>>2]);v[c+8>>2]=v[c+8>>2]+4;rd(a,c);Zf(c);ab=d+32|0}function J7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ng(4268);if(!d){return 0}v[22452]=0;a=da(874,d|0,a|0,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;xb(d);S(a|0);L()}function J5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ng(4228);if(!d){return 0}v[22452]=0;a=da(899,d|0,a|0,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;xb(d);S(a|0);L()}function F8(a,b){a=a|0;b=b|0;var c=0;b=ab-16|0;ab=b;c=-1;a:{if(!tj(a,b+8|0)){break a}c=0;if(!GK(b+8|0)){break a}a=HP(a,b);if(!a){im(b)}c=-1;if(!a){break a}c=FK(b)}a=c;ab=b+16|0;return a|0}function Bea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=sd(a);a:{if(b){v[22452]=0;R(584,a|0,b|0);e=v[22452];v[22452]=0;if((e|0)==1){break a}ao(a,b,c)}return a|0}a=P()|0;O()|0;_c(d);S(a|0);L()}function Ax(a,b,c,d,e,f,g,h,i){var j=0;j=ab-16|0;ab=j;og(j,b,c,d,e,f,g,h,i^-2147483648);d=v[j>>2];c=v[j+4>>2];b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;v[a>>2]=d;v[a+4>>2]=c;ab=j+16|0}function A5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ng(5048);if(!d){return 0}v[22452]=0;a=da(900,d|0,a|0,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;xb(d);S(a|0);L()}function zB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=sd(a);a:{if(b){v[22452]=0;R(253,a|0,b|0);e=v[22452];v[22452]=0;if((e|0)==1){break a}tm(a,b,c)}return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function oS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=sd(a);a:{if(b){v[22452]=0;R(407,a|0,b|0);e=v[22452];v[22452]=0;if((e|0)==1){break a}yA(a,b,c)}return a|0}a=P()|0;O()|0;Eh(d);S(a|0);L()}function mG(a,b){var c=0,d=0;d=ab-32|0;ab=d;c=vb(a);c=xl(d+8|0,ul(a,Ic(v[a>>2],v[a+4>>2])+1|0),Ic(v[a>>2],v[a+4>>2]),c);Bj(v[c+8>>2],w[b|0]);v[c+8>>2]=v[c+8>>2]+1;rd(a,c);wl(c);ab=d+32|0}function gga(){var a=0;a:{b:{if(t[89844]&1){break b}if(!Jd(89844)){break b}v[22452]=0;X(26);a=v[22452];v[22452]=0;if((a|0)==1){break a}Id(89844)}return}a=P()|0;O()|0;Xe(89844);S(a|0);L()}function Xg(a,b,c){a:{if(b>>>0<=c>>>0){a=aa(8)|0;v[22452]=0;T(184,a|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ba(a|0);S(b|0);L()}return w[a+c|0]}ia(a|0,26072,159);L()}function Vt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=sd(a);a:{if(b){v[22452]=0;R(312,a|0,b|0);e=v[22452];v[22452]=0;if((e|0)==1){break a}tm(a,b,c)}return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function IU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=sd(a);a:{if(b){v[22452]=0;R(219,a|0,b|0);e=v[22452];v[22452]=0;if((e|0)==1){break a}eC(a,b,c)}return a|0}a=P()|0;O()|0;ec(d);S(a|0);L()}function BO(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function xT(a,b){var c=0,d=0,e=0;c=ab-16|0;ab=c;Yt(c+8|0,b);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){eB(b)}return a}function vR(a,b){var c=0,d=0,e=0;c=ab-16|0;ab=c;xR(c+8|0,b);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){wR(b)}return a}function tj(a,b){var c=0,d=0,e=0;c=ab-16|0;ab=c;Am(c+8|0,b);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){nl(b)}return a}function mQ(a,b){var c=0,d=0,e=0;c=ab-16|0;ab=c;iQ(c+8|0,b);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){jQ(b)}return a}function _R(a,b,c,d){var e=0;e=ab-16|0;ab=e;v[e+12>>2]=b;v[e+8>>2]=d;a=pn(a,c,v[zb(e+12|0,e+8|0)>>2]);a:{if(a){break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}ab=e+16|0;return a}function Zi(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function YA(a,b){var c=0,d=0,e=0;c=ab-16|0;ab=c;XA(c+8|0,b);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){aT(b)}return a}function XQ(a,b){var c=0,d=0,e=0;c=ab-16|0;ab=c;UQ(c+8|0,b);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){VQ(b)}return a}function WC(a,b){var c=0,d=0,e=0;c=ab-16|0;ab=c;Cq(c+8|0,b);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){Dq(b)}return a}function ND(a,b){var c=0,d=0,e=0;c=ab-16|0;ab=c;LD(c+8|0,b);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){iv(b)}return a}function LA(a,b){var c=0,d=0,e=0;c=ab-16|0;ab=c;HS(c+8|0,b);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){IS(b)}return a}function E_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=Jt(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;gc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function EP(a,b){var c=0,d=0,e=0;c=ab-16|0;ab=c;HS(c+8|0,b);d=v[c+12>>2];$c(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;a=(d|0)==(e|0);if(!a){IS(b)}return a}function Cu(a,b){var c=0;c=ab-16|0;ab=c;a:{if(!Hb(a,256)){a=b+256|0;while(1){if((a|0)!=(b|0)){rf(b);b=b+1|0;continue}break}break a}Ub(c+8|0,b,256);fd(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0}function rt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;wQ(c+8|0,b);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){Dz(b)}}function ix(a){var b=0,c=0,d=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=qn(d)|b<<15;continue}break}A[c+4280>>3]=C(C(b|0)*C(-4.656612873077393e-10))}function N4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=ab-16|0;ab=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=YI(f,b,c,d,0,0,0,0,e);ab=f+16|0;return a|0}function IZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=ab-16|0;ab=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;h=a;a=g+16|0;b=Aj(h,b,c,d,e,f,g+8|0,a);ab=a;return b|0}function v1(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;d=v[13471];v[c+8>>2]=v[13470];v[c+12>>2]=d;d=v[13469];v[c>>2]=v[13468];v[c+4>>2]=d;eb[v[yh(c,Ig(w[b+20|0]))>>2]](a,b);ab=c+16|0}function lea(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;Ub(c+8|0,b,1100);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)|0}function _b(a,b,c,d){var e=0,f=0;e=ab-16|0;ab=e;f=v[b>>2];b=v[b+8>>2];v[e+12>>2]=d;v[e+8>>2]=c;c=v[v[f>>2]+28>>2];d=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=d;eb[c|0](a,f,b,e);ab=e+16|0}function Or(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=v[a+4>>2];d=((b<<2)+(Ju(v[a>>2],1)^270549120)|0)+2019860093|0;v[a>>2]=d;b=b+B(Ju(d,16),5)|0;v[a+4>>2]=b;continue}break}return b}function YD(a,b){var c=0,d=0;d=ab-32|0;ab=d;c=vb(a);c=ql(d+8|0,to(a,ad(v[a>>2],v[a+4>>2])+1|0),ad(v[a>>2],v[a+4>>2]),c);_q(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;kv(a,c);Zq(c);ab=d+32|0}function Kf(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-32|0;ab=c;u[c+30>>1]=0;Di(c+8|0,c+30|0);d=c+16|0;_m(d,a,v[c+8>>2],v[c+12>>2]);u[c+16>>1]=x[c+30>>1];u[b>>1]=w[d|0]|w[d+1|0]<<8;ab=c+32|0}function Ah(a){var b=0;a=kf(a);b=2147483647;a:{if(a>=C(2147483648)){break a}b=-2147483648;if(a<=C(-2147483648)){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function vB(a,b){var c=0;c=ab-16|0;ab=c;a:{if(!Hb(a,512)){a=b+512|0;while(1){if((a|0)!=(b|0)){im(b);b=b+4|0;continue}break}break a}eu(c+8|0,b);fd(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0}function sS(a){var b=0,c=0;a:{if(Ib(a,13814,4)){b=0;if(Ib(a,16224,4)){break a}}c=a+34|0;b=0;if((w[c|0]|w[c+1|0]<<8)>>>0>255){break a}a=a+36|0;b=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return b}function mY(){var a=0;a:{if(t[464952]&1){break a}if(!Jd(464952)){break a}a=464928;while(1){a=Bb(a)+12|0;if((a|0)!=464952){continue}break}Id(464952)}bd(464928,85264);bd(464940,85276)}function cY(){var a=0;a:{if(t[464920]&1){break a}if(!Jd(464920)){break a}a=464896;while(1){a=Bb(a)+12|0;if((a|0)!=464920){continue}break}Id(464920)}Xc(464896,13837);Xc(464908,13816)}function cJ(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=ab-16|0;ab=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=bJ(f,b,c,d,e,0,0,0,0);ab=f+16|0;return+c}function _f(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;Ve(a+12|0,d);if(b){d=ji(b)}else{d=0}v[a>>2]=d;c=d+(c<<2)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=ic(a),f=d+(b<<2)|0,v[e>>2]=f;return a|0}function ul(a,b){var c=0,d=0;c=ab-16|0;ab=c;v[c+12>>2]=b;d=b;b=$F();if(d>>>0<=b>>>0){a=Do(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}ab=c+16|0;return b}hd();L()}function uK(a,b){var c=0,d=0;c=ab-16|0;ab=c;v[c+12>>2]=b;d=b;b=tK();if(d>>>0<=b>>>0){a=vs(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}ab=c+16|0;return b}hd();L()}function to(a,b){var c=0,d=0;c=ab-16|0;ab=c;v[c+12>>2]=b;d=b;b=XD();if(d>>>0<=b>>>0){a=lk(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}ab=c+16|0;return b}hd();L()}function rj(a,b){var c=0,d=0;c=ab-16|0;ab=c;v[c+12>>2]=b;d=b;b=LC();if(d>>>0<=b>>>0){a=um(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}ab=c+16|0;return b}hd();L()}function rA(a,b){var c=0,d=0;c=ab-16|0;ab=c;v[c+12>>2]=b;d=b;b=_A();if(d>>>0<=b>>>0){a=St(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}ab=c+16|0;return b}hd();L()}function lL(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;iL(c,b+80|0);v[22452]=0;U(11,a|0,0,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){pb(c);ab=c+16|0;return}a=P()|0;O()|0;pb(c);S(a|0);L()}function lC(a,b){var c=0,d=0,e=0;c=ab-16|0;ab=c;Ub(c+8|0,b,37);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){Jb(b,0,37)}}function kD(a,b){var c=0,d=0;c=ab-16|0;ab=c;v[c+12>>2]=b;d=b;b=hD();if(d>>>0<=b>>>0){a=Yu(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}ab=c+16|0;return b}hd();L()}function fh(a,b){var c=0,d=0;c=ab-16|0;ab=c;v[c+12>>2]=b;d=b;b=Jn();if(d>>>0<=b>>>0){a=Ch(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}ab=c+16|0;return b}hd();L()}function OA(a,b){var c=0,d=0;c=ab-16|0;ab=c;v[c+12>>2]=b;d=b;b=aC();if(d>>>0<=b>>>0){a=cC(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}ab=c+16|0;return b}hd();L()}function Kq(a,b){var c=0,d=0;c=ab-16|0;ab=c;v[c+12>>2]=b;d=b;b=pD();if(d>>>0<=b>>>0){a=Fm(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}ab=c+16|0;return b}hd();L()}function Bp(a,b){var c=0,d=0;c=ab-16|0;ab=c;v[c+12>>2]=b;d=b;b=TO();if(d>>>0<=b>>>0){a=Mn(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}ab=c+16|0;return b}hd();L()}function BV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;v[d+12>>2]=c;c=0;a=eb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[zb(d+12|0,d+8|0)>>2]}ab=d+16|0;return c|0}function Av(a,b){var c=0,d=0;c=ab-16|0;ab=c;v[c+12>>2]=b;d=b;b=pE();if(d>>>0<=b>>>0){a=cr(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}ab=c+16|0;return b}hd();L()}function $q(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ab-16|0;ab=e;v[e+12>>2]=d;d=ub(b);if(d>>>0<c>>>0){Vp();L()}b=Eb(b);v[e+8>>2]=d-c;Lq(a,b+c|0,v[zb(e+12|0,e+8|0)>>2]);ab=e+16|0}function My(a){var b=0,c=0;b=v[a>>2];c=v[b>>2];a:{if(c){while(1){b=c;c=v[b+4>>2];if(c){continue}break}break a}while(1){c=gh(b);b=v[b+8>>2];if(c){continue}break}}v[a>>2]=b;return a}function xx(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;b=li(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);ab=d+16|0}else{ns(a,z[c>>2]);a=a+4|0;v[b+4>>2]=a;continue}break}}function ge(a,b){var c=0;a:{c=Pf(b);if((c|0)==(ub(a)|0)){v[22452]=0;a=Y(358,a|0,b|0,c|0)|0;b=v[22452];v[22452]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Gb();L()}function eC(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;b=li(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);ab=d+16|0}else{Dp(a,v[c>>2]);a=a+4|0;v[b+4>>2]=a;continue}break}}function ao(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;b=Ai(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);ab=d+16|0}else{wi(a,x[c>>1]);a=a+2|0;v[b+4>>2]=a;continue}break}}function VR(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+4|0]|w[b+5|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8}function uca(a,b){a=a|0;b=b|0;var c=0,d=0;c=sd(a);a:{if(b){v[22452]=0;R(219,a|0,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break a}FO(a,b)}return a|0}a=P()|0;O()|0;ec(c);S(a|0);L()}function tm(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;b=zk(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);ab=d+16|0}else{Bj(a,w[c|0]);a=a+1|0;v[b+4>>2]=a;continue}break}}function tb(a,b){var c=0,d=0;c=ab-16|0;ab=c;if(me(a)){xb(v[a>>2])}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;ye(b,0);t[c+15|0]=0;md(b,c+15|0);ab=c+16|0;return a}function qt(a){var b=0,c=0,d=0,e=0;d=a+32|0;while(1){a:{if((a|0)==(d|0)){e=b;break a}c=w[a|0];if((c-1&255)>>>0<31|((b^1)&1?0:c)){break a}a=a+1|0;b=!c|b;continue}break}return e&1}function nfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=sd(a);a:{if(b){v[22452]=0;R(537,a|0,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break a}mA(a,b)}return a|0}a=P()|0;O()|0;ec(c);S(a|0);L()}function dga(){var a=0,b=0,c=0;a=ab-16|0;ab=a;b=pc(1);v[22452]=0;X(30);c=v[22452];v[22452]=0;if((c|0)!=1){b=v[yf(a+8|0,b)>>2];ab=a+16|0;return b|0}a=P()|0;O()|0;xb(b);S(a|0);L()}function Zw(a){a=a|0;var b=0;a:{if(!a){a=aa(8)|0;v[22452]=0;T(929,a|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ba(a|0);S(b|0);L()}return}ia(a|0,49112,928);L()}function WI(a){a=a|0;var b=0;a:{if(!a){a=aa(8)|0;v[22452]=0;T(927,a|0)|0;b=v[22452];v[22452]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ba(a|0);S(b|0);L()}return}ia(a|0,49056,928);L()}function Kh(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;Am(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)|0}function Kga(a,b){a=a|0;b=b|0;var c=0;c=ab-32|0;ab=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;lS(b,c);kS(a,c);ab=c+32|0}function Gha(a,b){a=a|0;b=b|0;var c=0,d=0;c=sd(a);a:{if(b){v[22452]=0;R(334,a|0,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break a}Gv(a,b)}return a|0}a=P()|0;O()|0;Xb(c);S(a|0);L()}function BX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=x[(a<<1)+75952>>1]}else{a=0}u[d>>1]=a;d=d+2|0;b=b+4|0;continue}break}return c|0}function BR(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;QA(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)|0}function pS(a,b){a=a|0;b=b|0;var c=0,d=0;c=sd(a);a:{if(b){v[22452]=0;R(312,a|0,b|0);d=v[22452];v[22452]=0;if((d|0)==1){break a}Gv(a,b)}return a|0}a=P()|0;O()|0;Xb(c);S(a|0);L()}function hW(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;ID(b,0,a);v[22452]=0;a=T(116,b|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){pb(b);ab=b+16|0;return a|0}a=P()|0;O()|0;pb(b);S(a|0);L()}function UD(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&-256)!=(a|0)}return b}function Pr(a){var b=0,c=0,d=0;b=ab-16|0;ab=b;v[b+12>>2]=12;while(1){v[b+8>>2]=32;if(y[zb(b+12|0,b+8|0)>>2]<=c>>>0){ab=b+16|0}else{c=c+15|0;d=qn(a)&4095;continue}break}return d}function Gea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;v[d+8>>2]=b;while(1){if(Tb(b,c)){v[d+4>>2]=v[b>>2];Xz(a,d+4|0);te(d+8|0);b=v[d+8>>2];continue}else{ab=d+16|0}break}}function I0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;v[d+12>>2]=c;Iw(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[zb(d+8|0,d+12|0)>>2]}ab=d+16|0;return c|0}function Aha(a,b){a=a|0;b=b|0;if(!ZS(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0}}function mda(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;b=-1;a:{if(!tj(a,c+8|0)){break a}b=0;if(!kP(c+8|0)){break a}b=-1;if(!Qf(a,4)){break a}b=IP(a)>>>31|0}ab=c+16|0;return b|0}function dX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;eb[v[v[a>>2]+12>>2]](d+8|0,a,b);a=v[d+8>>2];b=v[c>>2];a=jc(v[d+12>>2],v[c+4>>2])&(a|0)==(b|0);ab=d+16|0;return a|0}function UK(a){var b=0,c=0,d=0;b=ab-16|0;ab=b;while(1){v[b+12>>2]=7;v[b+8>>2]=32;if(y[zb(b+12|0,b+8|0)>>2]<=c>>>0){ab=b+16|0}else{c=c+15|0;d=qn(a)&127;continue}break}return d}function $c(a,b,c,d){var e=0,f=0;e=ab-16|0;ab=e;f=v[b+12>>2];v[e+12>>2]=d;v[e+8>>2]=c;c=v[v[b>>2]+28>>2];d=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=d;eb[c|0](a,b,f,e);ab=e+16|0}function aaa(a,b){a=a|0;b=b|0;var c=0;c=of(a);t[a+534|0]=0;v[a+4>>2]=0;v[22452]=0;R(732,a|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;bl(c);S(a|0);L()}function Go(a){var b=0,c=0;b=v[22371];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(nw()>>>0<a>>>0){if(!(ta(a|0)|0)){break a}}v[22371]=a;return b}v[114934]=48;return-1}function yA(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;b=_p(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);ab=d+16|0}else{Et(a,c);a=a+6|0;v[b+4>>2]=a;continue}break}}function lR(a){var b=0,c=0;a:{if(Ib(a,14991,3)){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-2147483647>>>0<2147484072){break a}c=w[a+3|0]<6}return c}function ig(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=Xg(v[d>>2],v[d+4>>2],a);return((Xg(v[d>>2],v[d+4>>2],a+1|0)<<8|e<<16|Xg(v[d>>2],v[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function VL(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;b=Hq(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);ab=d+16|0}else{UL(a,c);a=a+8|0;v[b+4>>2]=a;continue}break}}function OQ(a,b){var c=0,d=0,e=0;c=ab-16|0;ab=c;UQ(c+8|0,b);d=v[c+12>>2];_b(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;if((d|0)!=(e|0)){VQ(b)}}function Dy(a,b){var c=0;c=ab-32|0;ab=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=-1;v[c+12>>2]=0;a=fE(c+16|0,iu(c+24|0,c+8|0));ab=c+32|0;return v[a>>2]}function Bs(a,b){var c=0;a:{if(v[b+88>>2]&134218752){break a}b=v[b+656>>2];if(!Kj(b)){break a}b=w[b+34|0];if((b+5&255)>>>0<6){break a}c=v[(B(b,160)+a|0)+906140>>2]}return c}function xl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;Ve(a+12|0,d);if(b){d=pc(b)}else{d=0}v[a>>2]=d;c=c+d|0;v[a+8>>2]=c;v[a+4>>2]=c;e=ic(a),f=b+d|0,v[e>>2]=f;return a|0}function mv(a,b,c){var d=0,e=0;d=Eb(a);a=ub(a);e=Eb(b);b=ub(b);a:{if(a>>>0>=c>>>0){if(!b){break a}a=a+d|0;b=VD(c+d|0,a,e,b+e|0);c=(a|0)==(b|0)?-1:b-d|0}else{c=-1}}return c}function m9(a,b){a=a|0;b=b|0;var c=0,d=0;c=SL(a);d=al(b);b=Af(b);v[22452]=0;U(783,a|0,d|0,b|0);b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;eM(c);S(a|0);L()}function aS(a,b,c){var d=0;d=ab-32|0;ab=d;v[d+28>>2]=c;t[d+24|0]=0;v[d+12>>2]=1;c=d+16|0;Er(c,a,d+24|0,v[zb(d+28|0,d+12|0)>>2]);t[d+16|0]=w[d+24|0];t[b|0]=w[c|0];ab=d+32|0}function Lp(a){var b=0,c=0;c=v[a+4>>2];b=v[c>>2];v[a+4>>2]=b;if(b){Gl(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(gh(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c>>2]=a;Gl(a,c)}function Kp(a){var b=0,c=0;c=v[a>>2];b=v[c+4>>2];v[a>>2]=b;if(b){Gl(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(gh(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c+4>>2]=a;Gl(a,c)}function zX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=v[c>>2];if(!(a>>>0>127|!(x[(a<<1)+75952>>1]&b))){c=c+4|0;continue}break}d=c}return d|0}function wf(a,b,c,d,e){a:{if(d>>>0<e>>>0){v[22452]=0;W(1052,17326,9081,394,6342);a=v[22452];v[22452]=0;if((a|0)==1){break a}L()}qL(a,b,c,d,e);return}V(0)|0;O()|0;Gb();L()}function Ie(a,b,c){var d=0,e=0,f=0;d=ab-16|0;ab=d;v[d+8>>2]=c;v[d+4>>2]=31;e=d,f=IT(b,c),v[e+12>>2]=f;c=b;b=au(d+4|0);fk(c,c+b|0,a);e=Cb(a,b),f=0,t[e|0]=f;jB(a);ab=d+16|0}function zl(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function oaa(a,b){a=a|0;b=b|0;var c=0;c=Pb(a);t[a+16|0]=0;v[a+12>>2]=b;v[22452]=0;Z(725,a|0);b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;ZN(c);S(a|0);L()}function c2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=ab-16|0;ab=b;v[b+8>>2]=e;v[b+12>>2]=f;e=a;a=Zb(b,c,d);a=ss(e,v[a>>2],v[a+4>>2],b+8|0);ab=b+16|0;return a|0}function Gv(a,b){var c=0,d=0;c=ab-16|0;ab=c;b=zk(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){dc(b);ab=c+16|0}else{rf(a);a=a+1|0;v[b+4>>2]=a;continue}break}}
function Gfa(){var a=0,b=0,c=0;a=ab-16|0;ab=a;b=Mb(a,10226);v[22452]=0;Z(34,b|0);c=v[22452];v[22452]=0;if((c|0)!=1){pb(b);ab=a+16|0;return}a=P()|0;O()|0;pb(b);S(a|0);L()}function CV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=eb[v[v[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function mA(a,b){var c=0,d=0;c=ab-16|0;ab=c;b=li(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){dc(b);ab=c+16|0}else{im(a);a=a+4|0;v[b+4>>2]=a;continue}break}}function ZB(a,b){var c=0,d=0;c=ab-16|0;ab=c;b=Ai(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){dc(b);ab=c+16|0}else{YB(a);a=a+2|0;v[b+4>>2]=a;continue}break}}function FO(a,b){var c=0,d=0;c=ab-16|0;ab=c;b=li(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){dc(b);ab=c+16|0}else{_s(a);a=a+4|0;v[b+4>>2]=a;continue}break}}function AX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=v[c>>2];if(a>>>0>127|!(x[(a<<1)+75952>>1]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function bH(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function Sga(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;d=Hb(a,12);a:{if(!d){t[c|0]=0;Lh(b,12,c);break a}XA(c+8|0,b);fd(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0;return d|0}function zda(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-48|0;ab=c;d=-1;a:{if(!EP(a,c)){break a}d=0;if(!DP(c)){break a}d=we(a,b,CP(w[c+31|0],w[c+33|0]),db)}ab=c+48|0;return d|0}function rC(a,b,c){var d=0;d=ab-16|0;ab=d;b=ho(d,a+8|0,b);a=v[b>>2];while(1){if((a|0)!=v[b+4>>2]){wi(a,x[c>>1]);a=v[b>>2]+2|0;v[b>>2]=a;continue}break}xd(b);ab=d+16|0}function nD(a,b){var c=0,d=0;c=ab-16|0;ab=c;Ub(c+8|0,b,20);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function FR(a,b){var c=0,d=0;c=ab-16|0;ab=c;Ub(c+8|0,b,18);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function pV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[zb(d+12|0,d+8|0)>>2]}ab=d+16|0;return c|0}function afa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Pb(a+8|0);v[22452]=0;U(238,a|0,b|0,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Xb(d);S(a|0);L()}}function Xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;MR(b,c);c=Hb(a,c<<2);if(c){LR(d+8|0,v[b>>2],v[b+4>>2]);fd(d,a,v[d+8>>2],v[d+12>>2])}ab=d+16|0;return c|0}function TR(a,b,c){var d=0;d=ab-16|0;ab=d;b=Dv(d,a+8|0,b);a=v[b>>2];while(1){if((a|0)!=v[b+4>>2]){Bj(a,w[c|0]);a=v[b>>2]+1|0;v[b>>2]=a;continue}break}xd(b);ab=d+16|0}function R6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=Qo(d,a);xJ(a,c);v[22452]=0;R(71,b|0,1);a=v[22452];v[22452]=0;if((a|0)==1){a=P()|0;O()|0;Nb(d);S(a|0);L()}}function Pca(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;d=Hb(a,4);a:{if(!d){t[c|0]=0;aD(b,4,c);break a}qh(c+8|0,b);fd(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0;return d|0}function qi(a,b){var c=0;c=v[b+4>>2];b=v[b>>2];t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24;b=c;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24}function Xz(a,b){a=a|0;b=b|0;var c=0;if(y[a+4>>2]<y[vb(a)>>2]){c=ab-16|0;ab=c;a=li(c,a,1);Dp(v[a+4>>2],v[b>>2]);v[a+4>>2]=v[a+4>>2]+4;dc(a);ab=c+16|0;return}Kz(a,b)}function OV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;rD(b,c);c=Hb(a,c<<3);if(c){qD(d+8|0,v[b>>2],v[b+4>>2]);fd(d,a,v[d+8>>2],v[d+12>>2])}ab=d+16|0;return c|0}function J0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;Iw(a,b,c);a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function I$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ab-16|0;ab=e;a=qw(Na(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);ab=e+16|0;db=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function DV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[zb(d+12|0,d+8|0)>>2]}ab=d+16|0;return c|0}function Ce(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(!c){break a}a=v[ac(a)>>2];v[22452]=0;Z(a|0,c|0);a=v[22452];v[22452]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Gb();L()}}function BZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=eb[v[v[a+8>>2]+20>>2]](a+8|0)|0;b=Eb(a);return zj(g,h,c,d,e,f,b,b+(ub(a)<<2)|0)|0}function qQ(a,b){var c=0,d=0;c=ab-16|0;ab=c;aA(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function nT(a,b){var c=0,d=0;c=ab-16|0;ab=c;xu(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function lo(a,b){var c=0,d=0;c=ab-16|0;ab=c;qh(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function hu(a,b){var c=0,d=0;c=ab-16|0;ab=c;gu(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function hg(a,b){var c=0,d=0;c=ab-16|0;ab=c;uq(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function hG(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=rg(b),d=v[v[a>>2]+52>>2],eb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return rg(b)}function fu(a,b){var c=0,d=0;c=ab-16|0;ab=c;_n(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function fD(a,b){var c=0,d=0;c=ab-16|0;ab=c;LD(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function dT(a,b){var c=0,d=0;c=ab-16|0;ab=c;Yt(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function _S(a,b){var c=0,d=0;c=ab-16|0;ab=c;Zt(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function ZS(a,b){var c=0,d=0;c=ab-16|0;ab=c;XA(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function XC(a,b){var c=0,d=0;c=ab-16|0;ab=c;Cq(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function Sca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;iP(b,c);if(Hb(a,c<<8)){c=v[b>>2];Ub(d+8|0,c,eh(c,v[b+4>>2])<<8);fd(d,a,v[d+8>>2],v[d+12>>2])}ab=d+16|0}function RR(a,b){var c=0,d=0;c=ab-16|0;ab=c;QR(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function NQ(a,b){var c=0,d=0;c=ab-16|0;ab=c;MQ(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function LB(a,b){var c=0,d=0;c=ab-16|0;ab=c;KB(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function HP(a,b){var c=0,d=0;c=ab-16|0;ab=c;qh(c+8|0,b);b=v[c+12>>2];$c(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Rc(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function Aq(a,b){var c=0,d=0;c=ab-16|0;ab=c;ll(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}ab=c+16|0;return(b|0)==(d|0)}function qI(a,b){var c=0,d=0;c=ab-16|0;ab=c;b=zk(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){dc(b);ab=c+16|0}else{a=a+1|0;v[b+4>>2]=a;continue}break}}function VO(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;oz(a+112|0,48e3);v[a+668>>2]=0;nz(a+724|0);nz(a+732|0);nz(a+740|0);Fh(a+788|0);return a}function Ob(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Hb(a,b);if(c){v[a+8>>2]=v[a+8>>2]+b;return c|0}b=a;a=v[a>>2];d=b,e=eb[v[v[a>>2]+24>>2]](a)|0,v[d+8>>2]=e;return c|0}function yp(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function pc(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=yd(a);if(b){break a}b=v[116362];if(b){eb[b|0]();continue}break}a=aa(4)|0;gn(a);ia(a|0,88408,25);L()}return b|0}function au(a){var b=0,c=0;a:{c=Fb(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=Kt(v[b>>2],v[a>>2])?b:a;continue}}return v[a>>2]}function KW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;v[d+12>>2]=v[c>>2];a=eb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}ab=d+16|0;return a|0}function tL(a){var b=0,c=0,d=0;b=v[a+112>>2];if((b|0)>=11){c=378;while(1){if(c|d){sL(a);b=c;c=b-1|0;d=d-!b|0;continue}break}b=0}v[a+112>>2]=b+1;a=sL(a);return a}function sx(a,b){var c=0,d=0;a:{if(a>>>0<=99999999){a=mw(b,a);break a}c=(a>>>0)/1e8|0;d=B(c,-1e8)+a|0;a=(d>>>0)/1e4|0;a=Qi(Qi(wG(b,c),a),d+B(a,-1e4)|0)}return a}function rea(a,b){a=a|0;b=b|0;var c=0,d=0;d=ab-80|0;ab=d;c=-1;a:{if(!xT(a,d+8|0)){break a}c=0;if(!vQ(d+8|0)){break a}c=we(a,b,uQ(d+8|0),db)}ab=d+80|0;return c|0}function V8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-16|0;ab=c;d=c,e=oi(b),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[nj(c+12|0,c+8|0,43984)>>2],v[d+36>>2]=e;Wo(a);ab=c+16|0}function vD(a,b,c,d,e){var f=0;f=ab-16|0;ab=f;v[f+12>>2]=e;v[f+8>>2]=d;v[f+4>>2]=c;v[f>>2]=b;Gf(a,f);v[a+8>>2]=0;b=a+12|0;a=f+8|0;Gf(b,a);Cd(a);Cd(f);ab=f+16|0}function oy(a,b){var c=0,d=0;c=v[a+656>>2];a:{if(!c){break a}b:{if((b|0)!=1){break b}a=v[a+104>>2];if(!a){break b}if(w[a+35|0]&4){break a}}d=w[c+34|0]}return d}function hfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Pb(a);v[22452]=0;U(35,a|0,b|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;ec(d);S(a|0);L()}function gN(a,b,c,d){var e=0,f=0;e=ab-16|0;ab=e;while(1){if(c){f=Ns(c+16|0,a,b);d=f?d:c;c=v[(f?4:0)+c>>2];continue}break}a=v[$b(e+8|0,d)>>2];ab=e+16|0;return a}function QM(a,b){a=a|0;b=b|0;var c=0;if(y[a+4>>2]<y[vb(a)>>2]){c=ab-16|0;ab=c;a=kt(c,a,1);_q(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;dc(a);ab=c+16|0;return}YD(a,b)}function QH(a,b){var c=0,d=0;d=a+4|0;c=Ic(v[d>>2],v[a+8>>2]);a=v[a+16>>2]+b|0;if(c>>>0<a>>>0){a:{if(c){b=If(c);if(a>>>0<=b>>>0){break a}}b=RH(a,65536)}Ei(d,b)}}function HZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=eb[v[v[a+8>>2]+20>>2]](a+8|0)|0;b=Eb(a);return Aj(g,h,c,d,e,f,b,ub(a)+b|0)|0}function Gr(a){var b=0;a:{if((De(a)|0)!=79){break a}if((De(a)|0)!=103){break a}if((De(a)|0)!=103){break a}b=(De(a)|0)==83}if(!b){Vb(a,30);return 0}return WG(a)}function qU(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;v[c+12>>2]=-1;if(hg(a,c+8|0)){v[c+4>>2]=w[c+8|0];d=MB(a,b,v[zb(c+4|0,c+12|0)>>2])}ab=c+16|0;return d|0}function lE(a,b,c,d){var e=0,f=0;f=v[a+4>>2];e=0;a:{if(!c){break a}e=f>>8;if(!(f&1)){break a}e=qv(v[c>>2],e)}a=v[a>>2];eb[v[v[a>>2]+28>>2]](a,b,c+e|0,f&2?d:2)}function g7(a){a=a|0;var b=0,c=0,d=0;b=ab-16|0;ab=b;UJ(b+8|0,a,0);c=v[b+12>>2];if(c){a=v[a+20>>2];v[a+148>>2]=-1;d=a+4|0;a=v[b+8>>2];Vx(d,a,Cb(a,c))}ab=b+16|0}function Sl(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(D(a)<2147483648){return~~a}b=-2147483648}return b}function RS(a,b){var c=0,d=0;c=ab-16|0;ab=c;a:{if(me(a)){d=v[a>>2];t[c+15|0]=0;md(b+d|0,c+15|0);Qd(a,b);break a}t[c+14|0]=0;md(a+b|0,c+14|0);ye(a,b)}ab=c+16|0}function QB(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;v[c+12>>2]=-1;if(hg(a,c+8|0)){v[c+4>>2]=w[c+8|0];d=JB(a,b,v[zb(c+4|0,c+12|0)>>2])}ab=c+16|0;return d|0}function HI(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function Ed(a,b){var c=0,d=0,e=C(0);c=ab-16|0;ab=c;v[c+8>>2]=1065353216;z[c+12>>2]=b;d=c,e=xf(a),z[d+4>>2]=e;a=z[oA(c+4|0,c+12|0,c+8|0)>>2];ab=c+16|0;return a}function DO(a,b){var c=0;c=v[a+4>>2];a:{if((b|0)>=0){b=b+c|0;v[a>>2]=v[a>>2]+(b>>>3&536870908);break a}b=b+c|0;v[a>>2]=v[a>>2]+((b-31|0)/32<<2)}v[a+4>>2]=b&31}function x_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function t5(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;if((b|0)<=12){c=Ed(c,C(0));d=((b<<2)+a|0)+4208|0;if((b|0)==12){c=C(kf(C(c*C(3)))/C(3))}z[d>>2]=c;t[a+5046|0]=1}}function sz(a){var b=0;a=be(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(D(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function ql(a,b,c,d){var e=0,f=0;Ve(a+12|0,d);if(b){d=WD(b)}else{d=0}v[a>>2]=d;c=d+B(c,12)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=ic(a),f=d+B(b,12)|0,v[e>>2]=f;return a}function mJ(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function gW(a,b){a=a|0;b=b|0;var c=0;if(y[a+4>>2]<y[vb(a)>>2]){c=ab-16|0;ab=c;a=lv(c,a);_q(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;dc(a);ab=c+16|0;return}YD(a,b)}function dD(a){var b=0;if(!(Ib(a,15471,4)|(w[a+4|0]-16&255)>>>0<249|((w[a+5|0]-16&255)>>>0<249|(w[a+6|0]-16&255)>>>0<249))){b=(w[a+7|0]-9&255)>>>0<7}return b}function Sj(a,b){var c=0,d=0,e=0,f=0;d=sd(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=vb(b);e=vb(d),f=v[c>>2],v[e>>2]=f;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function R0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=ab-16|0;ab=e;v[e+8>>2]=c;v[e+12>>2]=d;a=Zb(e,a,b);a=ss(3,v[a>>2],v[a+4>>2],e+8|0);ab=e+16|0;return a|0}function NA(a,b,c,d){var e=0,f=0;Ve(a+12|0,d);if(b){d=$B(b)}else{d=0}v[a>>2]=d;c=d+B(c,20)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=ic(a),f=d+B(b,20)|0,v[e>>2]=f;return a}function zQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;while(1){if((b|0)==(c|0)){ab=d+16|0}else{v[d+12>>2]=v[b>>2];Xz(a,d+12|0);b=b+4|0;continue}break}}function uu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;Ei(b,c);if(Hb(a,c)){c=v[b>>2];Ub(d+8|0,c,Ic(c,v[b+4>>2]));fd(d,a,v[d+8>>2],v[d+12>>2])}ab=d+16|0}function mr(a){a=a|0;var b=0;b=aa(8)|0;v[22452]=0;Q(978,b|0,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){ia(b|0,88756,159);L()}a=P()|0;O()|0;ba(b|0);S(a|0);L()}function N1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((a|0)!=(b|0)){d=v[c>>2];v[d>>2]=v[a>>2];Rf(d+4|0,a+4|0);v[c>>2]=v[c>>2]+16;a=a+16|0;continue}break}}function Kca(a,b){a=a|0;b=b|0;var c=0,d=0;d=ab-48|0;ab=d;c=-1;a:{if(!EP(a,d)){break a}c=0;if(!QO(d)){break a}c=we(a,b,PO(w[d+47|0]),db)}ab=d+48|0;return c|0}function A_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function yv(a,b,c,d){var e=0,f=0;Ve(a+12|0,d);if(b){d=kE(b)}else{d=0}v[a>>2]=d;c=d+(c<<4)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=ic(a),f=d+(b<<4)|0,v[e>>2]=f;return a}function yL(){var a=0,b=0,c=0,d=0;a=ab-16|0;ab=a;b=a+8|0;while(1){if(c>>>0<32){c=c+48|0;d=Zx(89848);continue}break}v[b>>2]=d;qn(b);ab=a+16|0;return v[b>>2]}function wx(a,b,c,d){var e=0,f=0,g=0;a:{b:{e=c-b|0;if((e|0)<=9){if((tx(d)|0)>(e|0)){break b}}f=a,g=sx(d,b),v[f>>2]=g;b=0;break a}v[a>>2]=c;b=61}v[a+4>>2]=b}function qj(a,b,c,d){var e=0,f=0;Ve(a+12|0,d);if(b){d=JC(b)}else{d=0}v[a>>2]=d;c=d+(c<<1)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=ic(a),f=d+(b<<1)|0,v[e>>2]=f;return a}function lJ(a,b,c,d){var e=0,f=0,g=0;a:{b:{e=c-b|0;if((e|0)<=2){if((tx(d)|0)>(e|0)){break b}}f=a,g=sx(d,b),v[f>>2]=g;b=0;break a}v[a>>2]=c;b=61}v[a+4>>2]=b}function gD(a){a=a|0;var b=0,c=0;b=Bb(a);v[22452]=0;T(165,a+12|0)|0;c=v[22452];v[22452]=0;if((c|0)!=1){of(a+32|0);return a|0}a=P()|0;O()|0;pb(b);S(a|0);L()}function bt(a,b,c,d){var e=0,f=0;Ve(a+12|0,d);if(b){d=RO(b)}else{d=0}v[a>>2]=d;c=d+(c<<5)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=ic(a),f=d+(b<<5)|0,v[e>>2]=f;return a}function _w(a,b,c,d){var e=0,f=0,g=0;a:{b:{e=c-b|0;if((e|0)<=4){if((tx(d)|0)>(e|0)){break b}}f=a,g=sx(d,b),v[f>>2]=g;b=0;break a}v[a>>2]=c;b=61}v[a+4>>2]=b}function ZW(a,b,c){a=a|0;b=b|0;c=c|0;a:{if((c|0)>=257){oE();b=89792;break a}b:{if(t[465440]&1){break b}if(!Jd(465440)){break b}Id(465440)}b=89788}Zb(a,c,b)}function ZR(a,b,c,d){var e=0,f=0;Ve(a+12|0,d);if(b){d=UR(b)}else{d=0}v[a>>2]=d;c=d+B(c,6)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=ic(a),f=d+B(b,6)|0,v[e>>2]=f;return a}function Jq(a,b,c,d){var e=0,f=0;Ve(a+12|0,d);if(b){d=oD(b)}else{d=0}v[a>>2]=d;c=d+(c<<3)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=ic(a),f=d+(b<<3)|0,v[e>>2]=f;return a}function qda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-32|0;ab=c;if(lk(a)>>>0<b>>>0){d=vb(a);e=a;a=ql(c+8|0,b,ad(v[a>>2],v[a+4>>2]),d);rP(e,a);qP(a)}ab=c+32|0}function qV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function p0(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=Rf(a,b);v[22452]=0;Q(54,a+12|0,c|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){break a}a=P()|0;O()|0;pb(b);S(a|0);L()}}function mB(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function cD(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=v[b>>2];d=(eb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0;a=v[b>>2];Zb(c,d,(eb[v[v[a>>2]+24>>2]](a)|0)-v[b+8>>2]|0)}function Yi(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;A[a>>3]=A[a>>3]-c;A[a+8>>3]=A[a+8>>3]-d}function Qh(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function No(a,b){var c=0,d=0;a:{if(!a){break a}c=oia(a,0,b,0);d=db;if((a|b)>>>0<65536){break a}c=d?-1:c}a=yd(c);if(!(!a|!(w[a-4|0]&3))){Jb(a,0,c)}return a}function qR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-32|0;ab=c;if(um(a)>>>0<b>>>0){d=vb(a);e=a;a=qj(c+8|0,b,wc(v[a>>2],v[a+4>>2]),d);rd(e,a);Bi(a)}ab=c+32|0}function Wm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-32|0;ab=c;if(Do(a)>>>0<b>>>0){d=vb(a);e=a;a=xl(c+8|0,b,Ic(v[a>>2],v[a+4>>2]),d);rd(e,a);wl(a)}ab=c+32|0}function Vf(a,b,c){a:{switch(b-1|0){case 0:if(c){return bj(a,1)}return bj(a,0);case 1:if(c){return bj(a,3)}return bj(a,2);default:break a}}return bj(a,4)}function U9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-32|0;ab=c;if(Fm(a)>>>0<b>>>0){d=vb(a);e=a;a=Jq(c+8|0,b,Ag(v[a>>2],v[a+4>>2]),d);rd(e,a);Iq(a)}ab=c+32|0}function O8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-32|0;ab=c;if(lk(a)>>>0<b>>>0){d=vb(a);e=a;a=ql(c+8|0,b,ad(v[a>>2],v[a+4>>2]),d);kv(e,a);Zq(a)}ab=c+32|0}function N9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-32|0;ab=c;if(Gy(a)>>>0<b>>>0){d=vb(a);e=a;a=WM(c+8|0,b,Hy(v[a>>2],v[a+4>>2]),d);VM(e,a);UM(a)}ab=c+32|0}function M8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ab-32|0;ab=c;if(Ch(a)>>>0<b>>>0){d=vb(a);e=a;a=_f(c+8|0,b,nc(v[a>>2],v[a+4>>2]),d);rd(e,a);Zf(a)}ab=c+32|0}function EV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Aw(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(a*C(z[((c&3)<<2)+61808>>2]*C(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function z9(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;d=Hb(a,16);a:{if(!d){WB(b);break a}xu(c+8|0,b);fd(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0;return d|0}function xX(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=v[(a<<2)+78512>>2]}v[b>>2]=a;b=b+4|0;continue}break}return c|0}function vX(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=v[(a<<2)+76976>>2]}v[b>>2]=a;b=b+4|0;continue}break}return c|0}function i5(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=By(C(C(C(C(y[v[a+16>>2]+24620>>2])/C(3))+C(-80))/C(15920)),C(0),C(1)),z[b+4272>>2]=c;nJ(a);mJ(a)}function Ym(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=yd(b)}return c}function Qz(a){var b=0,c=0;b=a+26|0;b=Ab(w[b|0]|w[b+1|0]<<8);c=(w[a+24|0]>15)+(w[a+25|0]>64)|0;a=a+22|0;return c+(Ab(w[a|0]|w[a+1|0]<<8)<<1>>>0<b>>>0)|0}function PK(a,b){var c=0,d=0,e=C(0);c=ab-16|0;ab=c;v[c+12>>2]=b;v[c+8>>2]=127;d=a,e=C(C(C(y[zb(c+12|0,c+8|0)>>2])/C(-127))+C(1)),z[d+144>>2]=e;ab=c+16|0}function Ib(a,b,c){var d=0,e=0;a:{while(1){d=w[a|0];e=w[b|0];if((d|0)!=(e|0)){break a}b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break}return 0}return d-e|0}function sX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function dQ(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-56|0;nt(b);continue}break}v[a+4>>2]=c;b=v[a>>2];cQ(a);xb(b)}}function bm(a,b){var c=0,d=0,e=0;SA(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=vb(b);d=vb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function Wr(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;cl(b);continue}break}v[a+4>>2]=c;b=v[a>>2];cr(a);xb(b)}}function Uc(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;yb(b);continue}break}v[a+4>>2]=c;b=v[a>>2];lk(a);xb(b)}}function Tn(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;d=Hb(a,4);a:{if(!d){OR(b);break a}qh(c+8|0,b);fd(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0;return d|0}function Rz(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-24|0;qb(b);continue}break}v[a+4>>2]=c;b=v[a>>2];ut(a);xb(b)}}function On(a){var b=0,c=0;b=v[a>>2];c=v[b+4>>2];a:{if(c){b=nR(c);break a}while(1){if(!gh(b)){b=v[b+8>>2];continue}break}b=v[b+8>>2]}v[a>>2]=b;return a}function Nc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(eb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function M_(a,b){a=a|0;b=b|0;var c=0,d=0;b=Xv(b);v[a+36>>2]=b;c=a,d=cp(b),v[c+44>>2]=d;c=a,d=Qm(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){mr(5524);L()}}function I_(a,b){a=a|0;b=b|0;var c=0,d=0;b=bw(b);v[a+36>>2]=b;c=a,d=cp(b),v[c+44>>2]=d;c=a,d=Qm(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){mr(5524);L()}}function Hz(a,b,c){var d=0;d=ab-16|0;ab=d;v[d+8>>2]=a;while(1){if(!(!Tb(a,b)|x[a>>1]==x[c>>1])){Ke(d+8|0);a=v[d+8>>2];continue}break}ab=d+16|0;return a}function tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;rD(b,c);if(Hb(a,c<<3)){qD(d+8|0,v[b>>2],v[b+4>>2]);fd(d,a,v[d+8>>2],v[d+12>>2])}ab=d+16|0}function jn(a,b){v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Jb(a+32|0,0,40);iw(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function gj(a){var b=0;a=kf(a);b=-1;a:{if(a>=C(4294967296)){break a}b=0;if(a<=C(0)){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function K2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=ab-32|0;ab=h;i=h+8|0;GH(i,b,c,d,e,f,g);Ac(a,h+20|0);Pl(i);ab=h+32|0}function FS(a,b){var c=0;c=oia(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+db|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;a=b>>>0<11?a+1|0:a;db=a;return b}function uM(a,b,c){var d=0,e=0;v[b+56>>2]=0;d=b,e=un(a,x[b+70>>1],v[b+48>>2],c,0),u[d+68>>1]=e;if(!(!(w[a+480180|0]&5)|v[b+60>>2]==-1)){v[b+60>>2]=0}}function kX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=t[b|0];t[e|0]=(a|0)>=0?a:d;e=e+1|0;b=b+1|0;continue}break}return c|0}function gA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;MR(b,c);if(Hb(a,c<<2)){LR(d+8|0,v[b>>2],v[b+4>>2]);fd(d,a,v[d+8>>2],v[d+12>>2])}ab=d+16|0}function aJ(a,b){a=a|0;b=b|0;var c=0,d=0;d=ab-16|0;ab=d;c=pc(12);Tw(c);v[c+8>>2]=b;v[c+4>>2]=a;v[c>>2]=49132;a=v[yf(d+8|0,c)>>2];ab=d+16|0;return a|0}function Co(a){var b=0;b=aa(8)|0;v[22452]=0;Q(97,b|0,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){ia(b|0,88688,24);L()}a=P()|0;O()|0;ba(b|0);S(a|0);L()}
function pX(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=t[b|0];if((a|0)>=0){a=v[(a<<2)+78512>>2]}t[b|0]=a;b=b+1|0;continue}break}return c|0}function nX(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=t[b|0];if((a|0)>=0){a=v[(a<<2)+76976>>2]}t[b|0]=a;b=b+1|0;continue}break}return c|0}function kC(a){var b=0,c=0;a:{if(Ib(a,14149,3)){break a}b=w[a+3|0];if(b>>>0<8&(b|0)!=1|b>>>0>14){break a}c=(w[a+40|0]-1&255)>>>0<32|b>>>0<9}return c}function dea(a,b){a=a|0;b=b|0;var c=0,d=0;d=ab-96|0;ab=d;c=-1;a:{if(!mQ(a,d)){break a}c=0;if(!lQ(d)){break a}c=we(a,b,kQ(d),db)}ab=d+96|0;return c|0}function Ru(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function Pe(a){var b=0,c=0;b=ab-16|0;ab=b;a:{if(me(a)){c=v[a>>2];t[b+15|0]=0;md(c,b+15|0);Qd(a,0);break a}t[b+14|0]=0;md(a,b+14|0);ye(a,0)}ab=b+16|0}function Oe(a){var b=0;b=aa(8)|0;v[22452]=0;Q(23,b|0,a|0)|0;a=v[22452];v[22452]=0;if((a|0)!=1){ia(b|0,88636,24);L()}a=P()|0;O()|0;ba(b|0);S(a|0);L()}function Gda(a,b){a=a|0;b=b|0;var c=0,d=0;d=ab-96|0;ab=d;c=-1;a:{if(!mQ(a,d)){break a}c=0;if(!QP(d)){break a}c=we(a,b,PP(d),db)}ab=d+96|0;return c|0}function tJ(a){var b=0;b=y[v[a+16>>2]+24620>>2]/(gj(C(z[a+4208>>2]*C(999)))+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;mc(a+4224|0,b)}function qK(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;v[a+8>>2]=b;Lk(b);continue}break}c=v[a>>2];if(c){ic(a);xb(c)}}function o9(a,b){a=a|0;b=b|0;var c=0;c=$L(a);v[22452]=0;R(780,c|0,b|0);b=v[22452];v[22452]=0;if((b|0)==1){b=P()|0;O()|0;jp(a);S(b|0);L()}return a|0}function hL(a){if(w[a+480224|0]==2){return+y[a+1074420>>2]/1e4}return+y[a+24620>>2]/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))*60}function bQ(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;v[a+8>>2]=b;nt(b);continue}break}c=v[a>>2];if(c){ic(a);xb(c)}}function _u(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;v[a+8>>2]=b;Fq(b);continue}break}c=v[a>>2];if(c){ic(a);xb(c)}}function Zq(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;yb(b);continue}break}c=v[a>>2];if(c){Yq(a);xb(c)}}function Xy(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;v[a+8>>2]=b;Uk(b);continue}break}c=v[a>>2];if(c){Yq(a);xb(c)}}function TW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Bg(a,v[b+8>>2],f)){tv(b,c,d,e);return}a=v[a+8>>2];eb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function Mt(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;v[a+8>>2]=b;qb(b);continue}break}c=v[a>>2];if(c){ic(a);xb(c)}}function CT(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;v[a+8>>2]=b;Tc(b);continue}break}c=v[a>>2];if(c){ic(a);xb(c)}}function vha(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{if(!Hb(b,6)){t[c|0]=0;Lh(a,6,c);break a}QA(c+8|0,a);fd(c,b,v[c+8>>2],v[c+12>>2])}ab=c+16|0}function qia(a,b,c){var d=0;d=b>>31;a=a^d;mia(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);db=cb;a=d^bb;b=a-d|0;db=(d^db)-((a>>>0<d>>>0)+d|0)|0;return b}function gE(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function aq(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];d=v[a+4>>2];if(wc(c,d)>>>0>b>>>0){a=he(v[a+24>>2]+484344|0,x[yi(c,d,b)>>1])}else{a=0}return a|0}function aT(a){t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function W_(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;eb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);continue}break}}function Ty(a,b,c){var d=0,e=0,f=0;d=Rk(a,b);if((d|0)!=255){e=Yb(a+26|0,d),f=c,u[e>>1]=f;a=a+62|0;e=Cb(a,b),f=255,t[e|0]=f;e=Cb(a,c),f=d,t[e|0]=f}}function JN(a){var b=0,c=0,d=0;d=w[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=w[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function Bx(a,b,c,d){var e=0;e=ab-16|0;ab=e;a=_p(e,a,d);c=c-b|0;if((c|0)>0){gc(v[a+4>>2],b,c);v[a+4>>2]=v[a+4>>2]+B((c>>>0)/6|0,6)}dc(a);ab=e+16|0}function $da(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{if(!Hb(b,5)){t[c|0]=0;Lh(a,5,c);break a}gu(c+8|0,a);fd(c,b,v[c+8>>2],v[c+12>>2])}ab=c+16|0}function nm(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{if(!Hb(b,4)){t[c|0]=0;Lh(a,4,c);break a}qh(c+8|0,a);fd(c,b,v[c+8>>2],v[c+12>>2])}ab=c+16|0}function bia(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;Am(c+8|0,b);b=v[c+12>>2];_b(c,a,v[c+8>>2],b);if((b|0)==v[c+4>>2]){Ob(a,v[c+12>>2])}ab=c+16|0}function RB(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0}function J3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=ab-32|0;ab=h;i=h+8|0;GH(i,b,c,d,e,f,g);Ac(a,i);Pl(i);ab=h+32|0}function kca(a,b){a=a|0;b=b|0;var c=0;c=ab-32|0;ab=c;t[c+24|0]=44;v[c+16>>2]=-1;v[c+20>>2]=0;v[c+8>>2]=1058;v[c+12>>2]=3;eR(a,b,c+8|0);ab=c+32|0}function iw(a){var b=0,c=0;v[22452]=0;c=ha(1076)|0;b=v[22452];v[22452]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;Bm(a);return}V(0)|0;O()|0;Gb();L()}function gK(a){var b=0;b=ab-16|0;ab=b;z[b+12>>2]=D(a);v[b+8>>2]=646978941;v[b+4>>2]=1259902592;a=z[oA(b+12|0,b+8|0,b+4|0)>>2];ab=b+16|0;return a}function _v(a){var b=0,c=0;b=ab-16|0;ab=b;c=-1;a:{if(kw(a)){break a}if((eb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}ab=b+16|0;return c}function O6(a){a=a|0;var b=0,c=0,d=0;b=ab-32|0;ab=b;if(Ch(a)>>>0<=12){c=vb(a);d=a;a=_f(b+8|0,13,nc(v[a>>2],v[a+4>>2]),c);rd(d,a);Zf(a)}ab=b+32|0}function Ng(a){var b=0;a=kf(a);b=255;a:{if(a>=C(255)){break a}b=0;if(a<=C(0)){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function Ko(a,b){var c=0;a:{if(!bH(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function Ida(a,b){a=a|0;b=b|0;var c=0;c=ab-32|0;ab=c;t[c+24|0]=44;v[c+16>>2]=-1;v[c+20>>2]=0;v[c+8>>2]=1042;v[c+12>>2]=2;ju(a,b,c+8|0);ab=c+32|0}function Gga(a,b){a=a|0;b=b|0;var c=0;c=ab-32|0;ab=c;t[c+24|0]=44;v[c+16>>2]=-1;v[c+20>>2]=0;v[c+8>>2]=1042;v[c+12>>2]=2;Mr(a,b,c+8|0);ab=c+32|0}function sP(a){a=a|0;var b=0,c=0;u[a+34>>1]=0;b=ab-16|0;ab=b;t[b+15|0]=0;c=a+43|0;Jl(c,c+22|0,b+15|0);ab=b+16|0;v[a+20>>2]=0;ed(a,0);return a|0}function pW(a,b){a=a|0;b=b|0;var c=0;c=ab-32|0;ab=c;t[c+24|0]=44;v[c+16>>2]=-1;v[c+20>>2]=0;v[c+8>>2]=1058;v[c+12>>2]=2;Su(a,b,c+8|0);ab=c+32|0}function m1(a,b){a=a|0;b=b|0;var c=0;c=ab-32|0;ab=c;t[c+24|0]=44;v[c+16>>2]=-1;v[c+20>>2]=0;v[c+8>>2]=1025;v[c+12>>2]=4;Mr(a,b,c+8|0);ab=c+32|0}function iU(a,b){a=a|0;b=b|0;var c=0;c=ab-32|0;ab=c;t[c+24|0]=44;v[c+16>>2]=-1;v[c+20>>2]=0;v[c+8>>2]=1025;v[c+12>>2]=2;ju(a,b,c+8|0);ab=c+32|0}function f1(a,b){a=a|0;b=b|0;var c=0;c=ab-32|0;ab=c;t[c+24|0]=44;v[c+16>>2]=-1;v[c+20>>2]=0;v[c+8>>2]=1025;v[c+12>>2]=2;Mr(a,b,c+8|0);ab=c+32|0}function bk(a,b,c,d){var e=0;e=B(b,c);a:{if(v[d+76>>2]<0){a=ou(a,e,d);break a}a=ou(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function _J(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-2048|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){ic(a);xb(b)}}function _7(a,b){a=a|0;b=b|0;var c=0;c=ab-32|0;ab=c;t[c+24|0]=44;v[c+16>>2]=-1;v[c+20>>2]=0;v[c+8>>2]=1058;v[c+12>>2]=1;Mr(a,b,c+8|0);ab=c+32|0}function Yz(a,b){a=a|0;b=b|0;var c=0;c=ab-32|0;ab=c;t[c+24|0]=44;v[c+16>>2]=-1;v[c+20>>2]=0;v[c+8>>2]=1058;v[c+12>>2]=2;eR(a,b,c+8|0);ab=c+32|0}function Wi(a,b,c){if(a>>>0<b>>>0){gc(a,b,c);return}if(c){a=a+c|0;b=b+c|0;while(1){a=a-1|0;b=b-1|0;t[a|0]=w[b|0];c=c-1|0;if(c){continue}break}}}function Nj(a,b){var c=0,d=0,e=0;a:{c=Rk(a,b);if((c|0)==255){break a}if(Oj(a)){break a}d=Cb(a+8|0,c);e=w[d|0]&223;t[d|0]=e;Mg(a,b,Ts(c)|176,e)}}function Bu(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;a:{if(!Hb(b,2)){t[c|0]=0;XB(a,c);break a}ll(c+8|0,a);fd(c,b,v[c+8>>2],v[c+12>>2])}ab=c+16|0}function wea(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=jg(b);jg(b);break a}a=xg(b);xg(b)}while(1){if(a){if(a&1){Ob(b,260)}a=a>>>1|0;continue}break}}function qW(a,b){a=a|0;b=b|0;var c=0;c=ab-32|0;ab=c;t[c+24|0]=44;v[c+16>>2]=-1;v[c+20>>2]=0;v[c+8>>2]=290;v[c+12>>2]=0;Su(a,b,c+8|0);ab=c+32|0}function jP(a,b){var c=0,d=0,e=0;Zz(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=vb(b);d=vb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function _i(a){var b=0,c=0;b=ab-16|0;ab=b;rb(b+8|0,a+1074312|0,7);if(sb(v[v[b+8>>2]>>2],v[b+12>>2])){c=_l(v[a+480180>>2])^1}ab=b+16|0;return c}function YT(a,b){a=a|0;b=b|0;var c=0;c=ab-32|0;ab=c;t[c+24|0]=44;v[c+16>>2]=-1;v[c+20>>2]=0;v[c+8>>2]=274;v[c+12>>2]=0;ju(a,b,c+8|0);ab=c+32|0}function R4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){Vw(a,0,0,0,0,0,0,c,d);return}Vw(a,v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2],v[b+24>>2],b,c,d)}function QV(a,b){a=a|0;b=b|0;var c=0;c=ab-32|0;ab=c;t[c+24|0]=44;v[c+16>>2]=-1;v[c+20>>2]=0;v[c+8>>2]=257;v[c+12>>2]=0;Su(a,b,c+8|0);ab=c+32|0}function MG(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function Ky(a){var b=0,c=0;b=ab-16|0;ab=b;v[b+8>>2]=a;c=b+8|0;a=1;while(1){if((a|0)>0){On(c);a=a-1|0;continue}break}ab=b+16|0;return v[b+8>>2]}function yE(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){Yq(a);xb(b)}}function vU(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;v[c+12>>2]=-1;if(hg(a,c+8|0)){v[c+4>>2]=w[c+8|0];OB(a,b,v[zb(c+4|0,c+12|0)>>2])}ab=c+16|0}function qP(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){Yq(a);xb(b)}}function hm(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;if(lo(a,b+8|0)){c=Wb(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))}ab=b+16|0;return c|0}function fT(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-48|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){ic(a);xb(b)}}function UO(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){Yq(a);xb(b)}}function RT(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;v[c+12>>2]=-1;if(hg(a,c+8|0)){v[c+4>>2]=w[c+8|0];kB(a,b,v[zb(c+4|0,c+12|0)>>2])}ab=c+16|0}function Ph(a){var b=0;a=a*a;b=a*a;return C(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function XR(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-6|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){ic(a);xb(b)}}function UM(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-7|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){ic(a);xb(b)}}function Qy(a,b,c){var d=0;while(1){if((b|0)!=(c|0)){d=v[a>>2];v[a>>2]=d<<8^v[((w[b|0]^d>>>24)<<2)+29196>>2];b=b+1|0;continue}break}return a}function Iq(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-8|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){ic(a);xb(b)}}function I2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=ab-32|0;ab=g;h=g+8|0;HH(h,b,c,d,e,f);Ac(a,g+20|0);Pl(h);ab=g+32|0}function Bi(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-2|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){ic(a);xb(b)}}function zm(a,b){var c=0;Cm(a);v[a>>2]=58364;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function ve(a,b,c){t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a}function Tea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if($Q()>>>0<b>>>0){hd();L()}c=B(b,24);b=pc(c);v[a>>2]=b;v[a+4>>2]=b;d=vb(a),e=b+c|0,v[d>>2]=e}function Nca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(hD()>>>0<b>>>0){hd();L()}c=B(b,36);b=pc(c);v[a>>2]=b;v[a+4>>2]=b;d=vb(a),e=b+c|0,v[d>>2]=e}function Db(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ab-16|0;ab=d;if(b>>>0>=117){Co(12116);L()}e=d+8|0;rb(e,a,b);mg(e,c);ab=d+16|0;return a|0}function vO(a,b,c){var d=0;d=Pb(a);v[22452]=0;U(42,a|0,b|0,c|0);b=v[22452];v[22452]=0;if((b|0)!=1){return a}a=P()|0;O()|0;ec(d);S(a|0);L()}function Uha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(_A()>>>0<b>>>0){hd();L()}c=B(b,6);b=pc(c);v[a>>2]=b;v[a+4>>2]=b;d=vb(a),e=b+c|0,v[d>>2]=e}function Nk(a){var b=0,c=0,d=0;b=ab-16|0;ab=b;c=v[a+24>>2];d=v[a+40>>2];v[b+12>>2]=1;a=v[Pc(a+20|0,b+12|0)>>2];ab=b+16|0;return B(a,c+d|0)}function DX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=ab-16|0;ab=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=zb(a+12|0,a+8|0);ab=a+16|0;return v[b>>2]}function xz(a){a=50-(B(w[(a>>>4|0)+31536|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return vc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function rm(a,b,c){var d=0,e=0,f=0;d=ab-16|0;ab=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[Qb(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;ab=d+16|0}function qm(a,b,c){var d=0,e=0,f=0;d=ab-16|0;ab=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[Qb(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;ab=d+16|0}function kg(a,b){var c=0,d=0,e=0;c=Eb(a);a=ub(a);e=Pf(b);d=0;a:{if(!e){break a}a=a+c|0;b=VD(c,a,b,b+e|0);d=(a|0)==(b|0)?-1:b-c|0}return d}function Jc(a){var b=0;b=ab-16|0;ab=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[b+4>>2]=32767;a=u[Ee(b+8|0,jd(b+12|0,b+4|0))>>1];ab=b+16|0;return a}function IP(a){var b=0,c=0;b=ab-16|0;ab=b;if(HP(a,b+8|0)){a=b+8|0;c=Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}ab=b+16|0;return c}function lw(a,b){var c=0;if(b>>>0<=99){return wG(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return zr(vG(c,a),B(a,-100)+b|0)}return Qi(a,b)}function f7(a,b){a=a|0;b=b|0;var c=0;b=ab-16|0;ab=b;c=v[a+20>>2];de(b,v[c+4>>2],v[c+8>>2]);TJ(a,Zb(b+8|0,v[b>>2],v[b+4>>2]),0);ab=b+16|0}function Xt(a){var b=0,c=0,d=0;b=ab-16|0;ab=b;u[b+14>>1]=1;c=b,d=el(a),u[c+12>>1]=d;a=x[Ne(b+14|0,b+12|0)>>1];ab=b+16|0;return a-1&65535}function VS(a){var b=0,c=0,d=0;c=ab-16|0;ab=c;b=c+8|0;Xu(b,a);a=w[Cb(b,0)|0];d=w[Cb(b,1)|0];b=w[Cb(b,2)|0];ab=c+16|0;return a|d<<8|b<<16}function I9(a){a=a|0;var b=0;b=v[a>>2];if(eb[v[v[b>>2]+32>>2]](b,0,32)|0){a=v[a>>2];a=eb[v[v[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function $1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=ab-16|0;ab=b;e=a;a=Zb(b+8|0,c,d);a=ss(e,v[a>>2],v[a+4>>2],0);ab=b+16|0;return a|0}function vq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((b|0)<0){gz();L()}b=(b-1>>>5|0)+1|0;c=GC(b);v[a+4>>2]=0;v[a>>2]=c;d=vb(a),e=b,v[d>>2]=e}function Rc(a,b){var c=0,d=0,e=0;c=Qf(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=eb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function Ps(a){var b=0,c=0;c=lf(a);while(1){a:{b=c;if(!(b&65535)){b=0;break a}c=b-1|0;if(!he(a,c&65535)){continue}}break}return b&65535}function H3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=ab-32|0;ab=g;h=g+8|0;HH(h,b,c,d,e,f);Ac(a,h);Pl(h);ab=g+32|0}function F$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+7&-8;v[c>>2]=b+16;d=a,e=Ew(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function BP(a){var b=0,c=0,d=0;c=a+8|0;while(1){b=(a|0)==(c|0);if(!b){d=w[a|0];a=a+1|0;if((d-127&255)>>>0>160){continue}}break}return b}function wl(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;v[a+8>>2]=b;continue}break}a=v[a>>2];if(a){xb(a)}}function v0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(XD()>>>0<b>>>0){hd();L()}c=WD(b);v[a>>2]=c;v[a+4>>2]=c;d=vb(a),e=B(b,12)+c|0,v[d>>2]=e}function lT(a,b){var c=0,d=0;d=ab-16|0;ab=d;c=d+8|0;qi(c,b);ab=d+16|0;return v[a>>2]==(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}function _L(a,b){var c=0;c=ab-16|0;ab=c;v[c+8>>2]=a;v[c+12>>2]=b;v[c>>2]=2147483647;v[c+4>>2]=0;a=il(c+8|0,c);ab=c+16|0;return v[a>>2]}function XM(a){var b=0;a:{if(w[a|0]<24){break a}b=15;b:{switch(w[a+3|0]){case 3:b=14;break;case 0:break b;default:break a}}t[a+3|0]=b}}function Uea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Jn()>>>0<b>>>0){hd();L()}c=GC(b);v[a>>2]=c;v[a+4>>2]=c;d=vb(a),e=(b<<2)+c|0,v[d>>2]=e}function Dr(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function BU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(aC()>>>0<b>>>0){hd();L()}c=$B(b);v[a>>2]=c;v[a+4>>2]=c;d=vb(a),e=B(b,20)+c|0,v[d>>2]=e}function vN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(pD()>>>0<b>>>0){hd();L()}c=oD(b);v[a>>2]=c;v[a+4>>2]=c;d=vb(a),e=(b<<3)+c|0,v[d>>2]=e}function tN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(pE()>>>0<b>>>0){hd();L()}c=kE(b);v[a>>2]=c;v[a+4>>2]=c;d=vb(a),e=(b<<4)+c|0,v[d>>2]=e}function pv(a,b,c,d,e,f){var g=0,h=0;g=v[a+4>>2];h=g>>8;if(g&1){h=qv(v[d>>2],h)}a=v[a>>2];eb[v[v[a>>2]+20>>2]](a,b,c,d+h|0,g&2?e:2,f)}function jg(a){var b=0,c=0;b=ab-16|0;ab=b;if(lo(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}ab=b+16|0;return c}function jS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(_A()>>>0<b>>>0){hd();L()}c=UR(b);v[a>>2]=c;v[a+4>>2]=c;d=vb(a),e=B(b,6)+c|0,v[d>>2]=e}function _6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Kc(c&255))){VJ(a,8,C(0))}a=Hj(a);if(a){eb[v[v[a>>2]+92>>2]](a,b,c,d,e)}}function Xu(a,b){var c=0;c=ab-16|0;ab=c;a:{if(!Hb(b,3)){t[c|0]=0;Lh(a,3,c);break a}Wu(c+8|0,a);fd(c,b,v[c+8>>2],v[c+12>>2])}ab=c+16|0}function QD(a){a=a|0;var b=0;a=Bb(a);v[22452]=0;Q(127,a|0,13633)|0;b=v[22452];v[22452]=0;if((b|0)==1){b=P()|0;O()|0;pb(a);S(b|0);L()}}function Ez(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(LC()>>>0<b>>>0){hd();L()}c=JC(b);v[a>>2]=c;v[a+4>>2]=c;d=vb(a),e=(b<<1)+c|0,v[d>>2]=e}function $n(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Jn()>>>0<b>>>0){hd();L()}c=ji(b);v[a>>2]=c;v[a+4>>2]=c;d=vb(a),e=(b<<2)+c|0,v[d>>2]=e}function oq(a,b){return(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0?b:a}function nq(a,b,c){var d=0;d=ab-16|0;ab=d;if(!(!b|!c)){t[d+15|0]=0;nL(a+36|0,b,fi(b,b+c|0,d+15|0))}ab=d+16|0;return(b|0)!=0&(c|0)!=0}function aR(a){var b=0;b=ab-16|0;ab=b;v[b+12>>2]=a;v[b+8>>2]=-128;v[b+4>>2]=127;a=t[Ee(b+8|0,jd(b+12|0,b+4|0))|0];ab=b+16|0;return a}function Nn(a){var b=0;a=be(a);b=255;a:{if(a>=255){break a}b=0;if(a<=0){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b}function Fi(a,b){var c=0;if(me(a)){c=v[a>>2];gk(a);xb(c)}v[a+8>>2]=v[b+8>>2];c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;ye(b,0);nd(b,0)}function zh(a,b){var c=0,d=0;c=v[a>>2];d=v[a+4>>2];b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[xc(c,d,(b>>31&a)+b|0)>>2]}function gw(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return eb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return rg(t[b|0])|0}function X5(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;if((b|0)<=4){c=Ed(c,C(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=kf(c)}z[d>>2]=c;wJ(a)}}function M9(a,b){a=a|0;b=b|0;a=fu(a,b);if(!a){t[b+6|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0}return a|0}function G5(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;if((b|0)<=1){c=Ed(c,C(0));d=((b<<2)+a|0)+4208|0;if((b|0)==1){c=kf(c)}z[d>>2]=c;tJ(a)}}function Cf(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;if(b>>>0>=117){Co(12081);L()}d=c+8|0;rb(d,a,b);mg(d,0);ab=c+16|0;return a|0}function Br(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function z$(a){a=a|0;var b=0;if((eb[v[v[a>>2]+36>>2]](a)|0)!=-1){b=a;a=v[a+12>>2];v[b+12>>2]=a+1;a=rg(t[a|0])}else{a=-1}return a|0}function ZJ(a){a=a|0;a=ab-16|0;ab=a;v[a+12>>2]=1869112133;ab=a+16|0;a=a+12|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function LG(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}ca(14201,13164,1180,5695);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function Id(a){var b=0,c=0;b=ab-16|0;ab=b;a=uv(b,a);c=ab-16|0;ab=c;mE(v[$b(c+8|0,v[a+4>>2])>>2]);mE(v[a+8>>2]);ab=c+16|0;ab=b+16|0}function s9(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;if(b>>>0>=250){Co(12116);L()}d=c+8|0;rb(d,a,b);Zl(d);ab=c+16|0;return a|0}function pi(a){var b=0;b=ab-16|0;ab=b;v[b+12>>2]=a;v[b+8>>2]=0;v[b+4>>2]=255;a=w[Ee(b+8|0,jd(b+12|0,b+4|0))|0];ab=b+16|0;return a}function br(a,b,c,d,e){var f=0,g=0;f=v[a+4>>2];g=f>>8;if(f&1){g=qv(v[c>>2],g)}a=v[a>>2];eb[v[v[a>>2]+24>>2]](a,b,c+g|0,f&2?d:2,e)}function OS(a){var b=0;a:{if(Ib(a,3863,4)){break a}if(Ib(a+44|0,17784,3)){break a}a=a+47|0;b=(w[a|0]|w[a+1|0]<<8)>>>0>97}return b}function Fha(a){a=a|0;var b=0,c=0,d=0;if(Jn()>>>0<=8191){hd();L()}b=pc(32768);v[a>>2]=b;v[a+4>>2]=b;c=vb(a),d=b+32768|0,v[c>>2]=d}function zz(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=vb(b),d=0,v[c>>2]=d}function xC(a,b){var c=0;c=oia(b&255,0,1536,0);b=db;a=oia(a&255,0,25,0);c=a+c|0;b=db+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;db=b;return a}function t_(a){a=a|0;var b=0,c=0;b=v[v[a>>2]>>2];c=v[b+8>>2];a=v[b+4>>2];b=v[b>>2]+(c>>1)|0;if(c&1){a=v[a+v[b>>2]>>2]}eb[a|0](b)}function o0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ww(a+8|0,b,c,d,2);if(a>>>0<=15){a=w[a+43888|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function kl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if($F()>>>0<b>>>0){hd();L()}c=pc(b);v[a>>2]=c;v[a+4>>2]=c;d=vb(a),e=b+c|0,v[d>>2]=e}function FI(a){a=a|0;var b=0,c=0;c=ab-16|0;ab=c;b=pc(8);nI(b);v[b+4>>2]=a;v[b>>2]=53896;a=v[yf(c+8|0,b)>>2];ab=c+16|0;return a|0}function ww(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}gc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function v$(a){a=a|0;var b=0;if((eb[v[v[a>>2]+36>>2]](a)|0)!=-1){b=a;a=v[a+12>>2];v[b+12>>2]=a+4;a=v[a>>2]}else{a=-1}return a|0}function uX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function tM(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(w[a+480180|0]&2){break a}}v[b+56>>2]=0;d=un(a,x[b+70>>1],v[b+48>>2],c,0)}return d}function bx(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=b-24|0;ec(b);if((b|0)!=(c|0)){continue}break}ff(a);return a|0}function _E(a,b,c,d,e,f){a=eb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=jr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function XE(a,b,c,d,e,f){a=eb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=hr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function QU(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;b=v[v[b>>2]-12>>2]+b|0;if(uh(b)){b=v[b+72>>2];if(b){Ou(b)}t[a|0]=1}return a|0}function LC(){var a=0,b=0;a=ab-16|0;ab=a;v[a+12>>2]=2147483647;v[a+8>>2]=2147483647;b=zb(a+12|0,a+8|0);ab=a+16|0;return v[b>>2]}function Jn(){var a=0,b=0;a=ab-16|0;ab=a;v[a+12>>2]=1073741823;v[a+8>>2]=2147483647;b=zb(a+12|0,a+8|0);ab=a+16|0;return v[b>>2]}function Hj(a){var b=0,c=0;b=vm(v[a+20>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[(v[a+16>>2]+B(b,160)|0)+906300>>2]}return c}function Cd(a){var b=0;a=v[a+4>>2];if(a){if(Em(a)){a:{b=a+8|0;if(v[b>>2]){if((bv(b)|0)!=-1){break a}}eb[v[v[a>>2]+16>>2]](a)}}}}function wv(a,b){var c=0,d=0,e=0,f=0;c=Pf(b);d=pc(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=gc(d+12|0,b,c+1|0),v[e>>2]=f}function pE(){var a=0,b=0;a=ab-16|0;ab=a;v[a+12>>2]=268435455;v[a+8>>2]=2147483647;b=zb(a+12|0,a+8|0);ab=a+16|0;return v[b>>2]}function pD(){var a=0,b=0;a=ab-16|0;ab=a;v[a+12>>2]=536870911;v[a+8>>2]=2147483647;b=zb(a+12|0,a+8|0);ab=a+16|0;return v[b>>2]}function mX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function js(a){var b=0;b=A[a+4248>>3]/+y[v[a+16>>2]+24620>>2];A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*(A[a+4288>>3]/60)}}function hD(){var a=0,b=0;a=ab-16|0;ab=a;v[a+12>>2]=119304647;v[a+8>>2]=2147483647;b=zb(a+12|0,a+8|0);ab=a+16|0;return v[b>>2]}function aC(){var a=0,b=0;a=ab-16|0;ab=a;v[a+12>>2]=214748364;v[a+8>>2]=2147483647;b=zb(a+12|0,a+8|0);ab=a+16|0;return v[b>>2]}function _A(){var a=0,b=0;a=ab-16|0;ab=a;v[a+12>>2]=715827882;v[a+8>>2]=2147483647;b=zb(a+12|0,a+8|0);ab=a+16|0;return v[b>>2]}function XD(){var a=0,b=0;a=ab-16|0;ab=a;v[a+12>>2]=357913941;v[a+8>>2]=2147483647;b=zb(a+12|0,a+8|0);ab=a+16|0;return v[b>>2]}function Up(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function TO(){var a=0,b=0;a=ab-16|0;ab=a;v[a+12>>2]=134217727;v[a+8>>2]=2147483647;b=zb(a+12|0,a+8|0);ab=a+16|0;return v[b>>2]}function TD(){var a=0,b=0,c=0;a=ab-16|0;ab=a;b=Mb(a,14944);if(ub(b)){c=(kg(b,13838)|0)!=-1}else{c=0}pb(b);ab=a+16|0;return c|0}function SN(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){Qd(b,a)}if(c){Qd(c,a)}if(d){Qd(d,a)}if(e){Qd(e,a)}}function PB(a,b){var c=0;c=v[b+4>>2];if(c){Ub(a,c,v[b>>2]);return}c=v[b+8>>2];b=v[b+12>>2];if(!jc(c,b)){de(a,c,b);return}Vd(a)}function GX(a){a=a|0;var b=0;b=ab-16|0;ab=b;Rh(Sh(b+8|0,v[a+8>>2]));ab=b+16|0;a=v[a+8>>2];if(!a){return 1}return(xE(a)|0)==1|0}function Fc(a,b){var c=0;c=ab-16|0;ab=c;v[c+8>>2]=a;v[c+12>>2]=b;v[c>>2]=-1;v[c+4>>2]=0;a=il(c+8|0,c);ab=c+16|0;return v[a>>2]}function $Q(){var a=0,b=0;a=ab-16|0;ab=a;v[a+12>>2]=178956970;v[a+8>>2]=2147483647;b=zb(a+12|0,a+8|0);ab=a+16|0;return v[b>>2]}function tK(){var a=0,b=0;a=ab-16|0;ab=a;v[a+12>>2]=82595524;v[a+8>>2]=2147483647;b=zb(a+12|0,a+8|0);ab=a+16|0;return v[b>>2]}function Zk(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(eb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function RW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Bg(a,v[b+8>>2],0)){rv(b,c,d);return}a=v[a+8>>2];eb[v[v[a>>2]+28>>2]](a,b,c,d)}function oG(a){v[a>>2]=73376;iw(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function bs(a){v[a>>2]=73312;iw(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function YE(a,b,c,d,e,f){a=eb[v[v[a+8>>2]>>2]](a+8|0)|0;a=hr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function Kk(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;Fx(a,c,d)}function $E(a,b,c,d,e,f){a=eb[v[v[a+8>>2]>>2]](a+8|0)|0;a=jr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function jM(a,b,c){var d=0,e=0,f=0;d=t[c+26|0];if(d){e=a,f=Sb(v[a>>2]+((B((w[c+27|0]^-1)+b|0,d)|0)/2|0)|0,0,256),v[e>>2]=f}}function co(a,b){var c=0;a:{if(!b){break a}if(!Hb(a,b)){break a}if(b>>>0<=3){c=AC(a,b);break a}c=jg(a);Ob(a,b-4|0)}return c}function MP(a,b,c){var d=0;if(!(w[b+31|0]&6|w[b+30|0]!=4)){Gc(a,8,1,0,10);return}d=a;a=w[b+31|0];Gc(d,a&4?16:8,a&2|1,0,c^1)}function GP(a,b){var c=0;c=ab-16|0;ab=c;pQ(c+8|0,a);qe(c,b);a=yc(v[c+8>>2],v[c+12>>2],v[c>>2],v[c+4>>2]);ab=c+16|0;return a}function Fu(a,b){var c=0;a:{if(!b){break a}if(!Hb(a,b)){break a}if(b>>>0<=1){c=zC(a,1);break a}c=xg(a);Ob(a,b-2|0)}return c}function LK(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function IM(a){uy(a);v[a>>2]=0;v[a+4>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;Rg(a);Rg(a+12|0);t[a+24|0]=1}function I6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if((b|0)<=2){d=(a+b|0)+4232|0,e=Ng(C(Ed(c,C(0))*C(127))),t[d|0]=e;hs(a)}}function Fz(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function D7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=Ng(C(Ed(c,C(0))*C(255))),t[d|0]=e;ls(a)}}function jo(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function ce(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function EO(a,b){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24}function t0(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((a|0)!=(b|0)){mn(v[c>>2],a);v[c>>2]=v[c>>2]+12;a=a+12|0;continue}break}}function sf(a,b,c,d,e){var f=0;f=ab-16|0;ab=f;v[f+12>>2]=e;c=Sh(f+8|0,c);a=kr(a,b,d,v[f+12>>2]);Rh(c);ab=f+16|0;return a}function jO(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){gO(a,1);gO(a,0)}}function iO(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){hO(a,1);hO(a,0)}}function eG(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return eb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function aP(a){var b=0;if(!(w[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){v[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function _Q(a,b){var c=0;c=ab-16|0;ab=c;a:{if(!Qf(a,4)){OR(b);break a}qh(c+8|0,b);Pz(c,a,v[c+8>>2],v[c+12>>2])}ab=c+16|0}function fi(a,b,c){c=w[c|0];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=w[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function dL(a,b){var c=0;c=21598;a:{if(b>>>0>255){break a}a=v[((b<<2)+a|0)+900380>>2];if(!a){break a}c=a+492|0}return c}function QP(a){var b=0;if(!(Ib(a+44|0,13799,4)|w[a+29|0]!=16)){a=a+42|0;b=((w[a|0]|w[a+1|0]<<8)-1&65535)>>>0<2}return b}function $F(){var a=0,b=0;a=ab-16|0;ab=a;v[a+12>>2]=-1;v[a+8>>2]=2147483647;b=zb(a+12|0,a+8|0);ab=a+16|0;return v[b>>2]}function vW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return eb[a|0](h|b,c,d,e,b|f,g)|0}function vQ(a){var b=0;if(!(Ib(a,13790,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64))){b=(w[a+33|0]-1&255)>>>0<32}return b}function kP(a){if(Ib(a,13772,4)){a=0}else{a=a+4|0;a=(Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0)==1}return a}function ifa(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;if(Aq(a,b+8|0)){c=(w[b+8|0]|w[b+9|0]<<8)<<16>>16}ab=b+16|0;return c|0}function Rs(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function De(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function ti(a){var b=0;while(1){a:{if((b|0)!=46){if(w[b+43920|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function lc(a,b){var c=0;Dl(a);v[a+4>>2]=0;v[a>>2]=49232;c=a;a=yd(ub(b)+1|0);v[c+4>>2]=a;if(a){gc(a,Eb(b),ub(b)+1|0)}}function l5(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if((b|0)<=2){d=((b<<2)+a|0)+4208|0,e=Ed(c,C(0)),z[d>>2]=e;nJ(a)}}function j6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if((b|0)<=5){d=((b<<2)+a|0)+4208|0,e=Ed(c,C(0)),z[d>>2]=e;EJ(a)}}function fF(a,b,c){var d=0;d=ab-16|0;ab=d;v[d+12>>2]=c;b=Sh(d+8|0,b);a=EF(a,9233,v[d+12>>2]);Rh(b);ab=d+16|0;return a}function e5(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if((b|0)<=3){d=((b<<2)+a|0)+4208|0,e=Ed(c,C(0)),z[d>>2]=e;kJ(a)}}function c6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if((b|0)<=4){d=((b<<2)+a|0)+4208|0,e=Ed(c,C(0)),z[d>>2]=e;zJ(a)}}function sg(a){var b=0;Xl(a);b=et(v[a>>2],hk(x[a+34>>1]));v[a+20>>2]=b;if(!b){return 0}return mj(v[a>>2],x[a+34>>1])}function sQ(a){var b=0;a=a+1104|0;a=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+8|0;b=a>>>0<8?1:b;db=b;return a}function ro(a){var b=0,c=0;c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;Fq(b);continue}break}v[a+4>>2]=c}function qO(a){v[a+700>>2]=0;u[a+842>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function R7(a){a=a|0;var b=0;b=ab-16|0;ab=b;if(!Vc(a,4)){Hv(a)}a=v[$b(b+8|0,wb(v[a+44>>2]))>>2];ab=b+16|0;return a|0}function Q7(a){a=a|0;var b=0;b=ab-16|0;ab=b;if(!Vc(a,4)){Hv(a)}a=v[$b(b+8|0,wb(v[a+48>>2]))>>2];ab=b+16|0;return a|0}function JT(a){var b=0,c=0;c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;Tc(b);continue}break}v[a+4>>2]=c}function IT(a,b){var c=0;c=ab-16|0;ab=c;t[c+15|0]=0;if(b){b=Qp(a,b,c+15|0);a=b?b-a|0:-1}else{a=-1}ab=c+16|0;return a}function yK(a){var b=0,c=0,d=0;if(v[a>>2]){uc(a);b=v[a>>2];St(a);xb(b);c=vb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function oi(a){var b=0;b=ab-16|0;ab=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=v[zb(b+12|0,b+8|0)>>2];ab=b+16|0;return a}function iN(a){var b=0,c=0,d=0;if(v[a>>2]){uc(a);b=v[a>>2];Fm(a);xb(b);c=vb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function eO(a){var b=0,c=0,d=0;if(v[a>>2]){uc(a);b=v[a>>2];um(a);xb(b);c=vb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function Zz(a){var b=0,c=0,d=0;if(v[a>>2]){uc(a);b=v[a>>2];Ch(a);xb(b);c=vb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function JF(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function rd(a,b){var c=0;c=b+4|0;Gn(v[a>>2],v[a+4>>2],c);cc(a,c);cc(a+4|0,b+8|0);cc(vb(a),ic(b));v[b>>2]=v[b+4>>2]}function lB(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function gc(a,b,c){var d=0;if(c){d=a;while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function KG(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+((c+c)*d+(c*c-e))}function IO(a){var b=0;b=a+68|0;if(((w[b|0]|w[b+1|0]<<8)-128&65535)>>>0>=65409){a=Ib(a,17627,17)}else{a=1}return!a}function yJ(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function rl(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}Tg(a,b);a=a+1|0;continue}}}function rM(a,b){var c=0;c=b&15;if(c){t[a+827|0]=c<<2}b=b&240;if(b){t[a+826|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function ir(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}cc(a,b);a=a+4|0;continue}}}function bG(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!jc(hG(c,b),-1)){break a}v[a>>2]=0}return a|0}function Wk(a,b){var c=0;c=ab-16|0;ab=c;v[c+8>>2]=v[a>>2];a=c+8|0;v[a>>2]=v[a>>2]+(b<<2);ab=c+16|0;return v[a>>2]}function Mk(a,b){var c=0;c=b&15;if(c){t[a+824|0]=c<<2}b=b&240;if(b){t[a+823|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function NO(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;v[a+8>>2]=b;continue}break}}function GK(a){if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179011410){a=Wl(a)>>>0>80}else{a=0}return a}function om(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function kI(a){var b=0;while(1){a:{if((b|0)!=4){if(v[(b<<2)+a>>2]){break a}}else{b=4}return b}b=b+1|0;continue}}function hq(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;if(Aq(a,b+8|0)){c=Ab(w[b+8|0]|w[b+9|0]<<8)}ab=b+16|0;return c|0}function S_(a,b){a=a|0;b=b|0;var c=0,d=0;eb[v[v[a>>2]+24>>2]](a)|0;b=Xv(b);v[a+36>>2]=b;c=a,d=Qm(b),t[c+44|0]=d}function P_(a,b){a=a|0;b=b|0;var c=0,d=0;eb[v[v[a>>2]+24>>2]](a)|0;b=bw(b);v[a+36>>2]=b;c=a,d=Qm(b),t[c+44|0]=d}function Mv(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(v[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function Mi(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function Js(a){var b=0;b=1;a:{switch(w[a+3|0]-4|0){default:b=w[a+2|0]==11;break;case 0:case 2:break a}}return b}function pG(a,b){var c=0;c=ab-16|0;ab=c;a=zk(c,a,1);Bj(v[a+4>>2],w[b|0]);v[a+4>>2]=v[a+4>>2]+1;dc(a);ab=c+16|0}function oK(a){var b=0;b=ab-16|0;ab=b;v[b+12>>2]=a;v[b+8>>2]=32767;a=u[zb(b+12|0,b+8|0)>>1];ab=b+16|0;return a}function mg(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function X1(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=Mb(b,12495);lc(a,c);pb(c);v[a>>2]=49192;ab=b+16|0;return a|0}function Wt(a){var b=0;b=ab-16|0;ab=b;v[b+12>>2]=a;v[b+8>>2]=65535;a=x[zb(b+12|0,b+8|0)>>1];ab=b+16|0;return a}function Vc(a,b){var c=0;c=ab-16|0;ab=c;vk(c+8|0,a+24|0,b);a=sb(v[v[c+8>>2]>>2],v[c+12>>2]);ab=c+16|0;return a}function Ut(a,b){var c=0;c=ab-16|0;ab=c;v[c+12>>2]=(B(a,b)>>>0)/255;ce(c+12|0,0,15);ab=c+16|0;return w[c+12|0]}function Oo(a,b){var c=0,d=0,e=0;c=ab-16|0;ab=c;d=c,e=Pd(b),v[d+12>>2]=e;v[a>>2]=v[c+12>>2];ab=c+16|0;return a}function CP(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;b=a>>>0>c>>>0?b+1|0:b;db=b;return c}function Bg(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!Zi(v[a+4>>2],v[b+4>>2])}function jL(a,b){var c=0;c=ab-16|0;ab=c;a=fz(c,a);Dp(v[a+4>>2],v[b>>2]);v[a+4>>2]=v[a+4>>2]+4;dc(a);ab=c+16|0}function fo(a){var b=0,c=0;b=a+68|0;a=0;while(1){if((a|0)!=9){c=Fb(b,a);a=a+1|0;v[c>>2]=a<<11;continue}break}}function Y1(a,b){a=a|0;b=b|0;if(a){b=eb[v[v[b>>2]+8>>2]](b)|0;a:{if(b){b=$d(b);break a}b=$d(21598)}v[a>>2]=b}}function WA(a){var b=0,c=0;b=a+68|0;a=0;while(1){if((a|0)!=9){c=Fb(b,a);a=a+1|0;v[c>>2]=a<<16;continue}break}}function W1(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=Mb(b,8178);lc(a,c);pb(c);v[a>>2]=49212;ab=b+16|0;return a|0}function Vo(a,b){var c=0;c=ab-32|0;ab=c;qh(c+16|0,b);_m(c+24|0,a,v[c+16>>2],v[c+20>>2]);qh(c+8|0,b);ab=c+32|0}function TK(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function Pt(a){var b=0;b=ab-16|0;ab=b;u[b+14>>1]=a;u[b+12>>1]=255;a=w[Lc(b+14|0,b+12|0)|0];ab=b+16|0;return a}function Pk(a,b,c,d){var e=0;e=ab-16|0;ab=e;v[e+12>>2]=d;v[e+8>>2]=c;Zb(a,b,v[zb(e+12|0,e+8|0)>>2]);ab=e+16|0}function yq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ab-16|0;ab=d;t[d+15|0]=0;pg(a,b,fi(b,b+c|0,d+15|0));ab=d+16|0}function saa(){var a=0;a=ab-16|0;ab=a;if(Wa(a+12|0,4)|0){yr(v[114934],12616);L()}ab=a+16|0;return v[a+12>>2]}function rR(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;u[c+14>>1]=b;if((el(a)|0)!=65535){DB(a,c+14|0)}ab=c+16|0}function mw(a,b){var c=0;if(b>>>0<=9999){return lw(a,b)}c=a;a=(b>>>0)/1e4|0;return Qi(lw(c,a),B(a,-1e4)+b|0)}function jG(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return eb[v[v[a>>2]+36>>2]](a)|0}return rg(t[b|0])}function bi(a){var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function ZE(a,b,c,d,e){b=Hi(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function WE(a,b,c,d,e){b=Gi(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function PN(a){var b=0;b=v[a+4>>2];u[a+70>>1]=w[((x[b+20>>1]>>>6|x[b+22>>1]<<4)&65535)+29056|0]>>>x[a+68>>1]}function tY(){var a=0;if(Jn()>>>0<=29){hd();L()}a=FE(Ev(465280),30);v[116320]=a;v[116321]=a;v[116322]=a+120}function pm(a){var b=0;b=ab-16|0;ab=b;v[b+12>>2]=a;v[b+8>>2]=255;a=w[zb(b+12|0,b+8|0)|0];ab=b+16|0;return a}function ZG(a,b,c,d){z[d+4>>2]=a+c;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=b+a}function PQ(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(b>=0){A[a+8>>3]=b;v[a+16>>2]=3}return a}function Ffa(a,b){a=a|0;b=b|0;if(!BR(a,b)){t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0}}function wfa(a,b){a=a|0;b=b|0;var c=0;b=ab-16|0;ab=b;c=-1;if(tj(a,b+8|0)){c=lR(b+8|0)}ab=b+16|0;return c|0}function lQ(a){var b=0;if(!(Ib(a,17779,4)|w[a+5|0]!=16|(w[a+54|0]-33&255)>>>0<224)){b=w[a+4|0]>95}return b}function fS(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){eS(c+52|0);pb(c+40|0);ec(c+16|0);ec(c+4|0)}xb(c)}}function dia(a,b){a=a|0;b=b|0;var c=0;b=ab-80|0;ab=b;c=-1;if(xT(a,b+8|0)){c=wT(b+8|0)}ab=b+80|0;return c|0}function Gs(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=qn(a);continue}break}return a}function Eu(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function zx(a,b){Pb(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;Ye(a+24|0);Bb(a+36|0);v[a+48>>2]=b;return a}function yk(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return eb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function xg(a){var b=0,c=0;b=ab-16|0;ab=b;if(Aq(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8}ab=b+16|0;return c}function wE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function aU(a,b){a=a|0;b=b|0;var c=0;b=ab-16|0;ab=b;c=-1;if(tj(a,b+8|0)){c=tB(b+8|0)}ab=b+16|0;return c|0}function _t(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;nm(c+8|0,a);v[c+4>>2]=v[c+8>>2];Nt(c+4|0,b);ab=c+16|0}function DR(a,b){var c=0;c=ab-16|0;ab=c;a=li(c,a,1);Pn(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;dc(a);ab=c+16|0}function uL(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;Lk(c);continue}break}v[a+4>>2]=b}function oP(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;nP(c);continue}break}v[a+4>>2]=b}function lN(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;Be(c);continue}break}v[a+4>>2]=b}function bC(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;qb(c);continue}break}v[a+4>>2]=b}function XN(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;Uk(c);continue}break}v[a+4>>2]=b}function Lb(a,b,c){var d=0;c=v[a+4>>2]+c|0;d=b;b=v[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;v[a>>2]=b;v[a+4>>2]=c}function FK(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return(a|0)==1179012417|(a|0)==538987841}function vm(a){a=a+28|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return(a>>>0>127?a^128:-1)&255}function bT(a){a:{if(Ib(a,14158,4)){break a}if(Ib(a+8|0,14139,4)){break a}return 1}return!Ib(a,14139,4)}function LM(a,b){var c=0,d=0;a:{if(b<0){break a}c=A[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}A[a>>3]=d}}function AO(a,b,c){var d=0;return(a&255)!=255|(b&224)!=224|(!(b&6)|(b&24)==8)|(c&12)==12?d:(c&240)!=240}function xE(a){var b=0,c=0;b=ab-16|0;ab=b;a=Sh(b+8|0,a);c=v[v[114936]>>2];Rh(a);ab=b+16|0;return c?4:1}function hN(a,b,c,d){a=a&65535;c=c&65535;if(a>>>0>=c>>>0){a=b>>>0<d>>>0&a>>>0<=c>>>0}else{a=1}return a}function _d(a,b){ol(a,v[b>>2],v[b+4>>2]);v[a+8>>2]=v[b+8>>2];ol(a+12|0,v[b+12>>2],v[b+16>>2]);return a}function kV(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=-1;if(tj(a,b+8|0)){c=dD(b+8|0)}ab=b+16|0;return c|0}function UA(a,b){if(b>>>0<=126){Le(((b<<5)+a|0)+480280|0);Dn((B(b,872)+a|0)+1074992|0,a,b,134217728)}}function SV(a){a=a|0;var b=0,c=0;b=ab-32|0;ab=b;c=-1;if(ND(a,b+8|0)){c=MD(b+8|0)}ab=b+32|0;return c|0}function SA(a){var b=0,c=0;if(v[a>>2]){uc(a);xb(v[a>>2]);b=vb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function Jb(a,b,c){var d=0;if(c){d=a;while(1){t[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function q0(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;NB(c+8|0,b);yq(a,v[c+8>>2],v[c+12>>2]);ab=c+16|0}function nl(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function mu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0}function ZQ(a){u[a+10>>1]=0;u[a+12>>1]=0;u[a+8>>1]=1084;v[a>>2]=0;v[a+4>>2]=40;u[a+14>>1]=0;return a}function YU(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;sm(c+8|0,b);yq(a,v[c+8>>2],v[c+12>>2]);ab=c+16|0}function XU(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;mi(a+8|0,0);vq(a,127);HC(a,127,w[b|0]);return a|0}function KO(a){Rd(a+140|0);qb(a+120|0);qb(a+100|0);qb(a+80|0);qb(a+60|0);qb(a+40|0);qb(a+20|0);qb(a)}function JA(a,b){var c=0;c=ab-16|0;ab=c;v[c+8>>2]=v[a>>2];a=v[DS(c+8|0,0-b|0)>>2];ab=c+16|0;return a}function WR(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]+B((b|0)/-6|0,6)|0;v[d>>2]=c;if((b|0)>0){gc(c,a,b)}}function zE(a,b,c,d,e){var f=0;f=ab-16|0;ab=f;e=Sh(f+8|0,e);a=lr(a,b,c,d);Rh(e);ab=f+16|0;return a}function pN(a,b,c){var d=0;d=ab-16|0;ab=d;a=v[$b(d+8|0,gN(b,c,Kd(a),ac(a)))>>2];ab=d+16|0;return a}function Y6(a,b,c){a=a|0;b=b|0;c=c|0;a=Hj(a);if(!a){return 0}return eb[v[v[a>>2]+100>>2]](a,b,c)|0}function WL(a,b,c,d){a=a&255;c=c&255;if(a>>>0>=c>>>0){a=(b|0)<(d|0)&a>>>0<=c>>>0}else{a=1}return a}function T1(a,b){a=a|0;b=b|0;var c=0;b=Eb(b);c=v[a+4>>2];if(c){eb[c|0](b,v[a+8>>2]);return}as(b,a)}function Kea(a,b){a=a|0;b=b|0;var c=0;b=ab-16|0;ab=b;c=-1;if(YA(a,b)){c=GQ(b)}ab=b+16|0;return c|0}function Gu(a){a=a|0;var b=0;b=ab-16|0;ab=b;a=hg(a,b+15|0);ab=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function J6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;eb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;Qo(d,a);xJ(a,c)}function Dw(a,b,c){b=(B(B(Bw(a),Cw(a,b)),125)>>>0)/(eH(a,b)>>>0)|0;a=(a&6)==6?b&-4:b;return a?a:c}function s$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;eb[v[v[a>>2]+12>>2]](a,b,c,d,e,f)|0}function r$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;eb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function q$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;eb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function p$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;eb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function o$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;eb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function n$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;eb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function le(a,b){var c=0;c=ab-16|0;ab=c;v[c+8>>2]=v[a>>2];a=v[XS(c+8|0,b)>>2];ab=c+16|0;return a}function _m(a,b,c,d){var e=0;e=ab-16|0;ab=e;Gg(e+8|0,c,d);fH(a,b,v[e+8>>2],v[e+12>>2]);ab=e+16|0}function Uh(a,b,c){if(c){while(1){v[a>>2]=v[b>>2];a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}}function NU(a){a=a|0;var b=0;b=v[a+76>>2];if(jc(-1,b)){b=KC(a,32);v[a+76>>2]=b}return b<<24>>24}
function Er(a,b,c,d){var e=0;e=ab-16|0;ab=e;Ub(e+8|0,c,d);fH(a,b,v[e+8>>2],v[e+12>>2]);ab=e+16|0}function Bz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){v[a>>2]=v[c>>2];b=b-1|0;a=a+4|0;continue}break}}function xQ(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}v[a>>2]=b}}function w1(a){a=a|0;var b=0;b=ab-16|0;ab=b;a=v[yf(b+8|0,Sj(pc(12),a))>>2];ab=b+16|0;return a|0}function fU(a,b){a=a|0;b=b|0;if(!hu(a,b)){t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b|0]=0}}function ega(a){a=a|0;var b=0;b=ab-16|0;ab=b;a=lo(a,b+8|0);ab=b+16|0;return C(a?z[b+8>>2]:C(0))}function d$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function Ys(a,b){b=oia(a,a>>31,b,b>>31)+5e5|0;a=db;return vc(pia(b,b>>>0<5e5?a+1|0:a,1e6,0),db)}function VU(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;if(hg(a,b+8|0)){c=w[b+8|0]}ab=b+16|0;return c|0}function NG(a){var b=0;b=+((a&2097151)>>>0);return C(xj(+C((a|0)>=0?b:-b),(a>>>21&1023)-788|0))}function LW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Bg(a,v[b+8>>2],f)){tv(b,c,d,e)}}function yF(a){var b=0;b=v[114936];if(a){v[114936]=(a|0)==-1?463460:a}return(b|0)==463460?-1:b}function tx(a){var b=0;b=B(32-E(a|1)|0,1233)>>>12|0;return(b-(y[(b<<2)+25760>>2]>a>>>0)|0)+1|0}function qT(a,b){return(Sb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Sb((B(a&15,b)>>>0)/15|0,1,15))&255}function n0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=jz(Ww(a+8|0,b,c,d,3));return(a>>>0<5?a+1|0:0)|0}function bz(a){Pb(a);t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=255}function Xh(a){if(uI(w[a+20|0])){a=aa(4)|0;v[a>>2]=0;Dl(a);v[a>>2]=87976;ia(a|0,88012,25);L()}}function N8(a,b){a=a|0;b=b|0;di(a);di(a);a:{if(b>>>0>=60){Ob(a,4);break a}di(a)}return di(a)|0}function BT(a){var b=0;if(!(Ib(a,26340,20)|(w[a+25|0]-9&255)>>>0<248)){b=t[a+47|0]>=0}return b}function $R(a,b,c){var d=0;d=ab-16|0;ab=d;t[d+15|0]=0;Zb(a,b,fi(b,b+c|0,d+15|0)-b|0);ab=d+16|0}function rk(a){var b=0;b=ab-16|0;ab=b;a=v[$b(b+8|0,Eb(a)+(ub(a)<<2)|0)>>2];ab=b+16|0;return a}function qE(a){var b=0;b=a;a=0;while(1){if((a|0)!=3){v[(a<<2)+b>>2]=0;a=a+1|0;continue}break}}function pC(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;a=b>>>0<2624?a+1|0:a;db=a;return b}function mP(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function af(a,b){a=a|0;b=b|0;var c=0,d=0;c=ab-16|0;ab=c;d=a;a=Mb(c,b);Ac(d,a);pb(a);ab=c+16|0}function Uu(a,b){YC(a,v[b>>2],v[b+4>>2]);v[a+8>>2]=v[b+8>>2];YC(a+12|0,v[b+12>>2],v[b+16>>2])}function Jl(a,b,c){b=b-a|0;while(1){if((b|0)>0){t[a|0]=w[c|0];b=b-1|0;a=a+1|0;continue}break}}function zF(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function uE(a){a=a|0;var b=0;v[a>>2]=80012;b=v[a+8>>2];if(!(!b|!w[a+12|0])){xb(b)}return a|0}function nE(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<4)+d;return a}function jl(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<2)+d;return a}function j$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return eb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function iL(a,b){var c=0;c=ab-16|0;ab=c;Gz(c,1,b);tc(a,v[c>>2],v[c+4>>2],w[c+8|0]);ab=c+16|0}function ho(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<1)+d;return a}function SO(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<5)+d;return a}function Rea(a){a=a|0;var b=0,c=0;b=ab-32|0;ab=b;c=a;a=Nh(b+8|0);jR(c,a,0,0);qb(a);ab=b+32|0}function yea(a){a=a|0;var b=0;b=ab-16|0;ab=b;a=Kh(a,b+8|0);ab=b+16|0;return+(a?A[b+8>>3]:0)}function wu(a,b){a=a|0;b=b|0;var c=0;c=ab-16|0;ab=c;t[c+15|0]=w[b|0];rJ(a,c+15|0);ab=c+16|0}function wg(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){UA(a,c);b=b+1|0;continue}break}}function ty(a){var b=0;v[a+84>>2]=0;v[a+88>>2]=0;b=v[a+80>>2];v[a+92>>2]=b;v[a+96>>2]=b<<12}function gQ(a){a:{if(Ib(a,17572,4)){break a}if(Ib(a+8|0,14196,4)){break a}return 1}return 0}function Yw(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=rK(d);b=b+1|0}QI(a,b,c,d,e)}function Mp(a,b){var c=0;c=ub(a);if((c|0)==(ub(b)|0)){a=pn(Eb(a),Eb(b),c)}else{a=1}return!a}function Hb(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];return eb[v[v[c>>2]+32>>2]](c,v[a+8>>2],b)|0}function EC(a,b){if((a&4088)>>>0>=520){b=Ju(0-sia(b^1230262859,25)|0,4)^1247037516}return b}function Cw(a,b){a=a&255;return w[(B(a>>>3&1,45)+B(a>>>1&3,15)+((b&240)>>>4)|0)+60705|0]<<1}function AL(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3}function xv(a,b,c){var d=0;d=ab-16|0;ab=d;c=Sh(d+8|0,c);a=ow(a,b);Rh(c);ab=d+16|0;return a}function sJ(a,b){var c=0;c=v[a+12>>2];if((c|0)>0){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function ri(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function nv(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=v[(b<<2)+21644>>2]}else{b=9703}Mb(a,b)}function jN(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[ac(a)+4|0]){kN(b+16|0)}if(b){xb(b)}}}function iG(a){var b=0;b=v[a>>2];if(b){if(!jc(jG(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function cS(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[ac(a)+4|0]){cl(b+16|0)}if(b){xb(b)}}}function Vea(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=a;a=Mb(b,16763);Ac(c,a);pb(a);ab=b+16|0}function Pga(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=a;a=Mb(b,16132);Ac(c,a);pb(a);ab=b+16|0}function PO(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;a=b>>>0<259?a+1|0:a;db=a;return b}function MK(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[ac(a)+4|0]){yb(b+16|0)}if(b){xb(b)}}}function Ac(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];qE(b)}function $4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;Vw(a,b,c,d,e,0,0,f,g)}function sia(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function rfa(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=a;a=Mb(b,3883);Ac(c,a);pb(a);ab=b+16|0}function pfa(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=a;a=Mb(b,4848);Ac(c,a);pb(a);ab=b+16|0}function b7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Hj(a);if(a){eb[v[v[a>>2]+76>>2]](a,b,c,d)}}function a7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Hj(a);if(a){eb[v[v[a>>2]+84>>2]](a,b,c,d)}}function _o(a,b,c){a=a+1074992|0;return v[(a+B(b,872)|0)+680>>2]>v[(a+B(c,872)|0)+680>>2]}function Wv(a,b,c,d){var e=0;e=ab-16|0;ab=e;v[e+12>>2]=d;a=kr(a,b,c,d);ab=e+16|0;return a}function Wea(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=a;a=Mb(b,3968);Ac(c,a);pb(a);ab=b+16|0}function WV(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=a;a=Mb(b,16790);Ac(c,a);pb(a);ab=b+16|0}function Uw(a){a=a|0;var b=0;v[a>>2]=49232;b=v[a+4>>2];if(b){xb(b);v[a+4>>2]=0}return a|0}function SL(a){var b=0,c=0;v[a>>2]=0;bS(a+4|0);mi(a+8|0,0);b=a,c=ac(a),v[b>>2]=c;return a}function Mga(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=a;a=Mb(b,4445);Ac(c,a);pb(a);ab=b+16|0}function Iha(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=a;a=Mb(b,3892);Ac(c,a);pb(a);ab=b+16|0}function Fga(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=a;a=Mb(b,4339);Ac(c,a);pb(a);ab=b+16|0}function Eda(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=a;a=Mb(b,4126);Ac(c,a);pb(a);ab=b+16|0}function EK(a,b){a=a|0;b=b|0;var c=0;c=ub(a);if(c>>>0<b>>>0){$t(a,b-c|0,0);return}RS(a,b)}function $6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Hj(a);if(a){eb[v[v[a>>2]+88>>2]](a,b,c,d)}}function ue(a){var b=0;b=ab-16|0;ab=b;a=hg(a,b+15|0);ab=b+16|0;return(a?w[b+15|0]:0)&255}function rs(a,b){var c=0;c=Eb(a);if(c>>>0<=b>>>0){a=ub(a)+c>>>0>=b>>>0}else{a=0}return a}function pQ(a,b){var c=0;c=ab-16|0;ab=c;sm(c+8|0,b);$R(a,v[c+8>>2],v[c+12>>2]);ab=c+16|0}function jU(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=a;a=Mb(b,4319);Ac(c,a);pb(a);ab=b+16|0}function gv(){var a=0,b=0;a=ab-16|0;ab=a;b=yf(a+8|0,Pb(pc(12)));ab=a+16|0;return v[b>>2]}function Z_(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){aw(a,c);return}Mb(a,7872)}function Xs(a){var b=0;b=ab-16|0;ab=b;t[b+15|0]=0;Jl(a,a+32|0,b+15|0);ab=b+16|0;return a}function XV(a){a=a|0;var b=0,c=0;b=ab-16|0;ab=b;c=a;a=Mb(b,4493);Ac(c,a);pb(a);ab=b+16|0}function HQ(a){var b=0;b=a+512|0;while(1){if((a|0)!=(b|0)){rf(a);a=a+1|0;continue}break}}function Ff(a){var b=0;b=ab-16|0;ab=b;a=v[$b(b+8|0,Eb(a)+ub(a)|0)>>2];ab=b+16|0;return a}function FL(a,b){var c=0;c=w[a+851|0];if(c&1){t[a+851|0]=c|64;v[a+852>>2]=v[a+852>>2]+b}}function tV(a){a=a|0;var b=0;b=v[a+4>>2];return(eb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function rN(a,b){a=v[a+24>>2]+484344|0;if(he(a,b)){a=v[Rb(a,b)+12>>2]}else{a=1}return a}function oA(a,b,c){var d=C(0);d=z[a>>2];if(!Ct(d,z[b>>2])){b=Ct(z[c>>2],d)?c:a}return b}function fp(a,b,c){a=Nk(a)-v[a+16>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function fG(a){var b=0;b=v[a>>2];if(b){if(!Tm(yk(b))){return!v[a>>2]}v[a>>2]=0}return 1}function d7(a,b){a=a|0;b=b|0;a=Hj(a);if(!a){return 1}return eb[v[v[a>>2]+68>>2]](a,b)|0}function WB(a){var b=0;b=a+16|0;while(1){if((a|0)!=(b|0)){rf(a);a=a+1|0;continue}break}}function Fh(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function Ex(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=rK(d);b=b+1|0}wx(a,b,c,d)}function Em(a){var b=0;b=bv(a+4|0);if((b|0)==-1){eb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function EA(a){var b=0;b=ez(a);while(1){if((a|0)!=(b|0)){jB(a);a=a+32|0;continue}break}}function Dv(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function DF(a,b){var c=0;c=ab-16|0;ab=c;v[c+12>>2]=b;a=EF(a,11082,b);ab=c+16|0;return a}function uB(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+26288|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function tk(a,b,c){var d=0,e=0;d=ab-16|0;ab=d;e=d+8|0;vk(e,a+24|0,b);mg(e,c);ab=d+16|0}function sc(a,b){var c=0,d=0;c=ab-16|0;ab=c;d=c+8|0;sm(d,a);pj(d,b);ab=c+16|0;return a}function qf(a){var b=0;b=a+24|0;while(1){b=pb(b-12|0);if((b|0)!=(a|0)){continue}break}}function kk(a){var b=0;b=a+36|0;while(1){b=pb(b-12|0);if((b|0)!=(a|0)){continue}break}}function eH(a,b){a=a&255;return v[(b&12)+60708>>2]>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function _V(){var a=0;a:{if(UD(19923456)){break a}if(TD()){break a}a=SD()^1}return a|0}function Yy(a,b){Sj(a,b);Ac(a+12|0,b+12|0);u[a+28>>1]=x[b+28>>1];v[a+24>>2]=v[b+24>>2]}function Ok(a,b){var c=0,d=0;c=ab-16|0;ab=c;d=c+8|0;rb(d,a,b);Zl(d);ab=c+16|0;return a}function OR(a){var b=0;b=a+4|0;while(1){if((a|0)!=(b|0)){rf(a);a=a+1|0;continue}break}}function Ny(a,b){a=a+484360|0;b=b&255;if(dj(a)>>>0<=b>>>0){return Kb(a)}return jj(a,b)}function KN(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function JM(a,b){var c=0,d=0;c=ab-16|0;ab=c;d=c+8|0;vk(d,a,b);Zl(d);ab=c+16|0;return a}function BL(a){Bb(a);Bb(a+12|0);Bb(a+24|0);Bb(a+36|0);Bb(a+48|0);v[a+60>>2]=0;return a}function $D(a){var b=0;b=a+48|0;while(1){b=pb(b-12|0);if((b|0)!=(a|0)){continue}break}}function yi(a,b,c){a=a|0;b=b|0;c=c|0;if(wc(a,b)>>>0<=c>>>0){Du();L()}return(c<<1)+a|0}function sl(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function qX(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[((b&255)<<2)+78512>>2]}return b<<24>>24}function oX(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[((b&255)<<2)+76976>>2]}return b<<24>>24}function mt(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function as(a,b){a=a|0;b=b|0;b=ab-16|0;ab=b;v[b>>2]=a;_I(17801,b);$r(89336);ab=b+16|0}function _z(a,b,c,d){var e=0;e=ab-16|0;ab=e;a=li(e,a,d);Ft(b,c,a+4|0);dc(a);ab=e+16|0}function VN(a,b,c,d){var e=0;e=ab-16|0;ab=e;a=Ai(e,a,d);Ft(b,c,a+4|0);dc(a);ab=e+16|0}function PE(a,b){var c=0,d=0;Ce(a,Pd(b));b=ac(b);c=ac(a),d=v[b>>2],v[c>>2]=d;return a}function M$(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function L$(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function JG(a){var b=0;b=HG(v[a>>2]-1|0);if(!b){a=HG(v[a+4>>2]);b=a?a+32|0:0}return b}function Gt(a,b,c,d){var e=0;e=ab-16|0;ab=e;a=zk(e,a,d);Ft(b,c,a+4|0);dc(a);ab=e+16|0}function Gn(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]-b|0;v[d>>2]=c;if((b|0)>0){gc(c,a,b)}}function Fs(a,b){if(!(t[b+851|0]&1&v[a+480180>>2]==8)){Qx(a,b,0);Qx(a,b,1);Qx(a,b,2)}}function At(a,b){var c=0;c=ab-16|0;ab=c;u[c+14>>1]=b;wt(a+236|0,128,c+14|0);ab=c+16|0}function vz(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function qn(a){var b=0;b=a;a=v[a>>2];v[b>>2]=B(a,214013)+2531011;return a>>>16&32767}function qg(a,b,c){var d=0;d=A[a>>3];if(!JO(d,A[b>>3])){b=JO(A[c>>3],d)?c:a}return b}function nj(a,b,c){var d=0;d=v[a>>2];if(!Io(d,v[b>>2])){b=Io(v[c>>2],d)?c:a}return b}function kh(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;Fh(a)}function Ze(a){a=a|0;var b=0;b=v[a>>2];return(eb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function FE(a,b){a:{if(!(w[a+120|0]|b>>>0>30)){t[a+120|0]=1;break a}a=ji(b)}return a}function xW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=eb[a|0](b,c,d)|0;ua(db|0);return a|0}function it(a,b,c){b=no(a,b,c);a=ab-16|0;ab=a;v[a+8>>2]=c;le(a+8|0,b-c|0);ab=a+16|0}function ef(a){a=a|0;v[a+60>>2]=74140;v[a>>2]=74120;es(a+8|0);Jk(a+60|0);return a|0}function Tp(a,b){var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=xe(Ej(b)*+(c>>>0)),v[d+24>>2]=e}function Ro(a){a=a|0;v[a+56>>2]=73976;v[a>>2]=73956;es(a+4|0);Jk(a+56|0);return a|0}function K4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return XI(a,b,c,d,0,0,0,0,e)|0}function H6(a,b){a=a|0;b=b|0;return C((b|0)<=2?C(C(w[(a+b|0)+4232|0])/C(127)):C(0))}function Gf(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function Dd(a){var b=0;b=ab-16|0;ab=b;v[b+12>>2]=49400;Hn(a,49296,b+12|0);ab=b+16|0}function C7(a,b){a=a|0;b=b|0;return C((b|0)<=3?C(C(w[(a+b|0)+4264|0])/C(255)):C(0))}function BF(a){return(a|0)!=0&(a|0)!=85472&(a|0)!=85496&(a|0)!=463376&(a|0)!=463400}function AE(a){a=a|0;v[a>>2]=80064;if(v[a+8>>2]!=(gd()|0)){AF(v[a+8>>2])}return a|0}function s7(a){a=a|0;t[a+4202|0]=1;v[a+4232>>2]=v[v[a+16>>2]+24620>>2];ls(a);WJ(a)}function qM(a,b){var c=0;c=b&15;if(c){t[a+830|0]=c}b=b&240;if(b){t[a+829|0]=b>>>4}}function Zx(a){var b=0;b=ab-16|0;ab=b;$b(b+8|0,a+116|0);a=tL(a);ab=b+16|0;return a}function Y_(a,b){a=a|0;b=b|0;XF(a,v[b>>2],v[b+4>>2],8914);v[a>>2]=74316;return a|0}function XO(a,b,c,d,e,f){$b(a,b);$b(a+4|0,c);$b(a+8|0,d);$b(a+12|0,e);$b(a+16|0,f)}function U5(a){a=a|0;t[a+4202|0]=1;v[a+4256>>2]=v[v[a+16>>2]+24620>>2];wJ(a);uJ(a)}function QG(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function Ip(a){var b=0;b=ab-16|0;ab=b;a=v[$b(b+8|0,v[a>>2])>>2];ab=b+16|0;return a}function zu(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,20);return a}function wt(a,b,c){while(1){if(b){u[a>>1]=x[c>>1];b=b-1|0;a=a+2|0;continue}break}}function kt(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,12);return a}function kT(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,48);return a}function hK(a,b,c){while(1){if(b){z[a>>2]=z[c>>2];b=b-1|0;a=a+4|0;continue}break}}function YC(a,b,c){var d=0;d=ab-16|0;ab=d;b=ol(d+8|0,b,c);FD(b,a);Cd(b);ab=d+16|0}function QO(a){if((w[a+14|0]-53&255)>>>0>=252){a=Ib(a,15518,14)}else{a=1}return!a}function Ln(a,b){a=gc(a,b,34);u[a+34>>1]=x[b+34>>1];gc(a+36|0,b+36|0,68);return a}function xo(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<4);return a}function li(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<2);return a}function kz(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<5);return a}function kd(a){var b=0;b=ab-16|0;ab=b;a=v[$b(b+8|0,Eb(a))>>2];ab=b+16|0;return a}function gB(a){a=a+4|0;return Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function bO(a){var b=0;b=ab-16|0;ab=b;a=v[$b(b+8|0,wb(a))>>2];ab=b+16|0;return a}function al(a){var b=0;b=ab-16|0;ab=b;a=v[$b(b+8|0,Ip(a))>>2];ab=b+16|0;return a}function _p(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,6);return a}function _I(a,b){var c=0;c=ab-16|0;ab=c;v[c+12>>2]=b;CG(89336,a,b,0,0);ab=c+16|0}function Jf(a){var b=0;b=ab-16|0;ab=b;a=v[$b(b+8|0,ac(a))>>2];ab=b+16|0;return a}function Hq(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<3);return a}function Ai(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<1);return a}function Af(a){var b=0;b=ab-16|0;ab=b;a=v[$b(b+8|0,Jf(a))>>2];ab=b+16|0;return a}function $j(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;bc(a+8|0,b+8|0)}function wW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;eb[a|0](b,c,d,e,f)}function aD(a,b,c){while(1){if(b){t[a|0]=w[c|0];b=b-1|0;a=a+1|0;continue}break}}function Rg(a){var b=0,c=0;bS(a+4|0);mi(a+8|0,0);b=a,c=ac(a),v[b>>2]=c;return a}function Ih(a){return(sj(v[a>>2],v[a+4>>2])|0)!=(0-sj(v[a+12>>2],v[a+16>>2])|0)}function CX(a,b,c){a=a|0;b=b|0;c=c|0;return(x[(c<<1)+75952>>1]&b)!=0&c>>>0<=127}function tu(a,b){return xe(Ej((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function tW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return eb[a|0](b,c,d,e)|0}function sC(a){var b=0;b=ab-16|0;ab=b;t[b+15|0]=0;Jl(a,so(a),b+15|0);ab=b+16|0}function Y$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return nH(a-88|0,b,c,d,e)|0}function TY(){var a=0,b=0;Nd(465008);v[116252]=80064;a=465016,b=gd(),v[a>>2]=b}function SS(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[vb(a)>>2]){pG(a,b);return}mG(a,b)}function Kn(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function Jx(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[vb(a)>>2]){jL(a,b);return}Kz(a,b)}function zy(a){var b=0;if(!(w[a+2|0]|(w[a|0]|w[a+1|0]))){b=!w[a+3|0]}return b}function ux(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function s5(a,b){a=a|0;b=b|0;return C((b|0)<=12?z[((b<<2)+a|0)+4208>>2]:C(0))}function ln(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function ke(a,b){var c=0,d=0;c=ab-16|0;ab=c;d=c+8|0;Lu(d,a);pj(d,b);ab=c+16|0}function jm(a,b){var c=0,d=0;c=ab-16|0;ab=c;d=c+8|0;NB(d,a);pj(d,b);ab=c+16|0}function hh(a,b,c){$b(a,b);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;return a}function gs(a){a=a|0;v[a>>2]=46404;ec(a+4276|0);ec(a+4264|0);ff(a);return a|0}function bN(a){v[a>>2]=0;v[a+4>>2]=0;v[a>>2]=-2078137563;v[a+4>>2]=-873292572}function aX(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Mb(a,7908);return}aw(a,c)}function a9(a,b){a=a|0;b=b|0;if(y[a+4>>2]<y[vb(a)>>2]){jL(a,b);return}Kz(a,b)}function _W(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Mb(a,7838);return}aw(a,c)}function Ri(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}xb(b)}function Qi(a,b){var c=0;c=a;a=(b>>>0)/100|0;return zr(zr(c,a),B(a,-100)+b|0)}function QW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Bg(a,v[b+8>>2],0)){rv(b,c,d)}}function GD(a,b){var c=0;c=ab-16|0;ab=c;b=Gf(c+8|0,b);FD(b,a);Cd(b);ab=c+16|0}function wb(a){var b=0;b=ab-16|0;ab=b;a=v[$b(b+8|0,a)>>2];ab=b+16|0;return a}function w6(a,b){a=a|0;b=b|0;return C((b|0)<=6?z[((b<<2)+a|0)+4208>>2]:C(0))}function oE(){a:{if(t[465444]&1){break a}if(!Jd(465444)){break a}Id(465444)}}function k5(a,b){a=a|0;b=b|0;return C((b|0)<=2?z[((b<<2)+a|0)+4208>>2]:C(0))}function iF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function i6(a,b){a=a|0;b=b|0;return C((b|0)<=5?z[((b<<2)+a|0)+4208>>2]:C(0))}function eF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function d5(a,b){a=a|0;b=b|0;return C((b|0)<=3?z[((b<<2)+a|0)+4208>>2]:C(0))}function b6(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4208>>2]:C(0))}function Wl(a){a=a+4|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function Wj(a){var b=0;b=ab-16|0;ab=b;a=v[yf(b+8|0,a)>>2];ab=b+16|0;return a}function W5(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function Sd(a){var b=0;b=ab-16|0;ab=b;pu(b+8|0,a);ab=b+16|0;return v[b+8>>2]}function Md(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];Ob(b,c);dv(a,b,d,c)}function KE(a){var b=0;b=ab-16|0;ab=b;v[b+8>>2]=a;ab=b+16|0;return v[b+8>>2]}function F5(a,b){a=a|0;b=b|0;return C((b|0)<=1?z[((b<<2)+a|0)+4208>>2]:C(0))}function zk(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function yX(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[(b<<2)+78512>>2]}return b|0}function wX(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[(b<<2)+76976>>2]}return b|0}function tz(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function qr(a,b,c,d,e,f,g,h){return eb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function nR(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function fX(a,b){a=a|0;b=b|0;Dl(a);v[a>>2]=88448;wv(a+4|0,Eb(b));return a|0}function _F(a,b,c,d,e,f,g,h){return eb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function Qq(a,b){a=a|0;b=b|0;a=v[a>>2];return eb[v[v[a>>2]+32>>2]](a,0,b)|0}function OO(a,b){aQ(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function Fp(a,b,c){a=Ab(w[a|0]|w[a+1|0]<<8);return(a|0)>=(b|0)&(a|0)<=(c|0)}function EN(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);wN(a,b,0,0,b+-1,0)}function DI(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){cn(c+120|0)}xb(c)}}function zr(a,b){b=x[(b<<1)+73104>>1];t[a|0]=b;t[a+1|0]=b>>>8;return a+2|0}function uv(a,b){v[a+12>>2]=0;v[a+4>>2]=b;v[a>>2]=b;v[a+8>>2]=b+1;return a}function lv(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+12;return a}function lD(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+36;return a}function gg(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function cX(a,b,c){a=a|0;b=b|0;c=c|0;return jc(a,v[b+4>>2])&v[b>>2]==(c|0)}function _M(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;DO(a,c)}function Zg(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function FT(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+28;return a}function xk(a,b,c){a=a|0;b=b|0;c=c|0;return eb[v[v[a>>2]+12>>2]](a,b,c)|0}function m$(a,b,c){a=a|0;b=b|0;c=c|0;return eb[v[v[a>>2]+32>>2]](a,b,c)|0}function km(a,b,c){a=a|0;b=b|0;c=c|0;return eb[v[v[a>>2]+48>>2]](a,b,c)|0}function fz(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+4;return a}function dN(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+8;return a}function Zs(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function QQ(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function Gc(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function Ft(a,b,c){b=b-a|0;if((b|0)>0){gc(v[c>>2],a,b);v[c>>2]=b+v[c>>2]}}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=co(a,b),v[d>>2]=e}function Bga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Fu(a,b),u[d>>1]=e}function sG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Zg(a,-1,-1)}function _B(a,b){return(w[a|0]|w[a+1|0]<<8)>>>0<(w[b|0]|w[b+1|0]<<8)>>>0}function Zv(a,b){var c=0;c=is(a+4|0);v[a>>2]=74968;v[c>>2]=74988;jn(c,b)}function Yv(a,b){var c=0;c=RF(a+4|0);v[a>>2]=75136;v[c>>2]=75156;jn(c,b)}function S6(a,b){a=a|0;b=b|0;a=v[a+20>>2]+24|0;t[a|0]=w[a|0]&253|(b?2:0)}function GT(a){return Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function zv(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function zD(a,b){a=a|0;b=b|0;Dl(a);v[a>>2]=88448;wv(a+4|0,b);return a|0}function wH(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function tw(a){return((ah(a)+(ah(a)<<8)|0)+(ah(a)<<16)|0)+(ah(a)<<24)|0}function pP(a){var b=0;if(v[a>>2]){oP(a,v[a>>2]);b=v[a>>2];lk(a);xb(b)}}function nF(a){u[a+12>>1]=0;v[a+8>>2]=-1;v[a>>2]=0;v[a+4>>2]=0;return a}function mT(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function kc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=Pf(b),v[c+4>>2]=d;return a}function aB(a,b,c){var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function Yc(a){var b=0;if(v[a>>2]){bC(a,v[a>>2]);b=v[a>>2];cC(a);xb(b)}}function RN(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function Mc(a,b){GD(a,b);v[a+8>>2]=v[b+8>>2];GD(a+12|0,b+12|0);return a}function LN(a){if(a>>>0<=8){return w[a+29184|0]}return w[a+29175|0]|256}function J1(a,b,c){a=a|0;b=b|0;c=c|0;mO(a,0,v[v[b+24>>2]+1298404>>2],c)}function yU(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){xa();L()}}function vA(a,b){if(b){vA(a,v[b>>2]);vA(a,v[b+4>>2]);cl(b+16|0);xb(b)}}function sv(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function sA(a,b){if(b){sA(a,v[b>>2]);sA(a,v[b+4>>2]);cl(b+16|0);xb(b)}}function qy(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];t[a+6|0]=w[b+6|0]}function qp(a,b){if(b){qp(a,v[b>>2]);qp(a,v[b+4>>2]);kN(b+16|0);xb(b)}}function pk(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function bD(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function Rk(a,b){a=w[Cb(a+62|0,b)|0];return(a<<24>>24>=0?a&127:-1)&255}function Qc(a,b,c){return ud(v[a>>2],B(oj(v[v[a+48>>2]+12>>2]),b)+c|0)}function Ix(a,b){if(b){Ix(a,v[b>>2]);Ix(a,v[b+4>>2]);yb(b+16|0);xb(b)}}function GQ(a){if(Ib(a,13794,4)){a=1}else{a=Ib(a+8|0,13847,4)}return!a}function Fy(a,b){if(b){Fy(a,v[b>>2]);Fy(a,v[b+4>>2]);Pl(b+16|0);xb(b)}}function yc(a,b,c,d){if((b|0)==(d|0)){a=_R(a,b,c,d)}else{a=1}return!a}function vL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){bl(c)}xb(c)}}function qL(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function _g(a,b,c){return(x[v[a+8>>2]+((c&255)<<1)>>1]&b)!=0&(c|0)>=0}function RC(a){return(w[v[a+104>>2]+34|0]&8)>>>3&(v[a+88>>2]&2050)==2}function OK(a,b,c,d){if((b|0)==(d|0)){a=YL(a,b,c,d)}else{a=1}return!a}function JW(a){a=a|0;if(!a){return 0}return(py(a,88060,88204)|0)!=0|0}function HD(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Xb(c)}xb(c)}}function Cv(a){a=a|0;if(v[a+8>>2]!=(gd()|0)){AF(v[a+8>>2])}return a|0}function zK(a,b,c){b=b-a|0;if(b){Wi(c,a,b)}return B((b|0)/6|0,6)+c|0}function u_(a){a=a|0;var b=0;b=v[115920]+1|0;v[115920]=b;v[a+4>>2]=b}function uW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return eb[a|0](b,c,d)|0}function tl(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function gq(a,b){var c=0;c=ab-16|0;ab=c;DC(c,a,64);IC(c,b);ab=c+16|0}function bu(a,b){var c=0;c=ab-16|0;ab=c;DC(c,a,32);IC(c,b);ab=c+16|0}function _Y(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Rf(a,f)}function WD(a){if(a>>>0>=357913942){Oe(11129);L()}return pc(B(a,12))}function AR(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];bc(a+8|0,b+8|0)}function $y(a,b){Pb(a);Bb(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function $k(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){ac(a);if(b){xb(b)}}}function $B(a){if(a>>>0>=214748365){Oe(11129);L()}return pc(B(a,20))}function xc(a,b,c){if(nc(a,b)>>>0<=c>>>0){Du();L()}return(c<<2)+a|0}function sK(a){if(a>>>0>=82595525){Oe(11129);L()}return pc(B(a,52))}function iu(a,b){return cE(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?b:a}function il(a,b){return Iu(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?b:a}function fM(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(b){Es(b)}xb(b)}}function fE(a,b){return cE(v[a>>2],v[a+4>>2],v[b>>2],v[b+4>>2])?b:a}function ZO(a,b,c,d,e){$b(a,b);$b(a+4|0,c);$b(a+8|0,d);$b(a+12|0,e)}function Xe(a){var b=0;b=ab-16|0;ab=b;rf(v[uv(b,a)+8>>2]);ab=b+16|0}function UR(a){if(a>>>0>=715827883){Oe(11129);L()}return pc(B(a,6))}function Pn(a,b){b=x[b>>1]|x[b+2>>1]<<16;u[a>>1]=b;u[a+2>>1]=b>>>16}function IR(a){t[a+4|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function Ek(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(b){Hf(b)}xb(b)}}function EL(a,b){v[a+852>>2]=v[a+852>>2]+b;t[a+851|0]=w[a+851|0]|64}function wK(a,b){if((a|0)!=(b|0)){oR(a,v[b>>2],v[b+4>>2])}return a}function tX(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function ji(a){if(a>>>0>=1073741824){Oe(11129);L()}return pc(a<<2)}function he(a,b){if(lm(a,b)){a=Gh(Nf(v[a>>2],b))}else{a=0}return a}function an(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<1)|0}function LO(a,b){zz(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function HE(a,b,c){a:{if((a|0)==(b|0)){t[a+120|0]=0;break a}xb(b)}}function xi(a,b){v[a>>2]=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];return a}function vV(a){a=a|0;a=v[a+4>>2];return eb[v[v[a>>2]+12>>2]](a)|0}function uV(a){a=a|0;a=v[a+4>>2];return eb[v[v[a>>2]+16>>2]](a)|0}function uH(a){a=a|0;return+(+v[v[a+32>>2]+1074456>>2]*.00390625)}function si(a,b){if($f(v[a>>2],v[a+4>>2])>>>0>b>>>0){t[a+16|0]=b}}function q9(a,b){a=a|0;b=b|0;if(!v[22452]){v[22453]=b;v[22452]=a}}function oD(a){if(a>>>0>=536870912){Oe(11129);L()}return pc(a<<3)}function kE(a){if(a>>>0>=268435456){Oe(11129);L()}return pc(a<<4)}function Um(a,b){if(y[a+4>>2]<y[vb(a)>>2]){pG(a,b);return}mG(a,b)}function TP(a){a=a+34|0;a=oia(w[a|0]|w[a+1|0]<<8,0,80,0);return a}function RO(a){if(a>>>0>=134217728){Oe(11129);L()}return pc(a<<5)}function NS(a){db=0;a=a+47|0;a=(w[a|0]|w[a+1|0]<<8)-98|0;return a}function zs(a){pb(a+48|0);pb(a+36|0);pb(a+24|0);pb(a+12|0);pb(a)}function wV(a){a=a|0;a=v[a+4>>2];return eb[v[v[a>>2]+8>>2]](a)|0}function cE(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function Wc(a,b){return((a^-2147483648)>>>b)-(-2147483648>>>b)|0}function UL(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function Sc(a){a=(a|0)<32767?a:32767;return(a|0)>-32768?a:-32768}function Pj(a){a=hz(a)?a+172|0:a+156|0;return w[a|0]|w[a+1|0]<<8}function Jw(a,b,c){return xh(v[a>>2],v[a+4>>2],b,v[a+12>>2]+c|0)}function $m(a,b,c){return bR(v[a>>2],v[a+4>>2],b,v[a+12>>2]+c|0)}function y1(a,b){a=a|0;b=b|0;Lq(a,v[b>>2],v[b+4>>2]);return a|0}function rz(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];Yu(a);xb(b)}}function pr(a,b){a=a|0;b=b|0;return eb[v[v[a>>2]+44>>2]](a,b)|0}function ni(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];Mn(a);xb(b)}}function nP(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];lk(a);xb(b)}}function nN(a){var b=0;if(v[a>>2]){mN(a);b=v[a>>2];lk(a);xb(b)}}function kL(a){var b=0;if(v[a>>2]){ro(a);b=v[a>>2];Yu(a);xb(b)}}function jk(a){a=a|0;a=v[a>>2];return eb[v[v[a>>2]+24>>2]](a)|0}function jR(a,b,c,d){_d(a,b);u[a+22>>1]=d;u[a+20>>1]=c;return a}function hx(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];qx(a);xb(b)}}function ht(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];mz(a);xb(b)}}function hl(a,b){a=a|0;b=b|0;return eb[v[v[a>>2]+28>>2]](a,b)|0}function ec(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];Ch(a);xb(b)}}function ar(a){var b=0;b=ab-16|0;A[b+8>>3]=a;return A[b+8>>3]*a}function ag(a,b,c,d){v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function _x(a){var b=0;if(v[a>>2]){ws(a);b=v[a>>2];vs(a);xb(b)}}function _c(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];um(a);xb(b)}}function ZN(a){var b=0;if(v[a>>2]){YN(a);b=v[a>>2];Mn(a);xb(b)}}function Z4(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function Vj(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];cr(a);xb(b)}}function Ud(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];Fm(a);xb(b)}}function TM(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];Gy(a);xb(b)}}function Rn(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];CR(a);xb(b)}}function Rd(a){var b=0;if(v[a>>2]){JT(a);b=v[a>>2];iB(a);xb(b)}}function Qv(a,b){a=a|0;b=b|0;return eb[v[v[a>>2]+12>>2]](a,b)|0}function Oc(a){var b=0;if(me(a)){b=v[a>>2];gk(a);xb(b)}return a}function Iu(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function IJ(a){a=a|0;return C(C(C(z[a+4228>>2]*C(198))+C(-99)))}function Hf(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];ut(a);xb(b)}}function FG(a){var b=0;b=ab-16|0;z[b+12>>2]=a;return z[b+12>>2]}function Eh(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];St(a);xb(b)}}function EX(a){a=a|0;a=v[a+8>>2];if(!a){return 1}return xE(a)|0}function Cp(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];vb(a);xb(b)}}function $x(a){var b=0;if(v[a>>2]){uc(a);b=v[a>>2];eT(a);xb(b)}}function zN(a,b){a=a|0;b=b|0;Rt(a,b);v[a>>2]=88468;return a|0}
function xD(a,b){Gf(a,b);v[a+8>>2]=v[b+8>>2];Gf(a+12|0,b+12|0)}function st(a,b){a=a|0;b=b|0;a=_S(a,b);if(!a){Qt(b)}return a|0}function sW(a,b){a=a|0;b=b|0;eb[v[v[b>>2]+16>>2]](a,b,0,0,1,8)}function rZ(a,b){a=a|0;b=b|0;ZL(a,gw(v[b>>2])<<24>>24,v[b>>2])}function ev(a,b){a=a|0;b=b|0;a=nD(a,b);if(!a){mD(b)}return a|0}function es(a){a=a|0;v[a>>2]=73440;pb(a+32|0);Fl(a);return a|0}function eA(a,b){a=a|0;b=b|0;a=lo(a,b);if(!a){im(b)}return a|0}function _K(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function Zha(a,b){a=a|0;b=b|0;Rt(a,b);v[a>>2]=88604;return a|0}function Wn(a,b){a=a|0;b=b|0;a=ZS(a,b);if(!a){aT(b)}return a|0}function Wb(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function Vu(a,b){a=a|0;b=b|0;a=XC(a,b);if(!a){Dq(b)}return a|0}function Rq(a,b){a=a|0;b=b|0;a=fD(a,b);if(!a){iv(b)}return a|0}function RM(a,b){a=a|0;b=b|0;a=nT(a,b);if(!a){Tt(b)}return a|0}function Qf(a,b){return eb[v[v[a>>2]+32>>2]](a,v[a+12>>2],b)|0}function O9(a,b){a=a|0;b=b|0;a=FR(a,b);if(!a){ER(b)}return a|0}function NP(a){return w[a+15|0]<<12|w[a+14|0]<<4|w[a+13|0]<<20}function Mh(a,b){a=a|0;b=b|0;a=Kh(a,b);if(!a){nl(b)}return a|0}function GB(a,b){a=a|0;b=b|0;a=fu(a,b);if(!a){mu(b)}return a|0}function Eq(a){a=a|0;a=v[a>>2];return eb[v[v[a>>2]+8>>2]](a)|0}function ED(a,b,c){Cm(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=58364}function DA(a,b){a=a|0;b=b|0;a=RR(a,b);if(!a){pA(b)}return a|0}function Bq(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function yfa(a,b,c){a=a|0;b=b|0;c=c|0;Ac(a,mR(c,Eb(b),ub(b)))}function v_(a,b){a=a|0;b=b|0;Rt(a,b);v[a>>2]=88656;return a|0}function ol(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(c){Bm(c)}return a}function eq(a,b){b=w[b|0]|w[b+1|0]<<8;t[a|0]=b;t[a+1|0]=b>>>8}function eL(a,b){return b>>>0<4e3?((b<<5)+a|0)+946304|0:21598}function RH(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function yg(a,b,c,d){db=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function yH(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function nV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Ub(a,v[d>>2],0)}function kx(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function eE(a,b,c){b=Ma(933,a|0,b|0,c|0)|0;db=O()|0;return b}function cc(a,b){var c=0;c=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=c}function Zu(a,b){Ac(a,b);bc(a+12|0,b+12|0);Oh(a+32|0,b+32|0)}function Qp(a,b,c){if(!b){return 0}return Jt(a,rg(t[c|0]),b)}function Ox(a,b){var c=0;c=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=c}function HG(a){return t[(B(0-a&a,124511785)>>>27|0)+69744|0]}function CL(a){v[a>>2]=0;Pb(a+4|0);Jb(a+16|0,0,144);return a}function wT(a){return!Ib(a,14144,4)&(w[a+4|0]-1&255)>>>0<10}function wG(a,b){if(b>>>0<=9){return vG(a,b)}return zr(a,b)}function qz(a,b){if(b){qz(a,v[b>>2]);qz(a,v[b+4>>2]);xb(b)}}function pz(a,b){if(b){pz(a,v[b>>2]);pz(a,v[b+4>>2]);xb(b)}}function pI(a,b){a=a|0;b=b|0;return Ic(v[b>>2],v[b+4>>2])|0}function lX(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>=0?b:c)|0}function kn(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function hR(a){var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b}function cA(a,b){if(b){cA(a,v[b>>2]);cA(a,v[b+4>>2]);xb(b)}}function bv(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function bA(a,b){if(b){bA(a,v[b>>2]);bA(a,v[b+4>>2]);xb(b)}}function Z6(a){a=a|0;a=Hj(a);if(a){eb[v[v[a>>2]+96>>2]](a)}}function Yp(a){return v[a+20>>2]+(v[a+8>>2]-v[a+24>>2]|0)|0}function Sh(a,b){var c=0,d=0;c=a,d=yF(b),v[c>>2]=d;return a}function Ds(a,b){if(b){Ds(a,v[b>>2]);Ds(a,v[b+4>>2]);xb(b)}}function Cs(a,b){if(b){Cs(a,v[b>>2]);Cs(a,v[b+4>>2]);xb(b)}}function ub(a){if(me(a)){return v[a+4>>2]}return w[a+11|0]}function hz(a){a=a+156|0;return(w[a|0]|w[a+1|0]<<8)==65534}function Zl(a){var b=0;b=v[a>>2];v[b>>2]=v[b>>2]|v[a+4>>2]}function U_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;db=0;return 0}function Rv(){var a=0;a=aa(4)|0;gn(a);ia(a|0,88408,25);L()}function Rm(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function H1(a){a=a|0;KI(a,2,100);si(v[a+24>>2]+484360|0,0)}function Fx(a,b,c){A[a>>3]=A[a>>3]+b;A[a+8>>3]=A[a+8>>3]+c}function zga(a,b,c){a=a|0;b=b|0;c=c|0;pg(a,b,Ic(b,c)+b|0)}function yw(a,b){return v[((a>>>24^b)<<2)+458688>>2]^a<<8}function iA(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){xb(c)}}function gp(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function g9(a){a=a|0;Rt(a,21598);v[a>>2]=88548;return a|0}function dw(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function aV(a){a=a|0;AD(a,13301);v[a>>2]=26092;return a|0}function Zf(a){var b=0;NO(a);b=v[a>>2];if(b){iz(a);xb(b)}}function VG(a){while(1){if((Hr(a)|0)!=-1){continue}break}}function HT(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0];return a}function Fv(a){if(v[a>>2]){uc(a);HE(Ev(a),v[a>>2],Ch(a))}}function Fn(a){v[a>>2]=0;v[a+4>>2]=0;mi(a+8|0,0);return a}function Fd(a){if(!v[a+20>>2]){return 0}return v[a>>2]!=0}function CI(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){fs(c)}}function yga(a,b){a=a|0;b=b|0;Mb(a,b?b:21598);return a|0}function xJ(a,b){Bm(v[b>>2]);Em(v[a>>2]);v[a>>2]=v[b>>2]}function rG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Zg(a,-1,-1)}function kW(a){a=a|0;zN(a,7943);v[a>>2]=41992;return a|0}function im(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function gt(a,b){cc(a,b);cc(a+4|0,b+4|0);cc(vb(a),vb(b))}function Tg(a,b){var c=0;c=w[a|0];t[a|0]=w[b|0];t[b|0]=c}function Si(a){return De(a)|De(a)<<8|De(a)<<16|De(a)<<24}function Q1(a,b,c){a=a|0;b=b|0;c=c|0;Ac(a,mR(c,b,Pf(b)))}function Oy(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function O$(a,b,c){a=a|0;b=b|0;c=c|0;return yd(B(b,c))|0}function NH(a){a=a|0;v[a>>2]=57708;Xb(a+12|0);return a|0}function LV(a,b,c){a=a|0;b=b|0;c=c|0;dv(a,b,v[b+8>>2],c)}function KV(a){a=a|0;AD(a,8675);v[a>>2]=30500;return a|0}function JC(a){if((a|0)<0){Oe(11129);L()}return pc(a<<1)}function CE(a){a=a|0;v[a>>2]=80152;pb(a+16|0);return a|0}function BE(a){a=a|0;v[a>>2]=80112;pb(a+12|0);return a|0}function uD(a){a=a|0;v[a>>2]=43264;Cd(a+4|0);return a|0}function sd(a){v[a>>2]=0;v[a+4>>2]=0;Ap(a+8|0);return a}function qo(a){var b=0;b=v[a+8>>2];v[a+8>>2]=0;return b}function oe(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){fs(b)}}function no(a,b,c){b=b-a|0;if(b){Wi(c,a,b)}return b+c|0}function jE(a){a=Gw(v[a>>2]);if((bv(a+8|0)|0)<0){xb(a)}}function dH(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function bB(a){a=a|0;v[a>>2]=88428;jE(a+4|0);return a|0}function UH(a){a=a|0;v[a>>2]=58172;Xb(a+4|0);return a|0}function U8(a,b,c){a=a|0;b=b|0;c=c|0;return SK(a,b,c)|0}function Tr(a){a=a|0;v[a>>2]=49444;Wr(a+4|0);return a|0}function Mq(a){a=a|0;v[a>>2]=88448;jE(a+4|0);return a|0}function Ld(a,b,c){return a>>>0<b>>>0?b:a>>>0>c>>>0?c:a}function IA(a){a=a&255;return Kc(a)^1|(a-49&255)>>>0<36}function Hn(a,b,c){v[a>>2]=b;v[a+4>>2]=v[c>>2];return a}function GE(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Em(b)}}function Fo(a){a=a|0;v[a>>2]=73376;Nb(a+4|0);return a|0}function Fl(a){a=a|0;v[a>>2]=73312;Nb(a+4|0);return a|0}function Ec(a){if(me(a)){a=gk(a)-1|0}else{a=10}return a}function D5(a){a=a|0;tJ(a);t[a+4202|0]=1;v[a+4224>>2]=0}function yo(a){if(me(a)){a=gk(a)-1|0}else{a=1}return a}function y_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;uF(a,c,d)}function yW(a){a=a|0;a=eb[a|0]()|0;ua(db|0);return a|0}function th(a,b){a=a|0;b=b|0;eb[v[v[b>>2]+24>>2]](a,b)}function sh(a,b){a=a|0;b=b|0;eb[v[v[b>>2]+28>>2]](a,b)}function sca(a,b){a=a|0;b=b|0;if(!qQ(a,b)){Jb(b,0,40)}}function nG(a){a=a|0;return vr(v[v[a>>2]-12>>2]+a|0)|0}function kZ(a,b){a=a|0;b=b|0;Zb(a,eG(v[b>>2]),v[b>>2])}function dG(a){a=a|0;return tr(v[v[a>>2]-12>>2]+a|0)|0}function cM(a,b){bM(a,b);bM(a+12|0,b+12|0);t[a+24|0]=1}function c$(a){a=a|0;return Ro(v[v[a>>2]-12>>2]+a|0)|0}function ah(a){var b=0;b=Hr(a);v[a+1396>>2]=0;return b}function a$(a){a=a|0;return ef(v[v[a>>2]-12>>2]+a|0)|0}function Sb(a,b,c){return(a|0)<(b|0)?b:(a|0)>(c|0)?c:a}function Oi(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function Lw(a,b,c){return Gp(v[a>>2],b,v[a+12>>2]+c|0)}function Jo(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function GJ(a){a=a|0;return gj(C(z[a+4224>>2]*C(4)))|0}function Eg(a,b){a=a|0;b=b|0;eb[v[v[b>>2]+20>>2]](a,b)}function Bw(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function B_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;pg(a,c,d)}function BK(a,b){return(b>>>0<=15?t[a+b|0]:63)<<24>>24}function AK(a,b){return(b>>>0<=45?t[a+b|0]:63)<<24>>24}function vF(a,b,c){a=wF(a,b,c,0,-2147483648);return a}function q7(a,b,c){a=a|0;b=b|0;c=c|0;Zb(a,b+4260|0,8)}function cp(a){a=a|0;return eb[v[v[a>>2]+24>>2]](a)|0}function _e(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function T0(a,b){a=a|0;b=b|0;QM(v[a>>2],b);return a|0}function RJ(a){ec(a+36|0);ec(a+24|0);hx(a+12|0);hx(a)}function Mb(a,b){a=a|0;b=b|0;Lq(a,b,Pf(b));return a|0}function Li(a){a=a|0;return eb[v[v[a>>2]+16>>2]](a)|0}function Km(a,b){return eb[v[v[a>>2]+36>>2]](a,b,0)|0}function Ki(a){a=a|0;return eb[v[v[a>>2]+12>>2]](a)|0}function Jm(a,b){return eb[v[v[a>>2]+52>>2]](a,b,0)|0}function Dfa(a,b,c){a=a|0;b=b|0;c=c|0;oR(a,b,Fb(b,c))}function C6(a,b,c){a=a|0;b=b|0;c=c|0;Zb(a,b+4228|0,7)}function $u(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(c){Bm(c)}}function x7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function q6(a){a=a|0;return C(C(z[a+4232>>2]*C(20)))}function nia(a){if(a){return 31-E(a-1^a)|0}return 32}function eD(a){return GG(a,C(2.524354896707238e-29))}function Xp(a,b,c,d,e){Zb(a,b+d|0,(e|0)==-1?c-d|0:e)}function X6(a){a=a|0;t[a+4202|0]=1;js(a);ix(a);SJ(a)}function JD(a){return GG(a,C(1.5845632502852868e29))}function HJ(a){a=a|0;return C(C(z[a+4216>>2]*C(10)))}function $M(a,b,c,d){return(a|0)==(c|0)&(b|0)==(d|0)}function zY(){Nd(465224);EE(465232);v[116306]=82768}function xr(a,b){v[a>>2]=b;v[a+4>>2]=b>>31;return a}function xY(){Nd(465240);EE(465248);v[116310]=82924}function us(a){v[a>>2]=49552;v[a>>2]=49524;return a}function rb(a,b,c){Zb(a,(c>>>3&536870908)+b|0,1<<c)}function qw(a){if(!a){return 0}v[114934]=a;return-1}function pn(a,b,c){if(!c){return 0}return Ib(a,b,c)}function oca(a,b){a=a|0;b=b|0;Lq(a,b,12);return a|0}function nz(a){t[a+6|0]=0;u[a+4>>1]=65535;v[a>>2]=0}function mo(a){a=a|0;a=ic(a);eb[v[v[a>>2]>>2]](a)|0}function hj(a){if(!a){return 0}return v[a+44>>2]!=0}function go(a,b,c){Zb(a,(c>>>3&536870908)+b|0,c&31)}function a0(a,b,c){a=a|0;b=b|0;c=c|0;rH(a-88|0,b,c)}function _$(a,b,c){a=a|0;b=b|0;c=c|0;pH(a-88|0,b,c)}function Zm(a,b,c){v[a>>2]=b;v[a+4>>2]=c-b;return a}function ZA(a,b){_d(a,b);Jb(a+20|0,0,1040);return a}function Xc(a,b){a=a|0;b=b|0;return SK(a,b,Pf(b))|0}function Vq(a,b){a=a|0;b=b|0;return Op(a,b,Pf(b))|0}function R1(a){a=a|0;a=v[a+4>>2];return(a?a:4972)|0}function Qo(a,b){b=v[b>>2];v[a>>2]=b;Bm(b);return a}function Pd(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function Os(a,b,c){return hN(a,b,x[c>>1],v[c+4>>2])}function Oq(a,b){bc(a,b);Jb(a+20|0,0,1040);return a}function Ns(a,b,c){return hN(x[a>>1],v[a+4>>2],b,c)}function L5(a){a=a|0;return C(C(z[a+4232>>2]*C(4)))}function Kj(a){if(!a){return 0}return fj(w[a+31|0])}function Ica(a,b,c){a=a|0;b=b|0;c=c|0;Ac(a,Vq(b,c))}function DC(a,b,c){t[a+8|0]=1;v[a+4>>2]=c;v[a>>2]=b}function CN(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function Be(a){var b=0;b=v[a>>2];if(b){vb(a);xb(b)}}function wm(a,b){return(a&65535)>>>0<(b&65535)>>>0}function qs(a){a=a|0;Nh(a);v[a+20>>2]=0;return a|0}function np(a){a=a+168|0;return w[a|0]|w[a+1|0]<<8}function jy(a,b,c){return WL(a,b,w[c|0],v[c+4>>2])}function jx(a){a=a|0;Xb(a+4208|0);ff(a);return a|0}function iy(a,b,c){return WL(w[a|0],v[a+4>>2],b,c)}function fs(a){a=a|0;if(a){eb[v[v[a>>2]+4>>2]](a)}}function ex(a){a=a|0;ec(a+4256|0);ff(a);return a|0}function cm(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function c0(a,b,c){a=a|0;b=b|0;c=+c;tH(a-88|0,b,c)}function Z$(a,b){a=a|0;b=b|0;return oH(a-88|0,b)|0}function Xq(a,b,c){a=a|0;b=b|0;c=c|0;Ac(a,yD(b,c))}function To(a){a=a|0;ec(a+4208|0);ff(a);return a|0}function S$(a,b,c){a=a|0;b=b|0;c=+c;jH(a-92|0,b,c)}function Qj(a){a=a+158|0;return w[a|0]|w[a+1|0]<<8}function Q$(a,b,c){a=a|0;b=b|0;c=+c;hH(a-92|0,b,c)}function Ml(a){$i(a+724|0);$i(a+732|0);$i(a+740|0)}function En(a){a=a+170|0;return w[a|0]|w[a+1|0]<<8}function $$(a,b){a=a|0;b=b|0;return qH(a-88|0,b)|0}function xfa(a,b){a=a|0;b=b|0;if(!XC(a,b)){Dq(b)}}function vs(a){return(v[vb(a)>>2]-v[a>>2]|0)/52|0}function ut(a){return(v[vb(a)>>2]-v[a>>2]|0)/24|0}function uS(a){if(!(a&255)){return 1}return Kc(a)}function qC(a){return!Ib(a,26176,25)&w[a+34|0]<65}function lp(a,b){v[a+4>>2]=256;v[a>>2]=b;return a}function lk(a){return(v[vb(a)>>2]-v[a>>2]|0)/12|0}function lf(a){return ck(v[a>>2],v[a+4>>2])&65535}function iB(a){return(v[vb(a)>>2]-v[a>>2]|0)/28|0}function hE(a){return(a<<1)+16777216>>>0<16777217}function eT(a){return(v[vb(a)>>2]-v[a>>2]|0)/48|0}function cg(a,b){if(me(a)){Qd(a,b);return}ye(a,b)}function cQ(a){return(v[vb(a)>>2]-v[a>>2]|0)/56|0}function cC(a){return(v[vb(a)>>2]-v[a>>2]|0)/20|0}function bn(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function Zb(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function Yu(a){return(v[vb(a)>>2]-v[a>>2]|0)/36|0}function Xha(a,b){a=a|0;b=b|0;if(!nT(a,b)){Tt(b)}}function Vi(a){return jc(v[a+36>>2],v[a+40>>2])^1}function Ufa(a,b){a=a|0;b=b|0;if(!FR(a,b)){ER(b)}}function Rl(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function Ql(a,b,c){v[a+4>>2]=c;u[a>>1]=b;return a}function Og(a,b,c){b=v[b>>2];t[a+4|0]=c;v[a>>2]=b}function LF(a){return(Dj(a)|0)!=0|(a|32)-97>>>0<6}function Gp(a,b,c){return v[(b<<2)+a>>2]+(c<<2)|0}function Dea(a,b){a=a|0;b=b|0;if(!fu(a,b)){mu(b)}}function CR(a){return(v[vb(a)>>2]-v[a>>2]|0)/33|0}function vT(a,b){a=dT(a,b);if(!a){eB(b)}return a}function su(a,b){a=a|0;b=b|0;if(!Aq(a,b)){qq(b)}}function po(a,b,c){a=Vd(a);v[a+4>>2]=c;v[a>>2]=b}function pU(a,b){a=a|0;b=b|0;if(!LB(a,b)){nu(b)}}function kia(a,b){a=a|0;b=b|0;return $t(a,1,b)|0}function kS(a,b){a=a|0;b=b|0;return nq(a,b,32)|0}function kO(a,b){$b(a,v[b>>2]);t[a+4|0]=w[b+4|0]}function hA(a,b){a=a|0;b=b|0;if(!RR(a,b)){pA(b)}}function cO(a,b){v[a>>2]=v[a>>2]+(b<<1);return a}function b0(a,b){a=a|0;b=b|0;return+sH(a-88|0,b)}function ZL(a,b,c){v[a+4>>2]=c;t[a|0]=b;return a}function Uy(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function Sw(a,b){v[a>>2]=v[b>>2];Ac(a+4|0,b+4|0)}function St(a){return(v[vb(a)>>2]-v[a>>2]|0)/6|0}function Rt(a,b){Dl(a);v[a>>2]=88428;wv(a+4|0,b)}function R$(a,b){a=a|0;b=b|0;return+iH(a-92|0,b)}function Qn(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function P$(a,b){a=a|0;b=b|0;return+gH(a-92|0,b)}function JK(a){return B(Qj(a),En(a))+7>>>3&65535}function H8(a,b){a=a|0;b=b|0;if(!fD(a,b)){iv(b)}}function Gy(a){return(v[vb(a)>>2]-v[a>>2]|0)/7|0}function Eb(a){if(me(a)){return v[a>>2]}return a}function EB(a,b){a=a|0;b=b|0;if(!nD(a,b)){mD(b)}}function DS(a,b){v[a>>2]=v[a>>2]+B(b,6);return a}function $p(a,b){a=a|0;b=b|0;if(!Kh(a,b)){nl(b)}}function $S(a,b){a=a|0;b=b|0;if(!_S(a,b)){Qt(b)}}function zt(a){ec(a+88|0);ec(a+68|0);ec(a+48|0)}function zb(a,b){return Kt(v[b>>2],v[a>>2])?b:a}function yG(a,b){if(!a){return 0}return ow(a,b)}function uy(a){if(w[a+24|0]){gM(a);t[a+24|0]=0}}function tG(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function s6(a){a=a|0;return z[a+4220>>2]<C(1)|0}function q5(a){a=a|0;qJ(a);ax(a);t[a+4202|0]=1}
function mk(a){return eb[v[v[a>>2]+36>>2]](a)|0}function jd(a,b){return Io(v[b>>2],v[a>>2])?b:a}function gx(a,b){return Ct(z[a>>2],z[b>>2])?b:a}function fR(a){var b=0;b=v[a>>2];Fe(a);return b}function el(a){return Wt(wc(v[a>>2],v[a+4>>2]))}function dq(a,b,c){if(b){Jb(a,rg(c),b)}return a}function dj(a){return $f(v[a>>2],v[a+4>>2])&255}function Yha(a,b,c){a=a|0;b=b|0;c=c|0;MB(a,b,c)}function Wp(a,b,c){b=b-a|0;if(b){Wi(c-b|0,a,b)}}function Us(a,b){a=a|0;b=b|0;Rf(a,b);return a|0}function Ug(a,b){a=a|0;b=b|0;CB(a,v[a+16>>2]|b)}function UU(a,b){a=a|0;b=b|0;pp(a,b);return a|0}function Qm(a){return eb[v[v[a>>2]+28>>2]](a)|0}function Pc(a,b){return Kt(v[a>>2],v[b>>2])?b:a}function Ne(a,b){return wm(x[a>>1],x[b>>1])?b:a}function N5(a){a=a|0;return z[a+4212>>2]<C(1)|0}function Lc(a,b){return wm(x[b>>1],x[a>>1])?b:a}function JR(a){return!Ib(a,13852,4)&w[a+4|0]<32}function El(a,b){return Ct(z[b>>2],z[a>>2])?b:a}function Ee(a,b){return Io(v[a>>2],v[b>>2])?b:a}function EE(a){var b=0,c=0;b=a,c=gd(),v[b>>2]=c}function zA(a,b,c){a=a|0;b=b|0;c=c|0;JB(a,b,c)}function tO(a){v[a>>2]=0;v[a+4>>2]=-1;return a}function tB(a){return!Ib(a,15422,4)&w[a+4|0]<4}function oo(a){DD(a);v[a+8>>2]=0;v[a>>2]=85396}function mea(a,b){a=a|0;b=b|0;return qQ(a,b)|0}function jz(a){return a>>>0<=45?w[a+43840|0]:0}function ih(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function g6(a){a=a|0;t[a+4202|0]=1;CJ(a);EJ(a)}function eX(a,b,c){a=a|0;b=b|0;c=c|0;Zb(a,c,b)}function du(a,b,c){a=a|0;b=b|0;c=c|0;kB(a,b,c)}function df(a,b,c){if(!(w[a|0]&32)){ou(b,c,a)}}function Wf(a,b,c){a=pia(a,b,c,c>>31);return a}function Ts(a){return(a>>>0<9?a:a-9|256)&65535}function Tj(a,b){return(B(b,104)+a|0)+484380|0}function HN(a){Py(a);Jb(a+27|0,0,255);return a}function Fr(a,b){return(a&255)>>>0<(b&255)>>>0}function A1(a,b){a=a|0;b=b|0;Ac(a,Vq(b,17587))}function $5(a){a=a|0;t[a+4202|0]=1;zJ(a);yJ(a)}function wk(a,b){a=a|0;b=b|0;return gG(a,b)|0}function ur(a,b){a=a|0;b=b|0;return gG(a,b)^1}function tP(a){return xe(443250/+(a>>>0)*1e4)}function tD(a){a=a|0;v[a>>2]=43128;return a|0}function sT(a){t[a+12|0]=w[a+12|0]|2;return a}function sD(a){a=a|0;v[a>>2]=42888;return a|0}function ria(a,b,c,d){a=mia(a,b,c,d);return a}function qx(a){return v[vb(a)>>2]-v[a>>2]>>11}function pb(a){if(me(a)){xb(v[a>>2])}return a}function mc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function lg(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function lW(a,b){a=a|0;b=b|0;return ZD(a,b)|0}function lG(a){a=a|0;hw(v[v[a>>2]-12>>2]+a|0)}function jv(a,b){a=a|0;b=b|0;return Vq(a,b)|0}function i8(a,b){a=a|0;b=b|0;Wx(wK(a+24|0,b))}function cG(a){a=a|0;ew(v[v[a>>2]-12>>2]+a|0)}function b$(a){a=a|0;ZF(v[v[a>>2]-12>>2]+a|0)}function Yr(a){return x[v[a+24>>2]+480192>>1]}function Xr(a){return x[v[a+24>>2]+480190>>1]}function Xk(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function Xb(a){if(v[a>>2]){uc(a);xb(v[a>>2])}}function Vd(a){v[a>>2]=0;v[a+4>>2]=0;return a}function Uv(a,b,c){a=wF(a,b,c,-1,-1);return a}function Tw(a){a=a|0;v[a>>2]=49276;return a|0}function Qr(a,b){a=a|0;b=b|0;return yD(a,b)|0}function Qb(a,b){return Fr(w[b|0],w[a|0])?b:a}function PH(a){a=a|0;v[a>>2]=57808;return a|0}function Mo(a){return x[v[a+24>>2]+480188>>1]}function MH(a){a=a|0;v[a>>2]=57308;return a|0}function KR(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function Jh(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function JE(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function Gh(a){return jc(v[a>>2],v[a+4>>2])^1}function Eo(a,b){a=a|0;b=b|0;return kG(a,b)^1}function Cj(a,b){a=a|0;b=b|0;return kG(a,b)|0}function BD(a){a=a|0;v[a>>2]=58228;return a|0}function $e(a,b){return Fr(w[a|0],w[b|0])?b:a}function $_(a){a=a|0;YF(v[v[a>>2]-12>>2]+a|0)}function xh(a,b,c,d){return(B(b,d)+c<<2)+a|0}function vf(a){return v[a+8>>2]-v[a+12>>2]|0}function um(a){return v[vb(a)>>2]-v[a>>2]>>1}function rF(a,b,c){$b(a,b);$b(a+4|0,v[c>>2])}function oJ(a){return C(C(a*C(19980))+C(20))}function mz(a){return v[vb(a)>>2]-v[a>>2]>>8}function lx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function ko(a,b,c,d){a=pia(a,b,c,d);return a}function iz(a){return v[ic(a)>>2]-v[a>>2]>>2}function iS(a,b){a=a|0;b=b|0;return(b|0)<6|0}function gh(a){return v[v[a+8>>2]>>2]==(a|0)}function gR(a){if(a){YG(a);ne(v[a+80>>2],a)}}function dE(a){a=Ga(a|0)|0;db=O()|0;return a}function cx(a){return C(C(a*C(7900))+C(100))}function cr(a){return v[vb(a)>>2]-v[a>>2]>>4}function bR(a,b,c,d){return(B(b,d)+c<<1)+a|0}function Mn(a){return v[vb(a)>>2]-v[a>>2]>>5}function L0(a){a=a|0;SH(a);return v[a+16>>2]}function K$(a){a=a|0;return Fa(v[a+60>>2])|0}function Ig(a){a=a&255;return(a|0)==255?-1:a}function Hg(a,b,c,d){return(B(b,d)+c<<3)+a|0}function Fm(a){return v[vb(a)>>2]-v[a>>2]>>3}function Es(a){jp(a+223860|0);Xb(a+223848|0)}function Ch(a){return v[vb(a)>>2]-v[a>>2]>>2}function $w(a){return C(C(a*C(1e4))+C(-1e4))}function $L(a){t[a+24|0]=0;t[a|0]=0;return a}function zn(a,b,c){b=b-a|0;if(b){Wi(c,a,b)}}function vl(a){a=a|0;gw(v[a>>2]);return a|0}function r6(a){a=a|0;return C(z[a+4212>>2])}function oI(a,b){a=a|0;b=b|0;return Td(b)|0}function jf(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function jI(a){t[a+4|0]=0;t[a|0]=0;return a}function is(a){vJ(a);v[a>>2]=74608;return a}function ij(a,b){return a<<16>>16<b<<16>>16}function dg(a,b,c){if(c){gc(a,b,c)}return a}function dJ(a){return Ah(C(fJ(a)*C(32768)))}function _j(a,b,c){if(c){Wi(a,b,c)}return a}function XS(a,b){v[a>>2]=v[a>>2]+b;return a}function Vs(a,b,c){t[a|0]=b;t[a+1|0]=w[c|0]}function Vk(a,b){return a<<24>>24<b<<24>>24}function Td(a){return nc(v[a>>2],v[a+4>>2])}function Sm(a){a=a|0;eG(v[a>>2]);return a|0}function RF(a){vJ(a);v[a>>2]=74832;return a}function Qg(a,b){return Tb(v[a>>2],v[b>>2])}function M5(a){a=a|0;return C(z[a+4220>>2])}function M0(a){a=a|0;SH(a);return v[a+4>>2]}function LE(a,b,c){return no(KE(a),KE(b),c)}function Kb(a){return ie(v[a>>2],w[a+16|0])}function JJ(a){a=a|0;return C(z[a+4208>>2])}function Do(a){return v[vb(a)>>2]-v[a>>2]|0}function $h(a,b){a=a|0;b=b|0;return C(C(0))}function v7(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function t$(a){a=a|0;return nh(a,463504)|0}function ok(a,b){eb[v[v[b>>2]+44>>2]](a,b)}function nt(a){Be(a+24|0);Xb(a+12|0);Xb(a)}function nk(a,b){eb[v[v[b>>2]+32>>2]](a,b)}function k$(a){a=a|0;return nh(a,463520)|0}function iJ(a){return C(C(a*C(96))+C(-96))}function gk(a){return v[a+8>>2]&2147483647}function fw(a){a=a|0;return nh(a,463684)|0}function fP(a,b,c,d){Zb(a,b,(d|0)==-1?c:d)}function dr(a,b){eb[v[v[b>>2]+40>>2]](a,b)}function bw(a){a=a|0;return nh(a,463700)|0}function Xv(a){a=a|0;return nh(a,463708)|0}function Xl(a){az(v[a+20>>2]);v[a+20>>2]=0}function Tu(a,b,c){a=oia(c,0,a,b);return a}function Sv(a){a=a|0;return nh(a,463732)|0}function Q6(a,b,c){a=a|0;b=b|0;c=c|0;Vd(a)}function Nv(a){a=a|0;return nh(a,463740)|0}function Lk(a){pb(a+36|0);ec(a+24|0);Eh(a)}function Ku(a){a=a|0;return nh(a,463692)|0}function Kr(a){return(a|0)<=65535&(a|0)>=0}function IB(a){return w[a+1|0]==2&w[a|0]<3}function GV(a){a=a|0;return v[a+4>>2]!=0|0}function GG(a,b){return C(FG(a?C(-b):b)*b)}function Fq(a){Pq(a+32|0);qb(a+12|0);pb(a)}function BJ(a){return C(C(a*C(60))+C(-60))}function yD(a,b){return Op(a,Eb(b),ub(b))}function vr(a){a=a|0;Jk(a+8|0);return a|0}function vG(a,b){t[a|0]=b+48;return a+1|0}function tr(a){a=a|0;Jk(a+4|0);return a|0}function te(a){v[a>>2]=v[a>>2]+4;return a}function k0(a,b){a=a|0;b=b|0;BH(a-88|0,b)}function jJ(a){a=a|0;Jb(a+4296|0,0,81928)}function j0(a,b){a=a|0;b=b|0;AH(a-88|0,b)}function b8(a,b){a=a|0;b=b|0;Rf(a,b+36|0)}function am(a,b){return v[a>>2]-v[b>>2]|0}function aO(a){v[a>>2]=v[a>>2]-2;return a}function Yg(a,b){v[a>>2]=v[b>>2];return a}function YX(a,b){a=a|0;b=b|0;Rf(a,b+16|0)}function X8(a,b){a=a|0;b=b|0;wj(a+40|0,b)}function X$(a,b){a=a|0;b=b|0;mH(a-88|0,b)}function VT(a,b){a=a|0;b=b|0;wj(a+12|0,b)}function U$(a,b){a=a|0;b=b|0;lH(a-92|0,b)}function T$(a,b){a=a|0;b=b|0;kH(a-92|0,b)}function QT(a,b){a=a|0;b=b|0;wj(a+36|0,b)}function PC(a){return(w[a+24|0]&16)>>>4|0}function Mm(a,b,c){pg(a,b,b+c|0);return a}function KM(a,b){if(z[a>>2]>b){z[a>>2]=b}}function Ju(a,b){return sia(a,(b|0)%32|0)}function Jr(a){a=a|0;Zr(a+8|0);return a|0}function IH(a,b){a=a|0;b=b|0;Rf(a,b+12|0)}function Fe(a){v[a>>2]=v[a>>2]+1;return a}function Dh(a){return x[a+480190>>1]<3999}function Cca(a){a=a|0;return Eq(a+20|0)|0}function Bf(a){a=a|0;Nh(a+8|0);return a|0}function Ak(a){a=a|0;return jG(a)<<24>>24}function v5(a){a=a|0;return v[a+4260>>2]}function uk(a){return(a|0)==32|a-9>>>0<5}function sr(a,b){v[a+24>>2]=v[a+24>>2]+b}function m0(a){a=a|0;return Jr(a-88|0)|0}function i0(a,b){a=a|0;b=+b;zH(a-88|0,b)}function hk(a){return B(xm(a),qd(a))&255}function g0(a,b){a=a|0;b=+b;xH(a-88|0,b)}function e0(a,b){a=a|0;b=+b;vH(a-88|0,b)}function dd(a,b){return io(v[a+12>>2],b)}function dc(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function cN(a,b,c){v[a>>2]=b;v[a+4>>2]=c}function aj(a,b){return v[a>>2]!=v[b>>2]}function XX(a,b){a=a|0;b=b|0;Bv(a,80184)}function WX(a,b){a=a|0;b=b|0;Bv(a,80204)}function W$(a){a=a|0;return Jr(a-92|0)|0}function Sfa(a,b){a=a|0;b=b|0;nq(a,b,17)}function SX(a,b){a=a|0;b=b|0;Mb(a,11254)}function RX(a,b){a=a|0;b=b|0;Mb(a,11371)}function PJ(a){return(w[a+24|0]&8)>>>3|0}function Lf(a,b){v[a+8>>2]=b|-2147483648}function FD(a,b){cc(a,b);cc(a+4|0,b+4|0)}function DD(a){v[a+4>>2]=0;v[a>>2]=87956}function D6(a){a=a|0;t[a+4202|0]=1;NJ(a)}function BI(a){return(Eb(a)+ub(a)|0)-1|0}function $i(a){u[a+4>>1]=65535;v[a>>2]=0}function vE(a,b){a=a|0;b=b|0;return b|0}function u7(a){a=a|0;return w[a+4201|0]}function tU(a,b){a=a|0;b=b|0;nq(a,b,11)}function t7(a){a=a|0;return w[a+4202|0]}function rw(a){return(p(a),j(2))>>>20|0}function lm(a,b){return lf(a)>>>0>b>>>0}function ZP(a,b,c,d){return Xk(c,d,a,b)}function X4(a){a=a|0;return(a|0)==277|0}function Vh(a,b,c){Ac(a,b);Ac(a+12|0,c)}function UE(a,b){a=a|0;b=b|0;ze(a,1,45)}function TE(a,b){a=a|0;b=b|0;cF(a,1,45)}function Rfa(a,b){a=a|0;b=b|0;OB(a,b,8)}function RL(a,b){return(Rk(a,b)|0)!=255}function MI(a){v[a+4>>2]=v[a+4>>2]|8192}function Lj(a,b){return ry(a&255,b&255)}function Dm(a){a=v[a+8>>2];if(a){xb(a)}}function By(a,b,c){return a<b?b:a>c?c:a}function Ay(a,b,c){return a<b?b:a>c?c:a}function Ab(a){return(a<<8|a>>>8)&65535}function $P(a,b,c,d){return ZP(a,b,c,d)}function yI(a){return a?(a|0)==2?3:2:1}function xd(a){v[v[a+8>>2]>>2]=v[a>>2]}function x5(a){a=a|0;if(a){bx(a)}xb(a)}function sV(a){a=a|0;return v[a+16>>2]}function ov(a,b){v[a+4>>2]=4;v[a>>2]=b}function nx(a){a=a|0;if(a){To(a)}xb(a)}function nU(a){a=a|0;return v[a+12>>2]}function m6(a){a=a|0;if(a){ex(a)}xb(a)}function l7(a){a=a|0;if(a){jx(a)}xb(a)}function jca(a){a=a|0;OP(a);return a|0}function h0(a){a=a|0;return+yH(a-88|0)}function f5(a){a=a|0;return-2013527448}function f0(a){a=a|0;return+wH(a-88|0)}function er(a){a=a|0;return 2147483647}function de(a,b,c){Zm(a,b,Ic(b,c)+b|0)}function d0(a){a=a|0;return+uH(a-88|0)}function cs(a){a=a|0;if(a){ff(a)}xb(a)}function Ui(a,b){v[a+4>>2]=1;v[a>>2]=b}function Tq(a,b){v[a+4>>2]=3;v[a>>2]=b}function Q5(a){a=a|0;if(a){gs(a)}xb(a)}function Mj(a,b){return Eb(a)+(b<<2)|0}function Fj(a){return(v[a+16>>2]&5)!=0}function Di(a,b){v[a+4>>2]=2;v[a>>2]=b}function AD(a,b){zD(a,b);v[a>>2]=88708}function y6(a){a=a|0;return-270114148}function wr(a,b){a=a|0;b=b|0;return-1}function w5(a){a=a|0;return-275227023}function uA(a,b){return wm(a,x[b>>1])}function tA(a,b){return wm(x[a>>1],b)}function sq(a){a=a|0;return v[a+4>>2]}function qD(a,b,c){Ub(a,b,Ag(b,c)<<3)}function me(a){return w[a+11|0]>>>7|0}function mK(a,b){return ij(a,x[b>>1])}function m5(a){a=a|0;return 302837129}function lK(a,b){return ij(x[a>>1],b)}function l6(a){a=a|0;return-285139079}function kG(a,b){return iG(a)^iG(b)^1}function k7(a){a=a|0;return 542066252}function jj(a,b){return ie(v[a>>2],b)}function gG(a,b){return fG(a)^fG(b)^1}function fj(a){return(a-1&255)>>>0<17}function ee(a,b,c){rF(a,b,c);return a}function d6(a){a=a|0;return-284078960}function _l(a){return(a&740327453)!=0}function _4(a,b){a=a|0;b=b|0;return 3}function YM(a,b){a=a|0;b=b|0;return 0}function Y5(a){a=a|0;return-281111764}function Y4(a,b){a=a|0;b=b|0;return 2}function Xn(a,b){u[a+8>>1]=b;return a}function WF(a){a=a|0;$v(a);return a|0}function Rh(a){a=v[a>>2];if(a){yF(a)}}function Rb(a,b){return Nf(v[a>>2],b)}function P5(a){a=a|0;return-271958638}function Oh(a,b){mi(a,Pd(b));return a}function Nh(a){a=a|0;wD(a);return a|0}function L_(a){a=a|0;return NF(a,0)|0}function LR(a,b,c){Ub(a,b,nc(b,c)<<2)}function K_(a){a=a|0;return NF(a,1)|0}function Jk(a){a=a|0;jw(a);return a|0}function Ht(a,b){a=a|0;b=b|0;return 1}function H_(a){a=a|0;return MF(a,0)|0}function H5(a){a=a|0;return-620920304}function H0(a){a=a|0;return w[a+40|0]}function Gd(a,b){return io(v[a>>2],b)}function G_(a){a=a|0;return MF(a,1)|0}function Dt(a){a=a|0;return Hb(a,1)^1}function DM(a,b){return(0-b|0)!=(a|0)}function DH(a){v[a>>2]=59024;return a}function CH(a){v[a>>2]=59104;return a}function CD(a){a=a|0;return v[a+8>>2]}function Ae(a,b){v[a+4>>2]=b;return a}function $v(a){a=a|0;Mq(a);return a|0}function $I(a){a=C(a-a);return C(a/a)}function tq(a,b){a=a|0;b=b|0;Xu(a,b)}function rL(a,b,c,d,e){qL(a,b,c,d,e)}function qA(a,b){a=a|0;b=b|0;ZI(a,b)}function ph(a,b){a=a|0;b=b|0;mn(a,b)}function oj(a){return x[a+480188>>1]}function my(a,b){return Fr(a,w[b|0])}function mn(a,b){a=a|0;b=b|0;ch(a,b)}function mM(a){return(a+5&255)>>>0<2}function ly(a,b){return Fr(w[a|0],b)}function kM(a,b){a=a|0;b=b|0;ZM(a,b)}function gJ(a){v[a>>2]=0;v[a+4>>2]=0}function eP(a,b){return B(b,872)+a|0}function ch(a,b){a=a|0;b=b|0;Rf(a,b)}function at(a){return v[vb(a)>>2]<<5}function _D(a,b){a=a|0;b=b|0;rp(a,b)}function XJ(a,b,c){a=a|0;b=b|0;c=c|0}function UX(a){a=a|0;return t[a+8|0]}function TX(a){a=a|0;return t[a+9|0]}function TQ(a,b){if(!NQ(a,b)){Iz(b)}}function Sg(a){Vj(a+44|0);Xb(a+32|0)}function Qw(a){return Ig(w[a+140|0])}function Oca(a){a=a|0;return ji(a)|0}function OI(a,b,c,d,e){QI(a,b,c,d,e)}function N6(a,b){a=a|0;b=b|0;Us(a,b)}function Mha(a){a=a|0;return VS(a)|0}function Lt(a,b){return w[a+b|0]!=63}function LP(a){return(a|0)<120?a:120}function JV(a){a=a|0;QC(Eb(a),ub(a))}function GO(a,b,c,d){DO(Zb(a,b,c),d)}function Cx(a,b){a=a|0;b=b|0;EK(a,b)}function C0(a){a=a|0;return w[a+8|0]}function Bm(a){v[a+4>>2]=v[a+4>>2]+1}function $V(a,b){a=a|0;b=b|0;bE(a,b)}function yY(){Wd(465224,Od(463552))}function y9(a){a=a|0;return jk(a)|0}function wY(){Wd(465240,Od(463560))}function vY(){Wd(465256,Od(463632))}function uw(a){return!Ib(a,89324,6)}function ug(a){return wb(v[a+4>>2])}function uY(){Wd(465264,Od(463640))}function tg(a,b){return B(b,20)+a|0}function sF(a,b){rF(a,0,b);return a}function qB(a){a=a|0;return pc(a)|0}function ps(a,b){return B(b,28)+a|0}function mq(a){a=a|0;return ue(a)|0}function ld(a,b){return B(b,12)+a|0}function lV(a){a=a|0;gD(Jb(a,0,36))}function l$(a){a=a|0;return yk(a)|0}function jt(a,b){return B(b,36)+a|0}function jp(a){if(w[a+24|0]){gM(a)}}function jc(a,b){return(a|0)==(b|0)}function fq(a,b){return(b-a|0)/28|0}function en(a,b){return(b-a|0)/24|0}function ck(a,b){return(b-a|0)/52|0}function ap(a){return mT(a,251,255)}function ad(a,b){return(b-a|0)/12|0}function _k(a,b){return B(b,24)+a|0}function Zp(a,b){return(b-a|0)/48|0}function Yf(a){return C(D(a))==C(N)}function YY(){Wd(464960,Od(463488))}function XY(){Wd(464968,Od(463496))}function WY(){Wd(464976,Od(463692))}function VY(){Wd(464992,Od(463684))}function Uz(a,b){return le(a,0-b|0)}function TT(a){a=a|0;return Eq(a)|0}function SY(){Wd(465008,Od(463708))}function RY(){Wd(465024,Od(463716))}function QY(){Wd(465032,Od(463724))}function Q8(a){a=a|0;return di(a)|0}function PY(){Wd(465040,Od(463732))}function PV(a){a=a|0;return jg(a)|0}function OY(){Wd(465064,Od(463740))}function OC(a){a=a|0;return xg(a)|0}function Nu(a){t[a+2|0]=0;u[a>>1]=0}function Np(a){return(a&255)==1?1:2}function Nf(a,b){return B(b,52)+a|0}function NY(){Wd(465096,Od(463504))}function MY(){Wd(465104,Od(463512))}function LY(){Wd(465112,Od(463520))}function Kt(a,b){return a>>>0<b>>>0}function KY(){Wd(465120,Od(463528))}function JY(){Wd(465128,Od(463568))}function IY(){Wd(465136,Od(463576))}function HY(){Wd(465144,Od(463584))}function HR(a,b){return B(b,33)+a|0}function Gq(a,b){return(b-a|0)/36|0}function GY(){Wd(465152,Od(463592))}function FY(){Wd(465160,Od(463600))}function FM(a){return zd(w[a+24|0])}function FA(a,b,c){return Jt(a,b,c)}function Ep(a,b){return(b-a|0)/56|0}function Ef(a,b){return(b-a|0)/20|0}function EY(){Wd(465168,Od(463608))}function DY(){Wd(465176,Od(463616))}function Ci(a,b,c){return no(a,b,c)}function CY(){Wd(465184,Od(463624))}function C5(a){a=a|0;v[a+4224>>2]=0}function Bt(a,b){return(b-a|0)/33|0}function BY(){Wd(465192,Od(463536))}function Az(a,b){return B(b,56)+a|0}function AY(){Wd(465208,Od(463544))}function $b(a,b){v[a>>2]=b;return a}function zS(a){return w[a+1|0]!=63}function wq(a){return(a&128)>>>7|0}function ud(a,b){return B(b,6)+a|0}function uI(a){return(Ig(a)|0)==-1}function sI(a,b){a=a|0;b=b|0;Xb(b)}function rh(a,b){a=a|0;b=b|0;Bb(a)}function rI(a,b){a=a|0;b=b|0;ec(b)}function qq(a){t[a|0]=0;t[a+1|0]=0}function qe(a,b){Zb(a,Eb(b),ub(b))}function os(a,b){return(a-b|0)/6|0}function nM(a){Ud(a+8|0);fM(a+4|0)}function mj(a,b){return B(hk(b),a)}function io(a,b){return(b<<11)+a|0}function id(a){return v[a>>2]+16|0}function gn(a){Dl(a);v[a>>2]=88368}function dn(a,b){v[a+1298464>>2]=b}function dW(a){a=a|0;Gm(a,1,13423)}function d8(a){a=a|0;nq(a,21598,1)}function cw(a){return jc(a,-1)?0:a}function bj(a,b){return(b<<13)+a|0}function _h(a){a=a|0;t[a+4202|0]=0}function Yj(a,b){return(b-a|0)/6|0}function Ve(a,b){dh(a);$b(a+4|0,b)}function UY(){Wd(465e3,Od(463700))}function RK(a){return zd(w[a+4|0])}function RE(a){return nh(a,463576)}function QE(a){return nh(a,463568)}function OE(a){return nh(a,463592)}function Nd(a){DD(a);v[a>>2]=80440}function NE(a){return nh(a,463584)}function N$(a,b){a=a|0;b=b|0;xb(b)}function Jp(a){return v[a>>2]+14|0}function Io(a,b){return(a|0)<(b|0)}function Hy(a,b){return(b-a|0)/7|0}function Hl(a){return C(D(a))<C(N)}function Gk(a,b){return(a+b|0)-1|0}function $g(a,b){v[a>>2]=v[a>>2]|b}function yf(a,b){mi(a,b);return a}function xf(a){return a!=a?C(0):a}function vg(a){return wb(v[a>>2])}function sn(a){return a+1074328|0}function qv(a,b){return v[a+b>>2]}function pL(a){v[a>>2]=v[a>>2]+52}function pJ(a){return C(a*C(100))}function oc(a,b){return Eb(a)+b|0}function mh(a){v[a>>2]=1;return a}function jh(a){v[a>>2]=v[a>>2]+20}function ie(a,b){return(b<<5)+a|0}function ep(a){Xb(a+4|0);return a}function em(a){v[a>>2]=v[a>>2]+28}function dm(a){v[a>>2]=2;return a}function dh(a){v[a>>2]=0;return a}function bc(a,b){xD(a,b);return a}function bX(a){a=a|0;return 13112}function az(a){if(a){xb(a+-64|0)}}function ae(a,b){return!Ib(a,b,4)}function _y(a){v[a>>2]=v[a>>2]+32}function __(a){a=a|0;return 10367}function Yb(a,b){return(b<<1)+a|0}function Vda(a){a=a|0;rR(a,65535)}function Ul(a,b){return(b<<8)+a|0}function UB(a){return w[a+1|0]==1}function Tb(a,b){return jc(a,b)^1}function Sp(a,b){return ge(a,b)^1}function Sn(a){v[a>>2]=v[a>>2]+12}function Rw(a,b){return LK(a,b)^1}function Qu(a){return t[a+24|0]&1}function Ol(a){u[a>>1]=0;return a}function Of(a,b){return Qc(a,b,0)}function Kd(a){return v[ac(a)>>2]}function Kc(a){return mT(a,1,120)}function KH(a){v[a>>2]=v[a>>2]+24}function In(a){v[a>>2]=v[a>>2]+16}function Hw(a){return a+1298408|0}function He(a,b){return(b<<3)+a|0}function Hc(a,b){return(b<<4)+a|0}function HW(a){a=a|0;return 12998}function Fb(a,b){return(b<<2)+a|0}function Dj(a){return a-48>>>0<10}function $W(a){a=a|0;return 10247}function uo(a){a=a|0;bB(a);xb(a)}function ui(a){v[a>>2]=v[a>>2]+6}function uh(a){return!v[a+16>>2]}function td(a){return v[a>>2]!=0}function sR(a,b){gc(a,b+4|0,256)}function ds(a){a=a|0;ff(a);xb(a)}function bq(a){return Jb(a,0,48)}function av(a){a=a|0;Mq(a);xb(a)}function WW(a){a=a|0;return 6827}function U1(a){a=a|0;Tw(a);xb(a)}function TF(a){v[a+72>>2]=462504}function Se(a,b,c,d){_e(a,c,d,b)}function SF(a){v[a+72>>2]=462588}function R5(a){a=a|0;gs(a);xb(a)}function Qs(a){v[a>>2]=v[a>>2]+8}function QF(a){a=a|0;Fo(a);xb(a)}function OF(a){a=a|0;Fl(a);xb(a)}function NV(a){a=a|0;QC(a,Pf(a))}function N0(a){a=a|0;UH(a);xb(a)}function Ke(a){v[a>>2]=v[a>>2]+2}function JP(a){return w[a|0]<129}function JI(a){a=a|0;Uw(a);xb(a)}function IW(a){a=a|0;return 9806}function Gg(a,b,c){Zm(a,b,b+c|0)}function EW(a){a=a|0;return 5681}function D0(a){a=a|0;NH(a);xb(a)}function Cy(a){t[a|0]=0;return a}function $8(a){a=a|0;mf(a,ej(a))}function zi(a,b){return Eu(a,b)}function zd(a){return(a&255)!=0}function yh(a,b){return Fb(a,b)}function xe(a){return Up(be(a))}function vk(a,b,c){Zb(a,b,1<<c)}function tF(a,b){return ad(a,b)}function sj(a,b){return b-a>>11}function sb(a,b){return(a&b)!=0}function qb(a){Cd(a+12|0);Cd(a)}function pf(a){pb(a+20|0);pb(a)}function of(a){mi(a,0);return a}function lj(a,b,c){_e(a,c,20,b)}function l0(a){a=a|0;Fw(a-88|0)}function ip(a){oN(a+12|0);nN(a)}function hn(a){return a<<24>>24}function hi(a,b){return Ic(a,b)}function hB(a,b){return fm(b,a)}function gl(a,b,c){_e(a,c,22,b)}function gi(a,b){return(a|b)!=0}function gM(a){eM(a+12|0);dM(a)}function fr(a){a=a|0;return 127}function dl(a,b,c){_e(a,c,28,b)}function cu(a,b,c){_e(a,c,30,b)}function bf(a){a=a|0;return a|0}function Zj(a,b,c){_e(a,c,12,b)}function Xf(a){return Bh(a)?0:a}function We(a,b){return hg(a,b)}function VK(a,b){return TK(a,b)}function V$(a){a=a|0;Fw(a-92|0)}function Uk(a){pb(a+12|0);_c(a)}function US(a,b){return TA(b,a)}function Tl(a){return Sl(be(a))}function Sf(a){return hn(rg(a))}function SR(a,b){Zm(a,b,b+16|0)}function Qe(a,b,c){_e(a,c,32,b)}function Pl(a){pb(a+12|0);pb(a)}function Lg(a){return mM(a&255)}function Ks(a,b){return Ey(a,b)}function Jv(a,b){return Jg(a,b)}function Iy(a,b){return wc(a,b)}function Ii(a,b){return a>>>b&1}function Hu(a,b){return AC(a,b)}function Hh(a,b,c){_e(a,c,13,b)}function Gz(a,b,c){_e(a,c,64,b)}function FH(a,b){return Ag(a,b)}function Ev(a){return vb(a+8|0)}function CC(a,b){return zC(a,b)}function AF(a){if(BF(a)){xb(a)}}function $z(a,b){return nc(a,b)}function $o(a){u[a+480214>>1]=0}function z6(a){a=a|0;xb(gs(a))}function yt(a,b){return a-b>>2}function y5(a){a=a|0;xb(bx(a))}function y0(a){a=a|0;xb(MH(a))}function xV(a){a=a|0;xb(uD(a))}function x$(a){a=a|0;xb(Fo(a))}function wc(a,b){return b-a>>1}function uG(a){a=a|0;xb(Jk(a))}function u5(a){a=a|0;return 13}function ry(a,b){return a<<8|b}function rX(a){a=a|0;xb(uE(a))}function qd(a){return a&64?2:1}function q1(a){a=a|0;xb(Tr(a))}function ox(a){a=a|0;xb(To(a))}function oV(a){a=a|0;xb(tD(a))}function ne(a,b){if(!a){xb(b)}}function nc(a,b){return b-a>>2}function n6(a){a=a|0;xb(ex(a))}function md(a,b){t[a|0]=w[b|0]}function mV(a){a=a|0;xb(sD(a))}function m7(a){a=a|0;xb(jx(a))}function lt(a){return a>>>27^a}function jX(a){a=a|0;xb(tE(a))}function hw(a){a=a|0;xb(vr(a))}function gP(a){return a+4096|0}function fm(a,b){return a-b>>1}function ez(a){return a+4896|0}function ew(a){a=a|0;xb(tr(a))}function eh(a,b){return b-a>>8}function e$(a){a=a|0;xb(es(a))}function ZX(a){a=a|0;xb(CE(a))}function ZF(a){a=a|0;xb(Ro(a))}function YF(a){a=a|0;xb(ef(a))}function X_(a){a=a|0;xb(WF(a))}function XW(a){a=a|0;xb($v(a))}function Vb(a,b){v[a+100>>2]=b}function V_(a){a=a|0;xb(jw(a))}function VX(a){a=a|0;xb(BE(a))}function Tm(a){return(a|0)==-1}function S1(a){a=a|0;xb(Uw(a))}function KX(a){a=a|0;xb(AE(a))}function GW(a){a=a|0;xb(bB(a))}function GC(a){return pc(a<<2)}function Fw(a){a=a|0;xb(Jr(a))}function FW(a){a=a|0;xb(Mq(a))}function F0(a){a=a|0;xb(PH(a))}function DE(a){a=a|0;xb(Cv(a))}function Cg(a,b){return b-a>>4}function B$(a){a=a|0;xb(Fl(a))}function Ag(a,b){return b-a>>3}function AV(a){a=a|0;xb(BD(a))}function $f(a,b){return b-a>>5}function zq(a,b){_e(a,b,26,3)}function zc(a,b){Qo(a,b+28|0)}function xm(a){return a&1?2:1}function xB(a,b){Ub(a,b,1954)}function re(a){a=a|0;return 1}function rQ(a,b){Ub(a,b,1108)}function qG(a){a=a|0;return-1}function pe(a){a=a|0;return 2}function nw(){return fb()<<16}function nA(a,b){Ub(a,b,4896)}function ms(a){a=a|0;return 4}function k6(a){a=a|0;return 6}function i7(a){a=a|0;return 9}function hX(){Qo(463668,YJ())}function fc(a){a=a|0;return 0}function fQ(a,b){_e(a,b,33,1)}function by(a){bD(a);return a}function bo(a){return a>>>0<5}function Ye(a){Pb(a);return a}function Vr(a,b){v[a+32>>2]=b}function V4(){return 19923456}function Ue(a){return D(a)==N}function TA(a,b){return a-b|0}function Re(a,b){u[a+28>>1]=b}function Pb(a){sd(a);return a}function Oj(a){return td(a)^1}function OJ(a){a=a|0;return 3}function NR(a){bq(Jb(a,0,48))}function LJ(a){a=a|0;return 7}function KS(a,b){_e(a,b,40,2)}function KK(a,b,c){Rl(a,b,-c)}function Jz(a,b){Ub(a,b,1024)}function Ic(a,b){return b-a|0}function FC(a){return(a|0)!=0}function Dk(a){return a+120|0}function Cb(a,b){return a+b|0}function Bn(a,b){v[a+36>>2]=b}function Bb(a){qE(a);return a}function Au(a){return!v[a>>2]}function Ap(a){dh(a);return a}function AJ(a){a=a|0;return 5}function $s(a){return a+256|0}function zp(a){return a+32|0}function ye(a,b){t[a+11|0]=b}function ws(a){uL(a,v[a>>2])}function wS(a,b){Ub(a,b,576)}function wO(a){return a+48|0}function wC(a,b){Ub(a,b,497)}function vj(a){return a-36|0}function vP(a,b){Ub(a,b,204)}function vJ(a){v[a>>2]=74636}function vI(a,b,c){tI(a,b,c)}function uc(a){Qd(a,v[a>>2])}function tS(a,b){Ub(a,b,674)}function so(a){return a+20|0}function se(a,b){a=a|0;b=b|0}function sN(a){return D(a)<N}function rr(a,b){Qo(a,b+4|0)}function nS(a){return a+36|0}function nI(a){v[a>>2]=49608}function mN(a){lN(a,v[a>>2])}function jq(a,b){Ub(a,b,192)}function ic(a){return a+12|0}function gm(a,b){_d(a,b+8|0)}function fv(a,b){HD(a,Pd(b))}function fk(a,b,c){no(a,b,c)}function eu(a,b){Ub(a,b,512)}function Zo(a,b){z[a+8>>2]=b}function Yo(a,b){z[a+4>>2]=b}function Yk(a,b,c){go(a,b,c)}function YP(a){return a-28|0}function YN(a){XN(a,v[a>>2])}function Xo(a,b){t[a+33|0]=b}function WP(a,b){Ub(a,b,146)}function Vz(a,b){iA(a,Pd(b))}function Ub(a,b,c){Zb(a,b,c)}function SP(a,b){Ub(a,b,608)}function Rr(a){v[a>>2]=54776}function Qd(a,b){v[a+4>>2]=b}function QN(a,b,c){op(a,c,b)}function PR(a,b){Ub(a,b,128)}function Mx(a,b){t[a+34|0]=b}function MQ(a,b){Ub(a,b,130)}function Lx(a,b){t[a+32|0]=b}function Lh(a,b,c){aD(a,b,c)}function Kx(a,b){t[a+35|0]=b}function KQ(a,b){Ub(a,b,600)}function KA(a,b){_e(a,b,8,2)}function Jy(a){t[a+6152|0]=0}function JH(a){return a-48|0}function IN(a,b,c){up(a,c,b)}function Hp(a,b){return a<<b}function Gw(a){return a-12|0}function Gl(a,b){v[a+8>>2]=b}function ES(a,b){Ub(a,b,218)}function EQ(a,b){Ub(a,b,126)}function Dl(a){v[a>>2]=89008}function Cm(a){v[a>>2]=57760}function CO(a,b){Ub(a,b,263)}function BS(a,b){Ub(a,b,157)}function AT(a,b){Ub(a,b,610)}function $K(a){return a-32|0}function yu(a,b){Ub(a,b,65)}function xu(a,b){Ub(a,b,16)}function xq(a){return a&127}function xR(a,b){Ub(a,b,52)}function wQ(a,b){Ub(a,b,32)}function wB(a){Jb(a,0,1954)}function vi(a){return a+3|0}function vb(a){return a+8|0}function sm(a,b){Zb(a,b,32)}function rg(a){return a&255}function rK(a){return 0-a|0}function px(a){Jb(a,0,2048)}function pd(a){return!ub(a)}function on(a){return a-4|0}function oC(a,b){Ub(a,b,38)}function nf(a,b){t[a+3|0]=b}function kA(a,b){Ub(a,b,33)}function jT(a,b){gc(a,b,48)}function jC(a,b){Ub(a,b,41)}function iQ(a,b){Ub(a,b,96)}function eo(a,b){t[a+1|0]=b}function dp(a){Jb(a,0,8192)}function ay(a){Jb(a,0,4096)}function ac(a){return a+4|0}function aA(a,b){Ub(a,b,40)}function Zt(a,b){Ub(a,b,64)}function Zn(a){v[a+12>>2]=0}function Zc(a){return a+1|0}function Yt(a,b){Ub(a,b,66)}function XA(a,b){Ub(a,b,12)}function Vp(){Co(10941);L()}function UQ(a,b){Ub(a,b,30)}function U4(){return 393217}function SB(a,b){Ub(a,b,11)}function QR(a,b){Ub(a,b,80)}function Ot(a,b){Ub(a,b,22)}function NB(a,b){Zb(a,b,20)}function Me(a){return a+2|0}function MS(a,b){Ub(a,b,98)}function Lu(a,b){Zb(a,b,22)}function LD(a,b){Ub(a,b,24)}function KB(a,b){Ub(a,b,17)}function JO(a,b){return a<b}function HS(a,b){Ub(a,b,48)}function H$(){return 459736}function GN(a,b){Ub(a,b,27)}function EH(a){v[a>>2]=59e3}function Df(){Oe(10941);L()}function Ct(a,b){return a<b}function Cq(a,b){Ub(a,b,36)}function zT(a){Jb(a,0,610)}function xt(a){cA(a,Kd(a))}function wi(a,b){u[a>>1]=b}function vS(a){Jb(a,0,576)}function vC(a){Jb(a,0,497)}function uq(a,b){Ub(a,b,1)}function uP(a){Jb(a,0,204)}function qh(a,b){Ub(a,b,4)}function qc(a){v[a+8>>2]=0}function qaa(){return ab|0}function qS(a){Jb(a,0,192)}function oN(a){qp(a,Kd(a))}function nn(a,b){z[a>>2]=b}function nd(a,b){v[a>>2]=b}function lz(a){Jb(a,0,256)}function ll(a,b){Ub(a,b,2)}function gz(){Oe(7636);L()}function gu(a,b){Ub(a,b,5)}function gS(a){sA(a,Kd(a))}function eS(a){vA(a,Kd(a))}function eM(a){Cs(a,Kd(a))}function dM(a){Ds(a,Kd(a))}function dA(a){bA(a,Kd(a))}function _n(a,b){Ub(a,b,7)}function _O(a){qz(a,Kd(a))}function XB(a,b){Lh(a,2,b)}function Wu(a,b){Ub(a,b,3)}function VP(a){Jb(a,0,146)}function Uq(a){a=a|0;Wq(a)}function Rj(a,b){go(a,b,0)}function RP(a){Jb(a,0,608)}function Qk(a){Fy(a,Kd(a))}function QA(a,b){Ub(a,b,6)}function Nb(a){Em(v[a>>2])}function NK(a){Ix(a,Kd(a))}function KJ(a,b){hK(a,3,b)}function JQ(a){Jb(a,0,600)}function Iz(a){Jb(a,0,130)}function Du(){Co(7636);L()}function Dc(a){a=a|0;xb(a)}function DQ(a){Jb(a,0,126)}function Bh(a){return a!=a}function Am(a,b){Ub(a,b,8)}function AU(a){a=a|0;Nh(a)}function AS(a){Jb(a,0,157)}function $O(a){pz(a,Kd(a))}function wR(a){Jb(a,0,52)}function vh(a,b){t[a|0]=b}function pA(a){Jb(a,0,80)}function nC(a){Jb(a,0,38)}function lA(a){Jb(a,0,33)}function jQ(a){Jb(a,0,96)}function iC(a){Jb(a,0,41)}function eB(a){Jb(a,0,66)}function a2(){return 2048}function W9(a){a=a|0;ab=a}function Qt(a){Jb(a,0,64)}function LS(a){Jb(a,0,98)}function IS(a){Jb(a,0,48)}function Dq(a){Jb(a,0,36)}function zg(a){a=a|0;L()}function vK(a,b){uL(a,b)}function rx(a,b){Oh(a,b)}function rc(a){Xb(a+8|0)}function pu(a,b){PB(a,b)}function ns(a,b){nn(a,b)}function nQ(a,b){_d(a,b)}function mi(a,b){$b(a,b)}function kN(a){Ud(a+8|0)}function jA(a,b){AR(a,b)}function fB(a,b){$j(a,b)}function cl(a){pb(a+4|0)}function _s(a){v[a>>2]=0}function _q(a,b){Ac(a,b)}function YB(a){u[a>>1]=0}function Wh(a,b){wh(a,b)}function WN(a,b){XN(a,b)}function Tc(a){qb(a+8|0)}function TN(a,b){Kf(a,b)}function PA(a,b){bc(a,b)}function Ls(a,b){bL(a,b)}function Im(a,b){CB(a,b)}function Hd(a,b){Qd(a,b)}function Et(a,b){VR(a,b)}function Dp(a,b){nd(a,b)}function Bj(a,b){vh(a,b)}function AB(a,b){rJ(a,b)}function rf(a){t[a|0]=0}function mE(a){t[a|0]=1}function Pfa(){xa();L()}function ys(a){wL(a,0)}function xs(a){vL(a,0)}function vv(){ya();L()}function hd(){gz();L()}function bl(a){iA(a,0)}function bg(a){fS(a,0)}function Zh(a){EI(a,0)}function Yh(a){CI(a,0)}function YK(a){zL(a,0)}function VW(){vv();L()}function Pq(a){HD(a,0)}function Lo(a){DI(a,0)}function Bc(a){Ce(a,0)}function yb(a){pb(a)}function sE(a){nF(a)}function lP(a){Pb(a)}function hP(a){te(a)}function gf(a){a=a|0}function fN(a){Fn(a)}function bS(a){Ap(a)}function aM(a){$L(a)}function Yq(a){ic(a)}function Uj(a){On(a)}function RI(a){Fe(a)}
// EMSCRIPTEN_END_FUNCS
e=w;var eb=c([null,Mb,Xq,Rf,RD,Gm,QV,NV,ID,JV,HV,UC,QU,NU,mm,Ug,yU,$,Ku,hl,bG,cp,km,Zha,bB,bf,fga,dga,Pfa,Mfa,Gfa,Xz,hfa,$ea,Xba,Gea,zQ,E$,D$,yr,gga,Cba,zQ,saa,maa,zN,rp,pp,L9,H9,BM,t9,qB,nL,Rf,Mb,RD,U8,mn,EK,Cx,ch,YJ,y7,r7,j7,iX,R6,J6,k$,j$,W_,mn,p5,rp,B4,t4,f3,X2,ch,t2,j2,V1,I1,E1,B1,x1,u1,m1,Qr,f1,a1,WH,Op,gw,xa,m$,v_,sW,rW,qW,pW,oW,nW,ph,mW,_D,lW,Qr,kW,ia,iW,hW,$q,ch,gW,fW,eW,TD,SD,dW,$q,cW,Hm,jv,Uq,wj,pl,af,ZV,Hm,$V,_V,YV,bW,XV,PD,WV,PD,aW,QD,VV,UV,TV,ph,OD,Nc,Hb,PV,ev,OV,jk,MV,KD,LV,ik,KD,Nq,KV,Mq,cv,lV,IV,zV,yV,Nh,Ei,gV,fV,Eq,gD,eV,O8,P8,QM,M8,N8,Jx,qs,Ob,Q8,Md,cD,bV,aV,OC,_U,ZU,OC,VU,Gu,UU,e8,Ze,afa,z9,$U,mq,Je,dU,y9,Tha,o8,d8,KU,gC,JU,IU,fC,HU,eg,GU,FU,tc,EU,DU,fg,Vg,CU,$n,BU,dC,AU,wU,QB,vU,uU,tU,uu,mO,uC,Xw,sU,rU,qU,pU,oU,wu,mU,GB,vd,wj,jU,iU,lu,FB,hU,gU,fU,EB,eU,DB,vu,kl,Bu,_T,iq,ZT,Db,Cf,af,YT,du,XT,Xc,hq,WT,VT,UT,TT,sB,ed,ST,hm,RT,QT,PT,oB,nB,Ei,af,OT,NT,kaa,MT,Wg,LT,jia,ak,lia,_D,kia,Qr,Kh,Bf,gia,fia,eia,uT,bia,ak,kj,aia,$ha,aq,_ha,dB,Yha,Xha,Wha,Vha,Uha,kl,cT,$S,Qha,Nha,Wm,Lha,mf,yT,Mha,uu,WS,Kha,Jha,VA,Iha,cv,Hha,Gha,SS,eda,Fha,kl,Cha,iq,Vn,Bha,Aha,sB,zha,yha,xha,wha,vha,nm,uha,tha,sha,qha,ak,RA,rha,Kh,Bf,cB,lha,iha,oh,dha,cha,$ga,_ga,Zga,Yga,Xga,Wga,$p,Vga,Uga,Tga,DA,WU,Sga,Rga,af,Qga,Pga,Oga,TU,Nga,Mga,Lga,Kga,pS,oS,Jga,Iga,af,Hga,Gga,tT,Fga,eha,Ega,fha,Dga,Cga,Bga,AA,AA,AA,zA,Aga,zga,mS,jS,yga,j_,xga,wga,vga,uga,tga,sga,rga,hS,fd,Tn,ega,qA,qga,R7,Q7,P7,O7,N7,M7,pga,oga,Kf,nga,mga,lga,kga,Xq,jaa,haa,a8,m8,n8,jga,iga,hga,Z8,K7,mn,faa,eaa,daa,caa,$fa,_fa,Zfa,Yfa,Xfa,Wfa,Vfa,Ufa,Tfa,Sfa,Rfa,Qfa,Ofa,Lfa,Kfa,Nfa,BR,Bf,uR,hA,Hfa,gA,Ffa,Efa,Dfa,Cfa,tR,fA,Bfa,Gu,fC,Afa,rR,qR,yq,eA,zfa,ze,yfa,Xq,$p,su,$p,xfa,tq,af,uT,$p,paa,Wm,ufa,tfa,sfa,rfa,Yz,vt,qfa,pfa,ofa,nfa,mfa,lfa,kfa,hC,jfa,ifa,gfa,ffa,efa,dfa,cfa,bfa,xA,_ea,Zea,Yea,Xea,af,lS,kS,GA,Wea,Vea,lu,cv,Uea,Tea,Sea,R9,ph,Rea,Vt,_t,pg,x9,V9,Ms,aN,w9,v9,EM,Is,zM,u9,pM,MN,s9,Ry,cj,Mh,Iea,Hea,st,Pea,Dt,Dea,zB,Cea,Bea,BQ,Tn,Aea,zea,yea,xea,wea,AQ,vea,uea,tea,rt,sea,Ez,nea,Cz,mea,lea,kea,ak,Kh,Bf,Mh,hea,gea,fea,eea,gA,bea,aea,rt,$da,$n,p8,Yda,Xda,kj,oQ,Cz,vu,Wda,Vda,Uda,Tda,pt,Sda,pt,Rda,Qq,XU,Oda,ak,Pda,Qda,yz,aQ,Kh,Bf,st,Lda,Ida,hA,Hda,Eda,Dda,OP,AQ,DA,Cda,lu,af,tda,sda,EB,rda,qda,pda,oda,sP,nda,hm,kda,jda,ida,hda,gda,fda,Vl,iP,dda,cda,bda,ada,$ca,_ca,Zca,Yca,Xca,Wca,Vca,Uca,Tca,gA,Sca,Rca,Qca,Dt,Pca,Nca,Mca,iq,I9,ev,Cca,Q9,P9,iq,O9,Mh,ev,N9,M9,K9,Lca,WO,Ica,Hca,Gca,Fca,Eca,Dca,vq,zca,yca,xca,wca,vca,uca,tca,sca,rca,qca,pca,oca,jW,bE,nca,af,mca,lca,yi,S9,raa,qB,_N,naa,laa,iaa,gaa,Us,baa,NN,$9,_9,FN,Z9,Y9,X9,vN,tN,An,qN,U9,T9,Wn,F9,kj,RM,Rq,L8,K8,J8,r9,YU,I8,Vu,Rq,GB,H8,RM,D9,G8,J9,ak,Kh,Bf,G9,ak,Kh,Bf,E9,ak,Kh,Bf,OD,Qr,ph,p9,o9,n9,m9,l9,k9,oaa,jca,xO,j9,pc,h9,h8,g9,SV,kV,dV,iV,e9,d9,cV,jV,RV,hV,mL,c9,b9,a9,lL,Yx,$8,_8,aaa,Y8,X8,W8,V8,pK,_7,Vq,ZD,aE,Jx,S8,mn,DL,$t,pq,B9,C9,D8,C8,kj,B8,Cz,A8,z8,y8,st,x8,Mh,w8,v8,u8,t8,s8,ak,Kh,Bf,E8,l8,k8,j8,i8,wh,Cl,g8,f8,c8,Y7,X7,W7,V7,U7,nK,$7,Wo,kK,qk,wh,Kf,S7,Te,L7,T7,Z7,H7,G7,V6,F7,Ij,$J,_f,iK,n7,W6,xl,P6,ch,O6,N6,M6,Jx,Us,K6,Vx,MJ,o6,e6,Z5,S5,I5,z5,B5,n5,g5,aJ,as,a5,$4,Q0,S0,S4,R4,P4,jv,T8,U0,M4,aJ,L4,J4,D1,x0,r1,H1,WI,Zw,H4,X1,Uw,W1,zI,F4,R8,C4,I7,D4,E7,z4,y1,Q1,x4,A1,VI,Xq,UI,TI,SI,m4,k4,WI,Zw,h4,g4,f4,e4,d4,c4,b4,a4,$3,_3,Z3,Y3,X3,W3,V3,U3,T3,S3,R3,Q3,P3,O3,N3,M3,J3,H3,F3,zD,q0,J1,D3,p3,w1,n3,l3,Hk,r0,s0,j3,w0,b3,$2,b8,Y2,Zw,S2,P2,M2,fn,IH,K2,I2,G2,E2,C2,A2,y2,w2,u2,r2,p2,n2,LI,h2,f2,gL,tt,KI,c2,b2,$1,_1,Z1,Y1,Uo,A9,Sq,kM,Sk,tN,O1,N1,L1,Tk,BM,G1,i9,C1,WH,Op,z1,v1,$n,kl,kl,s1,f9,F1,P1,K1,nv,ca,T0,GI,FI,R0,VH,P0,O0,E0,v0,u0,t0,p0,aL,kca,LH,O$,N$,M$,L$,G$,F$,XF,$v,gX,t$,s$,r$,q$,p$,o$,n$,bf,YW,fX,Y_,WF,T_,bw,Xv,E_,D_,Sv,th,sh,jr,xb,Rv,Eo,Cj,Ak,Qv,vl,u_,t_,Li,Eg,iF,Ki,fw,Nv,th,sh,hr,ur,wk,l$,hl,Sm,Li,Eg,eF,Ki,_Z,VZ,aG,QZ,pr,km,LZ,Lm,gf,tZ,mr,sZ,rZ,qZ,SE,oZ,mZ,lZ,xk,kZ,SE,iZ,hZ,fZ,eZ,bZ,aZ,YY,XY,WY,VY,UY,TY,SY,RY,QY,PY,OY,NY,MY,LY,KY,JY,IY,HY,GY,FY,EY,DY,CY,BY,AY,zY,yY,xY,wY,vY,uY,tY,sY,qY,oY,mY,Bv,gY,eY,cY,hX,Oca,vv,av,sq,ica,hca,gca,fca,eca,dca,cca,bca,aca,$ba,_ba,Zba,Yba,Wba,Vba,Uba,Tba,Sba,Rba,Qba,Pba,Oba,Nba,Mba,Lba,Kba,Jba,Iba,Hba,Gba,Fba,Eba,Dba,Bba,Aba,zba,yba,xba,wba,vba,uba,tba,sba,rba,qba,pba,oba,nba,mba,lba,kba,jba,iba,hba,gba,fba,eba,dba,cba,bba,aba,$aa,_aa,Zaa,Yaa,Xaa,Waa,Vaa,Uaa,Taa,Saa,Raa,Qaa,Paa,Oaa,Naa,Maa,Laa,Kaa,Jaa,Iaa,Haa,Gaa,Faa,Eaa,Daa,Caa,Baa,Aaa,zaa,yaa,xaa,waa,vaa,uaa,taa,av,Bca,Aca,bha,aha,Gda,Fda,zda,yda,Jfa,Ifa,rea,qea,bga,aga,aU,$T,pha,oha,zU,xU,lU,kU,jea,iea,Kda,Jda,Kca,Jca,dia,cia,Sha,Rha,PU,OU,MU,LU,_da,Zda,Nda,Mda,Fea,Eea,cga,KR,kha,jha,hha,gha,iia,hia,Eha,Dha,dea,cea,F8,r8,q8,Kea,Jea,mda,lda,pea,oea,nha,mha,Bda,Ada,vda,uda,Pha,Oha,xda,wda,Qea,Mea,Lea,SU,RU,cU,bU,wfa,vfa,Oea,Nea,uo,sq,sD,mV,mo,YM,Dc,bf,Dc,fc,re,re,fc,fc,nV,CV,BV,tD,oV,mo,Dc,uD,xV,wV,vV,uV,tV,sV,rV,qV,pV,To,ox,nx,ZJ,fc,gf,fc,fc,fc,se,ms,D7,C7,B7,A7,z7,$h,Ht,Ht,lx,XJ,lx,lx,x7,gf,KR,w7,v7,u7,t7,s7,_h,WJ,S6,fc,fc,re,kx,pe,pe,re,q7,p7,se,gf,se,gf,jx,m7,l7,k7,fc,gf,fc,fc,fc,se,i7,VJ,h7,g7,f7,e7,$h,d7,c7,b7,a7,$6,_6,Z6,Y6,X6,_h,SJ,fc,fc,re,pe,pe,re,UJ,TJ,ff,zg,VW,U6,mx,T6,fc,Q6,XJ,A6,p6,f6,_5,T5,J5,A5,o5,h5,K5,J7,o7,L6,To,ox,nx,ZJ,fc,gf,fc,fc,fc,se,OJ,I6,H6,G6,F6,E6,$h,D6,_h,NJ,fc,fc,re,pe,pe,re,C6,B6,ex,n6,m6,l6,fc,gf,fc,fc,fc,se,k6,j6,i6,h6,$h,g6,_h,CJ,fc,fc,re,pe,pe,ds,cs,d6,fc,gf,fc,fc,fc,se,AJ,c6,b6,a6,$h,$5,_h,yJ,fc,fc,re,pe,pe,To,ox,nx,Y5,fc,gf,fc,fc,fc,se,AJ,X5,W5,V5,$h,U5,_h,uJ,fc,fc,re,pe,pe,gs,R5,Q5,P5,fc,gf,fc,fc,fc,se,LJ,O5,w6,v6,$h,u6,_h,t6,fc,fc,re,pe,pe,se,gf,JJ,N5,M5,IJ,L5,HJ,GJ,z6,fs,y6,LJ,x6,JJ,s6,r6,IJ,q6,HJ,GJ,ds,cs,H5,fc,gf,fc,fc,fc,se,pe,G5,F5,E5,$h,D5,_h,C5,fc,fc,re,pe,pe,bx,y5,x5,w5,fc,gf,fc,fc,v5,se,u5,t5,s5,r5,$h,q5,_h,ax,fc,fc,re,pe,pe,se,gf,ds,cs,m5,fc,gf,fc,fc,fc,se,OJ,l5,k5,j5,$h,i5,_h,mJ,fc,fc,re,pe,pe,ds,cs,f5,fc,gf,fc,fc,fc,se,ms,e5,d5,c5,$h,b5,_h,jJ,fc,fc,re,pe,pe,Tw,U1,T1,JI,R1,JI,S1,zg,Tr,q1,M1,bf,Dc,iS,Ht,zg,bf,zg,bf,Dc,p1,o1,zg,pI,oI,pI,oI,se,Ur,se,Ur,sI,rI,sI,rI,Dc,t1,bf,Dc,n1,l1,Dc,iI,hI,zg,i1,fI,h1,fI,k1,gI,j1,gI,Dc,g1,e1,Dc,eI,dI,Nr,Nr,Nr,Nr,d1,Mw,Mw,Mw,Dc,c1,b1,Dc,bI,aI,Z0,_H,Y0,_H,$0,$H,_0,$H,Dc,X0,W0,Dc,YH,XH,Lr,Lr,Lr,Lr,V0,Kw,Kw,Kw,MH,y0,mo,Dc,NH,D0,re,re,C0,B0,sq,A0,z0,zg,zg,PH,F0,mo,Dc,UH,N0,re,fc,re,M0,L0,K0,J0,I0,H0,G0,zg,BD,AV,mo,Dc,Dc,GV,re,re,sq,CD,FV,EV,DV,se,Ur,se,Ur,Jr,Fw,o0,n0,BH,AH,zH,yH,xH,wH,vH,uH,tH,sH,rH,qH,pH,oH,nH,mH,lH,kH,jH,iH,hH,gH,m0,l0,k0,j0,i0,h0,g0,f0,e0,d0,c0,b0,a0,$$,_$,Z$,Y$,X$,W$,V$,U$,T$,S$,R$,Q$,P$,bf,zg,bf,zg,bf,zg,K$,J$,I$,Fl,B$,se,tG,sG,rG,fc,fc,A$,qG,z$,wr,y$,wr,Fo,x$,se,tG,sG,rG,fc,fc,w$,qG,v$,wr,u$,wr,es,e$,f$,d$,i$,h$,g$,Ro,ZF,c$,b$,tr,ew,dG,cG,ef,YF,a$,$_,vr,hw,nG,lG,bf,Dc,__,eX,dX,cX,Z_,X_,C$,fc,U_,OF,I_,H_,G_,F_,Jk,uG,jw,V_,QF,M_,L_,K_,J_,vr,hw,nG,lG,Jk,uG,OF,P_,PF,O_,N_,QF,S_,PF,R_,Q_,tr,ew,dG,cG,tE,jX,fs,uE,rX,qX,pX,oX,nX,vE,mX,lX,kX,AE,KX,JX,IX,HX,GX,fc,FX,EX,BE,VX,UX,TX,IH,SX,RX,CE,ZX,CD,nU,YX,XX,WX,bf,Dc,Dc,CX,BX,AX,zX,yX,xX,wX,vX,vE,uX,tX,sX,Dc,wE,wE,zv,re,re,DX,re,Dc,NX,MX,zv,fc,fc,LX,ms,Dc,QX,PX,zv,fc,fc,OX,ms,bf,Dc,C_,B_,A_,bf,Dc,z_,y_,x_,Dc,w_,s_,r_,q_,mF,mF,p_,o_,n_,m_,l_,Dc,k_,i_,h_,g_,dF,dF,f_,e_,d_,c_,b_,Dc,a_,$Z,ZZ,YZ,XZ,WZ,UZ,TZ,Dc,SZ,RZ,PZ,OZ,NZ,MZ,KZ,JZ,bf,Dc,pe,IZ,HZ,GZ,FZ,EZ,DZ,hY,fY,dY,bY,aY,$X,_X,bf,Dc,pe,CZ,BZ,AZ,zZ,yZ,xZ,rY,pY,nY,lY,kY,jY,iY,Cv,DE,wZ,Cv,DE,vZ,Dc,fr,fr,rh,rh,rh,UE,fc,pk,pk,Dc,fr,fr,rh,rh,rh,UE,fc,pk,pk,Dc,er,er,rh,rh,rh,TE,fc,pk,pk,Dc,er,er,rh,rh,rh,TE,fc,pk,pk,Dc,uZ,pZ,Dc,nZ,jZ,Dc,gZ,dZ,Dc,cZ,$Y,Dc,JE,_Y,se,Dc,JE,ZY,se,bf,zg,Dc,bX,aX,Dc,$W,ZW,_W,XW,zg,Dc,WW,ya,bf,Dc,gf,gf,UW,MW,OW,PW,Dc,HW,GW,FW,uo,uo,uo,uo,av,Dc,EW,Dc,LW,NW,QW,Dc,TW,SW,RW,Dc,IW]);function fb(){return s.byteLength/65536|0}function kb(lb){lb=lb|0;var gb=fb()|0;var hb=gb+lb|0;if(gb<hb&&hb<65536){var ib=new ArrayBuffer(B(hb,65536));var jb=new Int8Array(ib);jb.set(t);t=new Int8Array(ib);u=new Int16Array(ib);v=new Int32Array(ib);w=new Uint8Array(ib);x=new Uint16Array(ib);y=new Uint32Array(ib);z=new Float32Array(ib);A=new Float64Array(ib);s=ib;r.buffer=s;e=w}return gb}return{"pa":KT,"qa":U4,"ra":V4,"sa":Dc,"ta":xb,"ua":T4,"va":Q4,"wa":O4,"xa":as,"ya":se,"za":X4,"Aa":W4,"Ba":_4,"Ca":Ht,"Da":Y4,"Ea":YM,"Fa":Z4,"Ga":bf,"Ha":cJ,"Ia":bJ,"Ja":cJ,"Ka":a2,"La":DW,"Ma":CW,"Na":BW,"Oa":N4,"Pa":YI,"Qa":K4,"Ra":XI,"Sa":s4,"Ta":k2,"Ua":l2,"Va":q4,"Wa":p4,"Xa":o4,"Ya":r4,"Za":m2,"_a":O2,"$a":d2,"ab":R2,"bb":q3,"cb":g2,"db":U2,"eb":i2,"fb":T2,"gb":e2,"hb":s2,"ib":o2,"jb":q2,"kb":H2,"lb":D2,"mb":F2,"nb":v2,"ob":x2,"pb":z2,"qb":B2,"rb":k3,"sb":m3,"tb":x3,"ub":s3,"vb":r3,"wb":w3,"xb":v3,"yb":t3,"zb":u3,"Ab":B3,"Bb":C3,"Cb":y3,"Db":A3,"Eb":z3,"Fb":c3,"Gb":i3,"Hb":g3,"Ib":e3,"Jb":h3,"Kb":d3,"Lb":N2,"Mb":G3,"Nb":a3,"Ob":Z2,"Pb":o3,"Qb":Q2,"Rb":_2,"Sb":W2,"Tb":V2,"Ub":I3,"Vb":J2,"Wb":K3,"Xb":L2,"Yb":E3,"Zb":I4,"_b":G4,"$b":AW,"ac":E4,"bc":A4,"cc":y4,"dc":w4,"ec":zW,"fc":v4,"gc":u4,"hc":n4,"ic":l4,"jc":j4,"kc":L3,"lc":i4,"mc":yd,"nc":H$,"oc":eb,"pc":q9,"qc":qaa,"rc":W9,"sc":KW,"tc":JW,"uc":yW,"vc":xW,"wc":wW,"xc":vW,"yc":uW,"zc":tW,"Ac":tW}}return mb(ob)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


